@@ -1,8 +1,8 @@
 # --
 # Kernel/Config/Defaults.pm - Default Config file for OTRS kernel
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Defaults.pm,v 1.377.2.6 2011/08/15 14:13:30 mb Exp $
+# $Id: Defaults.pm,v 1.405.2.8 2012/06/01 18:57:21 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -29,7 +29,7 @@ use warnings;
 use 5.008_006;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.377.2.6 $) [1];
+$VERSION = qw($Revision: 1.405.2.8 $) [1];
 
 # prepend '../Custom', '../Kernel/cpan-lib' and '../' to the module search path @INC
 use File::Basename;
@@ -129,7 +129,7 @@ sub LoadDefaults {
 #    $ENV{NLS_LANG} = "german_germany.we8iso8859p15";
 #    $ENV{NLS_LANG} = "american_america.we8iso8859p1";
 
-    # If you want to use an init sql after connect, use this hier.
+    # If you want to use an init sql after connect, use this here.
     # (e. g. can be used for mysql encoding between client and server)
     #    $Self->{'Database::Connect'} = 'SET NAMES utf8';
 
@@ -144,14 +144,10 @@ sub LoadDefaults {
     # default valid
     $Self->{DefaultValid} = 'valid';
 
-    # default charset
-    # (default frontend charset - "utf-8" is a multi charset for all possible
-    # charsets - e. g. "iso-8859-1" is also possible for single charset)
-    # [default: utf-8]
+    # DEPRECATED. Compatibilty setting for older 3.0 code.
+    # Internal charset must always be utf-8.
     $Self->{DefaultCharset} = 'utf-8';
 
-#    $Self->{DefaultCharset} = 'iso-8859-1';
-
     # default language
     # (the default frontend language) [default: en]
     $Self->{DefaultLanguage} = 'en';
@@ -161,7 +157,7 @@ sub LoadDefaults {
     $Self->{DefaultUsedLanguages} = {
         ar_SA   => 'Arabic (Saudi Arabia)',
         bg      => 'Bulgarian (&#x0411;&#x044a;&#x043b;&#x0433;&#x0430;&#x0440;&#x0441;&#x043a;&#x0438;)',
-        ct      => 'Catal&agrave;',
+        ca      => 'Catal&agrave;',
         cs      => 'Czech (&#x010c;esky)',
         da      => 'Dansk',
         de      => 'Deutsch',
@@ -188,6 +184,7 @@ sub LoadDefaults {
         pt      => 'Portugu&ecirc;s',
         pl      => 'Polski',
         ru      => 'Russian (&#x0420;&#x0443;&#x0441;&#x0441;&#x043a;&#x0438;&#x0439;)',
+        sl      => 'Slovenian (Sloven&#x0161;&#x010d;ina)',
         sk_SK   => 'Slovak (Sloven&#x010d;ina)',
         sr_Cyrl => 'Serbian Latin (Srpski)',
         sr_Latn => 'Serbian Cyrillic (&#1089;&#1088;&#1087;&#1089;&#1082;&#1080;)',
@@ -201,7 +198,6 @@ sub LoadDefaults {
 #            th => 'Thai (&#x0e44;&#x0e17;&#x0e22;)',
 #            ro => 'Rom&acirc;n&auml;',
 #            hr => 'Croatian',
-#            sl => 'Slovenian (Sloven&#x0161;&#x010d;ina)',
 #            jp => 'Japanese (&#x65e5;&#x672c;&#x8a9e;)',
     };
 
@@ -344,6 +340,11 @@ sub LoadDefaults {
     # This is the auth. module againt the otrs db
     $Self->{AuthModule} = 'Kernel::System::Auth::DB';
 
+    # defines AuthSyncBackend (AuthSyncModule) for AuthModule
+    # if this key exists and is empty, there won't be a sync.
+    # example values: AuthSyncBackend, AuthSyncBackend2
+#    $Self->{'AuthModule::UseSyncBackend'} = '';
+
     # password crypt type (sha2|sha1|md5|crypt|plain)
 #    $Self->{'AuthModule::DB::CryptType'} = 'md5';
 
@@ -611,14 +612,10 @@ sub LoadDefaults {
     # --------------------------------------------------- #
     # Notification Settings
     # --------------------------------------------------- #
-    # agent interface notification module to check the used charset
-    $Self->{'Frontend::NotifyModule'}->{'1-CharsetCheck'} = {
-        Module => 'Kernel::Output::HTML::NotificationCharsetCheck',
-    };
 
     # agent interface notification module to check the admin user id
     # (don't work with user id 1 notification)
-    $Self->{'Frontend::NotifyModule'}->{'2-UID-Check'} = {
+    $Self->{'Frontend::NotifyModule'}->{'200-UID-Check'} = {
         Module => 'Kernel::Output::HTML::NotificationUIDCheck',
     };
 
@@ -889,18 +886,6 @@ sub LoadDefaults {
       'Core.Print.css'
     ];
 
-    # Agent Common CSS for IE7
-    $Self->{'Loader::Agent::CommonCSS::IE7'}->{'000-Framework'} =  [
-      'Core.Header.IE7.css',
-      'Core.OverviewControl.IE7.css',
-      'Core.OverviewSmall.IE7.css',
-      'Core.OverviewMedium.IE7.css',
-      'Core.OverviewLarge.IE7.css',
-      'Core.PageLayout.IE7.css',
-      'Core.Form.IE7.css',
-      'Core.Widget.IE7.css',
-      'Core.TicketDetail.IE7.css'
-    ];
     # Agent Common CSS for IE8
     $Self->{'Loader::Agent::CommonCSS::IE8'}->{'000-Framework'} =  [
       'Core.OverviewSmall.IE8.css'
@@ -912,24 +897,24 @@ sub LoadDefaults {
 
     # Customer Common JS
     $Self->{'Loader::Customer::CommonJS'}->{'000-Framework'} =  [
-      'thirdparty/jquery-1.4.4/jquery.js',
-      'thirdparty/stacktrace/stacktrace.js',
+      'thirdparty/jquery-1.6.4/jquery.js',
+      'thirdparty/stacktrace-0.3/stacktrace.js',
       'Core.Debug.js',
       'Core.Exception.js',
+      'Core.Config.js',
       'Core.App.js',
       'Core.Customer.js',
       'Core.JavaScriptEnhancements.js',
-      'Core.Config.js',
       'Core.UI.RichTextEditor.js'
     ];
 
     # Agent Common JS
     $Self->{'Loader::Agent::CommonJS'}->{'000-Framework'} =  [
       'thirdparty/json/json2.js',
-      'thirdparty/jquery-1.4.4/jquery.js',
-      'thirdparty/jquery-ui-1.8.7/jquery-ui.js',
-      'thirdparty/jquery-validate-1.7/jquery.validate.js',
-      'thirdparty/stacktrace/stacktrace.js',
+      'thirdparty/jquery-1.6.4/jquery.js',
+      'thirdparty/jquery-ui-1.8.16/jquery-ui.js',
+      'thirdparty/jquery-validate-1.9/jquery.validate.js',
+      'thirdparty/stacktrace-0.3/stacktrace.js',
       'Core.JavaScriptEnhancements.js',
       'Core.Debug.js',
       'Core.Data.js',
@@ -1076,18 +1061,6 @@ sub LoadDefaults {
         Active   => 0,
     };
 
-#    $Self->{PreferencesGroups}->{FreeText} = {
-#        Module  => 'Kernel::Output::HTML::PreferencesGeneric',
-#        Column  => 'Other Options',
-#        Label   => 'Free Text',
-#        Desc    => 'Example for free text.',
-#        Block   => 'Input',
-#        Data    => '$Env{"UserFreeText"}',
-#        PrefKey => 'UserFreeText',
-#        Prio    => 7000,
-#        Active   => 1,
-#    };
-
     $Self->{PreferencesGroups}->{Language} = {
         Module  => 'Kernel::Output::HTML::PreferencesLanguage',
         Column  => 'Frontend',
@@ -1344,13 +1317,18 @@ Your OTRS Notification Master
 #            User => '',
 #            Password => '',
             Table => 'customer_user',
+            # if your frontend is unicode and the charset of your
+            # customer database server is iso-8859-1, use these options.
+#           SourceCharset => 'iso-8859-1',
+#           DestCharset => 'utf-8',
+
             # CaseSensitive will control if the SQL statements need LOWER()
             #   function calls to work case insensitively. Setting this to
             #   1 will improve performance dramatically on large databases.
             CaseSensitive => 0,
         },
 
-        # customer uniq id
+        # customer unique id
         CustomerKey => 'login',
 
         # customer #
@@ -1384,7 +1362,7 @@ Your OTRS Notification Master
         Map => [
 
             # note: Login, Email and CustomerID needed!
-            # var, frontend, storage, shown (1=always,2=lite), required, storage-type, http-link, readonly, http-link-target
+            # var, frontend, storage, shown (1=always,2=lite), required, storage-type, http-link, readonly, http-link-target, link class(es)
             [ 'UserTitle',      'Title',      'title',      1, 0, 'var', '', 0 ],
             [ 'UserFirstname',  'Firstname',  'first_name', 1, 1, 'var', '', 0 ],
             [ 'UserLastname',   'Lastname',   'last_name',  1, 1, 'var', '', 0 ],
@@ -1392,7 +1370,7 @@ Your OTRS Notification Master
             [ 'UserPassword',   'Password',   'pw',         0, 0, 'var', '', 0 ],
             [ 'UserEmail',      'Email',      'email',      1, 1, 'var', '', 0 ],
 
-#            [ 'UserEmail',      'Email', 'email',           1, 1, 'var', '$Env{"CGIHandle"}?Action=AgentTicketCompose&ResponseID=1&TicketID=$Data{"TicketID"}&ArticleID=$Data{"ArticleID"}', 0 ],
+#            [ 'UserEmail',      'Email', 'email',           1, 1, 'var', '$Env{"CGIHandle"}?Action=AgentTicketCompose;ResponseID=1;TicketID=$Data{"TicketID"};ArticleID=$Data{"ArticleID"}', 0, '', 'AsPopup OTRSPopup_TicketAction' ],
             [ 'UserCustomerID', 'CustomerID', 'customer_id', 0, 1, 'var', '', 0 ],
 
 #            [ 'UserCustomerIDs', 'CustomerIDs', 'customer_ids', 1, 0, 'var', '', 0 ],
@@ -1439,10 +1417,10 @@ Your OTRS Notification Master
 #            # if both your frontend and your LDAP are unicode, use this:
 #            SourceCharset => 'utf-8',
 #            DestCharset   => 'utf-8',
-#            # if your frontend is e. g. iso-8859-1 and the charset of your
-#            # ldap server is utf-8, use these options.
-#            SourceCharset => 'utf-8',
-#            DestCharset => 'iso-8859-1',
+#            # if your frontend is unicode and the charset of your
+#            # ldap server is iso-8859-1, use these options.
+#            # SourceCharset => 'iso-8859-1',
+#            # DestCharset => 'utf-8',
 #            # die if backend can't work, e. g. can't connect to server
 #            Die => 0,
 #            # Net::LDAP new params (if needed - for more info see perldoc Net::LDAP)
@@ -1453,7 +1431,7 @@ Your OTRS Notification Master
 #                version => 3,
 #            },
 #        },
-#        # customer uniq id
+#        # customer unique id
 #        CustomerKey => 'uid',
 #        # customer #
 #        CustomerID => 'mail',
@@ -1497,9 +1475,10 @@ Your OTRS Notification Master
 #            User => '',
 #            Password => '',
             Table => 'customer_company',
+#            ForeignDB => 0,    # set this to 1 if your table does not have create_time, create_by, change_time and change_by fields
         },
 
-        # customer uniq id
+        # company unique id
         CustomerCompanyKey          => 'customer_id',
         CustomerCompanyValid        => 'valid_id',
         CustomerCompanyListFields   => [ 'customer_id', 'name' ],
@@ -1520,254 +1499,6 @@ Your OTRS Notification Master
             [ 'CustomerCompanyComment', 'Comment', 'comments', 1, 0, 'var', '', 0 ],
             [ 'ValidID',                'Valid',   'valid_id', 0, 1, 'int', '', 0 ],
         ],
-
-        # default selections
-        Selections => {
-            CustomerCompanyCountry => {
-                '-'                              => '-',
-                'Afghanistan'                    => 'Afghanistan',
-                'Albania'                        => 'Albania',
-                'Algeria'                        => 'Algeria',
-                'American Samoa'                 => 'American Samoa',
-                'Andorra'                        => 'Andorra',
-                'Angola'                         => 'Angola',
-                'Anguilla'                       => 'Anguilla',
-                'Antarctica'                     => 'Antarctica',
-                'Antigua and Barbuda'            => 'Antigua and Barbuda',
-                'Argentina'                      => 'Argentina',
-                'Armenia'                        => 'Armenia',
-                'Aruba'                          => 'Aruba',
-                'Australia'                      => 'Australia',
-                'Austria'                        => 'Austria',
-                'Azerbaijan'                     => 'Azerbaijan',
-                'Bahamas'                        => 'Bahamas',
-                'Bahrain'                        => 'Bahrain',
-                'Bangladesh'                     => 'Bangladesh',
-                'Barbados'                       => 'Barbados',
-                'Belarus'                        => 'Belarus',
-                'Belgium'                        => 'Belgium',
-                'Belize'                         => 'Belize',
-                'Benin'                          => 'Benin',
-                'Bermuda'                        => 'Bermuda',
-                'Bhutan'                         => 'Bhutan',
-                'Bolivia'                        => 'Bolivia',
-                'Bosnia and Herzegowina'         => 'Bosnia and Herzegowina',
-                'Botswana'                       => 'Botswana',
-                'Bouvet Island'                  => 'Bouvet Island',
-                'Brazil'                         => 'Brazil',
-                'British Indian Ocean Territory' => 'British Indian Ocean Territory',
-                'Brunei Darussalam'              => 'Brunei Darussalam',
-                'Bulgaria'                       => 'Bulgaria',
-                'Burkina Faso'                   => 'Burkina Faso',
-                'Burundi'                        => 'Burundi',
-                'Cambodia'                       => 'Cambodia',
-                'Cameroon'                       => 'Cameroon',
-                'Canada'                         => 'Canada',
-                'Cape Verde'                     => 'Cape Verde',
-                'Cayman Islands'                 => 'Cayman Islands',
-                'Central African Republic'       => 'Central African Republic',
-                'Chad'                           => 'Chad',
-                'Chile'                          => 'Chile',
-                'China'                          => 'China',
-                'Christmas Island'               => 'Christmas Island',
-                'Cocos (Keeling) Islands'        => 'Cocos (Keeling) Islands',
-                'Colombia'                       => 'Colombia',
-                'Comoros'                        => 'Comoros',
-                'Congo, Democratic Republic of'  => 'Congo, Democratic Republic of',
-                'Congo, Republic of'             => 'Congo, Republic of',
-                'Cook Islands'                   => 'Cook Islands',
-                'Costa Rica'                     => 'Costa Rica',
-                'Cote d\'Ivoire'                 => 'Cote d\'Ivoire',
-                'Croatia'                        => 'Croatia',
-                'Cuba'                           => 'Cuba',
-                'Cyprus'                         => 'Cyprus',
-                'Czech Republic'                 => 'Czech Republic',
-                'Denmark'                        => 'Denmark',
-                'Djibouti'                       => 'Djibouti',
-                'Dominica'                       => 'Dominica',
-                'Dominican Republic'             => 'Dominican Republic',
-                'Ecuador'                        => 'Ecuador',
-                'Egypt'                          => 'Egypt',
-                'El Salvador'                    => 'El Salvador',
-                'Equatorial Guinea'              => 'Equatorial Guinea',
-                'Eritrea'                        => 'Eritrea',
-                'Estonia'                        => 'Estonia',
-                'Ethiopia'                       => 'Ethiopia',
-                'Falkland Islands (Malvinas)'    => 'Falkland Islands (Malvinas)',
-                'Faroe Islands'                  => 'Faroe Islands',
-                'Fiji'                           => 'Fiji',
-                'Finland'                        => 'Finland',
-                'France'                         => 'France',
-                'French Guiana'                  => 'French Guiana',
-                'French Polynesia'               => 'French Polynesia',
-                'French Southern Territories'    => 'French Southern Territories',
-                'Gabon'                          => 'Gabon',
-                'Gambia'                         => 'Gambia',
-                'Georgia'                        => 'Georgia',
-                'Germany'                        => 'Germany',
-                'Ghana'                          => 'Ghana',
-                'Gibraltar'                      => 'Gibraltar',
-                'Greece'                         => 'Greece',
-                'Greenland'                      => 'Greenland',
-                'Grenada'                        => 'Grenada',
-                'Guadeloupe'                     => 'Guadeloupe',
-                'Guam'                           => 'Guam',
-                'Guatemala'                      => 'Guatemala',
-                'Guinea'                         => 'Guinea',
-                'Guinea-bissau'                  => 'Guinea-bissau',
-                'Guyana'                         => 'Guyana',
-                'Haiti'                          => 'Haiti',
-                'Heard and Mc Donald Islands'    => 'Heard and Mc Donald Islands',
-                'Honduras'                       => 'Honduras',
-                'Hong Kong'                      => 'Hong Kong',
-                'Hungary'                        => 'Hungary',
-                'Iceland'                        => 'Iceland',
-                'India'                          => 'India',
-                'Indonesia'                      => 'Indonesia',
-                'Iran (Islamic Republic of)'     => 'Iran (Islamic Republic of)',
-                'Iraq'                           => 'Iraq',
-                'Ireland'                        => 'Ireland',
-                'Israel'                         => 'Israel',
-                'Italy'                          => 'Italy',
-                'Jamaica'                        => 'Jamaica',
-                'Japan'                          => 'Japan',
-                'Jordan'                         => 'Jordan',
-                'Kazakhstan'                     => 'Kazakhstan',
-                'Kenya'                          => 'Kenya',
-                'Kiribati'                       => 'Kiribati',
-                'Korea, Democratic People\'s Republic of' =>
-                    'Korea, Democratic People\'s Republic of',
-                'Korea, Republic of'                => 'Korea, Republic of',
-                'Kuwait'                            => 'Kuwait',
-                'Kyrgyzstan'                        => 'Kyrgyzstan',
-                'Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
-                'Latvia'                            => 'Latvia',
-                'Lebanon'                           => 'Lebanon',
-                'Lesotho'                           => 'Lesotho',
-                'Liberia'                           => 'Liberia',
-                'Libyan Arab Jamahiriya'            => 'Libyan Arab Jamahiriya',
-                'Liechtenstein'                     => 'Liechtenstein',
-                'Lithuania'                         => 'Lithuania',
-                'Luxembourg'                        => 'Luxembourg',
-                'Macau'                             => 'Macau',
-                'Macedonia, the Former Yugoslav Republic of' =>
-                    'Macedonia, the Former Yugoslav Republic of',
-                'Madagascar'                       => 'Madagascar',
-                'Malawi'                           => 'Malawi',
-                'Malaysia'                         => 'Malaysia',
-                'Maldives'                         => 'Maldives',
-                'Mali'                             => 'Mali',
-                'Malta'                            => 'Malta',
-                'Marshall Islands'                 => 'Marshall Islands',
-                'Martinique'                       => 'Martinique',
-                'Mauritania'                       => 'Mauritania',
-                'Mauritius'                        => 'Mauritius',
-                'Mayotte'                          => 'Mayotte',
-                'Mexico'                           => 'Mexico',
-                'Micronesia, Federated States of'  => 'Micronesia, Federated States of',
-                'Moldova, Republic of'             => 'Moldova, Republic of',
-                'Monaco'                           => 'Monaco',
-                'Mongolia'                         => 'Mongolia',
-                'Montserrat'                       => 'Montserrat',
-                'Morocco'                          => 'Morocco',
-                'Mozambique'                       => 'Mozambique',
-                'Myanmar'                          => 'Myanmar',
-                'Namibia'                          => 'Namibia',
-                'Nauru'                            => 'Nauru',
-                'Nepal'                            => 'Nepal',
-                'Netherlands'                      => 'Netherlands',
-                'Netherlands Antilles'             => 'Netherlands Antilles',
-                'New Caledonia'                    => 'New Caledonia',
-                'New Zealand'                      => 'New Zealand',
-                'Nicaragua'                        => 'Nicaragua',
-                'Niger'                            => 'Niger',
-                'Nigeria'                          => 'Nigeria',
-                'Niue'                             => 'Niue',
-                'Norfolk Island'                   => 'Norfolk Island',
-                'Northern Mariana Islands'         => 'Northern Mariana Islands',
-                'Norway'                           => 'Norway',
-                'Oman'                             => 'Oman',
-                'Pakistan'                         => 'Pakistan',
-                'Palau'                            => 'Palau',
-                'Palestinian Territory, oCCUPIED'  => 'Palestinian Territory, oCCUPIED',
-                'Panama'                           => 'Panama',
-                'Papua New Guinea'                 => 'Papua New Guinea',
-                'Paraguay'                         => 'Paraguay',
-                'Peru'                             => 'Peru',
-                'Philippines'                      => 'Philippines',
-                'Pitcairn'                         => 'Pitcairn',
-                'Poland'                           => 'Poland',
-                'Portugal'                         => 'Portugal',
-                'Puerto Rico'                      => 'Puerto Rico',
-                'Qatar'                            => 'Qatar',
-                'Reunion'                          => 'Reunion',
-                'Romania'                          => 'Romania',
-                'Russian Federation'               => 'Russian Federation',
-                'Rwanda'                           => 'Rwanda',
-                'Saint Helena'                     => 'Saint Helena',
-                'Saint Kitts and Nevis'            => 'Saint Kitts and Nevis',
-                'Saint Lucia'                      => 'Saint Lucia',
-                'Saint Pierre and Miquelon'        => 'Saint Pierre and Miquelon',
-                'Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
-                'Samoa'                            => 'Samoa',
-                'San Marino'                       => 'San Marino',
-                'Sao tome and Principe'            => 'Sao tome and Principe',
-                'Saudi Arabia'                     => 'Saudi Arabia',
-                'Senegal'                          => 'Senegal',
-                'Serbia and Montenegro'            => 'Serbia and Montenegro',
-                'Seychelles'                       => 'Seychelles',
-                'Sierra Leone'                     => 'Sierra Leone',
-                'Singapore'                        => 'Singapore',
-                'Slovakia'                         => 'Slovakia',
-                'Slovenia'                         => 'Slovenia',
-                'Solomon Islands'                  => 'Solomon Islands',
-                'Somalia'                          => 'Somalia',
-                'South Africa'                     => 'South Africa',
-                'South Georgia and the South Sandwich Islands' =>
-                    'South Georgia and the South Sandwich Islands',
-                'Spain'                                => 'Spain',
-                'Sri Lanka'                            => 'Sri Lanka',
-                'Sudan'                                => 'Sudan',
-                'Suriname'                             => 'Suriname',
-                'Svalbard and Jan Mayen Islands'       => 'Svalbard and Jan Mayen Islands',
-                'Swaziland'                            => 'Swaziland',
-                'Sweden'                               => 'Sweden',
-                'Switzerland'                          => 'Switzerland',
-                'Syrian Arab Republic'                 => 'Syrian Arab Republic',
-                'Taiwan'                               => 'Taiwan',
-                'Tajikistan'                           => 'Tajikistan',
-                'Thailand'                             => 'Thailand',
-                'Timor-Leste'                          => 'Timor-Leste',
-                'Togo'                                 => 'Togo',
-                'Tokelau'                              => 'Tokelau',
-                'Tonga'                                => 'Tonga',
-                'Trinidad and Tobago'                  => 'Trinidad and Tobago',
-                'Tunisia'                              => 'Tunisia',
-                'Turkey'                               => 'Turkey',
-                'Turkmenistan'                         => 'Turkmenistan',
-                'Turks and Caicos Islands'             => 'Turks and Caicos Islands',
-                'Tuvalu'                               => 'Tuvalu',
-                'Uganda'                               => 'Uganda',
-                'Ukraine'                              => 'Ukraine',
-                'United Arab Emirates'                 => 'United Arab Emirates',
-                'United Kingdom'                       => 'United Kingdom',
-                'United States'                        => 'United States',
-                'United States Minor outlying Islands' => 'United States Minor outlying Islands',
-                'Uruguay'                              => 'Uruguay',
-                'Uzbekistan'                           => 'Uzbekistan',
-                'Vanuatu'                              => 'Vanuatu',
-                'Vatican City State (Holy See)'        => 'Vatican City State (Holy See)',
-                'Venezuela'                            => 'Venezuela',
-                'Viet nam'                             => 'Viet nam',
-                'Virgin Islands (British)'             => 'Virgin Islands (British)',
-                'Virgin Islands (U.S.)'                => 'Virgin Islands (U.S.)',
-                'Wallis and Futuna Islands'            => 'Wallis and Futuna Islands',
-                'Western Sahara'                       => 'Western Sahara',
-                'Yemen'                                => 'Yemen',
-                'Zambia'                               => 'Zambia',
-                'Zimbabwe'                             => 'Zimbabwe',
-            },
-        },
     };
 
     # --------------------------------------------------- #
@@ -2218,6 +1949,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.377.2.6 $ $Date: 2011/08/15 14:13:30 $
+$Revision: 1.405.2.8 $ $Date: 2012/06/01 18:57:21 $
 
 =cut
