@@ -1,8 +1,8 @@
 # --
 # Kernel/GenericInterface/Transport/HTTP/SOAP.pm - GenericInterface network transport interface for HTTP::SOAP
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: SOAP.pm,v 1.41 2011/07/07 21:53:20 cr Exp $
+# $Id: SOAP.pm,v 1.45.2.3 2012/05/10 11:19:24 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -21,7 +21,7 @@ use Encode;
 use PerlIO;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.41 $) [1];
+$VERSION = qw($Revision: 1.45.2.3 $) [1];
 
 =head1 NAME
 
@@ -236,6 +236,11 @@ sub ProviderProcessRequest {
 
     my $OperationData = $Body->{$Operation};
 
+    # remember if utf8 mode is set for stdin specially for Windows OS, see bug#8466
+    # this information is very important later (in the response) to set the binmode in STDOUT
+    my @IOLayers = PerlIO::get_layers(STDIN);
+    $Self->{LastIOLayerInbound} = $IOLayers[-1];
+
     # all ok - return data
     return {
         Success   => 1,
@@ -257,7 +262,7 @@ The HTTP code is set accordingly
 - 500 for content syntax errors
 
     my $Result = $TransportObject->ProviderGenerateResponse(
-        Success => 1m
+        Success => 1
         Data    => { # data payload for response, optional
             ...
         },
@@ -469,6 +474,53 @@ sub RequesterPerformRequest {
         }
     }
 
+    # add SSL options if configured
+    if ( IsHashRefWithData( $Config->{SSL} ) ) {
+
+        # use SSL options
+        if (
+            IsStringWithData( $Config->{SSL}->{UseSSL} )
+            && $Config->{SSL}->{UseSSL} eq 'Yes'
+            )
+        {
+
+            # force Net::SSL instead of IO::Socket::SSL, otherwise GI can't connect to certificate
+            # authentication restricted servers
+            my $SSLModule = 'Net::SSL';
+            if ( !$Self->{MainObject}->Require($SSLModule) ) {
+                return {
+                    Success      => 0,
+                    ErrorMessage => "The perl module \"$SSLModule\" needed to manage SSL"
+                        . " connections with certificates is missing!",
+                };
+            }
+
+            $ENV{HTTPS_PKCS12_FILE}     = $Config->{SSL}->{SSLP12Certificate};
+            $ENV{HTTPS_PKCS12_PASSWORD} = $Config->{SSL}->{SSLP12Password};
+
+            # add certificate authority
+            if ( IsStringWithData( $Config->{SSL}->{SSLCAFile} ) ) {
+                $ENV{HTTPS_CA_FILE} = $Config->{SSL}->{SSLCAFile};
+            }
+            if ( IsStringWithData( $Config->{SSL}->{SSLCADir} ) ) {
+                $ENV{HTTPS_CA_DIR} = $Config->{SSL}->{SSLCADir};
+            }
+
+            # add proxy
+            if ( IsStringWithData( $Config->{SSL}->{SSLProxy} ) ) {
+                $ENV{HTTPS_PROXY} = $Config->{SSL}->{SSLProxy};
+            }
+
+            # add proxy basic authentication
+            if ( IsStringWithData( $Config->{SSL}->{SSLProxyUser} ) ) {
+                $ENV{HTTPS_PROXY_USERNAME} = $Config->{SSL}->{SSLProxyUser};
+            }
+            if ( IsStringWithData( $Config->{SSL}->{SSLProxyPassword} ) ) {
+                $ENV{HTTPS_PROXY_PASSWORD} = $Config->{SSL}->{SSLProxyPassword};
+            }
+        }
+    }
+
     # prepare connect
     my $SOAPHandle = eval {
         SOAP::Lite
@@ -755,6 +807,29 @@ sub _Output {
         Data       => $Param{Content},
     );
 
+    # remember if utf8 mode is set for stout
+    # normally Windows OS needs to set the binmode to :raw, see bug#8466
+    my @IOLayers            = PerlIO::get_layers(STDOUT);
+    my $LastIOLayerOutbound = $IOLayers[-1];
+
+    my $LayerReset;
+
+    # set binmode if necessary, check if the last layer for inbound and outbound are different
+    if ( $LastIOLayerOutbound ne $Self->{LastIOLayerInbound} ) {
+
+        # set the binmode for STOUT to :raw to send the response
+        if ( $LastIOLayerOutbound eq 'utf8' ) {
+            $LayerReset = ':utf8';
+            binmode STDOUT, ':raw';
+        }
+
+        # otherwise set it to :utf8 to send the response
+        elsif ( $Self->{LastIOLayerInbound} eq 'utf8' ) {
+            $LayerReset = ':raw';
+            binmode STDOUT, ':utf8';
+        }
+    }
+
     # print data to http - '\r' is required according to HTTP RFCs
     my $StatusMessage = HTTP::Status::status_message( $Param{HTTPCode} );
     print STDOUT "$Protocol $Param{HTTPCode} $StatusMessage\r\n";
@@ -763,6 +838,11 @@ sub _Output {
     print STDOUT "\r\n";
     print STDOUT $Param{Content};
 
+    # reset binmode for stdout
+    if ($LayerReset) {
+        binmode STDOUT, $LayerReset;
+    }
+
     return {
         Success      => $Success,
         ErrorMessage => $ErrorMessage,
@@ -1098,7 +1178,7 @@ It contains functions to quote invalid XML characters and encode the string
 sub _SOAPOutputProcessString {
     my ( $Self, %Param ) = @_;
 
-    return '' if !$Param{Data};
+    return '' if !defined $Param{Data};
 
     # escape characters that are invalid in XML
     $Param{Data} =~ s{ & }{&amp;}xmsg;
@@ -1125,6 +1205,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.41 $ $Date: 2011/07/07 21:53:20 $
+$Revision: 1.45.2.3 $ $Date: 2012/05/10 11:19:24 $
 
 =cut
