@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminAutoResponse.pm - provides admin std response module
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminAutoResponse.pm,v 1.46 2010/11/19 22:28:58 en Exp $
+# $Id: AdminAutoResponse.pm,v 1.49 2012/02/27 22:53:37 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::Valid;
 use Kernel::System::HTMLUtils;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.46 $) [1];
+$VERSION = qw($Revision: 1.49 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -118,7 +118,7 @@ sub Run {
             }
         }
 
-        # someting has gone wrong
+        # something has gone wrong
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
@@ -206,7 +206,7 @@ sub Run {
             }
         }
 
-        # someting has gone wrong
+        # something has gone wrong
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
@@ -223,23 +223,6 @@ sub Run {
         return $Output;
     }
 
-    # ------------------------------------------------------------ #
-    # delete action
-    # ------------------------------------------------------------ #
-    elsif ( $Self->{Subaction} eq 'Delete' ) {
-
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
-
-        my $Delete = $Self->{AutoResponseObject}->AutoResponseDelete(
-            ID => $ID,
-        );
-        if ( !$Delete ) {
-            return $Self->{LayoutObject}->ErrorScreen();
-        }
-
-        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
-    }
-
     # ------------------------------------------------------------
     # overview
     # ------------------------------------------------------------
@@ -297,8 +280,9 @@ sub _Edit {
     $Param{SystemAddressOption} = $Self->{LayoutObject}->BuildSelection(
         Data => { $Self->{SystemAddressObject}->SystemAddressList( Valid => 1 ), },
         Name => 'AddressID',
-        SelectedID => $Param{AddressID},
-        Class => 'Validate_Required ' . ( $Param{Errors}->{'AddressIDInvalid'} || '' ),
+        SelectedID  => $Param{AddressID},
+        Translation => 0,
+        Class       => 'Validate_Required ' . ( $Param{Errors}->{'AddressIDInvalid'} || '' ),
     );
 
     $Self->{LayoutObject}->Block(
