@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminCustomerUserGroup.pm - to add/update/delete groups <-> users
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminCustomerUserGroup.pm,v 1.37 2010/11/10 11:04:28 mg Exp $
+# $Id: AdminCustomerUserGroup.pm,v 1.39 2011/12/21 13:42:54 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::CustomerUser;
 use Kernel::System::CustomerGroup;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.37 $) [1];
+$VERSION = qw($Revision: 1.39 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -170,6 +170,9 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ChangeGroup' ) {
 
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
 
         $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam( Param => 'CustomerUserSearch' )
@@ -215,6 +218,9 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ChangeCustomerUser' ) {
 
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
 
         $Param{CustomerUserSearch} = $Self->{ParamObject}->GetParam( Param => 'CustomerUserSearch' )
@@ -437,7 +443,7 @@ sub _Change {
     DATAITEM:
     for my $ID ( sort { uc( $Data{$a} ) cmp uc( $Data{$b} ) } keys %Data ) {
 
-        next DATAITEM if ( grep /$Param{Data}->{$ID}/, @CustomerAlwaysGroups );
+        next DATAITEM if ( grep /\Q$Param{Data}->{$ID}\E/, @CustomerAlwaysGroups );
 
         # set output class
         $Self->{LayoutObject}->Block(
@@ -574,7 +580,7 @@ sub _Overview {
         keys %GroupData
         )
     {
-        next GROUP if ( grep /$GroupData{$ID}/, @CustomerAlwaysGroups );
+        next GROUP if ( grep /\Q$GroupData{$ID}\E/, @CustomerAlwaysGroups );
 
         # output gorup block
         $Self->{LayoutObject}->Block(
