@@ -2,7 +2,7 @@
 # Kernel/Modules/AdminGenericInterfaceMappingSimple.pm - provides a TransportHTTPSOAP view for admins
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminGenericInterfaceMappingSimple.pm,v 1.19 2012/01/09 09:34:38 mg Exp $
+# $Id: AdminGenericInterfaceMappingSimple.pm,v 1.21 2012/04/20 00:19:42 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.19 $) [1];
+$VERSION = qw($Revision: 1.21 $) [1];
 
 use Kernel::System::VariableCheck qw(:all);
 use Kernel::System::GenericInterface::Webservice;
@@ -36,7 +36,7 @@ sub new {
         }
     }
 
-    # create addtional objects
+    # create additional objects
     $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
     $Self->{WebserviceObject} =
         Kernel::System::GenericInterface::Webservice->new( %{$Self} );
@@ -86,7 +86,7 @@ sub Run {
             ->ErrorScreen( Message => "Need WebserviceID!", );
     }
 
-    # get webserice configuration
+    # get webservice configuration
     my $WebserviceData =
         $Self->{WebserviceObject}->WebserviceGet( ID => $WebserviceID );
 
@@ -620,13 +620,13 @@ sub _GetParams {
         # get params for values
         my $ValueIndex = 0;
         for my $ValueCounter ( 1 .. $GetParam->{ 'ValueCounter' . $KeyIndex } ) {
-            my $Sufix = $KeyCounter . '_' . $ValueCounter;
+            my $Suffix = $KeyCounter . '_' . $ValueCounter;
             next
-                if $Self->{ParamObject}->GetParam( Param => 'ValueName' . $Sufix ) eq
+                if $Self->{ParamObject}->GetParam( Param => 'ValueName' . $Suffix ) eq
                     $Self->{DeletedString};
             $ValueIndex++;
             for my $ValueItem (qw(ValueMapTypeStrg ValueName ValueMapNew)) {
-                my $ValAux = $Self->{ParamObject}->GetParam( Param => $ValueItem . $Sufix ) || '';
+                my $ValAux = $Self->{ParamObject}->GetParam( Param => $ValueItem . $Suffix ) || '';
                 $GetParam->{ $ValueItem . $KeyIndex . '_' . $ValueIndex } = $ValAux;
                 $GetParam->{Error}->{ $ValueItem . $KeyIndex . '_' . $ValueIndex } = 'ServerError'
                     if $ValAux eq '';
