@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminLog.pm - provides a log view for admins
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminLog.pm,v 1.22 2009/02/16 11:20:52 tr Exp $
+# $Id: AdminLog.pm,v 1.23 2010/04/12 21:33:24 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.22 $) [1];
+$VERSION = qw($Revision: 1.23 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -46,30 +46,18 @@ sub Run {
     for (@Lines) {
         my @Row = split( /;;/, $_ );
         if ( $Row[3] ) {
-            if ( $Row[1] =~ /error/ ) {
-                $Self->{LayoutObject}->Block(
-                    Name => 'Row',
-                    Data => {
-                        StartFont => '<font color ="red">',
-                        StopFont  => '</font>',
-                        Time      => $Row[0],
-                        Priority  => $Row[1],
-                        Facility  => $Row[2],
-                        Message   => $Row[3],
-                    },
-                );
-            }
-            else {
-                $Self->{LayoutObject}->Block(
-                    Name => 'Row',
-                    Data => {
-                        Time     => $Row[0],
-                        Priority => $Row[1],
-                        Facility => $Row[2],
-                        Message  => $Row[3],
-                    },
-                );
-            }
+            my $ErrorClass = ( $Row[1] =~ /error/ ) ? 'Error' : '';
+
+            $Self->{LayoutObject}->Block(
+                Name => 'Row',
+                Data => {
+                    ErrorClass => $ErrorClass,
+                    Time       => $Row[0],
+                    Priority   => $Row[1],
+                    Facility   => $Row[2],
+                    Message    => $Row[3],
+                },
+            );
         }
     }
 
