@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminMailAccount.pm - to add/update/delete MailAccount acounts
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminMailAccount.pm,v 1.23 2010/11/19 22:28:58 en Exp $
+# $Id: AdminMailAccount.pm,v 1.28 2012/02/27 22:53:37 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::MailAccount;
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.23 $) [1];
+$VERSION = qw($Revision: 1.28 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -46,7 +46,9 @@ sub Run {
 
     my %GetParam = ();
     my @Params
-        = (qw(ID Login Password Host Type TypeAdd Comment ValidID QueueID Trusted DispatchingBy));
+        = (
+        qw(ID Login Password Host Type TypeAdd Comment ValidID QueueID IMAPFolder Trusted DispatchingBy)
+        );
     for my $Parameter (@Params) {
         $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter );
     }
@@ -55,6 +57,10 @@ sub Run {
     # Run
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Run' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my %Data = $Self->{MailAccount}->MailAccountGet(%GetParam);
         if ( !%Data ) {
             return $Self->{LayoutObject}->ErrorScreen();
@@ -68,18 +74,22 @@ sub Run {
         if ( !$Ok ) {
             return $Self->{LayoutObject}->ErrorScreen();
         }
-        return $Self->{LayoutObject}->Redirect( OP => 'Action=$Env{"Action"};Ok=1' );
+        return $Self->{LayoutObject}->Redirect( OP => 'Action=AdminMailAccount;Ok=1' );
     }
 
     # ------------------------------------------------------------ #
     # delete
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Delete' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Delete = $Self->{MailAccount}->MailAccountDelete(%GetParam);
         if ( !$Delete ) {
             return $Self->{LayoutObject}->ErrorScreen();
         }
-        return $Self->{LayoutObject}->Redirect( OP => 'Action=$Env{"Action"}' );
+        return $Self->{LayoutObject}->Redirect( OP => 'Action=AdminMailAccount' );
     }
 
     # ------------------------------------------------------------ #
@@ -145,7 +155,7 @@ sub Run {
             }
         }
 
-        # someting has gone wrong
+        # something has gone wrong
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
@@ -228,7 +238,7 @@ sub Run {
             }
         }
 
-        # someting has gone wrong
+        # something has gone wrong
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
@@ -430,6 +440,7 @@ sub _MaskAddMailAccount {
         },
         Name       => 'DispatchingBy',
         SelectedID => $Param{DispatchingBy},
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'DispatchingByInvalid'} || '' ),
     );
 
     $Param{QueueOption} = $Self->{LayoutObject}->AgentQueueListOption(
@@ -437,6 +448,7 @@ sub _MaskAddMailAccount {
         Name => 'QueueID',
         SelectedID     => $Param{QueueID},
         OnChangeSubmit => 0,
+        Class          => 'Validate_Required ' . ( $Param{Errors}->{'QueueIDInvalid'} || '' ),
     );
     $Self->{LayoutObject}->Block(
         Name => 'Overview',
