@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminPostMasterFilter.pm - to add/update/delete filters
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminPostMasterFilter.pm,v 1.38 2011/12/23 14:19:00 mg Exp $
+# $Id: AdminPostMasterFilter.pm,v 1.38.2.1 2012/05/11 08:33:02 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,10 +14,11 @@ package Kernel::Modules::AdminPostMasterFilter;
 use strict;
 use warnings;
 
+use Kernel::System::DynamicField;
 use Kernel::System::PostMaster::Filter;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.38 $) [1];
+$VERSION = qw($Revision: 1.38.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -33,7 +34,8 @@ sub new {
         }
     }
 
-    $Self->{PostMasterFilter} = Kernel::System::PostMaster::Filter->new(%Param);
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{PostMasterFilter}   = Kernel::System::PostMaster::Filter->new(%Param);
 
     return $Self;
 }
@@ -243,10 +245,20 @@ sub _MaskUpdate {
     $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
 
     # all headers
-    my %Header = ();
-    for my $ConfigHeader ( @{ $Self->{ConfigObject}->Get('PostmasterX-Header') } ) {
-        $Header{$ConfigHeader} = $ConfigHeader;
+    my @Headers = @{ $Self->{ConfigObject}->Get('PostmasterX-Header') };
+
+    # add Dynamic Field headers
+    my $DynamicFields = $Self->{DynamicFieldObject}->DynamicFieldList(
+        Valid      => 1,
+        ObjectType => [ 'Ticket', 'Article' ],
+        ResultType => 'HASH',
+    );
+    for my $DynamicField ( values %$DynamicFields ) {
+        push @Headers, 'X-OTRS-DynamicField-' . $DynamicField;
+        push @Headers, 'X-OTRS-FollowUp-DynamicField-' . $DynamicField;
     }
+
+    my %Header = map { $_ => $_ } @Headers;
     $Header{''} = '-';
     $Header{Body} = 'Body';
 
