@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminRole.pm - to add/update/delete roles
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminRole.pm,v 1.18 2009/02/17 23:37:11 martin Exp $
+# $Id: AdminRole.pm,v 1.31 2010/11/19 22:28:58 en Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.18 $) [1];
+$VERSION = qw($Revision: 1.31 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -27,9 +27,9 @@ sub new {
     bless( $Self, $Type );
 
     # check all needed objects
-    for (qw(ParamObject DBObject LayoutObject ConfigObject LogObject GroupObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
+    for my $Needed (qw(ParamObject DBObject LayoutObject ConfigObject LogObject GroupObject)) {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
         }
     }
     $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
@@ -56,7 +56,7 @@ sub Run {
             %Data,
         );
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminRoleForm',
+            TemplateFile => 'AdminRole',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -72,39 +72,65 @@ sub Run {
         $Self->{LayoutObject}->ChallengeTokenCheck();
 
         my $Note = '';
-        my %GetParam;
-        for (qw(ID Name Comment ValidID)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ ) || '';
+        my ( %GetParam, %Errors );
+        for my $Parameter (qw(ID Name Comment ValidID)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
-        # update group
-        if ( $Self->{GroupObject}->RoleUpdate( %GetParam, UserID => $Self->{UserID} ) ) {
-            $Self->_Overview();
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Info => 'Role updated!' );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminRoleForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+        # check for needed data
+        if ( !$GetParam{Name} ) {
+            $Errors{NameInvalid} = 'ServerError';
         }
-        else {
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-            $Self->_Edit(
-                Action => "Change",
+
+        # if no errors occurred
+        if ( !%Errors ) {
+
+            # update group
+            my $RoleUpdate = $Self->{GroupObject}->RoleUpdate(
                 %GetParam,
+                UserID => $Self->{UserID}
             );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminRoleForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+
+            if ($RoleUpdate) {
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Role updated!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminRole',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
+            }
+            else {
+                $Note = $Self->{LogObject}->GetLogEntry(
+                    Type => 'Error',
+                    What => 'Message',
+                );
+            }
         }
+
+        # something went wrong
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Note
+            ? $Self->{LayoutObject}->Notify(
+            Priority => 'Error',
+            Info     => $Note,
+            )
+            : '';
+        $Self->_Edit(
+            Action => 'Change',
+            %GetParam,
+            %Errors,
+        );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminRole',
+            Data         => \%Param,
+        );
+        $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
 
     # ------------------------------------------------------------ #
@@ -112,17 +138,15 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Add' ) {
         my %GetParam = ();
-        for (qw(Name)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
-        }
+        $GetParam{Name} = $Self->{ParamObject}->GetParam( Param => 'Name' );
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
-            Action => "Add",
+            Action => 'Add',
             %GetParam,
         );
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminRoleForm',
+            TemplateFile => 'AdminRole',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -138,39 +162,63 @@ sub Run {
         $Self->{LayoutObject}->ChallengeTokenCheck();
 
         my $Note = '';
-        my %GetParam;
-        for (qw(ID Name Comment ValidID)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ ) || '';
+        my ( %GetParam, %Errors );
+        for my $Parameter (qw(ID Name Comment ValidID)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
-        # add role
-        if ( my $RoleID = $Self->{GroupObject}->RoleAdd( %GetParam, UserID => $Self->{UserID} ) ) {
-            $Self->_Overview();
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Info => 'Role added!' );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminRoleForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+        # check for needed data
+        if ( !$GetParam{Name} ) {
+            $Errors{NameInvalid} = 'ServerError';
         }
-        else {
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-            $Self->_Edit(
-                Action => "Add",
+
+        # if no errors occurred
+        if ( !%Errors ) {
+
+            # add role
+            my $RoleID = $Self->{GroupObject}->RoleAdd(
                 %GetParam,
+                UserID => $Self->{UserID}
             );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminRoleForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+
+            if ($RoleID) {
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Role added!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminRole',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
+            }
+            else {
+                $Note = $Self->{LogObject}->GetLogEntry(
+                    Type => 'Error',
+                    What => 'Message',
+                );
+            }
         }
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Note
+            ? $Self->{LayoutObject}->Notify(
+            Priority => 'Error',
+            Info     => $Note,
+            )
+            : '';
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Self->_Edit(
+            Action => 'Add',
+            %GetParam,
+            %Errors,
+        );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminRole',
+            Data         => \%Param,
+        );
+        $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
 
     # ------------------------------------------------------------
@@ -181,7 +229,7 @@ sub Run {
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminRoleForm',
+            TemplateFile => 'AdminRole',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -197,16 +245,33 @@ sub _Edit {
         Name => 'Overview',
         Data => \%Param,
     );
-    $Param{'ValidOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
-        Data       => { $Self->{ValidObject}->ValidList(), },
+
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+
+    # get valid list
+    my %ValidList        = $Self->{ValidObject}->ValidList();
+    my %ValidListReverse = reverse %ValidList;
+
+    $Param{ValidOption} = $Self->{LayoutObject}->BuildSelection(
+        Data       => \%ValidList,
         Name       => 'ValidID',
-        SelectedID => $Param{ValidID},
+        SelectedID => $Param{ValidID} || $ValidListReverse{valid},
     );
 
     $Self->{LayoutObject}->Block(
         Name => 'OverviewUpdate',
         Data => \%Param,
     );
+
+    # shows header
+    if ( $Param{Action} eq 'Change' ) {
+        $Self->{LayoutObject}->Block( Name => 'HeaderEdit' );
+    }
+    else {
+        $Self->{LayoutObject}->Block( Name => 'HeaderAdd' );
+    }
+
     return 1;
 }
 
@@ -219,32 +284,44 @@ sub _Overview {
         Name => 'Overview',
         Data => \%Param,
     );
+
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionAdd' );
+
     $Self->{LayoutObject}->Block(
-        Name => 'OverviewResult',
-        Data => \%Param,
+        Name => 'OverviewHeader',
+        Data => {},
     );
+
     my %List = $Self->{GroupObject}->RoleList( ValidID => 0, );
 
-    # get valid list
-    my %ValidList = $Self->{ValidObject}->ValidList();
-    my $CssClass  = '';
-    for ( sort { $List{$a} cmp $List{$b} } keys %List ) {
-
-        # set output class
-        if ( $CssClass && $CssClass eq 'searchactive' ) {
-            $CssClass = 'searchpassive';
-        }
-        else {
-            $CssClass = 'searchactive';
-        }
-        my %Data = $Self->{GroupObject}->RoleGet( ID => $_, );
+    # if there is data available, it is shown
+    if (%List) {
         $Self->{LayoutObject}->Block(
-            Name => 'OverviewResultRow',
-            Data => {
-                Valid    => $ValidList{ $Data{ValidID} },
-                CssClass => $CssClass,
-                %Data,
-            },
+            Name => 'OverviewResult',
+            Data => \%Param,
+        );
+
+        # get valid list
+        my %ValidList = $Self->{ValidObject}->ValidList();
+        for my $KeyList ( sort { $List{$a} cmp $List{$b} } keys %List ) {
+
+            my %Data = $Self->{GroupObject}->RoleGet( ID => $KeyList );
+            $Self->{LayoutObject}->Block(
+                Name => 'OverviewResultRow',
+                Data => {
+                    Valid => $ValidList{ $Data{ValidID} },
+                    %Data,
+                },
+            );
+        }
+    }
+
+    # otherwise, a message is displayed
+    else {
+        $Self->{LayoutObject}->Block(
+            Name => 'NoRolesDefined',
+            Data => {},
         );
     }
     return 1;
