@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminService.pm - admin frontend to manage services
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminService.pm,v 1.34 2010/11/19 22:28:58 en Exp $
+# $Id: AdminService.pm,v 1.35.2.2 2012/06/05 10:22:51 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::Service;
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.34 $) [1];
+$VERSION = qw($Revision: 1.35.2.2 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -209,39 +209,31 @@ sub Run {
         );
 
         # get service list
-        my %ServiceList = $Self->{ServiceObject}->ServiceList(
+        my $ServiceList = $Self->{ServiceObject}->ServiceListGet(
             Valid  => 0,
             UserID => $Self->{UserID},
         );
 
         # if there are any services defined, they are shown
-        if (%ServiceList) {
+        if ( @{$ServiceList} ) {
 
             # get valid list
             my %ValidList = $Self->{ValidObject}->ValidList();
 
-            # add suffix for correct sorting
-            for ( keys %ServiceList ) {
-                $ServiceList{$_} .= '::';
-            }
-            for my $ServiceID ( sort { $ServiceList{$a} cmp $ServiceList{$b} } keys %ServiceList ) {
+            # sort the service list by long service name
+            @{$ServiceList} = sort { $a->{Name} . '::' cmp $b->{Name} . '::' } @{$ServiceList};
 
-                # get service data
-                my %ServiceData = $Self->{ServiceObject}->ServiceGet(
-                    ServiceID => $ServiceID,
-                    UserID    => $Self->{UserID},
-                );
+            for my $ServiceData ( @{$ServiceList} ) {
 
                 # output row
                 $Self->{LayoutObject}->Block(
                     Name => 'OverviewListRow',
                     Data => {
-                        %ServiceData,
-                        Valid => $ValidList{ $ServiceData{ValidID} },
+                        %{$ServiceData},
+                        Valid => $ValidList{ $ServiceData->{ValidID} },
                     },
                 );
             }
-
         }
 
         # otherwise a no data found msg is displayed
@@ -298,7 +290,6 @@ sub _MaskNew {
         PossibleNone   => 1,
         DisabledBranch => $ServiceData{Name},
         Translation    => 0,
-        Max            => 50,
     );
 
     # get valid list
