@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminSession.pm - to control all session ids
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminSession.pm,v 1.33 2010/06/23 17:31:38 dz Exp $
+# $Id: AdminSession.pm,v 1.34 2011/12/23 14:36:07 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.33 $) [1];
+$VERSION = qw($Revision: 1.34 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -43,6 +43,10 @@ sub Run {
     # kill session id
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Kill' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         $Self->{SessionObject}->RemoveSessionID( SessionID => $WantSessionID );
         return $Self->{LayoutObject}->Redirect( OP => "Action=AdminSession" );
     }
@@ -51,6 +55,10 @@ sub Run {
     # kill all session id
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'KillAll' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my @List = $Self->{SessionObject}->GetAllSessionIDs();
         for my $SessionID (@List) {
 
