@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminState.pm - to add/update/delete state
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminState.pm,v 1.26 2009/02/17 23:37:11 martin Exp $
+# $Id: AdminState.pm,v 1.41 2012/02/27 22:53:37 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::State;
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.26 $) [1];
+$VERSION = qw($Revision: 1.41 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -28,9 +28,9 @@ sub new {
     bless( $Self, $Type );
 
     # check all needed objects
-    for (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
+    for my $Needed (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
         }
     }
     $Self->{StateObject} = Kernel::System::State->new(%Param);
@@ -55,7 +55,7 @@ sub Run {
             %Data,
         );
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminStateForm',
+            TemplateFile => 'AdminState',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -70,58 +70,73 @@ sub Run {
         # challenge token check for write action
         $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my $Note = '';
-        my %GetParam;
-        for (qw(ID Name TypeID Comment ValidID)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ ) || '';
+        my ( %GetParam, %Errors );
+        for my $Parameter (qw(ID Name TypeID Comment ValidID)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
-        # update group
-        if ( $Self->{StateObject}->StateUpdate( %GetParam, UserID => $Self->{UserID} ) ) {
-            $Self->_Overview();
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Info => 'State updated!' );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminStateForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+        # check needed data
+        for my $Needed (qw(Name ValidID TypeID)) {
+            if ( !$GetParam{$Needed} ) {
+                $Errors{ $Needed . 'Invalid' } = 'ServerError';
+            }
         }
-        else {
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-            $Self->_Edit(
-                Action => "Change",
+
+        # if no errors occurred
+        if ( !%Errors ) {
+
+            # update the state data
+            my $UpdateSuccess = $Self->{StateObject}->StateUpdate(
                 %GetParam,
+                UserID => $Self->{UserID},
             );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminStateForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+
+            # update was successful
+            if ($UpdateSuccess) {
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'State updated!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminState',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
+            }
         }
+
+        # something has gone wrong
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
+        $Self->_Edit(
+            Action => 'Change',
+            Errors => \%Errors,
+            %GetParam,
+        );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminState',
+            Data         => \%Param,
+        );
+        $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
 
     # ------------------------------------------------------------ #
     # add
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Add' ) {
-        my %GetParam = ();
-        for (qw(Name)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
-        }
+        my %GetParam;
+        $GetParam{Name} = $Self->{ParamObject}->GetParam( Param => 'Name' );
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
-            Action => "Add",
+            Action => 'Add',
             %GetParam,
         );
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminStateForm',
+            TemplateFile => 'AdminState',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -136,41 +151,55 @@ sub Run {
         # challenge token check for write action
         $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my $Note = '';
-        my %GetParam;
-        for (qw(ID TypeID Name Comment ValidID)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ ) || '';
+        my ( %GetParam, %Errors );
+        for my $Parameter (qw(ID TypeID Name Comment ValidID)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
-        # add state
-        if ( my $StateID = $Self->{StateObject}->StateAdd( %GetParam, UserID => $Self->{UserID} ) )
-        {
-            $Self->_Overview();
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Info => 'State added!' );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminStateForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+        # check needed data
+        for my $Needed (qw(Name ValidID TypeID)) {
+            if ( !$GetParam{$Needed} ) {
+                $Errors{ $Needed . 'Invalid' } = 'ServerError';
+            }
         }
-        else {
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-            $Self->_Edit(
-                Action => "Add",
+
+        # if no errors occurred
+        if ( !%Errors ) {
+
+            # add state
+            my $StateID = $Self->{StateObject}->StateAdd(
                 %GetParam,
+                UserID => $Self->{UserID},
             );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminStateForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+            if ($StateID) {
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'State added!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminState',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
+            }
         }
+
+        # something has gone wrong
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
+        $Self->_Edit(
+            Action => 'Add',
+            Errors => \%Errors,
+            %GetParam,
+        );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminState',
+            Data         => \%Param,
+        );
+        $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
 
     # ------------------------------------------------------------
@@ -181,7 +210,7 @@ sub Run {
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminStateForm',
+            TemplateFile => 'AdminState',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -197,32 +226,56 @@ sub _Edit {
         Name => 'Overview',
         Data => \%Param,
     );
-    $Param{'ValidOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
-        Data       => { $Self->{ValidObject}->ValidList(), },
+
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+
+    # get valid list
+    my %ValidList        = $Self->{ValidObject}->ValidList();
+    my %ValidListReverse = reverse %ValidList;
+
+    $Param{ValidOption} = $Self->{LayoutObject}->BuildSelection(
+        Data       => \%ValidList,
         Name       => 'ValidID',
-        SelectedID => $Param{ValidID},
+        SelectedID => $Param{ValidID} || $ValidListReverse{valid},
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
     );
-    $Param{StateTypeOption} = $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{StateTypeOption} = $Self->{LayoutObject}->BuildSelection(
         Data => { $Self->{StateObject}->StateTypeList( UserID => 1 ), },
         Name => 'TypeID',
         SelectedID => $Param{TypeID},
+        Class => 'Validate_Required ' . ( $Param{Errors}->{'TypeIDInvalid'} || '' ),
     );
     $Self->{LayoutObject}->Block(
         Name => 'OverviewUpdate',
-        Data => \%Param,
+        Data => {
+            %Param,
+            %{ $Param{Errors} },
+        },
     );
+
+    # shows header
+    if ( $Param{Action} eq 'Change' ) {
+        $Self->{LayoutObject}->Block( Name => 'HeaderEdit' );
+    }
+    else {
+        $Self->{LayoutObject}->Block( Name => 'HeaderAdd' );
+    }
+
     return 1;
 }
 
 sub _Overview {
     my ( $Self, %Param ) = @_;
 
-    my $Output = '';
-
     $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
     );
+
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionAdd' );
+
     $Self->{LayoutObject}->Block(
         Name => 'OverviewResult',
         Data => \%Param,
@@ -232,26 +285,29 @@ sub _Overview {
         Valid  => 0,
     );
 
-    # get valid list
-    my %ValidList = $Self->{ValidObject}->ValidList();
-    my $CssClass  = '';
-    for ( sort { $List{$a} cmp $List{$b} } keys %List ) {
+    # if there are any states, they are shown
+    if (%List) {
 
-        # set output class
-        if ( $CssClass && $CssClass eq 'searchactive' ) {
-            $CssClass = 'searchpassive';
+        # get valid list
+        my %ValidList = $Self->{ValidObject}->ValidList();
+        for my $ListKey ( sort { $List{$a} cmp $List{$b} } keys %List ) {
+
+            my %Data = $Self->{StateObject}->StateGet( ID => $ListKey );
+            $Self->{LayoutObject}->Block(
+                Name => 'OverviewResultRow',
+                Data => {
+                    Valid => $ValidList{ $Data{ValidID} },
+                    %Data,
+                },
+            );
         }
-        else {
-            $CssClass = 'searchactive';
-        }
-        my %Data = $Self->{StateObject}->StateGet( ID => $_, );
+    }
+
+    # otherwise a no data found msg is displayed
+    else {
         $Self->{LayoutObject}->Block(
-            Name => 'OverviewResultRow',
-            Data => {
-                Valid    => $ValidList{ $Data{ValidID} },
-                CssClass => $CssClass,
-                %Data,
-            },
+            Name => 'NoDataFoundMsg',
+            Data => {},
         );
     }
     return 1;
