@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminSysConfig.pm - to change, import, export ConfigParameters
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminSysConfig.pm,v 1.112.2.3 2011/05/05 11:45:30 ub Exp $
+# $Id: AdminSysConfig.pm,v 1.119.2.1 2012/05/11 08:22:03 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::SysConfig;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.112.2.3 $) [1];
+$VERSION = qw($Revision: 1.119.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -692,6 +692,15 @@ sub Run {
         # submit config changes
         $Self->{SysConfigObject}->CreateConfig();
 
+        # if running under PerlEx, reload the application (and thus the configuration)
+        if (
+            exists $ENV{'GATEWAY_INTERFACE'}
+            and $ENV{'GATEWAY_INTERFACE'} eq "CGI-PerlEx"
+            )
+        {
+            PerlEx::ReloadAll();
+        }
+
         # redirect
         return $Self->{LayoutObject}->Redirect(
             OP =>
@@ -713,9 +722,6 @@ sub Run {
         # get the config level of the admin user
         my $ConfigLevel = $Self->{ConfigObject}->Get('ConfigLevel') || 0;
 
-        # Language
-        my $UserLang = $Self->{UserLanguage} || $Self->{ConfigObject}->Get('DefaultLanguage');
-
         # list all Items
         for (@List) {
 
@@ -1323,7 +1329,7 @@ sub ListConfigItem {
         );
 
         # Array Element Group
-        for my $ArrayElement qw(Group GroupRo) {
+        for my $ArrayElement (qw(Group GroupRo)) {
             for my $Index ( 1 .. $#{ $FrontendModuleReg->{$ArrayElement} } ) {
 
                 $Self->{LayoutObject}->Block(
@@ -1404,7 +1410,7 @@ sub ListConfigItem {
             );
 
             # Array Element Group
-            for my $ArrayElement qw(Group GroupRo) {
+            for my $ArrayElement (qw(Group GroupRo)) {
                 for my $Index2 ( 1 .. $#{ $FrontendModuleReg->{NavBar}[$Index]{$ArrayElement} } ) {
                     $Self->{LayoutObject}->Block(
                         Name => 'ConfigElementFrontendModuleRegContentNavBar' . $ArrayElement,
@@ -1425,7 +1431,7 @@ sub ListConfigItem {
         if ( ref $FrontendModuleReg->{NavBarModule} eq 'ARRAY' ) {
             for my $Index ( 1 .. $#{ $FrontendModuleReg->{NavBarModule} } ) {
                 my %Data;
-                for my $Key qw (Module Name Block Prio) {
+                for my $Key (qw(Module Name Block Pri)) {
                     $Data{ 'Key' . $Key }     = $Key;
                     $Data{ 'Content' . $Key } = '';
                     if ( defined $FrontendModuleReg->{NavBarModule}->[1]->{$Key}->[1]->{Content} ) {
@@ -1449,7 +1455,7 @@ sub ListConfigItem {
         }
         elsif ( defined $FrontendModuleReg->{NavBarModule} ) {
             my %Data;
-            for my $Key qw (Module Name Description Block Prio) {
+            for my $Key (qw(Module Name Description Block Prio)) {
                 $Data{ 'Key' . $Key }     = $Key;
                 $Data{ 'Content' . $Key } = '';
                 if ( defined $FrontendModuleReg->{NavBarModule}->{$Key}->[1]->{Content} ) {
