@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminSystemAddress.pm - to add/update/delete system addresses
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminSystemAddress.pm,v 1.30 2009/02/17 23:37:11 martin Exp $
+# $Id: AdminSystemAddress.pm,v 1.43 2012/02/27 22:53:37 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +17,10 @@ use warnings;
 use Kernel::System::Queue;
 use Kernel::System::SystemAddress;
 use Kernel::System::Valid;
+use Kernel::System::CheckItem;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.30 $) [1];
+$VERSION = qw($Revision: 1.43 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -29,9 +30,9 @@ sub new {
     bless( $Self, $Type );
 
     # check all needed objects
-    for (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
+    for my $Needed (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
         }
     }
     $Self->{QueueObject}         = Kernel::System::Queue->new(%Param);
@@ -44,6 +45,9 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    #create local object
+    my $CheckItemObject = Kernel::System::CheckItem->new( %{$Self} );
+
     # ------------------------------------------------------------ #
     # change
     # ------------------------------------------------------------ #
@@ -53,11 +57,11 @@ sub Run {
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
-            Action => "Change",
+            Action => 'Change',
             %Data,
         );
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminSystemAddressForm',
+            TemplateFile => 'AdminSystemAddress',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -73,44 +77,68 @@ sub Run {
         $Self->{LayoutObject}->ChallengeTokenCheck();
 
         my $Note = '';
-        my %GetParam;
-        for (qw(ID Name Realname QueueID Comment ValidID)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ ) || '';
+        my ( %GetParam, %Errors );
+        for my $Parameter (qw(ID Name Realname QueueID Comment ValidID)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
-        # update group
+        # check needed data
+        for my $Needed (qw(Name Realname QueueID ValidID)) {
+            if ( !$GetParam{$Needed} ) {
+                $Errors{ $Needed . 'Invalid' } = 'ServerError';
+            }
+        }
+
+        # check email address
         if (
-            $Self->{SystemAddressObject}->SystemAddressUpdate(
-                %GetParam, UserID => $Self->{UserID}
-            )
+            $GetParam{Name}
+            && !$CheckItemObject->CheckEmail( Address => $GetParam{Name} )
             )
         {
-            $Self->_Overview();
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Info => 'Updated!' );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminSystemAddressForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+            $Errors{NameInvalid} = 'ServerError';
+            $Errors{ErrorType}   = $CheckItemObject->CheckErrorType();
         }
-        else {
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-            $Self->_Edit(
-                Action => "Change",
-                %GetParam,
-            );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminSystemAddressForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+
+        # if no errors occurred
+        if ( !%Errors ) {
+
+            # update email system address
+            if (
+                $Self->{SystemAddressObject}->SystemAddressUpdate(
+                    %GetParam,
+                    UserID => $Self->{UserID},
+                )
+                )
+            {
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output
+                    .= $Self->{LayoutObject}->Notify( Info => 'System e-mail address updated!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminSystemAddress',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
+            }
         }
+
+        # something has gone wrong
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
+        $Self->_Edit(
+            Action => 'Change',
+            Errors => \%Errors,
+            %GetParam,
+        );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminSystemAddress',
+            Data         => \%Param,
+        );
+        $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
 
     # ------------------------------------------------------------ #
@@ -118,17 +146,15 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Add' ) {
         my %GetParam = ();
-        for (qw(Name)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
-        }
+        $GetParam{Name} = $Self->{ParamObject}->GetParam( Param => 'Name' );
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
-            Action => "Add",
+            Action => 'Add',
             %GetParam,
         );
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminSystemAddressForm',
+            TemplateFile => 'AdminSystemAddress',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -144,43 +170,66 @@ sub Run {
         $Self->{LayoutObject}->ChallengeTokenCheck();
 
         my $Note = '';
-        my %GetParam;
-        for (qw(ID Name Realname QueueID Comment ValidID)) {
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ ) || '';
+        my ( %GetParam, %Errors );
+        for my $Parameter (qw(ID Name Realname QueueID Comment ValidID)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
-        # add user
+        # check needed data
+        for my $Needed (qw(Name Realname QueueID ValidID)) {
+            if ( !$GetParam{$Needed} ) {
+                $Errors{ $Needed . 'Invalid' } = 'ServerError';
+            }
+        }
+
+        # check email address
         if (
-            my $AddressID
-            = $Self->{SystemAddressObject}->SystemAddressAdd( %GetParam, UserID => $Self->{UserID} )
+            $GetParam{Name}
+            && !$CheckItemObject->CheckEmail( Address => $GetParam{Name} )
             )
         {
-            $Self->_Overview();
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Info => 'Added!' );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminSystemAddressForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+            $Errors{NameInvalid} = 'ServerError';
+            $Errors{ErrorType}   = $CheckItemObject->CheckErrorType();
         }
-        else {
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-            $Self->_Edit(
-                Action => "Add",
+
+        # if no errors occurred
+        if ( !%Errors ) {
+
+            # add user
+            my $AddressID = $Self->{SystemAddressObject}->SystemAddressAdd(
                 %GetParam,
+                UserID => $Self->{UserID},
             );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminSystemAddressForm',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
+
+            if ($AddressID) {
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'System e-mail address added!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminSystemAddress',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
+            }
         }
+
+        # something has gone wrong
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
+        $Self->_Edit(
+            Action => 'Add',
+            Errors => \%Errors,
+            %GetParam,
+        );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminSystemAddress',
+            Data         => \%Param,
+        );
+        $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
     }
 
     # ------------------------------------------------------------
@@ -191,7 +240,7 @@ sub Run {
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminSystemAddressForm',
+            TemplateFile => 'AdminSystemAddress',
             Data         => \%Param,
         );
         $Output .= $Self->{LayoutObject}->Footer();
@@ -207,22 +256,58 @@ sub _Edit {
         Name => 'Overview',
         Data => \%Param,
     );
-    $Param{ValidOption} = $Self->{LayoutObject}->OptionStrgHashRef(
-        Data       => { $Self->{ValidObject}->ValidList(), },
+
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+
+    # get valid list
+    my %ValidList        = $Self->{ValidObject}->ValidList();
+    my %ValidListReverse = reverse %ValidList;
+
+    $Param{ValidOption} = $Self->{LayoutObject}->BuildSelection(
+        Data       => \%ValidList,
         Name       => 'ValidID',
-        SelectedID => $Param{ValidID},
+        SelectedID => $Param{ValidID} || $ValidListReverse{valid},
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
     );
     $Param{QueueOption} = $Self->{LayoutObject}->AgentQueueListOption(
         Data => { $Self->{QueueObject}->QueueList( Valid => 1 ), },
         Name => 'QueueID',
         SelectedID     => $Param{QueueID},
+        Class          => 'Validate_Required ' . ( $Param{Errors}->{'QueueIDInvalid'} || '' ),
         OnChangeSubmit => 0,
     );
 
     $Self->{LayoutObject}->Block(
         Name => 'OverviewUpdate',
-        Data => \%Param,
+        Data => {
+            %Param,
+            %{ $Param{Errors} },
+        },
     );
+
+    # shows header
+    if ( $Param{Action} eq 'Change' ) {
+        $Self->{LayoutObject}->Block( Name => 'HeaderEdit' );
+    }
+    else {
+        $Self->{LayoutObject}->Block( Name => 'HeaderAdd' );
+    }
+
+    # add the correct server error msg for the system email address
+    if ( $Param{Name} && $Param{Errors}->{ErrorType} ) {
+        $Self->{LayoutObject}->Block(
+            Name => 'Email' . $Param{Errors}->{ErrorType} . 'ServerErrorMsg',
+            Data => {},
+        );
+    }
+    else {
+        $Self->{LayoutObject}->Block(
+            Name => "RequiredFieldServerErrorMsg",
+            Data => {},
+        );
+    }
+
     return 1;
 }
 
@@ -235,6 +320,10 @@ sub _Overview {
         Name => 'Overview',
         Data => \%Param,
     );
+
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionAdd' );
+
     $Self->{LayoutObject}->Block(
         Name => 'OverviewResult',
         Data => \%Param,
@@ -243,22 +332,14 @@ sub _Overview {
 
     # get valid list
     my %ValidList = $Self->{ValidObject}->ValidList();
-    my $CssClass  = '';
-    for ( sort { $List{$a} cmp $List{$b} } keys %List ) {
 
-        # set output class
-        if ( $CssClass && $CssClass eq 'searchactive' ) {
-            $CssClass = 'searchpassive';
-        }
-        else {
-            $CssClass = 'searchactive';
-        }
-        my %Data = $Self->{SystemAddressObject}->SystemAddressGet( ID => $_, );
+    for my $ListKey ( sort { $List{$a} cmp $List{$b} } keys %List ) {
+
+        my %Data = $Self->{SystemAddressObject}->SystemAddressGet( ID => $ListKey );
         $Self->{LayoutObject}->Block(
             Name => 'OverviewResultRow',
             Data => {
-                Valid    => $ValidList{ $Data{ValidID} },
-                CssClass => $CssClass,
+                Valid => $ValidList{ $Data{ValidID} },
                 %Data,
             },
         );
