@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentBook.pm - addressbook module
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentBook.pm,v 1.18 2010/06/30 08:56:38 mn Exp $
+# $Id: AgentBook.pm,v 1.20 2012/03/09 13:00:30 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::CustomerUser;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.18 $) [1];
+$VERSION = qw($Revision: 1.20 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -43,7 +43,7 @@ sub Run {
     my ( $Self, %Param ) = @_;
 
     # get params
-    for (qw(To Cc Bcc)) {
+    for (qw(ToCustomer CcCustomer BccCustomer)) {
         $Param{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
     }
 
@@ -61,6 +61,20 @@ sub Run {
         }
     }
 
+    # build customer search autocomplete field
+    my $AutoCompleteConfig
+        = $Self->{ConfigObject}->Get('Ticket::Frontend::CustomerSearchAutoComplete');
+    $Self->{LayoutObject}->Block(
+        Name => 'CustomerSearchAutoComplete',
+        Data => {
+            ActiveAutoComplete  => $AutoCompleteConfig->{Active},
+            minQueryLength      => $AutoCompleteConfig->{MinQueryLength} || 2,
+            queryDelay          => $AutoCompleteConfig->{QueryDelay} || 100,
+            typeAhead           => $AutoCompleteConfig->{TypeAhead} || 'false',
+            maxResultsDisplayed => $AutoCompleteConfig->{MaxResultsDisplayed} || 20,
+        },
+    );
+
     if (%List) {
         $Self->{LayoutObject}->Block(
             Name => 'SearchResult',
