@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentSpelling.pm - spelling module
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentSpelling.pm,v 1.24 2009/08/26 13:05:05 martin Exp $
+# $Id: AgentSpelling.pm,v 1.28 2010/07/01 14:08:53 mn Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::Spelling;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.24 $) [1];
+$VERSION = qw($Revision: 1.28 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -44,76 +44,6 @@ sub Run {
         || $Self->{UserSpellDict}
         || $Self->{ConfigObject}->Get('SpellCheckerDictDefault');
 
-    # inline spell checker of richt text
-    if ( $Self->{Subaction} eq 'Inline' ) {
-
-        my $JSData = '';
-        my @Text = $Self->{ParamObject}->GetArray( Param => 'textinputs[]' );
-
-        my $TextAll = '';
-        for ( my $i = 0; $i <= $#Text; $i++ ) {
-            my $Line = $Self->{LayoutObject}->JSONQuote(
-                Data => $Text[$i],
-            );
-            $JSData .= "textinputs[$i] = decodeURIComponent('$Line')\n";
-
-            # change hex escapes to the proper characters
-            $Text[$i] =~ s/%([a-fA-F0-9]{2})/pack "H2", $1/eg;
-
-            my @Lines = split( /\n/, $Text[$i] );
-            for my $Line (@Lines) {
-                $TextAll .= $Line;
-            }
-        }
-
-        # do spell check
-        my $SpellingObject = Kernel::System::Spelling->new( %{$Self} );
-        $TextAll = $Self->{LayoutObject}->RichText2Ascii(
-            String => $TextAll,
-        );
-
-        my %SpellCheck = $SpellingObject->Check(
-            Text          => $TextAll,
-            SpellLanguage => $SpellLanguage,
-        );
-
-        $JSData .= "words[0] = [];\n";
-        $JSData .= "suggs[0] = [];\n";
-        my $Count = 0;
-        for ( sort { $a <=> $b } keys %SpellCheck ) {
-            my $Word = $Self->{LayoutObject}->Ascii2Html(
-                Text => $SpellCheck{$_}->{Word},
-                Type => 'JSText',
-            );
-            my $JS = $Self->{LayoutObject}->JSON(
-                Data => $SpellCheck{$_}->{Replace},
-            );
-
-            $JSData .= "words[0][$Count] = '$Word';\n";
-            $JSData .= "suggs[0][$Count] = $JS;\n";
-            $JSData .= "\n";
-            $Count++;
-        }
-
-        $Self->{LayoutObject}->Block(
-            Name => 'SpellCheckerInline',
-            Data => {
-                JSData => $JSData,
-            },
-        );
-
-        my $Output = $Self->{LayoutObject}->Output(
-            TemplateFile => 'AgentSpelling',
-            Data         => \%Param,
-        );
-        return $Self->{LayoutObject}->Attachment(
-            ContentType => 'text/html; charset=' . $Self->{LayoutObject}->{Charset},
-            Content     => $Output,
-            Type        => 'inline',
-            NoCache     => 1,
-        );
-    }
-
     # get params
     $Param{Body} = $Self->{ParamObject}->GetParam( Param => 'Body' );
     $Param{Field} = $Self->{ParamObject}->GetParam( Param => 'Field' ) || 'Body';
@@ -163,7 +93,7 @@ sub _Mask {
     my ( $Self, %Param ) = @_;
 
     # dict language selection
-    $Param{SpellLanguageString} .= $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{SpellLanguageString} .= $Self->{LayoutObject}->BuildSelection(
         Data       => $Self->{ConfigObject}->Get('PreferencesGroups')->{SpellDict}->{Data},
         Name       => 'SpellLanguage',
         SelectedID => $Param{SpellLanguage},
@@ -189,10 +119,9 @@ sub _Mask {
                 else {
                     $ReplaceWords{''} = 'No suggestions';
                 }
-                $Param{SpellCheckString} = $Self->{LayoutObject}->OptionStrgHashRef(
-                    Data     => \%ReplaceWords,
-                    Name     => "SpellCheckOption::$Param{SpellCounter}",
-                    OnChange => "change_selected($Param{SpellCounter})"
+                $Param{SpellCheckString} = $Self->{LayoutObject}->BuildSelection(
+                    Data => \%ReplaceWords,
+                    Name => "SpellCheckOption::$Param{SpellCounter}",
                 );
                 $Self->{LayoutObject}->Block(
                     Name => 'Row',
