@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketClose.pm - close a ticket
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketClose.pm,v 1.88 2010/06/18 18:15:49 en Exp $
+# $Id: AgentTicketClose.pm,v 1.89 2011/05/03 07:53:58 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,9 +11,12 @@
 
 package Kernel::Modules::AgentTicketClose;
 
+use strict;
+use warnings;
+
 use base qw( Kernel::Modules::AgentTicketActionCommon );
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.88 $) [1];
+$VERSION = qw($Revision: 1.89 $) [1];
 
 1;
