@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketEmail.pm - to compose initial email to customer
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketEmail.pm,v 1.205 2012/02/29 14:36:19 ep Exp $
+# $Id: AgentTicketEmail.pm,v 1.206.2.5 2012/06/18 15:58:22 cg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -25,10 +25,9 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 use Mail::Address;
-use Kernel::System::Service;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.205 $) [1];
+$VERSION = qw($Revision: 1.206.2.5 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -41,7 +40,7 @@ sub new {
 
     # check needed objects
     for my $Needed (
-        qw(ParamObject DBObject TicketObject LayoutObject LogObject QueueObject ConfigObject)
+        qw(ParamObject DBObject TicketObject LayoutObject LogObject QueueObject MainObject ConfigObject)
         )
     {
         if ( !$Self->{$Needed} ) {
@@ -58,7 +57,6 @@ sub new {
     $Self->{HTMLUtilsObject}    = Kernel::System::HTMLUtils->new(%Param);
     $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
     $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
-    $Self->{ServiceObject}      = Kernel::System::Service->new(%Param);
 
     # get form id
     $Self->{FormID} = $Self->{ParamObject}->GetParam( Param => 'FormID' );
@@ -139,7 +137,7 @@ sub Run {
                 my $CustomerErrorMsg = 'CustomerGenericServerErrorMsg';
                 my $CustomerError    = '';
                 my $CustomerDisabled = '';
-                my $CountAux         = $Count;
+                my $CountAux         = $CustomerCounter++;
 
                 if ( !$IsUpload ) {
 
@@ -185,6 +183,7 @@ sub Run {
         = $Self->{ParamObject}->GetParam( Param => 'CustomerTicketCounterCcCustomer' ) || 0;
 
     if ($CustomersNumberCc) {
+        my $CustomerCounterCc = 1;
         for my $Count ( 1 ... $CustomersNumberCc ) {
             my $CustomerElementCc
                 = $Self->{ParamObject}->GetParam( Param => 'CcCustomerTicketText_' . $Count );
@@ -195,7 +194,7 @@ sub Run {
                 my $CustomerErrorMsgCc = 'CustomerGenericServerErrorMsg';
                 my $CustomerErrorCc    = '';
                 my $CustomerDisabledCc = '';
-                my $CountAuxCc         = $Count;
+                my $CountAuxCc         = $CustomerCounterCc++;
 
                 if ( !$IsUpload ) {
                     $GetParam{Cc} .= $CustomerElementCc . ',';
@@ -241,6 +240,7 @@ sub Run {
         = $Self->{ParamObject}->GetParam( Param => 'CustomerTicketCounterBccCustomer' ) || 0;
 
     if ($CustomersNumberBcc) {
+        my $CustomerCounterBcc = 1;
         for my $Count ( 1 ... $CustomersNumberBcc ) {
             my $CustomerElementBcc
                 = $Self->{ParamObject}->GetParam( Param => 'BccCustomerTicketText_' . $Count );
@@ -251,7 +251,7 @@ sub Run {
             if ($CustomerElementBcc) {
 
                 my $CustomerDisabledBcc = '';
-                my $CountAuxBcc         = $Count;
+                my $CountAuxBcc         = $CustomerCounterBcc++;
                 my $CustomerErrorMsgBcc = 'CustomerGenericServerErrorMsg';
                 my $CustomerErrorBcc    = '';
                 if ( !$IsUpload ) {
@@ -957,17 +957,8 @@ sub Run {
                 QueueID        => $NewQueueID   || 1,
             );
 
-            my $SelectedService;
-            SERVICE:
-            for my $Service ( @{$Services} ) {
-                next SERVICE if !$Service->{Key} eq $GetParam{ServiceID};
-
-                $SelectedService = $Service->{Key};
-                last SERVICE;
-            }
-
             # reset previous ServiceID to reset SLA-List if no service is selected
-            if ( !$GetParam{ServiceID} || !$SelectedService ) {
+            if ( !$GetParam{ServiceID} || !$Services->{ $GetParam{ServiceID} } ) {
                 $GetParam{ServiceID} = '';
             }
 
@@ -1440,6 +1431,7 @@ sub Run {
                     SelectedID   => $Dest,
                     Translation  => 0,
                     PossibleNone => 0,
+                    TreeView     => $TreeView,
                     Max          => 100,
                 },
                 {
@@ -1560,12 +1552,12 @@ sub _GetUsers {
         %ShownUsers = %AllGroupsMembers;
     }
 
-    # show all users who are rw in the queue group
+    # show all users who are owner or rw in the queue group
     elsif ( $Param{QueueID} ) {
         my $GID = $Self->{QueueObject}->GetQueueGroupID( QueueID => $Param{QueueID} );
         my %MemberList = $Self->{GroupObject}->GroupMemberList(
             GroupID => $GID,
-            Type    => 'rw',
+            Type    => 'owner',
             Result  => 'HASH',
         );
         for my $MemberKey ( keys %MemberList ) {
@@ -1620,12 +1612,12 @@ sub _GetResponsibles {
         %ShownUsers = %AllGroupsMembers;
     }
 
-    # show all users who are rw in the queue group
+    # show all users who are responsible or rw in the queue group
     elsif ( $Param{QueueID} ) {
         my $GID = $Self->{QueueObject}->GetQueueGroupID( QueueID => $Param{QueueID} );
         my %MemberList = $Self->{GroupObject}->GroupMemberList(
             GroupID => $GID,
-            Type    => 'rw',
+            Type    => 'responsible',
             Result  => 'HASH',
         );
         for my $MemberKey ( keys %MemberList ) {
@@ -1684,112 +1676,28 @@ sub _GetServices {
 
     # get service
     my %Service;
-    my @ServiceList;
-    if ( ( $Param{QueueID} || $Param{TicketID} ) && $Param{CustomerUserID} ) {
+
+    # check needed
+    return \%Service if !$Param{QueueID} && !$Param{TicketID};
+
+    # get options for default services for unknown customers
+    my $DefaultServiceUnknownCustomer
+        = $Self->{ConfigObject}->Get('Ticket::Service::Default::UnknownCustomer');
+
+    # get service list
+    if ( $Param{CustomerUserID} || $DefaultServiceUnknownCustomer ) {
         %Service = $Self->{TicketObject}->TicketServiceList(
             %Param,
             Action => $Self->{Action},
             UserID => $Self->{UserID},
         );
-
-        my %OrigService = $Self->{ServiceObject}->CustomerUserServiceMemberList(
-            Result            => 'HASH',
-            CustomerUserLogin => $Param{CustomerUserID},
-            UserID            => 1,
-        );
-
-        # get all services
-        my $ServiceList = $Self->{ServiceObject}->ServiceListGet(
-            Valid  => 0,
-            UserID => 1,
-        );
-
-        # get a service lookup table
-        my %ServiceLoockup;
-        SERVICE:
-        for my $ServiceData ( @{$ServiceList} ) {
-            next SERVICE if !$ServiceData;
-            next SERVICE if !IsHashRefWithData($ServiceData);
-            next SERVICE if !$ServiceData->{ServiceID};
-
-            $ServiceLoockup{ $ServiceData->{ServiceID} } = $ServiceData;
-        }
-
-        # to store already printed ServiceIDs
-        my %AddedServices;
-
-        for my $ServiceKey ( sort { $OrigService{$a} cmp $OrigService{$b} } keys %OrigService ) {
-
-            # get the service parent
-            my $ServiceParentID = $ServiceLoockup{$ServiceKey}->{ParentID} || 0;
-
-            # check if direct parent is not listed as printed
-            if ( $ServiceParentID && !defined $AddedServices{$ServiceParentID} ) {
-
-                # get all parent IDs
-                my $ServiceParents = $Self->{ServiceObject}->ServiceParentsGet(
-                    ServiceID => $ServiceKey,
-                    UserID    => $Self->{UserID},
-                );
-
-                SERVICEID:
-                for my $ServiceID ( @{$ServiceParents} ) {
-                    next SERVICEID if !$ServiceID;
-                    next SERVICEID if $AddedServices{$ServiceID};
-
-                    my $ServiceParent = $ServiceLoockup{$ServiceID};
-                    next SERVICEID if !IsHashRefWithData($ServiceParent);
-
-                    # create a new register for each parent as disabled
-                    my %ParentServiceRegister = (
-                        Key      => $ServiceID,
-                        Value    => $ServiceParent->{Name},
-                        Selected => 0,
-                        Disabled => 1,
-                    );
-                    push @ServiceList, \%ParentServiceRegister;
-
-                    # set service as printed
-                    $AddedServices{$ServiceID} = 1;
-                }
-            }
-
-            # set default service structure
-            my %ServiceRegister = (
-                Key   => $ServiceKey,
-                Value => $OrigService{$ServiceKey},
-            );
-
-            # check if service is selected
-            if ( $Param{ServiceID} && $Param{ServiceID} eq $ServiceKey ) {
-                $ServiceRegister{Selected} = 1;
-            }
-
-            # check if service is disabled
-            if ( !$Service{$ServiceKey} ) {
-                $ServiceRegister{Disabled} = 1;
-            }
-            push @ServiceList, \%ServiceRegister;
-
-            # set service as printed
-            $AddedServices{$ServiceKey} = 1;
-        }
     }
-    return \@ServiceList;
+    return \%Service;
 }
 
 sub _GetSLAs {
     my ( $Self, %Param ) = @_;
 
-    # convert service ArrayHashRef to hashref
-    my %Services;
-    SERVICE:
-    for my $Service ( @{ $Param{Services} } ) {
-        next SERVICE if !$Service;
-        $Services{ $Service->{Key} } = $Service->{Value};
-    }
-    $Param{Services} = \%Services;
-
     # get sla
     my %SLA;
     if ( $Param{ServiceID} && $Param{Services} && %{ $Param{Services} } ) {
@@ -2175,8 +2083,10 @@ sub _MaskEmailNew {
             Data         => $Param{Services},
             Name         => 'ServiceID',
             Class        => $Param{Errors}->{ServiceInvalid} || ' ',
+            SelectedID   => $Param{ServiceID},
             PossibleNone => 1,
             TreeView     => $TreeView,
+            Sort         => 'TreeView',
             Translation  => 0,
             Max          => 200,
         );
