@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketForward.pm - to forward a message
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketForward.pm,v 1.129 2012/02/29 14:36:19 ep Exp $
+# $Id: AgentTicketForward.pm,v 1.131.2.5 2012/05/30 20:48:41 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -26,7 +26,7 @@ use Kernel::System::VariableCheck qw(:all);
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.129 $) [1];
+$VERSION = qw($Revision: 1.131.2.5 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -226,6 +226,13 @@ sub Form {
             ArticleID     => $GetParam{ArticleID},
             DynamicFields => 1,
         );
+
+        # Check if article is from the same TicketID as we checked permissions for.
+        if ( $Data{TicketID} ne $Self->{TicketID} ) {
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "Article does not belong to ticket $Self->{TicketID}!",
+            );
+        }
     }
     else {
         %Data = $Self->{TicketObject}->ArticleLastCustomerArticle(
@@ -506,8 +513,8 @@ sub SendEmail {
     }
     $GetParam{DynamicField} = \%DynamicFieldACLParameters;
 
-    my $QueueID   = $Self->{QueueID};
-    my %StateData = ();
+    my $QueueID = $Self->{QueueID};
+    my %StateData;
 
     if ( $GetParam{ComposeStateID} ) {
         %StateData = $Self->{TicketObject}->{StateObject}->StateGet(
@@ -867,14 +874,6 @@ sub SendEmail {
         );
     }
 
-    # set state
-    $Self->{TicketObject}->TicketStateSet(
-        TicketID  => $Self->{TicketID},
-        ArticleID => $ArticleID,
-        State     => $NextState,
-        UserID    => $Self->{UserID},
-    );
-
     # set state
     if ($NextState) {
         $Self->{TicketObject}->TicketStateSet(
@@ -883,20 +882,27 @@ sub SendEmail {
             State     => $NextState,
             UserID    => $Self->{UserID},
         );
-    }
 
-    # set pending time
-    elsif ( $StateData{TypeName} =~ /^pending/i ) {
+        # should I set an unlock?
+        if ( $StateData{TypeName} =~ /^close/i ) {
+            $Self->{TicketObject}->TicketLockSet(
+                TicketID => $Self->{TicketID},
+                Lock     => 'unlock',
+                UserID   => $Self->{UserID},
+            );
+        }
 
         # set pending time
-        $Self->{TicketObject}->TicketPendingTimeSet(
-            UserID   => $Self->{UserID},
-            TicketID => $Self->{TicketID},
-            %GetParam,
-        );
+        elsif ( $StateData{TypeName} =~ /^pending/i ) {
+            $Self->{TicketObject}->TicketPendingTimeSet(
+                UserID   => $Self->{UserID},
+                TicketID => $Self->{TicketID},
+                %GetParam,
+            );
+        }
     }
 
-    # remove pre submited attachments
+    # remove pre-submitted attachments
     $Self->{UploadCacheObject}->FormIDRemove( FormID => $GetParam{FormID} );
 
     # redirect
@@ -918,6 +924,42 @@ sub AjaxUpdate {
     my %GetParam          = %{ $Self->{GetParam} };
     my %ACLCompatGetParam = %{ $Self->{ACLCompatGetParam} };
 
+    my @ExtendedData;
+
+    # run compose modules
+    if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') eq 'HASH' ) {
+        my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') };
+        for my $Job ( sort keys %Jobs ) {
+
+            # load module
+            next if !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} );
+
+            my $Object = $Jobs{$Job}->{Module}->new( %{$Self}, Debug => $Self->{Debug}, );
+
+            # get params
+            for my $Parameter ( $Object->Option( %GetParam, Config => $Jobs{$Job} ) ) {
+                $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter );
+            }
+
+            # run module
+            my %Data = $Object->Data( %GetParam, Config => $Jobs{$Job} );
+
+            my $Key = $Object->Option( %GetParam, Config => $Jobs{$Job} );
+            if ($Key) {
+                push(
+                    @ExtendedData,
+                    {
+                        Name        => $Key,
+                        Data        => \%Data,
+                        SelectedID  => $GetParam{$Key},
+                        Translation => 1,
+                        Max         => 100,
+                    }
+                );
+            }
+        }
+    }
+
     my %DynamicFieldValues;
 
     # cycle trough the activated Dynamic Fields for this screen
@@ -1008,6 +1050,7 @@ sub AjaxUpdate {
                 PossibleNone => 1,
                 Max          => 100,
             },
+            @ExtendedData,
             @DynamicFieldAJAX,
         ],
     );
