@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketHistory.pm - ticket history
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketHistory.pm,v 1.14.2.2 2010/06/24 17:14:23 dz Exp $
+# $Id: AgentTicketHistory.pm,v 1.22 2012/01/24 00:08:45 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,9 +13,10 @@ package Kernel::Modules::AgentTicketHistory;
 
 use strict;
 use warnings;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.14.2.2 $) [1];
+$VERSION = qw($Revision: 1.22 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -25,9 +26,9 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(DBObject TicketObject LayoutObject LogObject UserObject ConfigObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
+    for my $Needed (qw(DBObject TicketObject LayoutObject LogObject UserObject ConfigObject)) {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
         }
     }
     return $Self;
@@ -48,10 +49,10 @@ sub Run {
 
     # check permissions
     if (
-        !$Self->{TicketObject}->Permission(
+        !$Self->{TicketObject}->TicketPermission(
             Type     => 'ro',
             TicketID => $Self->{TicketID},
-            UserID   => $Self->{UserID}
+            UserID   => $Self->{UserID},
         )
         )
     {
@@ -60,6 +61,27 @@ sub Run {
         return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
     }
 
+    # get ACL restrictions
+    $Self->{TicketObject}->TicketAcl(
+        Data          => '-',
+        TicketID      => $Self->{TicketID},
+        ReturnType    => 'Action',
+        ReturnSubType => '-',
+        UserID        => $Self->{UserID},
+    );
+    my %AclAction = $Self->{TicketObject}->TicketAclActionData();
+
+    # check if ACL resctictions if exist
+    if ( IsHashRefWithData( \%AclAction ) ) {
+
+        # show error screen if ACL prohibits this action
+        if ( defined $AclAction{ $Self->{Action} } && $AclAction{ $Self->{Action} } eq '0' ) {
+            return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
+        }
+    }
+
+    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Self->{TicketID} );
+
     my @Lines = $Self->{TicketObject}->HistoryGet(
         TicketID => $Self->{TicketID},
         UserID   => $Self->{UserID},
@@ -81,16 +103,16 @@ sub Run {
         my %Data = %{$DataTmp};
 
         # replace text
-        if ( $Data{Name} && $Data{Name} =~ /^%%/ ) {
+        if ( $Data{Name} && $Data{Name} =~ m/^%%/x ) {
             my %Info = ();
-            $Data{Name} =~ s/^%%//g;
-            my @Values = split( /%%/, $Data{Name} );
+            $Data{Name} =~ s/^%%//xg;
+            my @Values = split( /%%/x, $Data{Name} );
             $Data{Name} = '';
-            for (@Values) {
+            for my $Value (@Values) {
                 if ( $Data{Name} ) {
                     $Data{Name} .= "\", ";
                 }
-                $Data{Name} .= "\"$_";
+                $Data{Name} .= "\"$Value";
             }
             if ( !$Data{Name} ) {
                 $Data{Name} = '" ';
@@ -100,33 +122,44 @@ sub Run {
             );
 
             # remove not needed place holder
-            $Data{Name} =~ s/\%s//g;
+            $Data{Name} =~ s/\%s//xg;
         }
 
-        # seperate each searchresult line by using several css
-        if ( $Counter % 2 ) {
-            $Data{css} = 'searchpassive';
-        }
-        else {
-            $Data{css} = 'searchactive';
-        }
         $Self->{LayoutObject}->Block(
             Name => 'Row',
             Data => {%Data},
         );
+
+        if ( $Data{ArticleID} ne "0" ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'ShowLinkZoom',
+                Data => {%Data},
+            );
+        }
+        else {
+            $Self->{LayoutObject}->Block(
+                Name => 'NoLinkZoom',
+            );
+
+        }
     }
 
     # build page
-    my $Output = $Self->{LayoutObject}->Header( Value => $Tn );
-    $Output .= $Self->{LayoutObject}->NavigationBar();
+    my $Output = $Self->{LayoutObject}->Header(
+        Value => $Tn,
+        Type  => 'Small',
+    );
     $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentTicketHistory',
         Data         => {
             TicketNumber => $Tn,
             TicketID     => $Self->{TicketID},
+            Title        => $Ticket{Title},
         },
     );
-    $Output .= $Self->{LayoutObject}->Footer();
+    $Output .= $Self->{LayoutObject}->Footer(
+        Type => 'Small',
+    );
 
     return $Output;
 }
