@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketLock.pm - to set or unset a lock for tickets
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketLock.pm,v 1.14 2010/07/09 20:22:55 en Exp $
+# $Id: AgentTicketLock.pm,v 1.17 2012/01/24 00:08:45 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,9 +13,10 @@ package Kernel::Modules::AgentTicketLock;
 
 use strict;
 use warnings;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.14 $) [1];
+$VERSION = qw($Revision: 1.17 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -57,9 +58,31 @@ sub Run {
         return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
     }
 
+    # get ACL restrictions
+    $Self->{TicketObject}->TicketAcl(
+        Data          => '-',
+        TicketID      => $Self->{TicketID},
+        ReturnType    => 'Action',
+        ReturnSubType => '-',
+        UserID        => $Self->{UserID},
+    );
+    my %AclAction = $Self->{TicketObject}->TicketAclActionData();
+
+    # check if ACL resctictions if exist
+    if ( IsHashRefWithData( \%AclAction ) ) {
+
+        # show error screen if ACL prohibits this action
+        if ( defined $AclAction{ $Self->{Action} } && $AclAction{ $Self->{Action} } eq '0' ) {
+            return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
+        }
+    }
+
     # start with actions
     if ( $Self->{Subaction} eq 'Unlock' ) {
 
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         # check if I'm the owner
         my ( $OwnerID, $OwnerLogin ) = $Self->{TicketObject}->OwnerCheck(
             TicketID => $Self->{TicketID},
@@ -71,7 +94,7 @@ sub Run {
             );
             $Output .= $Self->{LayoutObject}->Warning(
                 Message => "Sorry, the current owner is $OwnerLogin!",
-                Comment => 'Please change the owner first.',
+                Comment => 'Please become the owner first.',
             );
             $Output .= $Self->{LayoutObject}->Footer(
                 Type => 'Small',
@@ -89,16 +112,13 @@ sub Run {
         if ( !$Lock ) {
             return $Self->{LayoutObject}->ErrorScreen();
         }
-
-        # redirekt
-        if ( $Self->{QueueID} ) {
-            return $Self->{LayoutObject}->Redirect( OP => "QueueID=$Self->{QueueID}" );
-        }
-        return $Self->{LayoutObject}->Redirect( OP => $Self->{LastScreenView} );
     }
     else {
 
-        # check if the agent is ablee to lock
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
+        # check if the agent is able to lock the ticket
         if ( $Self->{TicketObject}->TicketLockGet( TicketID => $Self->{TicketID} ) ) {
             my ( $OwnerID, $OwnerLogin ) = $Self->{TicketObject}->OwnerCheck(
                 TicketID => $Self->{TicketID},
@@ -108,7 +128,7 @@ sub Run {
                 Type  => 'Small',
             );
             $Output .= $Self->{LayoutObject}->Warning(
-                Message => "Ticket (ID=$Self->{TicketID}) is locked for $OwnerLogin!",
+                Message => "Ticket (ID=$Self->{TicketID}) is locked by $OwnerLogin!",
                 Comment => "Change the owner!",
             );
             $Output .= $Self->{LayoutObject}->Footer(
@@ -136,13 +156,13 @@ sub Run {
         {
             return $Self->{LayoutObject}->ErrorScreen();
         }
-
-        # redirekt
-        if ( $Self->{QueueID} ) {
-            return $Self->{LayoutObject}->Redirect( OP => ";QueueID=$Self->{QueueID}" );
-        }
-        return $Self->{LayoutObject}->Redirect( OP => $Self->{LastScreenView} );
     }
+
+    # redirect
+    if ( $Self->{QueueID} ) {
+        return $Self->{LayoutObject}->Redirect( OP => ";QueueID=$Self->{QueueID}" );
+    }
+    return $Self->{LayoutObject}->Redirect( OP => $Self->{LastScreenView} );
 }
 
 1;
