@@ -1,14 +1,21 @@
 # --
 # Kernel/Modules/AgentZoom.pm - to get a closer view
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentZoom.pm,v 1.96 2009/02/16 11:20:53 tr Exp $
+# $Id: AgentZoom.pm,v 1.98 2011/12/19 09:03:35 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
+#
+# LEGACY: This module redirects to AgentTicketZoom. It should be kept for a while
+#   because existing legacy/upgraded systems have it in their notifications.
+#   To drop it, existing notifications would have to be changed by the database
+#   upgrading script.
+#
+
 package Kernel::Modules::AgentZoom;
 
 use strict;
@@ -17,7 +24,7 @@ use warnings;
 use Kernel::System::CustomerUser;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.96 $) [1];
+$VERSION = qw($Revision: 1.98 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -47,7 +54,7 @@ sub Run {
     else {
         $Redirect
             = $Self->{LayoutObject}->{Baselink}
-            . 'Action=AgentTicketZoom&TicketID='
+            . 'Action=AgentTicketZoom;TicketID='
             . $Self->{TicketID};
     }
     return $Self->{LayoutObject}->Redirect( OP => $Redirect );
