@@ -1,12 +1,12 @@
 # --
 # Kernel/Modules/CustomerPreferences.pm - provides agent preferences
-# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: CustomerPreferences.pm,v 1.19 2008/05/08 09:36:37 mh Exp $
+# $Id: CustomerPreferences.pm,v 1.31 2010/07/14 22:18:25 dz Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::CustomerPreferences;
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.19 $) [1];
+$VERSION = qw($Revision: 1.31 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -43,13 +43,18 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $Group = $Self->{ParamObject}->GetParam( Param => 'Group' ) || '';
-
+    # ------------------------------------------------------------ #
+    # update preferences
+    # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Update' ) {
 
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         # check group param
+        my $Group = $Self->{ParamObject}->GetParam( Param => 'Group' ) || '';
         if ( !$Group ) {
-            return $Self->{LayoutObject}->ErrorScreen( Message => "Param Group is required!" );
+            return $Self->{LayoutObject}->ErrorScreen( Message => 'Param Group is required!' );
         }
 
         # check preferences setting
@@ -61,45 +66,55 @@ sub Run {
         # get user data
         my %UserData = $Self->{UserObject}->CustomerUserDataGet( User => $Self->{UserLogin} );
         my $Module = $Preferences{$Group}->{Module};
-        if ( $Self->{MainObject}->Require($Module) ) {
-            my $Object = $Module->new(
-                %{$Self},
-                ConfigItem => $Preferences{$Group},
-                Debug      => $Self->{Debug},
-            );
-
-            # log loaded module
-            if ( $Self->{Debug} > 1 ) {
-                $Self->{LogObject}->Log(
-                    Priority => 'debug',
-                    Message  => "Module: $Module loaded!",
-                );
-            }
-            my @Params = $Object->Param( UserData => \%UserData );
-            my %GetParam = ();
-            for my $ParamItem (@Params) {
-                my @Array = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
-                $GetParam{ $ParamItem->{Name} } = \@Array;
-            }
-            my $Message  = '';
-            my $Priority = '';
-            if ( $Object->Run( GetParam => \%GetParam, UserData => \%UserData ) ) {
-                $Message = $Object->Message();
-            }
-            else {
-                $Priority = 'Error';
-                $Message  = $Object->Error();
-            }
-
-            # mk rediect
-            return $Self->{LayoutObject}->Redirect(
-                OP => "Action=CustomerPreferences&Priority=$Priority&Message=$Message",
-            );
-        }
-        else {
+        if ( !$Self->{MainObject}->Require($Module) ) {
             return $Self->{LayoutObject}->FatalError();
         }
+        my $Object = $Module->new(
+            %{$Self},
+            ConfigItem => $Preferences{$Group},
+            Debug      => $Self->{Debug},
+        );
+
+        # log loaded module
+        if ( $Self->{Debug} > 1 ) {
+            $Self->{LogObject}->Log(
+                Priority => 'debug',
+                Message  => "Module: $Module loaded!",
+            );
+        }
+        my @Params = $Object->Param( UserData => \%UserData );
+        my %GetParam;
+        for my $ParamItem (@Params) {
+            my @Array = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
+            $GetParam{ $ParamItem->{Name} } = \@Array;
+        }
+        my $Message  = '';
+        my $Priority = '';
+        if ( $Object->Run( GetParam => \%GetParam, UserData => \%UserData ) ) {
+            $Message = $Object->Message();
+        }
+        else {
+            $Priority = 'Error';
+            $Message  = $Object->Error();
+        }
+
+        # check redirect
+        my $RedirectURL = $Self->{ParamObject}->GetParam( Param => 'RedirectURL' );
+        if ($RedirectURL) {
+            return $Self->{LayoutObject}->Redirect(
+                OP => $RedirectURL,
+            );
+        }
+
+        # rediect
+        return $Self->{LayoutObject}->Redirect(
+            OP => "Action=CustomerPreferences;Priority=$Priority;Message=$Message",
+        );
     }
+
+    # ------------------------------------------------------------ #
+    # show preferences
+    # ------------------------------------------------------------ #
     else {
         my $Output = $Self->{LayoutObject}->CustomerHeader( Title => 'Preferences' );
         $Output .= $Self->{LayoutObject}->CustomerNavigationBar();
@@ -132,15 +147,15 @@ sub CustomerPreferencesForm {
 
     $Self->{LayoutObject}->Block(
         Name => 'Body',
-        Data => { %Param, },
+        Data => \%Param,
     );
 
     my @Groups = @{ $Self->{ConfigObject}->Get('CustomerPreferencesView') };
-    for my $Colum (@Groups) {
-        my %Data        = ();
+    for my $Column (@Groups) {
+        my %Data;
         my %Preferences = %{ $Self->{ConfigObject}->Get('CustomerPreferencesGroups') };
         for my $Group ( keys %Preferences ) {
-            if ( $Preferences{$Group}->{Colum} eq $Colum ) {
+            if ( $Preferences{$Group}->{Column} eq $Column ) {
                 if ( $Data{ $Preferences{$Group}->{Prio} } ) {
                     for ( 1 .. 151 ) {
                         $Preferences{$Group}->{Prio}++;
@@ -155,14 +170,7 @@ sub CustomerPreferencesForm {
         }
         $Self->{LayoutObject}->Block(
             Name => 'Head',
-            Data => { Header => $Colum, },
-        );
-        $Self->{LayoutObject}->Block(
-            Name => 'Colum',
-            Data => {
-                Header => $Colum,
-                %Param,
-            },
+            Data => { Header => $Column, },
         );
 
         # sort
@@ -174,57 +182,53 @@ sub CustomerPreferencesForm {
         # show each preferences setting
         for my $Prio ( sort keys %Data ) {
             my $Group = $Data{$Prio};
-            if ( !$Self->{ConfigObject}->{CustomerPreferencesGroups}->{$Group} ) {
-                next;
-            }
+            next if !$Self->{ConfigObject}->{CustomerPreferencesGroups}->{$Group};
+
             my %Preference = %{ $Self->{ConfigObject}->{CustomerPreferencesGroups}->{$Group} };
-            if ( !$Preference{Activ} ) {
-                next;
-            }
+            next if !$Preference{Active};
 
             # load module
             my $Module = $Preference{Module} || 'Kernel::Output::HTML::CustomerPreferencesGeneric';
-            if ( $Self->{MainObject}->Require($Module) ) {
-                my $Object = $Module->new(
-                    %{$Self},
-                    ConfigItem => $Preferences{$Group},
-                    Debug      => $Self->{Debug},
-                );
-                my @Params = $Object->Param( UserData => $Param{UserData} );
-                if (@Params) {
-                    $Self->{LayoutObject}->Block(
-                        Name => 'Item',
-                        Data => {
-                            Group => $Group,
-                            %Preference,
-                        },
-                    );
-                    for my $ParamItem (@Params) {
-                        if (
-                            ref( $ParamItem->{Data} )   eq 'HASH'
-                            || ref( $Preference{Data} ) eq 'HASH'
-                            )
-                        {
-                            $ParamItem->{'Option'} = $Self->{LayoutObject}->OptionStrgHashRef(
-                                %Preference, %{$ParamItem},
-                            );
-                        }
-                        $Self->{LayoutObject}->Block(
-                            Name => $ParamItem->{Block} || 'Option',
-                            Data => { %Preference, %{$ParamItem}, },
-                        );
-                    }
-                }
-            }
-            else {
+            if ( !$Self->{MainObject}->Require($Module) ) {
                 return $Self->{LayoutObject}->FatalError();
             }
+            my $Object = $Module->new(
+                %{$Self},
+                ConfigItem => $Preferences{$Group},
+                Debug      => $Self->{Debug},
+            );
+            my @Params = $Object->Param( UserData => $Param{UserData} );
+            next if !@Params;
+
+            # show item
+            $Self->{LayoutObject}->Block(
+                Name => 'Item',
+                Data => {
+                    Group => $Group,
+                    %Preference,
+                },
+            );
+            for my $ParamItem (@Params) {
+                if ( ref $ParamItem->{Data} eq 'HASH' || ref $Preference{Data} eq 'HASH' ) {
+                    $ParamItem->{Option} = $Self->{LayoutObject}->BuildSelection(
+                        %Preference, %{$ParamItem},
+                    );
+                }
+                $Self->{LayoutObject}->Block(
+                    Name => 'Block',
+                    Data => { %Preference, %{$ParamItem}, },
+                );
+                $Self->{LayoutObject}->Block(
+                    Name => $ParamItem->{Block} || $Preference{Block} || 'Option',
+                    Data => { %Preference, %{$ParamItem}, },
+                );
+            }
         }
     }
 
     # create & return output
     return $Self->{LayoutObject}->Output(
-        TemplateFile => 'CustomerPreferencesForm',
+        TemplateFile => 'CustomerPreferences',
         Data         => \%Param
     );
 }
