@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/CustomerTicketZoom.pm - to get a closer view
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: CustomerTicketZoom.pm,v 1.75.2.2 2011/09/07 22:16:03 en Exp $
+# $Id: CustomerTicketZoom.pm,v 1.88 2012/01/27 12:29:12 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,9 +16,13 @@ use warnings;
 
 use Kernel::System::Web::UploadCache;
 use Kernel::System::State;
+use Kernel::System::User;
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.75.2.2 $) [1];
+$VERSION = qw($Revision: 1.88 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -39,9 +43,13 @@ sub new {
         }
     }
 
+    $Self->{AgentUserObject} = Kernel::System::User->new(%Param);
+
     # needed objects
-    $Self->{StateObject}       = Kernel::System::State->new(%Param);
-    $Self->{UploadCacheObject} = Kernel::System::Web::UploadCache->new(%Param);
+    $Self->{StateObject}        = Kernel::System::State->new(%Param);
+    $Self->{UploadCacheObject}  = Kernel::System::Web::UploadCache->new(%Param);
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
 
     # get form id
     $Self->{FormID} = $Self->{ParamObject}->GetParam( Param => 'FormID' );
@@ -53,12 +61,23 @@ sub new {
 
     $Self->{Config} = $Self->{ConfigObject}->Get("Ticket::Frontend::$Self->{Action}");
 
+    # get dynamic field config for frontend module
+    $Self->{DynamicFieldFilter} = $Self->{Config}->{DynamicField};
+
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    # ticket id lookup
+    if ( !$Self->{TicketID} && $Self->{ParamObject}->GetParam( Param => 'TicketNumber' ) ) {
+        $Self->{TicketID} = $Self->{TicketObject}->TicketIDLookup(
+            TicketNumber => $Self->{ParamObject}->GetParam( Param => 'TicketNumber' ),
+            UserID => $Self->{UserID},
+        );
+    }
+
     # check needed stuff
     if ( !$Self->{TicketID} ) {
         my $Output = $Self->{LayoutObject}->CustomerHeader( Title => 'Error' );
@@ -89,7 +108,10 @@ sub Run {
     }
 
     # get ticket data
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Self->{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Self->{TicketID},
+        DynamicFields => 0,
+    );
 
     # strip html and ascii attachments of content
     my $StripPlainBodyAsAttachment = 1;
@@ -99,13 +121,14 @@ sub Run {
         $StripPlainBodyAsAttachment = 2;
     }
 
-    # get all article of this ticket
+    # get all articles of this ticket
     my @CustomerArticleTypes = $Self->{TicketObject}->ArticleTypeList( Type => 'Customer' );
     my @ArticleBox = $Self->{TicketObject}->ArticleContentIndex(
         TicketID                   => $Self->{TicketID},
         ArticleType                => \@CustomerArticleTypes,
         StripPlainBodyAsAttachment => $StripPlainBodyAsAttachment,
         UserID                     => $Self->{UserID},
+        DynamicFields              => 0,
     );
 
     # get params
@@ -153,7 +176,7 @@ sub Run {
                 =~ s/(^>.+|.{4,$Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaNote')})(?:\s|\z)/$1\n/gm;
         }
 
-        # If is an action about attachments
+        # for attachment actions
         my $IsUpload = 0;
 
         # attachment delete
@@ -208,14 +231,36 @@ sub Run {
             return $Output;
         }
 
+        # unlock ticket if agent is on vacation
+        my $LockAction;
+        if ( $Ticket{OwnerID} ) {
+            my %User = $Self->{AgentUserObject}->GetUserData(
+                UserID => $Ticket{OwnerID},
+            );
+            if ( %User && $User{OutOfOffice} && $User{OutOfOfficeMessage} ) {
+                $LockAction = 'unlock';
+            }
+        }
+
         # set lock if ticket was closed
-        if ( $Lock && $State{TypeName} =~ /^close/i && $Ticket{OwnerID} ne '1' ) {
+        if (
+            !$LockAction
+            && $Lock
+            && $State{TypeName} =~ /^close/i && $Ticket{OwnerID} ne '1'
+            )
+        {
+
+            $LockAction = 'lock';
+        }
+
+        if ($LockAction) {
             $Self->{TicketObject}->TicketLockSet(
                 TicketID => $Self->{TicketID},
-                Lock     => 'lock',
-                UserID   => => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
+                Lock     => $LockAction,
+                UserID   => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
             );
         }
+
         my $From = "$Self->{UserFirstname} $Self->{UserLastname} <$Self->{UserEmail}>";
 
         my $MimeType = 'text/plain';
@@ -445,7 +490,12 @@ sub _Mask {
             Name => 'Service',
             Data => \%Param,
         );
-        if ( $Param{SLA} ) {
+        if (
+            $Param{SLA}
+            && $Self->{ConfigObject}->Get('Ticket::Service')
+            && $Self->{Config}->{AttributesView}->{SLA}
+            )
+        {
             $Self->{LayoutObject}->Block(
                 Name => 'SLA',
                 Data => \%Param,
@@ -498,40 +548,52 @@ sub _Mask {
         );
     }
 
-    # ticket free text
-    for my $Count ( 1 .. 16 ) {
-        next if !$Param{ 'TicketFreeText' . $Count };
-        next if !$Self->{Config}->{AttributesView}->{ 'TicketFreeText' . $Count };
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeText' . $Count,
-            Data => \%Param,
+    # get the dynamic fields for ticket object
+    my $DynamicField = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid       => 1,
+        ObjectType  => ['Ticket'],
+        FieldFilter => $Self->{DynamicFieldFilter} || {},
+    );
+
+    # cycle trough the activated Dynamic Fields for ticket object
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{$DynamicField} ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+        my $Value = $Self->{BackendObject}->ValueGet(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            ObjectID           => $Param{TicketID},
         );
+
+        next DYNAMICFIELD if !$Value;
+        next DYNAMICFIELD if $Value eq "";
+
+        # get print string for this dynamic field
+        my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Value              => $Value,
+            ValueMaxChars      => 25,
+            LayoutObject       => $Self->{LayoutObject},
+        );
+
+        my $Label = $DynamicFieldConfig->{Label};
+
         $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeText',
+            Name => 'TicketDynamicField',
             Data => {
-                %Param,
-                TicketFreeKey  => $Param{ 'TicketFreeKey' . $Count },
-                TicketFreeText => $Param{ 'TicketFreeText' . $Count },
-                Count          => $Count,
+                Label => $Label,
+                Value => $ValueStrg->{Value},
+                Title => $ValueStrg->{Title},
             },
         );
-    }
 
-    # ticket free time
-    for my $Count ( 1 .. 6 ) {
-        next if !$Param{ 'TicketFreeTime' . $Count };
-        next if !$Self->{Config}->{AttributesView}->{ 'TicketFreeTime' . $Count };
+        # example of dynamic fields order customization
         $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeTime' . $Count,
-            Data => \%Param,
-        );
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeTime',
+            Name => 'TicketDynamicField_' . $DynamicFieldConfig->{Name},
             Data => {
-                %Param,
-                TicketFreeTimeKey => $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count ),
-                TicketFreeTime    => $Param{ 'TicketFreeTime' . $Count },
-                Count             => $Count,
+                Label => $Label,
+                Value => $ValueStrg->{Value},
+                Title => $ValueStrg->{Title},
             },
         );
     }
@@ -599,15 +661,52 @@ sub _Mask {
             );
         }
 
-        # show article free text
-        for my $Count ( 1 .. 3 ) {
-            next if !$Article{ 'ArticleFreeText' . $Count };
-            next if !$Self->{Config}->{AttributesView}->{ 'ArticleFreeText' . $Count };
+        # get the dynamic fields for article object
+        my $DynamicField = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+            Valid       => 1,
+            ObjectType  => ['Article'],
+            FieldFilter => $Self->{DynamicFieldFilter} || {},
+        );
+
+        # cycle trough the activated Dynamic Fields for ticket object
+        DYNAMICFIELD:
+        for my $DynamicFieldConfig ( @{$DynamicField} ) {
+            next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+            my $Value = $Self->{BackendObject}->ValueGet(
+                DynamicFieldConfig => $DynamicFieldConfig,
+                ObjectID           => $Article{ArticleID},
+            );
+
+            next DYNAMICFIELD if !$Value;
+            next DYNAMICFIELD if $Value eq "";
+
+            # get print string for this dynamic field
+            my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
+                DynamicFieldConfig => $DynamicFieldConfig,
+                Value              => $Value,
+                ValueMaxChars      => 160,
+                LayoutObject       => $Self->{LayoutObject},
+            );
+
+            my $Label = $DynamicFieldConfig->{Label};
+
             $Self->{LayoutObject}->Block(
-                Name => 'ArticleFreeText',
+                Name => 'ArticleDynamicField',
                 Data => {
-                    Key   => $Article{ 'ArticleFreeKey' . $Count },
-                    Value => $Article{ 'ArticleFreeText' . $Count },
+                    Label => $Label,
+                    Value => $ValueStrg->{Value},
+                    Title => $ValueStrg->{Title},
+                },
+            );
+
+            # example of dynamic fields order customization
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleDynamicField_' . $DynamicFieldConfig->{Name},
+                Data => {
+                    Label => $Label,
+                    Value => $ValueStrg->{Value},
+                    Title => $ValueStrg->{Title},
                 },
             );
         }
@@ -648,11 +747,20 @@ sub _Mask {
                 );
             }
             else {
+                my $SessionInformation;
+
+                # Append session information to URL if needed
+                if ( !$Self->{LayoutObject}->{SessionIDCookie} ) {
+                    $SessionInformation = $Self->{LayoutObject}->{SessionName} . '='
+                        . $Self->{LayoutObject}->{SessionID};
+                }
+
                 $Self->{LayoutObject}->Block(
                     Name => 'BodyHTMLPlaceholder',
                     Data => {
                         %Param,
                         %Article,
+                        SessionInformation => $SessionInformation,
                     },
                 );
             }
