@@ -1,8 +1,8 @@
 # --
 # Kernel/Output/HTML/ArticleCheckSMIME.pm
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: ArticleCheckSMIME.pm,v 1.20.6.4 2011/04/08 19:32:59 dz Exp $
+# $Id: ArticleCheckSMIME.pm,v 1.28.2.1 2012/05/04 09:05:18 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::Crypt;
 use Kernel::System::EmailParser;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.20.6.4 $) [1];
+$VERSION = qw($Revision: 1.28.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -160,7 +160,7 @@ sub Check {
                 my @PrivateKeysResult
                     = $Self->{CryptObject}->PrivateSearch( Search => $EmailAddress, );
                 for my $Cert (@PrivateKeysResult) {
-                    $PrivateKeys{ $Cert->{Hash} } = $Cert;
+                    $PrivateKeys{ $Cert->{Filename} } = $Cert;
                 }
             }
 
@@ -170,7 +170,7 @@ sub Check {
                     @Return,
                     {
                         Key   => 'Crypted',
-                        Value => 'Impossible to decrypt: private key for email doesn\'t found!',
+                        Value => 'Impossible to decrypt: private key for email was not found!',
                     }
                 );
                 return @Return;
@@ -189,46 +189,29 @@ sub Check {
                 last PRIVATESEARCH if ( $Decrypt{Successful} );
             }
 
+            # ok, decryption went fine
             if ( $Decrypt{Successful} ) {
 
-                # updated article body
-                $Self->{TicketObject}->ArticleUpdate(
-                    TicketID  => $Param{Article}->{TicketID},
-                    ArticleID => $Self->{ArticleID},
-                    Key       => 'Body',
-                    Value     => $Decrypt{Data},
-                    UserID    => $Self->{UserID},
-                );
-
-                # delete crypted attachments
-                $Self->{TicketObject}->ArticleDeleteAttachment(
-                    ArticleID => $Self->{ArticleID},
-                    UserID    => $Self->{UserID},
-                );
-
                 push(
                     @Return,
                     {
                         Key => 'Crypted',
-                        Value => $Decrypt{Message} || 'Successfull decryption',
+                        Value => $Decrypt{Message} || 'Successful decryption',
                         %Decrypt,
                     }
                 );
 
+                # store decrypted data
+                my $EmailContent = $Decrypt{Data};
+
+                # now check if the data contains a signature too
                 %SignCheck = $Self->{CryptObject}->Verify( Message => $Decrypt{Data}, );
+
                 if ( $SignCheck{SignatureFound} ) {
 
-                    if ( $SignCheck{Successful} ) {
-
-                        # updated article body
-                        $Self->{TicketObject}->ArticleUpdate(
-                            TicketID  => $Param{Article}->{TicketID},
-                            ArticleID => $Self->{ArticleID},
-                            Key       => 'Body',
-                            Value     => $SignCheck{Content},
-                            UserID    => $Self->{UserID},
-                        );
-                    }
+                  # If the signature was verified well, use the stripped content to store the email.
+                  #   Now it contains only the email without other SMIME generated data.
+                    $EmailContent = $SignCheck{Content} if $SignCheck{Successful};
 
                     push(
                         @Return,
@@ -239,6 +222,38 @@ sub Check {
                         }
                     );
                 }
+
+                # parse the decrypted email body
+                my $ParserObject
+                    = Kernel::System::EmailParser->new( %{$Self}, Email => $EmailContent );
+                my $Body = $ParserObject->GetMessageBody();
+
+                # updated article body
+                $Self->{TicketObject}->ArticleUpdate(
+                    TicketID  => $Param{Article}->{TicketID},
+                    ArticleID => $Self->{ArticleID},
+                    Key       => 'Body',
+                    Value     => $Body,
+                    UserID    => $Self->{UserID},
+                );
+
+                # delete crypted attachments
+                $Self->{TicketObject}->ArticleDeleteAttachment(
+                    ArticleID => $Self->{ArticleID},
+                    UserID    => $Self->{UserID},
+                );
+
+                # write attachments to the storage
+                for my $Attachment ( $ParserObject->GetAttachments() ) {
+                    $Self->{TicketObject}->ArticleWriteAttachment(
+                        Content     => $Attachment->{Content},
+                        Filename    => $Attachment->{Filename},
+                        ContentType => $Attachment->{ContentType},
+                        ArticleID   => $Self->{ArticleID},
+                        UserID      => $Self->{UserID},
+                    );
+                }
+
                 return @Return;
             }
             else {
