@@ -1,12 +1,12 @@
 # --
 # Kernel/Output/HTML/CustomerNewTicketQueueSelectionGeneric.pm
-# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: CustomerNewTicketQueueSelectionGeneric.pm,v 1.7 2008/05/08 09:36:57 mh Exp $
+# $Id: CustomerNewTicketQueueSelectionGeneric.pm,v 1.10 2011/12/05 18:13:48 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::CustomerNewTicketQueueSelectionGeneric;
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.7 $) [1];
+$VERSION = qw($Revision: 1.10 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -39,7 +39,7 @@ sub Run {
     my ( $Self, %Param ) = @_;
 
     # check if own selection is configured
-    my %NewTos = ();
+    my %NewTos;
     if ( $Self->{ConfigObject}->{CustomerPanelOwnSelection} ) {
         for my $Queue ( keys %{ $Self->{ConfigObject}->{CustomerPanelOwnSelection} } ) {
             my $Value = $Self->{ConfigObject}->{CustomerPanelOwnSelection}->{$Queue};
@@ -58,6 +58,7 @@ sub Run {
 
         # check create permissions
         my %Queues = $Self->{TicketObject}->MoveList(
+            %{ $Param{ACLParams} },
             CustomerUserID => $Param{Env}->{UserID},
             Type           => 'create',
             Action         => $Param{Env}->{Action},
@@ -71,9 +72,10 @@ sub Run {
     else {
 
         # SelectionType Queue or SystemAddress?
-        my %Tos = ();
+        my %Tos;
         if ( $Self->{ConfigObject}->Get('CustomerPanelSelectionType') eq 'Queue' ) {
             %Tos = $Self->{TicketObject}->MoveList(
+                %{ $Param{ACLParams} },
                 CustomerUserID => $Param{Env}->{UserID},
                 Type           => 'create',
                 Action         => $Param{Env}->{Action},
@@ -81,6 +83,7 @@ sub Run {
         }
         else {
             my %Queues = $Self->{TicketObject}->MoveList(
+                %{ $Param{ACLParams} },
                 CustomerUserID => $Param{Env}->{UserID},
                 Type           => 'create',
                 Action         => $Param{Env}->{Action},
@@ -115,7 +118,7 @@ sub Run {
             $NewTos{$QueueID} = $String;
         }
     }
-    return (%NewTos);
+    return %NewTos;
 }
 
 1;
