@@ -1,8 +1,8 @@
 # --
 # Kernel/Output/HTML/LayoutTicket.pm - provides generic ticket HTML output
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: LayoutTicket.pm,v 1.123.2.4 2011/06/15 09:19:58 mg Exp $
+# $Id: LayoutTicket.pm,v 1.141.2.1 2012/05/22 10:41:55 mab Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.123.2.4 $) [1];
+$VERSION = qw($Revision: 1.141.2.1 $) [1];
 
 sub AgentCustomerViewTable {
     my ( $Self, %Param ) = @_;
@@ -107,6 +107,9 @@ sub AgentCustomerViewTable {
                 if ( $Field->[8] ) {
                     $Record{LinkStart} .= " target=\"$Field->[8]\"";
                 }
+                if ( $Field->[9] ) {
+                    $Record{LinkStart} .= " class=\"$Field->[9]\"";
+                }
                 $Record{LinkStart} .= "\">";
                 $Record{LinkStop} = "</a>";
             }
@@ -168,16 +171,17 @@ sub AgentCustomerViewTable {
 # !! DONT USE THIS FUNCTION !! Use BuildSelection() instead.
 #
 # Due to compatibility reason this function is still in use and will be removed
-# in a further release.
+# in a future release.
 
 sub AgentQueueListOption {
     my ( $Self, %Param ) = @_;
 
-    my $Size       = $Param{Size}                  ? "size='$Param{Size}'" : '';
-    my $MaxLevel   = defined( $Param{MaxLevel} )   ? $Param{MaxLevel}      : 10;
-    my $SelectedID = defined( $Param{SelectedID} ) ? $Param{SelectedID}    : '';
-    my $Selected   = defined( $Param{Selected} )   ? $Param{Selected}      : '';
-    my $Class      = defined( $Param{Class} )      ? $Param{Class}         : '';
+    my $Size           = $Param{Size}                      ? "size='$Param{Size}'"  : '';
+    my $MaxLevel       = defined( $Param{MaxLevel} )       ? $Param{MaxLevel}       : 10;
+    my $SelectedID     = defined( $Param{SelectedID} )     ? $Param{SelectedID}     : '';
+    my $Selected       = defined( $Param{Selected} )       ? $Param{Selected}       : '';
+    my $CurrentQueueID = defined( $Param{CurrentQueueID} ) ? $Param{CurrentQueueID} : '';
+    my $Class          = defined( $Param{Class} )          ? $Param{Class}          : '';
     my $SelectedIDRefArray = $Param{SelectedIDRefArray} || '';
     my $Multiple       = $Param{Multiple}                  ? 'multiple = "multiple"' : '';
     my $OptionTitle    = defined( $Param{OptionTitle} )    ? $Param{OptionTitle}     : 0;
@@ -225,6 +229,7 @@ sub AgentQueueListOption {
             HTMLQuote     => 0,
             SelectedID    => $Param{SelectedID} || $Param{SelectedIDRefArray} || '',
             SelectedValue => $Param{Selected},
+            Translation   => 0,
         );
         return $Param{MoveQueuesStrg};
     }
@@ -283,7 +288,20 @@ sub AgentQueueListOption {
                 # integrate the not selectable parent and root queues of this queue
                 # useful for ACLs and complex permission settings
                 for my $Index ( 0 .. ( scalar @Queue - 2 ) ) {
-                    if ( !$DisabledQueueAlreadyUsed{ $Queue[$Index] } ) {
+
+                    # get the Full Queue Name (with all it's parents separed by '::') this will
+                    # make a unique name and will be used to set the %DisabledQueueAlreadyUsed
+                    # using unique names will prevent erroneous hide of Sub-Queues with the
+                    # same name, refer to bug#8148
+                    my $FullQueueName;
+                    for my $Counter ( 0 .. $Index ) {
+                        $FullQueueName .= $Queue[$Counter];
+                        if ( int $Counter < int $Index ) {
+                            $FullQueueName .= '::';
+                        }
+                    }
+
+                    if ( !$DisabledQueueAlreadyUsed{$FullQueueName} ) {
                         my $DSpace               = '&nbsp;&nbsp;' x $Index;
                         my $OptionTitleHTMLValue = '';
                         if ($OptionTitle) {
@@ -299,7 +317,7 @@ sub AgentQueueListOption {
                             . $DSpace
                             . $Queue[$Index]
                             . "</option>\n";
-                        $DisabledQueueAlreadyUsed{ $Queue[$Index] } = 1;
+                        $DisabledQueueAlreadyUsed{$FullQueueName} = 1;
                     }
                 }
             }
@@ -326,6 +344,14 @@ sub AgentQueueListOption {
                     . $String
                     . "</option>\n";
             }
+            elsif ( $CurrentQueueID eq $_ )
+            {
+                $Param{MoveQueuesStrg}
+                    .= '<option value="-" disabled="disabled"'
+                    . $OptionTitleHTMLValue . '>'
+                    . $String
+                    . "</option>\n";
+            }
             else {
                 $Param{MoveQueuesStrg}
                     .= '<option value="'
@@ -341,497 +367,6 @@ sub AgentQueueListOption {
     return $Param{MoveQueuesStrg};
 }
 
-sub AgentFreeText {
-    my ( $Self, %Param ) = @_;
-
-    my %NullOption;
-    my %SelectData;
-    my %Ticket;
-    my %Config;
-    my $Class = '';
-    if ( $Param{NullOption} ) {
-
-        #        $NullOption{''} = '-';
-        $SelectData{Size}     = 3;
-        $SelectData{Multiple} = 1;
-    }
-    if ( $Param{Ticket} ) {
-        %Ticket = %{ $Param{Ticket} };
-    }
-    if ( $Param{Config} ) {
-        %Config = %{ $Param{Config} };
-    }
-    if ( $Param{Class} ) {
-        $Class = $Param{Class};
-    }
-    my %Data;
-    for ( 1 .. 16 ) {
-
-        # key
-        if ( ref $Config{"TicketFreeKey$_"} eq 'HASH' && %{ $Config{"TicketFreeKey$_"} } ) {
-            my $Counter = 0;
-            my $LastKey = '';
-            for ( keys %{ $Config{"TicketFreeKey$_"} } ) {
-                $Counter++;
-                $LastKey = $_;
-            }
-            if ( $Counter == 1 && $Param{NullOption} ) {
-                if ($LastKey) {
-                    $Data{"TicketFreeKeyField$_"} = $Config{"TicketFreeKey$_"}->{$LastKey};
-                }
-            }
-            elsif ( $Counter > 1 ) {
-                $Data{"TicketFreeKeyField$_"} = $Self->BuildSelection(
-                    Data => { %NullOption, %{ $Config{"TicketFreeKey$_"} }, },
-                    Name => "TicketFreeKey$_",
-                    SelectedID  => $Ticket{"TicketFreeKey$_"},
-                    Translation => 0,
-                    Class       => 'TicketFreeKey',
-                    HTMLQuote   => 1,
-                    %SelectData,
-                );
-            }
-            else {
-                if ($LastKey) {
-                    $Data{"TicketFreeKeyField$_"}
-                        = $Config{"TicketFreeKey$_"}->{$LastKey}
-                        . '<input type="hidden" name="TicketFreeKey'
-                        . $_
-                        . '" value="'
-                        . $Self->Ascii2Html( Text => $LastKey ) . '"/>';
-                }
-            }
-        }
-        else {
-            if ( defined $Ticket{"TicketFreeKey$_"} ) {
-                if ( ref $Ticket{"TicketFreeKey$_"} eq 'ARRAY' ) {
-                    if ( $Ticket{"TicketFreeKey$_"}->[0] ) {
-                        $Ticket{"TicketFreeKey$_"} = $Ticket{"TicketFreeKey$_"}->[0];
-                    }
-                    else {
-                        $Ticket{"TicketFreeKey$_"} = '';
-                    }
-                }
-                $Data{"TicketFreeKeyField$_"}
-                    = '<input type="text" class="TicketFreeKey" name="TicketFreeKey'
-                    . $_
-                    . '" value="'
-                    . $Self->Ascii2Html( Text => $Ticket{"TicketFreeKey$_"} )
-                    . '" />';
-            }
-            else {
-                $Data{"TicketFreeKeyField$_"}
-                    = '<input type="text" class="TicketFreeKey" name="TicketFreeKey' . $_
-                    . '" value="" />';
-            }
-        }
-
-        # Add Validate and Error classes
-        my $ClassParam = "$Class ";
-        my $DataParam  = "";
-        if ( $Config{"Required"}->{$_} ) {
-            $ClassParam .= 'Validate_Required';
-            if ( ref $Config{"TicketFreeText$_"} eq 'HASH' ) {
-                $ClassParam .= 'Dropdown';
-            }
-            $ClassParam .= ' ';
-
-            $DataParam
-                .= '<div id="TicketFreeText'
-                . $_
-                . 'Error" class="TooltipErrorMessage"><p>$Text{"This field is required."}</p></div>';
-
-            # for TicketFreeKeyFields
-            $Data{"TicketFreeKeyField$_"} =
-                '<label id="LabelTicketFreeText' . $_
-                . '" class="Mandatory"><span class="Marker">*</span> '
-                . $Data{"TicketFreeKeyField$_"}
-                . ':</label>';
-        }
-        else {
-
-            # for TicketFreeKeyFields
-            $Data{"TicketFreeKeyField$_"} =
-                '<label id="LabelTicketFreeText' . $_ . '">'
-                . $Data{"TicketFreeKeyField$_"}
-                . ':</label>';
-        }
-
-        if ( $Config{"Error"}->{$_} ) {
-            $ClassParam .= 'ServerError ';
-            $DataParam
-                .= '<div id="TicketFreeText'
-                . $_
-                . 'ServerError" class="TooltipErrorMessage"><p>$Text{"This field is required."}</p></div>';
-        }
-
-        # value
-        if ( ref $Config{"TicketFreeText$_"} eq 'HASH' ) {
-            $Data{"TicketFreeTextField$_"} = $Self->BuildSelection(
-                Data => { %NullOption, %{ $Config{"TicketFreeText$_"} }, },
-                Name => "TicketFreeText$_",
-                SelectedID  => $Ticket{"TicketFreeText$_"},
-                Translation => 0,
-                HTMLQuote   => 1,
-                Class       => "TicketFreeText $ClassParam",
-                %SelectData,
-            );
-
-            $Data{"TicketFreeTextField$_"} .= $DataParam;
-
-        }
-        else {
-            if ( defined $Ticket{"TicketFreeText$_"} ) {
-                if ( ref $Ticket{"TicketFreeText$_"} eq 'ARRAY' ) {
-                    if ( $Ticket{"TicketFreeText$_"}->[0] ) {
-                        $Ticket{"TicketFreeText$_"} = $Ticket{"TicketFreeText$_"}->[0];
-                    }
-                    else {
-                        $Ticket{"TicketFreeText$_"} = '';
-                    }
-                }
-                $Data{"TicketFreeTextField$_"}
-                    = '<input type="text" class="TicketFreeText '
-                    . $ClassParam
-                    . '" name="TicketFreeText'
-                    . $_
-                    . '" id="TicketFreeText'
-                    . $_
-                    . '" value="'
-                    . $Self->Ascii2Html( Text => $Ticket{"TicketFreeText$_"} )
-                    . '" />';
-
-                $Data{"TicketFreeTextField$_"} .= $DataParam;
-
-            }
-            else {
-                $Data{"TicketFreeTextField$_"}
-                    = '<input type="text" class="TicketFreeText ' . $ClassParam
-                    . '" name="TicketFreeText'
-                    . $_
-                    . '" id="TicketFreeText'
-                    . $_
-                    . '" value="" />';
-
-                $Data{"TicketFreeTextField$_"} .= $DataParam;
-            }
-        }
-    }
-    return %Data;
-}
-
-sub AgentFreeDate {
-    my ( $Self, %Param ) = @_;
-
-    my %NullOption;
-    my %SelectData;
-    my %Ticket;
-    my %Config;
-    my $Class = '';
-    if ( $Param{NullOption} ) {
-        $SelectData{Size}     = 3;
-        $SelectData{Multiple} = 1;
-    }
-    if ( $Param{Ticket} ) {
-        %Ticket = %{ $Param{Ticket} };
-    }
-    if ( $Param{Config} ) {
-        %Config = %{ $Param{Config} };
-    }
-    if ( $Param{Class} ) {
-        $Class = $Param{Class};
-    }
-    my %Data;
-    for my $Count ( 1 .. 6 ) {
-        my %TimePeriod;
-        if ( $Self->{ConfigObject}->Get( 'TicketFreeTimePeriod' . $Count ) ) {
-            %TimePeriod = %{ $Self->{ConfigObject}->Get( 'TicketFreeTimePeriod' . $Count ) };
-        }
-
-        $Data{ 'TicketFreeTime' . $Count } = $Self->BuildDateSelection(
-            %Param,
-            %Ticket,
-            Prefix                              => 'TicketFreeTime' . $Count,
-            Format                              => 'DateInputFormatLong',
-            'TicketFreeTime' . $Count . 'Class' => $Class,
-            DiffTime => $Self->{ConfigObject}->Get( 'TicketFreeTimeDiff' . $Count ) || 0,
-            %TimePeriod,
-            Validate => 1,
-            Required => $Param{'Ticket'}->{ 'TicketFreeTime' . $Count . 'Required' } ? 1 : 0,
-        );
-
-        if ( $Param{'Ticket'}->{ 'TicketFreeTime' . $Count . 'Required' } ) {
-            $Data{ 'TicketFreeTimeKey' . $Count } =
-                '<label class="Mandatory" id="LabelTicketFreeTime'
-                . $Count
-                . '"'
-                . ' for="TicketFreeTime'
-                . $Count
-                . 'Used">'
-                . '<span class="Marker">*</span> '
-                . '$Text{"'
-                . $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count )
-                . '"}'
-                . ':</label>';
-        }
-        else {
-            $Data{ 'TicketFreeTimeKey' . $Count } =
-                '<label id="LabelTicketFreeTime'
-                . $Count
-                . '"'
-                . ' for="TicketFreeTime'
-                . $Count
-                . 'Used">'
-                . '$Text{"'
-                . $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count )
-                . '"}'
-                . ':</label>';
-        }
-    }
-    return %Data;
-}
-
-sub TicketArticleFreeText {
-    my ( $Self, %Param ) = @_;
-
-    my %NullOption;
-    my %SelectData;
-    my %Article;
-    my %Config;
-    my $Class = '';
-    if ( $Param{NullOption} ) {
-        $SelectData{Size}     = 3;
-        $SelectData{Multiple} = 1;
-    }
-    if ( $Param{Article} ) {
-        %Article = %{ $Param{Article} };
-    }
-    if ( $Param{Config} ) {
-        %Config = %{ $Param{Config} };
-    }
-    if ( $Param{Class} ) {
-        $Class = $Param{Class};
-    }
-    my %Data;
-    for ( 1 .. 3 ) {
-
-        # key
-        if ( ref $Config{"ArticleFreeKey$_"} eq 'HASH' && %{ $Config{"ArticleFreeKey$_"} } ) {
-            my $Counter = 0;
-            my $LastKey = '';
-            for ( keys %{ $Config{"ArticleFreeKey$_"} } ) {
-                $Counter++;
-                $LastKey = $_;
-            }
-            if ( $Counter == 1 && $Param{NullOption} ) {
-                if ($LastKey) {
-                    $Data{"ArticleFreeKeyField$_"} = $Config{"ArticleFreeKey$_"}->{$LastKey};
-                }
-            }
-            elsif ( $Counter > 1 ) {
-                $Data{"ArticleFreeKeyField$_"} = $Self->BuildSelection(
-                    Data => { %NullOption, %{ $Config{"ArticleFreeKey$_"} }, },
-                    Name => "ArticleFreeKey$_",
-                    SelectedValue => $Article{"ArticleFreeKey$_"},
-                    Translation   => 0,
-                    Class         => 'ArticleFreeKey',
-                    HTMLQuote     => 1,
-                    %SelectData,
-                );
-            }
-            else {
-                if ($LastKey) {
-                    $Data{"ArticleFreeKeyField$_"}
-                        = $Config{"ArticleFreeKey$_"}->{$LastKey}
-                        . '<input type="hidden" name="ArticleFreeKey'
-                        . $_
-                        . '" value="'
-                        . $Self->Ascii2Html( Text => $LastKey ) . '"/>';
-                }
-            }
-        }
-        else {
-            if ( defined $Article{"ArticleFreeKey$_"} ) {
-                if ( ref $Article{"ArticleFreeKey$_"} eq 'ARRAY' ) {
-                    if ( $Article{"ArticleFreeKey$_"}->[0] ) {
-                        $Article{"ArticleFreeKey$_"} = $Article{"ArticleFreeKey$_"}->[0];
-                    }
-                    else {
-                        $Article{"ArticleFreeKey$_"} = '';
-                    }
-                }
-                $Data{"ArticleFreeKeyField$_"}
-                    = '<input type="text" class="ArticleFreeKey" name="ArticleFreeKey'
-                    . $_
-                    . '" value="'
-                    . $Self->Ascii2Html( Text => $Article{"ArticleFreeKey$_"} )
-                    . '" />';
-            }
-            else {
-                $Data{"ArticleFreeKeyField$_"}
-                    = '<input type="text" class="ArticleFreeKey" name="ArticleFreeKey' . $_
-                    . '" value="" />';
-            }
-        }
-
-        # Add Validate and Error classes
-        my $ClassParam = "$Class ";
-        my $DataParam  = "";
-        if ( $Config{"Required"}->{$_} ) {
-            $ClassParam .= 'Validate_Required';
-            if ( ref $Config{"ArticleFreeText$_"} eq 'HASH' ) {
-                $ClassParam .= 'Dropdown';
-            }
-            $ClassParam .= ' ';
-
-            $DataParam
-                .= '<div id="ArticleFreeText'
-                . $_
-                . 'Error" class="TooltipErrorMessage"><p>$Text{"This field is required."}</p></div>';
-
-            # for ArticleFreeKeyField
-            $Data{"ArticleFreeKeyField$_"} =
-                '<label id="LabelArticleFreeText' . $_
-                . '" class="Mandatory"><span class="Marker">*</span> '
-                . $Data{"ArticleFreeKeyField$_"}
-                . ':</label>';
-        }
-        else {
-
-            # for ArticleFreeKeyField
-            $Data{"ArticleFreeKeyField$_"} =
-                '<label id="LabelArticleFreeText' . $_ . '">'
-                . $Data{"ArticleFreeKeyField$_"}
-                . ':</label>';
-        }
-
-        if ( $Config{"Error"}->{$_} ) {
-            $ClassParam .= 'ServerError ';
-            $DataParam
-                .= '<div id="ArticleFreeText'
-                . $_
-                . 'ServerError" class="TooltipErrorMessage"><p>$Text{"This field is required."}</p></div>';
-        }
-
-        # value
-        if ( ref $Config{"ArticleFreeText$_"} eq 'HASH' ) {
-            $Data{"ArticleFreeTextField$_"} = $Self->BuildSelection(
-                Data => { %NullOption, %{ $Config{"ArticleFreeText$_"} }, },
-                Name => "ArticleFreeText$_",
-                SelectedValue => $Article{"ArticleFreeText$_"},
-                Translation   => 0,
-                HTMLQuote     => 1,
-                Class         => "ArticleFreeText $ClassParam",
-                %SelectData,
-            );
-
-            $Data{"ArticleFreeTextField$_"} .= $DataParam;
-        }
-        else {
-            if ( defined $Article{"ArticleFreeText$_"} ) {
-                if ( ref $Article{"ArticleFreeText$_"} eq 'ARRAY' ) {
-                    if ( $Article{"ArticleFreeText$_"}->[0] ) {
-                        $Article{"ArticleFreeText$_"} = $Article{"ArticleFreeText$_"}->[0];
-                    }
-                    else {
-                        $Article{"ArticleFreeText$_"} = '';
-                    }
-                }
-                $Data{"ArticleFreeTextField$_"}
-                    = '<input type="text" class="ArticleFreeText '
-                    . $ClassParam
-                    . '" name="ArticleFreeText'
-                    . $_
-                    . '" id="ArticleFreeText'
-                    . $_
-                    . '" value="'
-                    . $Self->Ascii2Html( Text => $Article{"ArticleFreeText$_"} )
-                    . '" />';
-
-                $Data{"ArticleFreeTextField$_"} .= $DataParam;
-            }
-            else {
-                $Data{"ArticleFreeTextField$_"}
-                    = '<input type="text" class="ArticleFreeText ' . $ClassParam
-                    . '" name="ArticleFreeText'
-                    . $_
-                    . '" id="ArticleFreeText'
-                    . $_
-                    . '" value="" />';
-
-                $Data{"ArticleFreeTextField$_"} .= $DataParam;
-            }
-        }
-    }
-    return %Data;
-}
-
-sub CustomerFreeDate {
-    my ( $Self, %Param ) = @_;
-
-    my %NullOption;
-    my %SelectData;
-    my %Ticket;
-    my %Config;
-    if ( $Param{NullOption} ) {
-        $SelectData{Size}     = 3;
-        $SelectData{Multiple} = 1;
-    }
-    if ( $Param{Ticket} ) {
-        %Ticket = %{ $Param{Ticket} };
-    }
-    if ( $Param{Config} ) {
-        %Config = %{ $Param{Config} };
-    }
-    my %Data;
-    for my $Count ( 1 .. 6 ) {
-        my %TimePeriod;
-        if ( $Self->{ConfigObject}->Get( 'TicketFreeTimePeriod' . $Count ) ) {
-            %TimePeriod = %{ $Self->{ConfigObject}->Get( 'TicketFreeTimePeriod' . $Count ) };
-        }
-
-        $Data{ 'TicketFreeTime' . $Count } = $Self->BuildDateSelection(
-            Area => 'Customer',
-            %Param,
-            %Ticket,
-            Prefix   => 'TicketFreeTime' . $Count,
-            Format   => 'DateInputFormatLong',
-            DiffTime => $Self->{ConfigObject}->Get( 'TicketFreeTimeDiff' . $Count ) || 0,
-            "TicketFreeTime${Count}Class" => 'DateSelection',
-            %TimePeriod,
-            Validate => 1,
-            Required => $Param{'Ticket'}->{ 'TicketFreeTime' . $Count . 'Required' } ? 1 : 0,
-        );
-
-        if ( $Param{'Ticket'}->{ 'TicketFreeTime' . $Count . 'Required' } ) {
-            $Data{ 'TicketFreeTimeKey' . $Count } =
-                '<label class="Mandatory" id="LabelTicketFreeTime'
-                . $Count
-                . '" for="TicketFreeTime'
-                . $Count
-                . 'Used">'
-                . '<span class="Marker">*</span> '
-                . '$Text{"'
-                . $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count )
-                . '"}'
-                . ':</label>';
-        }
-        else {
-            $Data{ 'TicketFreeTimeKey' . $Count } =
-                '<label id="LabelTicketFreeTime'
-                . $Count
-                . '" for="TicketFreeTime'
-                . $Count
-                . 'Used">'
-                . '$Text{"'
-                . $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count )
-                . '"}'
-                . ':</label>';
-        }
-    }
-    return %Data;
-}
-
 =item ArticleQuote()
 
 get body and attach e. g. inline documents and/or attach all attachments to
@@ -882,6 +417,7 @@ sub ArticleQuote {
             TicketID                   => $Param{TicketID},
             StripPlainBodyAsAttachment => 3,
             UserID                     => $Self->{UserID},
+            DynamicFields              => 0,
         );
 
         my %NotInlineAttachments;
@@ -937,12 +473,22 @@ sub ArticleQuote {
             my %Attachments = %{ $ArticleTmp->{Atms} };
             my %AttachmentAlreadyUsed;
             $Body =~ s{
-                "cid:(.*?)"
+                (=|"|')cid:(.*?)("|'|>|\/>|\s)
             }
             {
+                my $Start= $1;
+                my $ContentID = $2;
+                my $End = $3;
+
+                # improve html quality
+                if ( $Start ne '"' && $Start ne '\'' ) {
+                    $Start .= '"';
+                }
+                if ( $End ne '"' && $End ne '\'' ) {
+                    $End = '"' . $End;
+                }
 
                 # find attachment to include
-                my $ContentID = $1;
                 ATMCOUNT:
                 for my $AttachmentID ( sort keys %Attachments ) {
 
@@ -982,7 +528,7 @@ sub ArticleQuote {
                 }
 
                 # return link
-                '"' . $ContentID . '"';
+                $Start . $ContentID . $End;
             }egxi;
 
             # find inlines images using Content-Location instead of Content-ID
@@ -1002,7 +548,7 @@ sub ArticleQuote {
                 $AttachmentPicture{ContentID} =~ s/>$//;
 
                 $Body =~ s{
-                    (=|"|')(\Q$AttachmentPicture{ContentID}\E)("|'|>|\/>|\s)
+                    ("|')(\Q$AttachmentPicture{ContentID}\E)("|'|>|\/>|\s)
                 }
                 {
                     my $Start= $1;
@@ -1062,7 +608,10 @@ sub ArticleQuote {
     }
 
     # as fallback use text body for quote
-    my %Article = $Self->{TicketObject}->ArticleGet( ArticleID => $Param{ArticleID} );
+    my %Article = $Self->{TicketObject}->ArticleGet(
+        ArticleID     => $Param{ArticleID},
+        DynamicFields => 0,
+    );
 
     # check if original content isn't text/plain or text/html, don't use it
     if ( !$Article{ContentType} ) {
@@ -1140,11 +689,12 @@ sub TicketListShow {
         Value     => $View,
     );
 
-    # update preferences
-    if ( !$Self->{ConfigObject}->Get('DemoSystem') ) {
+    # update preferences if needed
+    my $Key = 'UserTicketOverview' . $Env->{Action};
+    if ( !$Self->{ConfigObject}->Get('DemoSystem') && $Self->{$Key} ne $View ) {
         $Self->{UserObject}->SetPreferences(
             UserID => $Self->{UserID},
-            Key    => 'UserTicketOverview' . $Env->{Action},
+            Key    => $Key,
             Value  => $View,
         );
     }
@@ -1170,7 +720,6 @@ sub TicketListShow {
             $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "No Config option found for view mode $View, took $Key instead!",
-                Message  => 'Need Depend Param Ajax option!',
             );
             $View = $Key;
             last;
@@ -1212,7 +761,7 @@ sub TicketListShow {
         %Data = %{ $Config->{$Group}->{Data} };
     }
 
-    # calculate max. sown page
+    # calculate max. shown per page
     if ( $StartHit > $Param{Total} ) {
         my $Pages = int( ( $Param{Total} / $PageShown ) + 0.99999 );
         $StartHit = ( ( $Pages - 1 ) * $PageShown ) + 1;
@@ -1230,14 +779,15 @@ sub TicketListShow {
         IDPrefix  => $Env->{LayoutObject}->{Action},
     );
 
-    # build shown ticket a page
+    # build shown ticket per page
     $Param{RequestedURL}    = "Action=$Self->{Action}";
     $Param{Group}           = $Group;
     $Param{PreferencesKey}  = $PageShownPreferencesKey;
     $Param{PageShownString} = $Self->BuildSelection(
-        Name       => $PageShownPreferencesKey,
-        SelectedID => $PageShown,
-        Data       => \%Data,
+        Name        => $PageShownPreferencesKey,
+        SelectedID  => $PageShown,
+        Translation => 0,
+        Data        => \%Data,
     );
 
     # nav bar at the beginning of a overview
@@ -1399,8 +949,6 @@ sub TicketListShow {
 sub TicketMetaItemsCount {
     my ( $Self, %Param ) = @_;
     return ( 'Priority', 'New Article' );
-
-    #    return ('New Article', 'Locked', 'Watched');
 }
 
 sub TicketMetaItems {
@@ -1414,106 +962,65 @@ sub TicketMetaItems {
     my @Result;
 
     # show priority
-    if (1) {
-        push @Result, {
+    push @Result, {
 
-            #            Image => $Image,
-            Title      => $Param{Ticket}->{Priority},
-            Class      => 'Flag',
-            ClassSpan  => 'PriorityID-' . $Param{Ticket}->{PriorityID},
-            ClassTable => 'Flags',
-        };
-    }
+        #            Image => $Image,
+        Title      => $Param{Ticket}->{Priority},
+        Class      => 'Flag',
+        ClassSpan  => 'PriorityID-' . $Param{Ticket}->{PriorityID},
+        ClassTable => 'Flags',
+    };
 
     # show new article
-    if (1) {
-        my %TicketFlag = $Self->{TicketObject}->TicketFlagGet(
-            TicketID => $Param{Ticket}->{TicketID},
-            UserID   => $Self->{UserID},
-        );
+    my %TicketFlag = $Self->{TicketObject}->TicketFlagGet(
+        TicketID => $Param{Ticket}->{TicketID},
+        UserID   => $Self->{UserID},
+    );
 
-        # show if new message is in there
-        if ( $TicketFlag{Seen} ) {
-            push @Result, undef;
+    # show if new message is in there
+    if ( $TicketFlag{Seen} ) {
+        push @Result, undef;
+    }
+    else {
+
+        # just show ticket flags if agent belongs to the ticket
+        my $ShowMeta;
+        if (
+            $Self->{UserID} == $Param{Ticket}->{OwnerID}
+            || $Self->{UserID} == $Param{Ticket}->{ResponsibleID}
+            )
+        {
+            $ShowMeta = 1;
         }
-        else {
-
-            # just show ticket flags if agent belongs to the ticket
-            my $ShowMeta;
-            if (
-                $Self->{UserID} == $Param{Ticket}->{OwnerID}
-                || $Self->{UserID} == $Param{Ticket}->{ResponsibleID}
-                )
-            {
+        if ( !$ShowMeta && $Self->{ConfigObject}->Get('Ticket::Watcher') ) {
+            my %Watch = $Self->{TicketObject}->TicketWatchGet(
+                TicketID => $Param{Ticket}->{TicketID},
+            );
+            if ( $Watch{ $Self->{UserID} } ) {
                 $ShowMeta = 1;
             }
-            if ( !$ShowMeta && $Self->{ConfigObject}->Get('Ticket::Watcher') ) {
-                my %Watch = $Self->{TicketObject}->TicketWatchGet(
-                    TicketID => $Param{Ticket}->{TicketID},
-                );
-                if ( $Watch{ $Self->{UserID} } ) {
-                    $ShowMeta = 1;
-                }
-            }
-
-            # show ticket flags
-            my $Image = 'meta-new-inactive.png';
-            if ($ShowMeta) {
-                $Image = 'meta-new.png';
-                push @Result, {
-                    Image      => $Image,
-                    Title      => 'Unread article(s) available',
-                    Class      => 'UnreadArticles',
-                    ClassSpan  => 'UnreadArticles Important',
-                    ClassTable => 'UnreadArticles',
-                };
-            }
-            else {
-                push @Result, {
-                    Image      => $Image,
-                    Title      => 'Unread article(s) available',
-                    Class      => 'UnreadArticles',
-                    ClassSpan  => 'UnreadArticles Unimportant',
-                    ClassTable => 'UnreadArticles',
-                };
-            }
         }
-    }
 
-    # show if it's locked
-    if (0) {
-        if ( $Param{Ticket}->{Lock} eq 'lock' ) {
-            if ( $Param{Ticket}->{OwnerID} == $Self->{UserID} ) {
-                push @Result, {
-                    Image => 'meta-lock-own.gif',
-                    Title => 'Locked by you!',
-                };
-            }
-            else {
-                push @Result, {
-                    Image => 'meta-lock.gif',
-                    Title => 'Locked by somebody else!',
-                };
-            }
-        }
-        else {
-            push @Result, undef;
-        }
-    }
-
-    # check if it get watched
-    if ( 0 && $Self->{ConfigObject}->Get('Ticket::Watcher') ) {
-        my %Watch = $Self->{TicketObject}->TicketWatchGet(
-            TicketID => $Param{Ticket}->{TicketID},
-        );
-        if ( $Watch{ $Self->{UserID} } ) {
+        # show ticket flags
+        my $Image = 'meta-new-inactive.png';
+        if ($ShowMeta) {
+            $Image = 'meta-new.png';
             push @Result, {
-                Image => 'meta-watch.gif',
-                Title => 'Watched by you!',
+                Image      => $Image,
+                Title      => 'Unread article(s) available',
+                Class      => 'UnreadArticles',
+                ClassSpan  => 'UnreadArticles Important',
+                ClassTable => 'UnreadArticles',
             };
         }
         else {
-            push @Result, undef;
+            push @Result, {
+                Image      => $Image,
+                Title      => 'Unread article(s) available',
+                Class      => 'UnreadArticles',
+                ClassSpan  => 'UnreadArticles Unimportant',
+                ClassTable => 'UnreadArticles',
+            };
         }
     }
 
