@@ -1,8 +1,8 @@
 # --
 # Kernel/Output/HTML/NavBarModuleAdmin.pm
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: NavBarModuleAdmin.pm,v 1.9 2009/02/16 11:16:22 tr Exp $
+# $Id: NavBarModuleAdmin.pm,v 1.11 2010/07/15 12:31:45 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.9 $) [1];
+$VERSION = qw($Revision: 1.11 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -34,18 +34,16 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $Output = '';
+    # only show it on admin start screen
+    return '' if $Self->{LayoutObject}->{Action} ne 'Admin';
 
-    if ( $Param{Type} ne 'Admin' ) {
-        return '';
-    }
     $Self->{LayoutObject}->Block(
         Name => 'AdminNavBar',
         Data => {},
     );
 
     # get all Frontend::Module
-    my %NavBarModule         = ();
+    my %NavBarModule;
     my $FrontendModuleConfig = $Self->{ConfigObject}->Get('Frontend::Module');
     for my $Module ( sort keys %{$FrontendModuleConfig} ) {
         my %Hash = %{ $FrontendModuleConfig->{$Module} };
@@ -108,14 +106,19 @@ sub Run {
 
         }
     }
+    my %Count;
     for my $Module ( sort keys %NavBarModule ) {
+        my $BlockName = $NavBarModule{$Module}->{NavBarModule}->{Block} || 'Item';
         $Self->{LayoutObject}->Block(
-            Name => $NavBarModule{$Module}->{NavBarModule}->{Block} || 'Item',
+            Name => $BlockName,
             Data => $NavBarModule{$Module},
         );
+        if ( $Count{$BlockName}++ % 2 ) {
+            $Self->{LayoutObject}->Block( Name => $BlockName . 'Clear' );
+        }
     }
 
-    $Output .= $Self->{LayoutObject}->Output(
+    my $Output = $Self->{LayoutObject}->Output(
         TemplateFile => 'AdminNavigationBar',
         Data         => \%Param,
     );
