@@ -1,8 +1,8 @@
 # --
 # Kernel/Output/HTML/TicketOverviewMedium.pm
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: TicketOverviewMedium.pm,v 1.40.2.1 2011/03/01 18:17:20 cg Exp $
+# $Id: TicketOverviewMedium.pm,v 1.54 2012/04/20 12:00:31 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,9 +15,12 @@ use strict;
 use warnings;
 
 use Kernel::System::CustomerUser;
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.40.2.1 $) [1];
+$VERSION = qw($Revision: 1.54 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -35,6 +38,19 @@ sub new {
     }
 
     $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
+
+    # get dynamic field config for frontend module
+    $Self->{DynamicFieldFilter}
+        = $Self->{ConfigObject}->Get("Ticket::Frontend::OverviewMedium")->{DynamicField};
+
+    # get the dynamic fields for this screen
+    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid       => 1,
+        ObjectType  => ['Ticket'],
+        FieldFilter => $Self->{DynamicFieldFilter} || {},
+    );
 
     return $Self;
 }
@@ -230,9 +246,18 @@ sub _Show {
 
     # get last article
     my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
-        TicketID => $Param{TicketID},
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
     );
 
+    # Fallback for tickets without articles: get at least basic ticket data
+    if ( !%Article ) {
+        %Article = $Self->{TicketObject}->TicketGet(
+            TicketID      => $Param{TicketID},
+            DynamicFields => 0,
+        );
+    }
+
     # user info
     my %UserInfo = $Self->{UserObject}->GetUserData(
         UserID => $Article{OwnerID},
@@ -422,33 +447,35 @@ sub _Show {
     }
 
     # run article modules
-    if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticlePreViewModule') eq 'HASH' ) {
-        my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticlePreViewModule') };
-        for my $Job ( sort keys %Jobs ) {
+    if ( $Article{ArticleID} ) {
+        if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticlePreViewModule') eq 'HASH' ) {
+            my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticlePreViewModule') };
+            for my $Job ( sort keys %Jobs ) {
 
-            # load module
-            if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
-                return $Self->{LayoutObject}->FatalError();
-            }
-            my $Object = $Jobs{$Job}->{Module}->new(
-                %{$Self},
-                ArticleID => $Article{ArticleID},
-                UserID    => $Self->{UserID},
-                Debug     => $Self->{Debug},
-            );
-
-            # run module
-            my @Data = $Object->Check( Article => \%Article, %Param, Config => $Jobs{$Job} );
-
-            for my $DataRef (@Data) {
-                $Self->{LayoutObject}->Block(
-                    Name => 'ArticleOption',
-                    Data => $DataRef,
+                # load module
+                if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
+                    return $Self->{LayoutObject}->FatalError();
+                }
+                my $Object = $Jobs{$Job}->{Module}->new(
+                    %{$Self},
+                    ArticleID => $Article{ArticleID},
+                    UserID    => $Self->{UserID},
+                    Debug     => $Self->{Debug},
                 );
-            }
 
-            # filter option
-            $Object->Filter( Article => \%Article, %Param, Config => $Jobs{$Job} );
+                # run module
+                my @Data = $Object->Check( Article => \%Article, %Param, Config => $Jobs{$Job} );
+
+                for my $DataRef (@Data) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'ArticleOption',
+                        Data => $DataRef,
+                    );
+                }
+
+                # filter option
+                $Object->Filter( Article => \%Article, %Param, Config => $Jobs{$Job} );
+            }
         }
     }
 
@@ -463,84 +490,6 @@ sub _Show {
     #            },
     #        );
     #    }
-    for my $Count ( 1 .. 3 ) {
-        next if !$Article{"ArticleFreeText$Count"};
-        $Self->{LayoutObject}->Block(
-            Name => 'ArticleFreeText',
-            Data => {
-                Key   => $Article{"ArticleFreeKey$Count"},
-                Value => $Article{"ArticleFreeText$Count"},
-            },
-        );
-    }
-
-    # ticket free text
-    for my $Count ( 1 .. 16 ) {
-        next if !$Article{ 'TicketFreeText' . $Count };
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeText' . $Count,
-            Data => { %Param, %Article, %AclAction },
-        );
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeText',
-            Data => {
-                %Param, %Article, %AclAction,
-                TicketFreeKey  => $Article{ 'TicketFreeKey' . $Count },
-                TicketFreeText => $Article{ 'TicketFreeText' . $Count },
-                Count          => $Count,
-            },
-        );
-        if ( !$Self->{ConfigObject}->Get( 'TicketFreeText' . $Count . '::Link' ) ) {
-            $Self->{LayoutObject}->Block(
-                Name => 'TicketFreeTextPlain' . $Count,
-                Data => { %Param, %Article, %AclAction },
-            );
-            $Self->{LayoutObject}->Block(
-                Name => 'TicketFreeTextPlain',
-                Data => {
-                    %Param, %Article, %AclAction,
-                    TicketFreeKey  => $Article{ 'TicketFreeKey' . $Count },
-                    TicketFreeText => $Article{ 'TicketFreeText' . $Count },
-                    Count          => $Count,
-                },
-            );
-        }
-        else {
-            $Self->{LayoutObject}->Block(
-                Name => 'TicketFreeTextLink' . $Count,
-                Data => { %Param, %Article, %AclAction },
-            );
-            $Self->{LayoutObject}->Block(
-                Name => 'TicketFreeTextLink',
-                Data => {
-                    %Param, %Article, %AclAction,
-                    TicketFreeTextLink =>
-                        $Self->{ConfigObject}->Get( 'TicketFreeText' . $Count . '::Link' ),
-                    TicketFreeKey  => $Article{ 'TicketFreeKey' . $Count },
-                    TicketFreeText => $Article{ 'TicketFreeText' . $Count },
-                    Count          => $Count,
-                },
-            );
-        }
-    }
-
-    # ticket free time
-    for my $Count ( 1 .. 6 ) {
-        next if !$Article{ 'TicketFreeTime' . $Count };
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeTime' . $Count,
-            Data => { %Param, %Article, %AclAction },
-        );
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeTime',
-            Data => {
-                %Param, %Article, %AclAction,
-                TicketFreeTimeKey => $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count ),
-                TicketFreeTime    => $Article{ 'TicketFreeTime' . $Count },
-                Count             => $Count,
-            },
-        );
-    }
 
     # create output
     $Self->{LayoutObject}->Block(
@@ -680,6 +629,177 @@ sub _Show {
         );
     }
 
+    # Dynamic fields
+    my $Counter                  = 0;
+    my $DisplayDynamicFieldTable = 1;
+
+    # cycle trough the activated Dynamic Fields for this screen
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+        $Counter++;
+
+        # get field value
+        my $Value = $Self->{BackendObject}->ValueGet(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            ObjectID           => $Param{TicketID},
+        );
+
+        next DYNAMICFIELD if ( !defined $Value );
+
+        my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Value              => $Value,
+            ValueMaxChars      => 20,
+            LayoutObject       => $Self->{LayoutObject},
+        );
+
+        my $Label = $DynamicFieldConfig->{Label};
+
+        # show dynamic field table if at least one field is displayed
+        if ( $DisplayDynamicFieldTable == 1 ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicFieldTable',
+                Data => {},
+            );
+            $DisplayDynamicFieldTable = 0;
+        }
+
+        # create a new row if counter is starting
+        if ( $Counter == 1 ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicFieldTableRow',
+                Data => {},
+            );
+        }
+
+        # outout dynamic field label
+        $Self->{LayoutObject}->Block(
+            Name => 'DynamicFieldTableRowRecord',
+            Data => {
+                Label => $Label,
+            },
+        );
+
+        if ( $ValueStrg->{Link} ) {
+
+            # outout dynamic field value link
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicFieldTableRowRecordLink',
+                Data => {
+                    Value                       => $ValueStrg->{Value},
+                    Title                       => $ValueStrg->{Title},
+                    Link                        => $ValueStrg->{Link},
+                    $DynamicFieldConfig->{Name} => $ValueStrg->{Title},
+                },
+            );
+        }
+        else {
+
+            # outout dynamic field value plain
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicFieldTableRowRecordPlain',
+                Data => {
+                    Value => $ValueStrg->{Value},
+                    Title => $ValueStrg->{Title},
+                },
+            );
+        }
+
+        # only 5 dynamic fields by row are allowed, reset couter if needed
+        if ( $Counter == 5 ) {
+            $Counter = 0;
+        }
+
+        # example of dynamic fields order customization
+        # outout dynamic field label
+        $Self->{LayoutObject}->Block(
+            Name => 'DynamicFieldTableRowRecord' . $DynamicFieldConfig->{Name},
+            Data => {
+                Label => $Label,
+            },
+        );
+
+        if ( $ValueStrg->{Link} ) {
+
+            # outout dynamic field value link
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicFieldTableRowRecord' . $DynamicFieldConfig->{Name} . 'Link',
+                Data => {
+                    Value                       => $ValueStrg->{Value},
+                    Title                       => $ValueStrg->{Title},
+                    Link                        => $ValueStrg->{Link},
+                    $DynamicFieldConfig->{Name} => $ValueStrg->{Title},
+                },
+            );
+        }
+        else {
+
+            # outout dynamic field value plain
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicFieldTableRowRecord' . $DynamicFieldConfig->{Name} . 'Plain',
+                Data => {
+                    Value => $ValueStrg->{Value},
+                    Title => $ValueStrg->{Title},
+                },
+            );
+        }
+    }
+
+    # fill the rest of the Dynamic Fields row with empty cells, this will look better
+    if ( $Counter > 0 && $Counter < 5 ) {
+
+        for ( $Counter + 1 ... 5 ) {
+
+            # outout dynamic field label
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicFieldTableRowRecord',
+                Data => {
+                    Label => '',
+                },
+            );
+
+            # outout dynamic field value plain
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicFieldTableRowRecordPlain',
+                Data => {
+                    Value => '',
+                    Title => '',
+                },
+            );
+        }
+    }
+
+    # test access to frontend module for Customer
+    my $Access = $Self->{LayoutObject}->Permission(
+        Action => 'AgentTicketCustomer',
+        Type   => 'rw',
+    );
+    if ($Access) {
+
+        # test access to ticket
+        my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::AgentTicketCustomer');
+        if ( $Config->{Permission} ) {
+            my $OK = $Self->{TicketObject}->Permission(
+                Type     => $Config->{Permission},
+                TicketID => $Param{TicketID},
+                UserID   => $Self->{UserID},
+                LogNo    => 1,
+            );
+            if ( !$OK ) {
+                $Access = 0;
+            }
+        }
+    }
+
+    # define proper DTL block based on permissions
+    my $CustomerIDBlock = $Access ? 'CustomerIDRW' : 'CustomerIDRO';
+    $Self->{LayoutObject}->Block(
+        Name => $CustomerIDBlock,
+        Data => { %Param, %Article },
+    );
+
     # get MoveQueuesStrg
     if ( $Self->{ConfigObject}->Get('Ticket::Frontend::MoveType') =~ /^form$/i ) {
         $Param{MoveQueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
