@@ -1,8 +1,8 @@
 # --
-# Kernel/System/Auth.pm - provides the authentification
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Kernel/System/Auth.pm - provides the authentication
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Auth.pm,v 1.42 2009/09/03 16:12:13 tr Exp $
+# $Id: Auth.pm,v 1.56 2012/04/16 11:11:59 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,15 +17,15 @@ use warnings;
 use Kernel::System::Valid;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.42 $) [1];
+$VERSION = qw($Revision: 1.56 $) [1];
 
 =head1 NAME
 
-Kernel::System::Auth - agent autentification module.
+Kernel::System::Auth - agent authentication module.
 
 =head1 SYNOPSIS
 
-The autentification module for the agent interface.
+The authentication module for the agent interface.
 
 =head1 PUBLIC INTERFACE
 
@@ -111,27 +111,35 @@ sub new {
         $Self->{$_} = $Param{$_} || die "No $_!";
     }
 
-    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
+    $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
 
     # load auth module
+    COUNT:
     for my $Count ( '', 1 .. 10 ) {
+
         my $GenericModule = $Self->{ConfigObject}->Get("AuthModule$Count");
-        next if !$GenericModule;
+
+        next COUNT if !$GenericModule;
 
         if ( !$Self->{MainObject}->Require($GenericModule) ) {
             $Self->{MainObject}->Die("Can't load backend module $GenericModule! $@");
         }
+
         $Self->{"AuthBackend$Count"} = $GenericModule->new( %Param, Count => $Count );
     }
 
     # load sync module
+    COUNT:
     for my $Count ( '', 1 .. 10 ) {
+
         my $GenericModule = $Self->{ConfigObject}->Get("AuthSyncModule$Count");
-        next if !$GenericModule;
+
+        next COUNT if !$GenericModule;
 
         if ( !$Self->{MainObject}->Require($GenericModule) ) {
             $Self->{MainObject}->Die("Can't load backend module $GenericModule! $@");
         }
+
         $Self->{"AuthSyncBackend$Count"} = $GenericModule->new( %Param, Count => $Count );
     }
 
@@ -140,10 +148,10 @@ sub new {
 
 =item GetOption()
 
-Get module options. Currently exists just one option, "PreAuth".
+Get module options. Currently there is just one option, "PreAuth".
 
-    if ($AuthObject->GetOption(What => 'PreAuth')) {
-        print "No login screen is needed. Autentificaion is based on some other options. E. g. $ENV{REMOTE_USER}\n";
+    if ( $AuthObject->GetOption( What => 'PreAuth' ) ) {
+        print "No login screen is needed. Authentication is based on some other options. E. g. $ENV{REMOTE_USER}\n";
     }
 
 =cut
@@ -156,9 +164,9 @@ sub GetOption {
 
 =item Auth()
 
-The autentificaion function.
+The authentication function.
 
-    if ($AuthObject->Auth(User => $User, Pw => $Pw)) {
+    if ( $AuthObject->Auth( User => $User, Pw => $Pw ) ) {
         print "Auth ok!\n";
     }
     else {
@@ -183,20 +191,40 @@ sub Auth {
         # next on no success
         next if !$User;
 
+        # configured auth sync backend
+        my $AuthSyncBackend = $Self->{ConfigObject}->Get("AuthModule::UseSyncBackend${Count}")
+            || $Self->{ConfigObject}->Get("AuthModule${Count}::UseSyncBackend");
+
+    # for backwards compatibility, OTRS 3.1.1, 3.1.2 and 3.1.3 used this wrong format (see bug#8387)
+
+        # sync with configured auth backend
+        if ( defined $AuthSyncBackend ) {
+
+            # if $AuthSyncBackend is defined but empty, don't sync with any backend
+            if ($AuthSyncBackend) {
+
+                # sync configured backend
+                $Self->{$AuthSyncBackend}->Sync( %Param, User => $User );
+            }
+        }
+
         # use all 11 sync backends
-        for my $Count ( '', 1 .. 10 ) {
+        else {
+            for my $Count ( '', 1 .. 10 ) {
 
-            # return on no config setting
-            next if !$Self->{"AuthSyncBackend$Count"};
+                # return on no config setting
+                next if !$Self->{"AuthSyncBackend$Count"};
 
-            # sync backend
-            $Self->{"AuthSyncBackend$Count"}->Sync( %Param, User => $User );
+                # sync backend
+                $Self->{"AuthSyncBackend$Count"}->Sync( %Param, User => $User );
+            }
         }
 
         # remember auth backend
         my $UserID = $Self->{UserObject}->UserLookup(
             UserLogin => $User,
         );
+
         if ($UserID) {
             $Self->{UserObject}->SetPreferences(
                 Key    => 'UserAuthBackend',
@@ -216,67 +244,82 @@ sub Auth {
         my $UserID = $Self->{UserObject}->UserLookup(
             UserLogin => $Param{User},
         );
-        if ($UserID) {
-            my %User = $Self->{UserObject}->GetUserData(
-                UserID => $UserID,
-                Valid  => 1,
-                Cached => 1,
-            );
-            my $Count = $User{UserLoginFailed} || 0;
-            $Count++;
-            $Self->{UserObject}->SetPreferences(
-                Key    => 'UserLoginFailed',
-                Value  => $Count,
-                UserID => $UserID,
-            );
 
-            # set agent to invalid-temporarily if max failed logins reached
-            my $Config = $Self->{ConfigObject}->Get('PreferencesGroups');
-            my $PasswordMaxLoginFailed;
-            if ( $Config && $Config->{Password} && $Config->{Password}->{PasswordMaxLoginFailed} ) {
-                $PasswordMaxLoginFailed = $Config->{Password}->{PasswordMaxLoginFailed};
-            }
-            if ( %User && $PasswordMaxLoginFailed && $Count >= $PasswordMaxLoginFailed ) {
-                my $ValidID = $Self->{ValidObject}->ValidLookup( Valid => 'invalid-temporarily' );
-                my $Update = $Self->{UserObject}->UserUpdate(
-                    %User,
-                    ValidID      => $ValidID,
-                    ChangeUserID => 1,
-                );
-                if ($Update) {
-                    $Self->{LogObject}->Log(
-                        Priority => 'notice',
-                        Message  => "Login failed $Count times. Set $User{UserLogin} to "
-                            . "'invalid-temporarily'.",
-                    );
-                }
-            }
+        return if !$UserID;
+
+        my %User = $Self->{UserObject}->GetUserData(
+            UserID => $UserID,
+            Valid  => 1,
+        );
+
+        my $Count = $User{UserLoginFailed} || 0;
+        $Count++;
+
+        $Self->{UserObject}->SetPreferences(
+            Key    => 'UserLoginFailed',
+            Value  => $Count,
+            UserID => $UserID,
+        );
+
+        # set agent to invalid-temporarily if max failed logins reached
+        my $Config = $Self->{ConfigObject}->Get('PreferencesGroups');
+        my $PasswordMaxLoginFailed;
+
+        if ( $Config && $Config->{Password} && $Config->{Password}->{PasswordMaxLoginFailed} ) {
+            $PasswordMaxLoginFailed = $Config->{Password}->{PasswordMaxLoginFailed};
         }
+
+        return if !%User;
+        return if !$PasswordMaxLoginFailed;
+        return if $Count < $PasswordMaxLoginFailed;
+
+        my $ValidID = $Self->{ValidObject}->ValidLookup( Valid => 'invalid-temporarily' );
+
+        my $Update = $Self->{UserObject}->UserUpdate(
+            %User,
+            ValidID      => $ValidID,
+            ChangeUserID => 1,
+        );
+
+        return if !$Update;
+
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message  => "Login failed $Count times. Set $User{UserLogin} to "
+                . "'invalid-temporarily'.",
+        );
+
         return;
     }
 
     # remember login attributes
     my $UserID = $Self->{UserObject}->UserLookup(
-        UserLogin => $Param{User},
+        UserLogin => $User,
     );
-    if ($UserID) {
 
-        # reset failed logins
-        $Self->{UserObject}->SetPreferences(
-            Key    => 'UserLoginFailed',
-            Value  => 0,
-            UserID => $UserID,
-        );
+    return $User if !$UserID;
 
-        # last login preferences update
-        $Self->{UserObject}->SetPreferences(
-            Key    => 'UserLastLogin',
-            Value  => $Self->{TimeObject}->SystemTime(),
-            UserID => $UserID,
-        );
-    }
+    # reset failed logins
+    $Self->{UserObject}->SetPreferences(
+        Key    => 'UserLoginFailed',
+        Value  => 0,
+        UserID => $UserID,
+    );
+
+    # last login preferences update
+    $Self->{UserObject}->SetPreferences(
+        Key    => 'UserLastLogin',
+        Value  => $Self->{TimeObject}->SystemTime(),
+        UserID => $UserID,
+    );
+
+    # last login preferences update
+    $Self->{UserObject}->SetPreferences(
+        Key    => 'UserLastLoginTimestamp',
+        Value  => $Self->{TimeObject}->CurrentTimestamp(),
+        UserID => $UserID,
+    );
 
-    # return auth user
     return $User;
 }
 
@@ -286,16 +329,16 @@ sub Auth {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.42 $ $Date: 2009/09/03 16:12:13 $
+$Revision: 1.56 $ $Date: 2012/04/16 11:11:59 $
 
 =cut
