@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Auth/DB.pm - provides the db authentication
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.26.2.1 2009/09/22 14:53:24 mb Exp $
+# $Id: DB.pm,v 1.34 2012/03/21 11:52:35 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Crypt::PasswdMD5 qw(unix_md5_crypt);
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.26.2.1 $) [1];
+$VERSION = qw($Revision: 1.34 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -29,7 +29,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(LogObject ConfigObject DBObject EncodeObject)) {
+    for (qw(LogObject ConfigObject DBObject EncodeObject MainObject)) {
         $Self->{$_} = $Param{$_} || die "No $_!";
     }
     $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
@@ -92,6 +92,7 @@ sub Auth {
         . " valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} ) AND "
         . " $Self->{UserTableUser} = '" . $Self->{DBObject}->Quote($User) . "'";
     $Self->{DBObject}->Prepare( SQL => $SQL );
+
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $GetPw  = $Row[0];
         $UserID = $Row[1];
@@ -108,17 +109,59 @@ sub Auth {
         $CryptedPw = $Pw;
     }
 
-    # md5 pw
+    # md5 or sha pw
     elsif ( $GetPw !~ /^.{13}$/ ) {
 
-        # strip Salt
-        $Salt =~ s/^\$.+?\$(.+?)\$.*$/$1/;
+        # md5 pw
+        if ( $GetPw =~ m{\A \$.+? \$.+? \$.* \z}xms ) {
 
-        # encode output, needed by unix_md5_crypt() only non utf8 signs
-        $Self->{EncodeObject}->EncodeOutput( \$Pw );
-        $Self->{EncodeObject}->EncodeOutput( \$Salt );
+            # strip Salt
+            $Salt =~ s/^\$.+?\$(.+?)\$.*$/$1/;
 
-        $CryptedPw = unix_md5_crypt( $Pw, $Salt );
+            # encode output, needed by unix_md5_crypt() only non utf8 signs
+            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+            $Self->{EncodeObject}->EncodeOutput( \$Salt );
+
+            $CryptedPw = unix_md5_crypt( $Pw, $Salt );
+        }
+
+        # sha256 pw
+        elsif ( $GetPw =~ m{\A .{64} \z}xms ) {
+
+            my $SHAObject;
+            if ( $Self->{MainObject}->Require('Digest::SHA') ) {
+                $SHAObject = Digest::SHA->new('sha256');
+            }
+            else {
+                $Self->{MainObject}->Require('Digest::SHA::PurePerl');
+                $SHAObject = Digest::SHA::PurePerl->new('sha256');
+            }
+
+            # encode output, needed by sha256_hex() only non utf8 signs
+            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+
+            $SHAObject->add($Pw);
+            $CryptedPw = $SHAObject->hexdigest();
+        }
+
+        # sha1 pw
+        else {
+
+            my $SHAObject;
+            if ( $Self->{MainObject}->Require('Digest::SHA') ) {
+                $SHAObject = Digest::SHA->new('sha1');
+            }
+            else {
+                $Self->{MainObject}->Require('Digest::SHA::PurePerl');
+                $SHAObject = Digest::SHA::PurePerl->new('sha1');
+            }
+
+            # encode output, needed by sha1_hex() only non utf8 signs
+            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+
+            $SHAObject->add($Pw);
+            $CryptedPw = $SHAObject->hexdigest();
+        }
     }
 
     # crypt pw
@@ -129,31 +172,10 @@ sub Auth {
             $Salt =~ s/^(..).*/$1/;
         }
 
-        # and do this check only in such case (unfortunately there is a mod_perl2
-        # bug on RH8 - check if crypt() is working correctly) :-/
-        if ( ( $Salt =~ /^\$\d\$/ ) || ( crypt( 'root', 'root@localhost' ) eq 'roK20XGbWEsSM' ) ) {
-
-            # encode output, needed by crypt() only non utf8 signs
-            $Self->{EncodeObject}->EncodeOutput( \$Pw );
-            $Self->{EncodeObject}->EncodeOutput( \$Salt );
-            $CryptedPw = crypt( $Pw, $Salt );
-        }
-        else {
-            $Self->{LogObject}->Log(
-                Priority => 'notice',
-                Message =>
-                    "The crypt() of your mod_perl(2) is not working correctly! Update mod_perl!",
-            );
-            my $TempSalt = quotemeta($Salt);
-            my $TempPw   = quotemeta($Pw);
-            my $CMD      = "perl -e \"print crypt('$TempPw', '$TempSalt');\"";
-            open( IO, " $CMD | " ) || print STDERR "Can't open $CMD: $!";
-            while (<IO>) {
-                $CryptedPw .= $_;
-            }
-            close(IO);
-            chomp $CryptedPw;
-        }
+        # encode output, needed by crypt() only non utf8 signs
+        $Self->{EncodeObject}->EncodeOutput( \$Pw );
+        $Self->{EncodeObject}->EncodeOutput( \$Salt );
+        $CryptedPw = crypt( $Pw, $Salt );
     }
 
     # just in case for debug!
@@ -177,14 +199,6 @@ sub Auth {
     # login note
     elsif ( ( ($GetPw) && ($User) && ($UserID) ) && $CryptedPw eq $GetPw ) {
 
-        # maybe check if pw is expired
-        # if () {
-        #           $Self->{LogObject}->Log(
-        #               Priority => 'info',
-        #               Message => "Password is expired!",
-        #           );
-        #            return;
-        #        }
         $Self->{LogObject}->Log(
             Priority => 'notice',
             Message  => "User: $User authentication ok (REMOTE_ADDR: $RemoteAddr).",
