@@ -1,8 +1,8 @@
 # --
 # Kernel/System/CustomerAuth/DB.pm - provides the db authentication
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.28.2.1 2009/09/22 14:50:40 mb Exp $
+# $Id: DB.pm,v 1.37 2012/03/21 11:52:35 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use warnings;
 use Crypt::PasswdMD5 qw(unix_md5_crypt);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.28.2.1 $) [1];
+$VERSION = qw($Revision: 1.37 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -27,7 +27,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(LogObject ConfigObject DBObject EncodeObject)) {
+    for (qw(LogObject ConfigObject DBObject MainObject EncodeObject)) {
         $Self->{$_} = $Param{$_} || die "No $_!";
     }
 
@@ -127,21 +127,66 @@ sub Auth {
     my $CryptedPw = '';
     my $Salt      = $GetPw;
 
-    # md5 pw
     if ( $Self->{CryptType} eq 'plain' ) {
         $CryptedPw = $Pw;
     }
+
+    # md5 or sha pw
     elsif ( $GetPw !~ /^.{13}$/ ) {
 
-        # strip salt
-        $Salt =~ s/^\$.+?\$(.+?)\$.*$/$1/;
+        # md5 pw
+        if ( $GetPw =~ m{\A \$.+? \$.+? \$.* \z}xms ) {
 
-        # encode output, needed by unix_md5_crypt() only non utf8 signs
-        $Self->{EncodeObject}->EncodeOutput( \$Pw );
-        $Self->{EncodeObject}->EncodeOutput( \$Salt );
+            # strip Salt
+            $Salt =~ s/^\$.+?\$(.+?)\$.*$/$1/;
 
-        $CryptedPw = unix_md5_crypt( $Pw, $Salt );
-        $Self->{EncodeObject}->Encode( \$CryptedPw );
+            # encode output, needed by unix_md5_crypt() only non utf8 signs
+            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+            $Self->{EncodeObject}->EncodeOutput( \$Salt );
+
+            $CryptedPw = unix_md5_crypt( $Pw, $Salt );
+            $Self->{EncodeObject}->EncodeInput( \$CryptedPw );
+        }
+
+        # sha256 pw
+        elsif ( $GetPw =~ m{\A .{64} \z}xms ) {
+
+            my $SHAObject;
+            if ( $Self->{MainObject}->Require('Digest::SHA') ) {
+                $SHAObject = Digest::SHA->new('sha256');
+            }
+            else {
+                $Self->{MainObject}->Require('Digest::SHA::PurePerl');
+                $SHAObject = Digest::SHA::PurePerl->new('sha256');
+            }
+
+            # encode output, needed by sha256_hex() only non utf8 signs
+            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+
+            $SHAObject->add($Pw);
+            $CryptedPw = $SHAObject->hexdigest();
+            $Self->{EncodeObject}->EncodeInput( \$CryptedPw );
+        }
+
+        # sha1 pw
+        else {
+
+            my $SHAObject;
+            if ( $Self->{MainObject}->Require('Digest::SHA') ) {
+                $SHAObject = Digest::SHA->new('sha1');
+            }
+            else {
+                $Self->{MainObject}->Require('Digest::SHA::PurePerl');
+                $SHAObject = Digest::SHA::PurePerl->new('sha1');
+            }
+
+            # encode output, needed by sha1_hex() only non utf8 signs
+            $Self->{EncodeObject}->EncodeOutput( \$Pw );
+
+            $SHAObject->add($Pw);
+            $CryptedPw = $SHAObject->hexdigest();
+            $Self->{EncodeObject}->EncodeInput( \$CryptedPw );
+        }
     }
 
     # crypt pw
@@ -152,39 +197,19 @@ sub Auth {
             $Salt =~ s/^(..).*/$1/;
         }
 
-        # and do this check only in such case (unfortunately there is a mod_perl2
-        # bug on RH8 - check if crypt() is working correctly) :-/
-        if ( $Salt =~ /^\$\d\$/ || ( crypt( 'root', 'root@localhost' ) eq 'roK20XGbWEsSM' ) ) {
-            $Self->{EncodeObject}->EncodeOutput( \$Pw );
-            $Self->{EncodeObject}->EncodeOutput( \$Salt );
+        $Self->{EncodeObject}->EncodeOutput( \$Pw );
+        $Self->{EncodeObject}->EncodeOutput( \$Salt );
 
-            # encode output, needed by crypt() only non utf8 signs
-            $CryptedPw = crypt( $Pw, $Salt );
-            $Self->{EncodeObject}->Encode( \$CryptedPw );
-        }
-        else {
-            $Self->{LogObject}->Log(
-                Priority => 'notice',
-                Message =>
-                    "The crypt() of your mod_perl(2) is not working correctly! Update mod_perl!",
-            );
-            my $TempSalt = quotemeta($Salt);
-            my $TempPw   = quotemeta($Pw);
-            my $CMD      = "perl -e \"print crypt('$TempPw', '$TempSalt');\"";
-            open( IO, " $CMD | " ) || print STDERR "Can't open $CMD: $!";
-            while (<IO>) {
-                $CryptedPw .= $_;
-            }
-            close(IO);
-            chomp $CryptedPw;
-        }
+        # encode output, needed by crypt() only non utf8 signs
+        $CryptedPw = crypt( $Pw, $Salt );
+        $Self->{EncodeObject}->EncodeInput( \$CryptedPw );
     }
 
     # just in case!
     if ( $Self->{Debug} > 0 ) {
         $Self->{LogObject}->Log(
             Priority => 'notice',
-            Message  => "CustomerUser: '$User' tried to authentificate with Pw: '$Pw' "
+            Message  => "CustomerUser: '$User' tried to authenticate with Pw: '$Pw' "
                 . "($UserID/$CryptedPw/$GetPw/$Salt/$RemoteAddr)",
         );
     }
@@ -203,7 +228,7 @@ sub Auth {
     elsif ( ( $GetPw && $User && $UserID ) && $CryptedPw eq $GetPw ) {
         $Self->{LogObject}->Log(
             Priority => 'notice',
-            Message  => "CustomerUser: $User authentication ok (REMOTE_ADDR: $RemoteAddr).",
+            Message  => "CustomerUser: $User Authentication ok (REMOTE_ADDR: $RemoteAddr).",
         );
         return $User;
     }
@@ -213,7 +238,7 @@ sub Auth {
         $Self->{LogObject}->Log(
             Priority => 'notice',
             Message =>
-                "CustomerUser: $User authentication with wrong Pw!!! (REMOTE_ADDR: $RemoteAddr)"
+                "CustomerUser: $User Authentication with wrong Pw!!! (REMOTE_ADDR: $RemoteAddr)"
         );
         return;
     }
