@@ -1,8 +1,8 @@
 # --
 # Kernel/System/CustomerGroup.pm - All Groups related function should be here eventually
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: CustomerGroup.pm,v 1.21 2009/04/17 08:36:44 tr Exp $
+# $Id: CustomerGroup.pm,v 1.25 2010/06/17 21:39:40 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::Group;
 use Kernel::System::Valid;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.21 $) [1];
+$VERSION = qw($Revision: 1.25 $) [1];
 
 =head1 NAME
 
@@ -66,8 +66,9 @@ create an object
     );
     my $CustomerGroupObject = Kernel::System::CustomerGroup->new(
         ConfigObject => $ConfigObject,
-        LogObject => $LogObject,
-        DBObject => $DBObject,
+        LogObject    => $LogObject,
+        DBObject     => $DBObject,
+        EncodeObject => $EncodeObject,
     );
 
 =cut
@@ -80,7 +81,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(DBObject ConfigObject LogObject)) {
+    for (qw(DBObject ConfigObject LogObject EncodeObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
     $Self->{GroupObject} = Kernel::System::Group->new(%Param);
@@ -99,12 +100,12 @@ to add a member to a group
         GID => 12,
         UID => 6,
         Permission => {
-            ro => 1,
+            ro        => 1,
             move_into => 1,
-            create => 1,
-            owner => 1,
-            priority => 0,
-            rw => 0,
+            create    => 1,
+            owner     => 1,
+            priority  => 0,
+            rw        => 0,
         },
         UserID => 123,
     );
@@ -122,13 +123,18 @@ sub GroupMemberAdd {
         }
     }
 
+    # check rw rule (set only rw and remove rest, because it's including all in rw)
+    if ( $Param{Permission}->{rw} ) {
+        %{ $Param{Permission} } = ( rw => 1 );
+    }
+
     # update permission
     for my $Type ( keys %{ $Param{Permission} } ) {
 
         # delete existing permission
         $Self->{DBObject}->Do(
-            SQL => "DELETE FROM group_customer_user WHERE "
-                . " group_id = ? AND user_id = ? AND permission_key = ?",
+            SQL => 'DELETE FROM group_customer_user WHERE '
+                . ' group_id = ? AND user_id = ? AND permission_key = ?',
             Bind => [ \$Param{GID}, \$Param{UID}, \$Type ],
         );
 
@@ -141,12 +147,13 @@ sub GroupMemberAdd {
             );
         }
 
-        # insert new permission
+        # insert new permission (if needed)
+        next if !$Param{Permission}->{$Type};
         $Self->{DBObject}->Do(
-            SQL => "INSERT INTO group_customer_user "
-                . " (user_id, group_id, permission_key, permission_value, "
-                . " create_time, create_by, change_time, change_by) "
-                . " VALUES (?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)",
+            SQL => 'INSERT INTO group_customer_user '
+                . '(user_id, group_id, permission_key, permission_value, '
+                . 'create_time, create_by, change_time, change_by) '
+                . 'VALUES (?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
             Bind => [
                 \$Param{UID}, \$Param{GID}, \$Type, \$Param{Permission}->{$Type}, \$Param{UserID},
                 \$Param{UserID},
@@ -169,7 +176,7 @@ returns a list of users of a group with ro/move_into/create/owner/priority/rw pe
     Example:
     $CustomerGroupObject->GroupMemberList(
         UserID => $ID,
-        Type => 'move_into',
+        Type   => 'move_into',
         Result => 'HASH',
     );
 
@@ -186,12 +193,12 @@ sub GroupMemberList {
         }
     }
     if ( !$Param{UserID} && !$Param{GroupID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need UserID or GroupID!" );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need UserID or GroupID!' );
         return;
     }
-    my %Data = ();
-    my @Name = ();
-    my @ID   = ();
+    my %Data;
+    my @Name;
+    my @ID;
 
     # check if customer group feature is activ, if not, return all groups
     if ( !$Self->{ConfigObject}->Get('CustomerGroupSupport') ) {
@@ -199,19 +206,16 @@ sub GroupMemberList {
         # get permissions
         %Data = $Self->{GroupObject}->GroupList( Valid => 1 );
         for ( keys %Data ) {
-            push( @Name, $Data{$_} );
-            push( @ID,   $_ );
+            push @Name, $Data{$_};
+            push @ID,   $_;
         }
     }
 
     # if it's activ, return just the permitted groups
     my $SQL = "SELECT g.id, g.name, gu.permission_key, gu.permission_value, gu.user_id "
-        . " FROM "
-        . " groups g, group_customer_user gu"
-        . " WHERE "
+        . " FROM groups g, group_customer_user gu WHERE "
         . " g.valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} ) AND "
-        . " g.id = gu.group_id AND "
-        . " gu.permission_value = 1 AND "
+        . " g.id = gu.group_id AND gu.permission_value = 1 AND "
         . " gu.permission_key IN ('" . $Self->{DBObject}->Quote( $Param{Type} ) . "', 'rw') "
         . " AND ";
 
@@ -236,8 +240,8 @@ sub GroupMemberList {
 
         # get permissions
         $Data{$Key} = $Value;
-        push( @Name, $Value );
-        push( @ID,   $Key );
+        push @Name, $Value;
+        push @ID,   $Key;
     }
 
     # add always groups
@@ -247,8 +251,8 @@ sub GroupMemberList {
             for my $GroupID ( keys %Groups ) {
                 if ( $_ eq $Groups{$GroupID} && !$Data{$GroupID} ) {
                     $Data{$GroupID} = $_;
-                    push( @Name, $_ );
-                    push( @ID,   $GroupID );
+                    push @Name, $_;
+                    push @ID,   $GroupID;
                 }
             }
         }
@@ -261,9 +265,7 @@ sub GroupMemberList {
     if ( $Param{Result} && $Param{Result} eq 'Name' ) {
         return @Name;
     }
-    else {
-        return %Data;
-    }
+    return %Data;
 }
 
 =item GroupLookup()
@@ -338,16 +340,16 @@ sub GroupLookup {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.21 $ $Date: 2009/04/17 08:36:44 $
+$Revision: 1.25 $ $Date: 2010/06/17 21:39:40 $
 
 =cut
