@@ -1,12 +1,12 @@
 # --
 # Kernel/System/DB/oracle.pm - oracle database backend
-# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: oracle.pm,v 1.57 2008/07/19 19:45:41 mh Exp $
+# $Id: oracle.pm,v 1.65 2011/03/01 18:23:35 en Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::DB::oracle;
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.57 $) [1];
+$VERSION = qw($Revision: 1.65 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -31,12 +31,15 @@ sub LoadPreferences {
     my ( $Self, %Param ) = @_;
 
     # db settings
-    $Self->{'DB::Limit'}              = 0;
-    $Self->{'DB::DirectBlob'}         = 0;
-    $Self->{'DB::QuoteSingle'}        = '\'';
-    $Self->{'DB::QuoteBack'}          = 0;
-    $Self->{'DB::QuoteSemicolon'}     = '';
-    $Self->{'DB::NoLowerInLargeText'} = 0;
+    $Self->{'DB::Limit'}                = 0;
+    $Self->{'DB::DirectBlob'}           = 0;
+    $Self->{'DB::QuoteSingle'}          = '\'';
+    $Self->{'DB::QuoteBack'}            = 0;
+    $Self->{'DB::QuoteSemicolon'}       = '';
+    $Self->{'DB::QuoteUnderscoreStart'} = '\\';
+    $Self->{'DB::QuoteUnderscoreEnd'}   = '';
+    $Self->{'DB::CaseInsensitive'}      = 0;
+    $Self->{'DB::LikeEscapeString'}     = q{ESCAPE '\\'};
 
     # dbi attributes
     $Self->{'DB::Attribute'} = {
@@ -74,6 +77,12 @@ sub Quote {
         if ( $Self->{'DB::QuoteSemicolon'} ) {
             ${$Text} =~ s/;/$Self->{'DB::QuoteSemicolon'};/g;
         }
+        if ( $Type && $Type eq 'Like' ) {
+            if ( $Self->{'DB::QuoteUnderscoreStart'} || $Self->{'DB::QuoteUnderscoreEnd'} ) {
+                ${$Text}
+                    =~ s/_/$Self->{'DB::QuoteUnderscoreStart'}_$Self->{'DB::QuoteUnderscoreEnd'}/g;
+            }
+        }
     }
     return $Text;
 }
