@@ -2,7 +2,7 @@
 # Kernel/System/DynamicField/Backend/Date.pm - Delegate for DynamicField Date backend
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Date.pm,v 1.48 2012/03/01 11:34:05 mg Exp $
+# $Id: Date.pm,v 1.50.2.1 2012/05/10 19:19:15 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::Time;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.48 $) [1];
+$VERSION = qw($Revision: 1.50.2.1 $) [1];
 
 =head1 NAME
 
@@ -121,6 +121,17 @@ sub ValueDelete {
     return $Success;
 }
 
+sub AllValuesDelete {
+    my ( $Self, %Param ) = @_;
+
+    my $Success = $Self->{DynamicFieldValueObject}->AllValuesDelete(
+        FieldID => $Param{DynamicFieldConfig}->{ID},
+        UserID  => $Param{UserID},
+    );
+
+    return $Success;
+}
+
 sub ValueValidate {
     my ( $Self, %Param ) = @_;
 
@@ -218,7 +229,9 @@ sub EditFieldRender {
     }
 
     # extract the dynamic field value form the web request
+    # TransformDates is always needed from EditFieldRender Bug#8452
     my $FieldValues = $Self->EditFieldValueGet(
+        TransformDates       => 1,
         ReturnValueStructure => 1,
         %Param,
     );
@@ -350,6 +363,17 @@ sub EditFieldValueGet {
             && !$DynamicFieldValues{ $Prefix . 'Month' }
             && !$DynamicFieldValues{ $Prefix . 'Day' };
 
+    # check if need and can transform dates
+    # transform the dates early for ReturnValueStructure or ManualTimeStamp Bug#8452
+    if ( $Param{TransformDates} && $Param{LayoutObject} ) {
+
+        # transform time stamp based on user time zone
+        %DynamicFieldValues = $Param{LayoutObject}->TransformDateSelection(
+            %DynamicFieldValues,
+            Prefix => $Prefix,
+        );
+    }
+
     # check if return value structure is nedded
     if ( defined $Param{ReturnValueStructure} && $Param{ReturnValueStructure} eq '1' ) {
         return \%DynamicFieldValues;
@@ -364,16 +388,6 @@ sub EditFieldValueGet {
 
     if ( $DynamicFieldValues{ $Prefix . 'Used' } ) {
 
-        # check if need and can transform dates
-        if ( $Param{TransformDates} && $Param{LayoutObject} ) {
-
-            # transform time stamp based on user time zone
-            %DynamicFieldValues = $Param{LayoutObject}->TransformDateSelection(
-                %DynamicFieldValues,
-                Prefix => $Prefix,
-            );
-        }
-
         # add a leading zero for date parts that could be less than ten to generate a correct
         # time stamp
         for my $Type (qw(Month Day Hour Minute Second)) {
@@ -853,6 +867,19 @@ sub AJAXPossibleValuesGet {
     return;
 }
 
+sub HistoricalValuesGet {
+    my ( $Self, %Param ) = @_;
+
+    # get historical values from database
+    my $HistoricalValues = $Self->{DynamicFieldValueObject}->HistoricalValueGet(
+        FieldID   => $Param{DynamicFieldConfig}->{ID},
+        ValueType => 'DateTime',
+    );
+
+    # retrun the historical values from database
+    return $HistoricalValues;
+}
+
 1;
 
 =back
