@@ -2,7 +2,7 @@
 # Kernel/System/DynamicField/Backend/Dropdown.pm - Delegate for DynamicField Dropdown backend
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Dropdown.pm,v 1.58 2012/03/01 17:03:36 cr Exp $
+# $Id: Dropdown.pm,v 1.63.2.1 2012/05/31 01:26:10 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.58 $) [1];
+$VERSION = qw($Revision: 1.63.2.1 $) [1];
 
 =head1 NAME
 
@@ -118,6 +118,17 @@ sub ValueDelete {
     return $Success;
 }
 
+sub AllValuesDelete {
+    my ( $Self, %Param ) = @_;
+
+    my $Success = $Self->{DynamicFieldValueObject}->AllValuesDelete(
+        FieldID => $Param{DynamicFieldConfig}->{ID},
+        UserID  => $Param{UserID},
+    );
+
+    return $Success;
+}
+
 sub ValueValidate {
     my ( $Self, %Param ) = @_;
 
@@ -226,6 +237,17 @@ sub EditFieldRender {
         $FieldPossibleNone = $FieldConfig->{PossibleNone} || 0;
     }
 
+    my $Size = 1;
+
+    # TODO change ConfirmationNeeded parameter name to something more generic
+
+    # when ConfimationNeeded parameter is present (AdminGenericAgent) the filed should be displayed
+    # as an open list, because you might not want to change the value, otherwise a value will be
+    # selected
+    if ( $Param{ConfirmationNeeded} ) {
+        $Size = 5;
+    }
+
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
         Data => $SelectionData || {},
         Name => $FieldName,
@@ -233,6 +255,7 @@ sub EditFieldRender {
         Translation  => $FieldConfig->{TranslatableValues} || 0,
         PossibleNone => $FieldPossibleNone,
         Class        => $FieldClass,
+        Size         => $Size,
         HTMLQuote    => 1,
     );
 
@@ -269,7 +292,7 @@ EOF
 
         my $FieldSelector = '#' . $FieldName;
 
-        my $FieldsToUpdate;
+        my $FieldsToUpdate = '';
         if ( IsArrayRefWithData( $Param{UpdatableFields} ) ) {
             my $FirstItem = 1;
             FIELD:
@@ -509,15 +532,14 @@ sub SearchFieldRender {
     my $SelectionData = $FieldConfig->{PossibleValues};
 
     # get historical values from database
-    my $HistoricalValues = $Self->{DynamicFieldValueObject}->HistoricalValueGet(
-        FieldID   => $Param{DynamicFieldConfig}->{ID},
-        ValueType => 'Text,',
-    );
+    my $HistoricalValues = $Self->HistoricalValuesGet(%Param);
 
     # add historic values to current values (if they don't exist anymore)
-    for my $Key ( keys %{$HistoricalValues} ) {
-        if ( !$SelectionData->{$Key} ) {
-            $SelectionData->{$Key} = $HistoricalValues->{$Key}
+    if ( IsHashRefWithData($HistoricalValues) ) {
+        for my $Key ( keys %{$HistoricalValues} ) {
+            if ( !$SelectionData->{$Key} ) {
+                $SelectionData->{$Key} = $HistoricalValues->{$Key}
+            }
         }
     }
 
@@ -530,7 +552,7 @@ sub SearchFieldRender {
         Name         => $FieldName,
         SelectedID   => $Value,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 1,
+        PossibleNone => 0,
         Class        => $FieldClass,
         Multiple     => 1,
         HTMLQuote    => 1,
@@ -795,6 +817,19 @@ sub AJAXPossibleValuesGet {
     return \%PossibleValues;
 }
 
+sub HistoricalValuesGet {
+    my ( $Self, %Param ) = @_;
+
+    # get historical values from database
+    my $HistoricalValues = $Self->{DynamicFieldValueObject}->HistoricalValueGet(
+        FieldID   => $Param{DynamicFieldConfig}->{ID},
+        ValueType => 'Text',
+    );
+
+    # retrun the historical values from database
+    return $HistoricalValues;
+}
+
 1;
 
 =back
