@@ -2,7 +2,7 @@
 # Kernel/System/DynamicField/Backend/Multiselect.pm - Delegate for DynamicField Multiselect backend
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Multiselect.pm,v 1.47 2012/03/01 17:03:36 cr Exp $
+# $Id: Multiselect.pm,v 1.51.2.1 2012/05/28 22:43:40 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.47 $) [1];
+$VERSION = qw($Revision: 1.51.2.1 $) [1];
 
 =head1 NAME
 
@@ -134,6 +134,17 @@ sub ValueDelete {
     return $Success;
 }
 
+sub AllValuesDelete {
+    my ( $Self, %Param ) = @_;
+
+    my $Success = $Self->{DynamicFieldValueObject}->AllValuesDelete(
+        FieldID => $Param{DynamicFieldConfig}->{ID},
+        UserID  => $Param{UserID},
+    );
+
+    return $Success;
+}
+
 sub ValueValidate {
     my ( $Self, %Param ) = @_;
 
@@ -607,15 +618,14 @@ sub SearchFieldRender {
     my $SelectionData = $FieldConfig->{PossibleValues};
 
     # get historical values from database
-    my $HistoricalValues = $Self->{DynamicFieldValueObject}->HistoricalValueGet(
-        FieldID   => $Param{DynamicFieldConfig}->{ID},
-        ValueType => 'Text,',
-    );
+    my $HistoricalValues = $Self->HistoricalValuesGet(%Param);
 
     # add historic values to current values (if they don't exist anymore)
-    for my $Key ( keys %{$HistoricalValues} ) {
-        if ( !$SelectionData->{$Key} ) {
-            $SelectionData->{$Key} = $HistoricalValues->{$Key}
+    if ( IsHashRefWithData($HistoricalValues) ) {
+        for my $Key ( keys %{$HistoricalValues} ) {
+            if ( !$SelectionData->{$Key} ) {
+                $SelectionData->{$Key} = $HistoricalValues->{$Key}
+            }
         }
     }
 
@@ -628,7 +638,7 @@ sub SearchFieldRender {
         Name         => $FieldName,
         SelectedID   => $Value,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 1,
+        PossibleNone => 0,
         Class        => $FieldClass,
         Multiple     => 1,
         HTMLQuote    => 1,
@@ -878,16 +888,31 @@ sub RandomValueSet {
 sub IsMatchable {
     my ( $Self, %Param ) = @_;
 
-    return 0;
+    return 1;
 }
 
 sub ObjectMatch {
     my ( $Self, %Param ) = @_;
 
-    my $FieldName = $Param{DynamicFieldConfig}->{Name};
+    my $FieldName = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
 
-    # not supported
-    return 0;
+    # the attribute must be an array
+    return 0 if !IsArrayRefWithData( $Param{ObjectAttributes}->{$FieldName} );
+
+    my $Match;
+
+    # search in all values for this attribute
+    VALUE:
+    for my $AttributeValue ( @{ $Param{ObjectAttributes}->{$FieldName} } ) {
+
+        # only need to match one
+        if ( $Param{Value} eq $AttributeValue ) {
+            $Match = 1;
+            last VALUE;
+        }
+    }
+
+    return $Match;
 }
 
 sub AJAXPossibleValuesGet {
@@ -913,6 +938,19 @@ sub AJAXPossibleValuesGet {
     return \%PossibleValues;
 }
 
+sub HistoricalValuesGet {
+    my ( $Self, %Param ) = @_;
+
+    # get historical values from database
+    my $HistoricalValues = $Self->{DynamicFieldValueObject}->HistoricalValueGet(
+        FieldID   => $Param{DynamicFieldConfig}->{ID},
+        ValueType => 'Text',
+    );
+
+    # retrun the historical values from database
+    return $HistoricalValues;
+}
+
 1;
 
 =back
