@@ -2,7 +2,7 @@
 # Kernel/System/DynamicField/Backend/TextArea.pm - Delegate for DynamicField TextArea backend
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: TextArea.pm,v 1.46 2012/03/01 11:34:05 mg Exp $
+# $Id: TextArea.pm,v 1.48.2.4 2012/05/07 21:43:10 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.46 $) [1];
+$VERSION = qw($Revision: 1.48.2.4 $) [1];
 
 =head1 NAME
 
@@ -62,6 +62,10 @@ sub new {
     $Self->{BackendCommonObject}
         = Kernel::System::DynamicField::Backend::BackendCommon->new( %{$Self} );
 
+    # set the maximum lenght for the textarea fields to still be a searchable field in some
+    # databases
+    $Self->{MaxLength} = 3800;
+
     return $Self;
 }
 
@@ -109,6 +113,17 @@ sub ValueDelete {
     return $Success;
 }
 
+sub AllValuesDelete {
+    my ( $Self, %Param ) = @_;
+
+    my $Success = $Self->{DynamicFieldValueObject}->AllValuesDelete(
+        FieldID => $Param{DynamicFieldConfig}->{ID},
+        UserID  => $Param{UserID},
+    );
+
+    return $Success;
+}
+
 sub ValueValidate {
     my ( $Self, %Param ) = @_;
 
@@ -190,10 +205,12 @@ sub EditFieldRender {
     }
 
     # set the rows number
-    my $RowsNumber = ( defined $FieldConfig->{Rows} ? $FieldConfig->{Rows} : '7' );
+    my $RowsNumber
+        = defined $FieldConfig->{Rows} && $FieldConfig->{Rows} ? $FieldConfig->{Rows} : '7';
 
     # set the cols number
-    my $ColsNumber = ( defined $FieldConfig->{Cols} ? $FieldConfig->{Cols} : '42' );
+    my $ColsNumber
+        = defined $FieldConfig->{Cols} && $FieldConfig->{Cols} ? $FieldConfig->{Cols} : '42';
 
     # check and set class if necessary
     my $FieldClass = 'DynamicFieldTextArea';
@@ -207,18 +224,41 @@ sub EditFieldRender {
     # set error css class
     $FieldClass .= ' ServerError' if $Param{ServerError};
 
+    # set validation class for maximum characters
+    $FieldClass .= ' Validate_MaxLength';
+
+    # create field HTML
+    # the XHTML definition does not support maxlenght attribute for a textarea field, therefore
+    # is nedded to be set by JS code (otherwise wc3 validator will complaint about it)
+    # notice that some browsers count new lines \n\r as only 1 character in this cases the
+    # validation framework might rise an error while the user is still capable to enter text in the
+    # textarea, otherwise the maxlenght property will prevent to enter more text than the maximum
     my $HTMLString = <<"EOF";
 <textarea class="$FieldClass" id="$FieldName" name="$FieldName" title="$FieldLabel" rows="$RowsNumber" cols="$ColsNumber" >$Value</textarea>
+<!--dtl:js_on_document_complete-->
+<script type="text/javascript">//<![CDATA[
+  \$('#$FieldName').attr('maxlength','$Self->{MaxLength}');
+//]]></script>
+<!--dtl:js_on_document_complete-->
 EOF
 
-    if ( $Param{Mandatory} ) {
-        my $DivID = $FieldName . 'Error';
+    # for client side validation
+    my $DivID = $FieldName . 'Error';
 
-        # for client side validation
+    if ( $Param{Mandatory} ) {
         $HTMLString .= <<"EOF";
     <div id="$DivID" class="TooltipErrorMessage">
         <p>
-            \$Text{"This field is required."}
+            \$Text{"This field is required or The field content is too long! Maximum size is $Self->{MaxLength} characters."}
+        </p>
+    </div>
+EOF
+    }
+    else {
+        $HTMLString .= <<"EOF";
+    <div id="$DivID" class="TooltipErrorMessage">
+        <p>
+            \$Text{"The field content is too long! Maximum size is $Self->{MaxLength} characters."}
         </p>
     </div>
 EOF
@@ -301,6 +341,12 @@ sub EditFieldValueValidate {
         $ServerError = 1;
     }
 
+    if ( length $Value > $Self->{MaxLength} ) {
+        $ServerError = 1;
+        $ErrorMessage
+            = "The field content is too long! Maximum size is $Self->{MaxLength} characters.";
+    }
+
     # create resulting structure
     my $Result = {
         ServerError  => $ServerError,
@@ -581,6 +627,19 @@ sub AJAXPossibleValuesGet {
     return;
 }
 
+sub HistoricalValuesGet {
+    my ( $Self, %Param ) = @_;
+
+    # get historical values from database
+    my $HistoricalValues = $Self->{DynamicFieldValueObject}->HistoricalValueGet(
+        FieldID   => $Param{DynamicFieldConfig}->{ID},
+        ValueType => 'Text',
+    );
+
+    # retrun the historical values from database
+    return $HistoricalValues;
+}
+
 1;
 
 =back
