@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Email.pm - the global email send module
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Email.pm,v 1.64.2.2 2010/04/15 19:49:15 mh Exp $
+# $Id: Email.pm,v 1.75.2.5 2012/06/20 12:40:16 alm Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -21,7 +21,7 @@ use Kernel::System::Crypt;
 use Kernel::System::HTMLUtils;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.64.2.2 $) [1];
+$VERSION = qw($Revision: 1.75.2.5 $) [1];
 
 =head1 NAME
 
@@ -225,8 +225,13 @@ sub Send {
             MainObject   => $Self->{MainObject},
         );
         if ( !$CryptObject ) {
+            $Self->{LogObject}->Log(
+                Message  => 'Not possible to create crypt object',
+                Priority => 'error',
+            );
             return;
         }
+
         my $Body = $CryptObject->Crypt(
             Message => $Param{Body},
             Key     => $Param{Crypt}->{Key},
@@ -238,7 +243,7 @@ sub Send {
     }
 
     # build header
-    my %Header = ();
+    my %Header;
     for (qw(From To Cc Subject Charset Reply-To)) {
         next if !$Param{$_};
         $Header{$_} = $Param{$_};
@@ -246,8 +251,9 @@ sub Send {
 
     # loop
     if ( $Param{Loop} ) {
-        $Header{'X-Loop'} = 'yes';
-        $Header{Precedence} = 'bulk';
+        $Header{'X-Loop'}          = 'yes';
+        $Header{'Precedence:'}     = 'bulk';
+        $Header{'Auto-Submitted:'} = "auto-generated";
     }
 
     # do some encode
@@ -292,8 +298,10 @@ sub Send {
     my $Product = $Self->{ConfigObject}->Get('Product');
     my $Version = $Self->{ConfigObject}->Get('Version');
 
-    $Header{'X-Mailer'}     = "$Product Mail Service ($Version)";
-    $Header{'X-Powered-By'} = 'OTRS - Open Ticket Request System (http://otrs.org/)';
+    if ( !$Self->{ConfigObject}->Get('Secure::DisableBanner') ) {
+        $Header{'X-Mailer'}     = "$Product Mail Service ($Version)";
+        $Header{'X-Powered-By'} = 'OTRS - Open Ticket Request System (http://otrs.org/)';
+    }
     $Header{Type} = $Param{MimeType} || 'text/plain';
 
     # define email encoding
@@ -350,82 +358,53 @@ sub Send {
 
     # add attachments to email
     if ( $Param{Attachment} ) {
-        my $Count          = 0;
-        my $PartType       = '';
-        my @NewAttachments = ();
-        ATTACHMENTS:
+        my $Count    = 0;
+        my $PartType = '';
+        my @NewAttachments;
+        ATTACHMENT:
         for my $Upload ( @{ $Param{Attachment} } ) {
-            if ( defined $Upload->{Content} && defined $Upload->{Filename} ) {
 
-                # if it's a html email, add the first attachment as alternative (to show it
-                # as alternative content)
-                if ($HTMLEmail) {
-                    $Count++;
-                    if ( $Count == 1 ) {
-                        $Entity->make_multipart('alternative;');
-                        $PartType = 'alternative';
+            # ignore attachment if no content is given
+            next ATTACHMENT if !defined $Upload->{Content};
+
+            # ignore attachment if no filename is given
+            next ATTACHMENT if !defined $Upload->{Filename};
+
+            # prepare ContentType for Entity Type. $Upload->{ContentType} has
+            # useless `name` parameter, we don't need to send it to the `attach`
+            # constructor. For more details see Bug #7879 and MIME::Entity.
+            # Note: we should remove `name` attribute only.
+            my @ContentTypeTmp = grep { !/\s*name=/ } ( split /;/, $Upload->{ContentType} );
+            $Upload->{ContentType} = join ';', @ContentTypeTmp;
+
+            # if it's a html email, add the first attachment as alternative (to show it
+            # as alternative content)
+            if ($HTMLEmail) {
+                $Count++;
+                if ( $Count == 1 ) {
+                    $Entity->make_multipart('alternative;');
+                    $PartType = 'alternative';
+                }
+                else {
+
+                    # don't attach duplicate html attachment (aka file-2)
+                    next ATTACHMENT if
+                        $Upload->{Filename} eq 'file-2'
+                            && $Upload->{ContentType} =~ /html/i
+                            && $Upload->{Content} eq $Param{HTMLBody};
+
+                    # skip, but remember all attachments except inline images
+                    if ( !defined $Upload->{ContentID} ) {
+                        push @NewAttachments, \%{$Upload};
+                        next ATTACHMENT;
                     }
-                    else {
 
-                        # don't attach duplicate html attachment (aka file-2)
-                        next ATTACHMENTS if
-                            $Upload->{Filename} eq 'file-2'
-                                && $Upload->{ContentType} =~ /html/i
-                                && $Upload->{Content} eq $Param{HTMLBody};
-
-                        # skip, but remember all attachments except inline images
-                        if (
-                            !defined $Upload->{ContentID}
-                            || $Upload->{ContentID} !~ /^inline/
-                            )
-                        {
-                            push( @NewAttachments, \%{$Upload} );
-                            next ATTACHMENTS;
-                        }
-
-                        # add inline images as related
-                        if ( $PartType ne 'related' ) {
-                            $Entity->make_multipart( 'related;', Force => 1, );
-                            $PartType = 'related';
-                        }
+                    # add inline images as related
+                    if ( $PartType ne 'related' ) {
+                        $Entity->make_multipart( 'related;', Force => 1, );
+                        $PartType = 'related';
                     }
                 }
-
-                # content encode
-                $Self->{EncodeObject}->EncodeOutput( \$Upload->{Content} );
-
-                # filename encode
-                my $Filename = $Self->_EncodeMIMEWords(
-                    Field   => 'filename',
-                    Line    => $Upload->{Filename},
-                    Charset => $Param{Charset},
-                );
-
-                # format content id, leave undefined if no value
-                my $ContentID = $Upload->{ContentID};
-                if ( $ContentID && $ContentID !~ /^</ ) {
-                    $ContentID = '<' . $ContentID . '>';
-                }
-
-                # attach file to email
-                $Entity->attach(
-                    Filename    => $Filename,
-                    Data        => $Upload->{Content},
-                    Type        => $Upload->{ContentType},
-                    Id          => $ContentID,
-                    Disposition => $Upload->{Disposition} || 'inline',
-                    Encoding    => $Upload->{Encoding} || '-SUGGEST',
-                );
-            }
-        }
-
-        # add all other attachments as multipart mixed (if we had html body)
-        for my $Upload (@NewAttachments) {
-
-            # make multipart mixed
-            if ( $PartType ne 'mixed' ) {
-                $Entity->make_multipart( 'mixed;', Force => 1, );
-                $PartType = 'mixed';
             }
 
             # content encode
@@ -454,6 +433,35 @@ sub Send {
                 Encoding    => $Upload->{Encoding} || '-SUGGEST',
             );
         }
+
+        # add all other attachments as multipart mixed (if we had html body)
+        for my $Upload (@NewAttachments) {
+
+            # make multipart mixed
+            if ( $PartType ne 'mixed' ) {
+                $Entity->make_multipart( 'mixed;', Force => 1, );
+                $PartType = 'mixed';
+            }
+
+            # content encode
+            $Self->{EncodeObject}->EncodeOutput( \$Upload->{Content} );
+
+            # filename encode
+            my $Filename = $Self->_EncodeMIMEWords(
+                Field   => 'filename',
+                Line    => $Upload->{Filename},
+                Charset => $Param{Charset},
+            );
+
+            # attach file to email (no content id needed)
+            $Entity->attach(
+                Filename    => $Filename,
+                Data        => $Upload->{Content},
+                Type        => $Upload->{ContentType},
+                Disposition => $Upload->{Disposition} || 'inline',
+                Encoding    => $Upload->{Encoding} || '-SUGGEST',
+            );
+        }
     }
 
     # get sign options for detached
@@ -467,8 +475,13 @@ sub Send {
             CryptType    => $Param{Sign}->{Type},
         );
         if ( !$CryptObject ) {
+            $Self->{LogObject}->Log(
+                Message  => 'Not possible to create crypt object',
+                Priority => 'error',
+            );
             return;
         }
+
         if ( $Param{Sign}->{Type} eq 'PGP' ) {
 
             # make_multipart -=> one attachment for sign
@@ -526,16 +539,16 @@ sub Send {
             $T =~ s/\x0A/\x0D\x0A/g;
             $T =~ s/\x0D+/\x0D/g;
             my $Sign = $CryptObject->Sign(
-                Message => $T,
-                Hash    => $Param{Sign}->{Key},
-                Type    => 'Detached',
+                Message  => $T,
+                Filename => $Param{Sign}->{Key},
+                Type     => 'Detached',
             );
             if ($Sign) {
                 use MIME::Parser;
-                my $Parser = new MIME::Parser;
+                my $Parser = MIME::Parser->new();
                 $Parser->output_to_core('ALL');
 
-                #        $Parser->output_dir($Self->{ConfigObject}->Get('TempDir'));
+                $Parser->output_dir( $Self->{ConfigObject}->Get('TempDir') );
                 $Entity = $Parser->parse_data( $Header . $Sign );
             }
         }
@@ -558,9 +571,7 @@ sub Send {
             MainObject   => $Self->{MainObject},
             CryptType    => $Param{Crypt}->{Type},
         );
-        if ( !$CryptObject ) {
-            return;
-        }
+        return if !$CryptObject;
 
         # make_multipart -=> one attachment for encryption
         $Entity->make_multipart(
@@ -611,7 +622,12 @@ sub Send {
             MainObject   => $Self->{MainObject},
             CryptType    => $Param{Crypt}->{Type},
         );
+
         if ( !$CryptObject ) {
+            $Self->{LogObject}->Log(
+                Message  => 'Failed creation of crypt object',
+                Priority => 'error',
+            );
             return;
         }
 
@@ -628,13 +644,13 @@ sub Send {
 
         # crypt it
         my $Crypt = $CryptObject->Crypt(
-            Message => $Entity->parts(0)->as_string(),
-            Hash    => $Param{Crypt}->{Key},
+            Message  => $Entity->parts(0)->as_string(),
+            Filename => $Param{Crypt}->{Key},
         );
         use MIME::Parser;
-        my $Parser = new MIME::Parser;
+        my $Parser = MIME::Parser->new();
 
-        #        $Parser->output_dir($Self->{ConfigObject}->Get('TempDir'));
+        $Parser->output_dir( $Self->{ConfigObject}->Get('TempDir') );
         $Entity = $Parser->parse_data( $Header . $Crypt );
     }
 
@@ -656,8 +672,8 @@ sub Send {
     $Param{Body} = $Entity->body_as_string();
 
     # get recipients
-    my @ToArray = ();
-    my $To      = '';
+    my @ToArray;
+    my $To = '';
     for (qw(To Cc Bcc)) {
         next if !$Param{$_};
         for my $Email ( Mail::Address->parse( $Param{$_} ) ) {
@@ -699,11 +715,38 @@ sub Send {
         Body    => \$Param{Body},
     );
 
-    return if !$Sent;
+    if ( !$Sent ) {
+        $Self->{LogObject}->Log(
+            Message  => "Error sending message",
+            Priority => 'info',
+        );
+        return;
+    }
 
     return ( \$Param{Header}, \$Param{Body} );
 }
 
+=item Check()
+
+Check mail configuration
+
+    my %Check = $SendObject->Check();
+
+=cut
+
+sub Check {
+    my ( $Self, %Param ) = @_;
+
+    my %Check = $Self->{Backend}->Check();
+
+    if ( $Check{Successful} ) {
+        return ( Successful => 1 )
+    }
+    else {
+        return ( Successful => 0, Message => $Check{Message} );
+    }
+}
+
 =item Bounce()
 
 Bounce an email
@@ -779,6 +822,10 @@ sub Bounce {
     return ( \$HeaderAsString, \$BodyAsString );
 }
 
+=begin Internal:
+
+=cut
+
 sub _EncodeMIMEWords {
     my ( $Self, %Param ) = @_;
 
@@ -829,20 +876,22 @@ sub _MessageIDCreate {
 
 1;
 
+=end Internal:
+
 =back
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.64.2.2 $ $Date: 2010/04/15 19:49:15 $
+$Revision: 1.75.2.5 $ $Date: 2012/06/20 12:40:16 $
 
 =cut
