@@ -1,8 +1,8 @@
 # --
 # Kernel/System/LinkObject.pm - to link objects
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: LinkObject.pm,v 1.52.2.1 2009/10/01 18:05:44 martin Exp $
+# $Id: LinkObject.pm,v 1.58 2010/08/27 19:07:11 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,9 +16,10 @@ use warnings;
 
 use Kernel::System::CheckItem;
 use Kernel::System::Valid;
+use Kernel::System::CacheInternal;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.52.2.1 $) [1];
+$VERSION = qw($Revision: 1.58 $) [1];
 
 =head1 NAME
 
@@ -89,10 +90,15 @@ sub new {
 
     # check needed objects
     for (qw(DBObject ConfigObject LogObject MainObject EncodeObject TimeObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
+        $Self->{$_} = $Param{$_} || die;
     }
-    $Self->{CheckItemObject} = Kernel::System::CheckItem->new( %{$Self} );
-    $Self->{ValidObject}     = Kernel::System::Valid->new( %{$Self} );
+    $Self->{CheckItemObject}     = Kernel::System::CheckItem->new( %{$Self} );
+    $Self->{ValidObject}         = Kernel::System::Valid->new( %{$Self} );
+    $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
+        %{$Self},
+        Type => 'LinkObject',
+        TTL  => 60 * 60 * 3,
+    );
 
     return $Self;
 }
@@ -139,8 +145,8 @@ sub PossibleTypesList {
     for my $PossibleLink ( keys %PossibleLinkList ) {
 
         # extract objects
-        my $Object1 = $PossibleLinkList{$PossibleLink}{Object1};
-        my $Object2 = $PossibleLinkList{$PossibleLink}{Object2};
+        my $Object1 = $PossibleLinkList{$PossibleLink}->{Object1};
+        my $Object2 = $PossibleLinkList{$PossibleLink}->{Object2};
 
         next POSSIBLELINK
             if ( $Object1 eq $Param{Object1} && $Object2 eq $Param{Object2} )
@@ -160,11 +166,11 @@ sub PossibleTypesList {
     for my $PossibleLink ( keys %PossibleLinkList ) {
 
         # extract type
-        my $Type = $PossibleLinkList{$PossibleLink}{Type} || '';
+        my $Type = $PossibleLinkList{$PossibleLink}->{Type} || '';
 
         next POSSIBLELINK if $TypeList{$Type};
 
-        # remove entry from list if type doesn't exists
+        # remove entry from list if type doesn't exist
         delete $PossibleLinkList{$PossibleLink};
     }
 
@@ -173,7 +179,7 @@ sub PossibleTypesList {
     for my $PossibleLink ( keys %PossibleLinkList ) {
 
         # extract type
-        my $Type = $PossibleLinkList{$PossibleLink}{Type};
+        my $Type = $PossibleLinkList{$PossibleLink}->{Type};
 
         $PossibleTypesList{$Type} = 1;
     }
@@ -223,8 +229,8 @@ sub PossibleObjectsList {
     for my $PossibleLink ( keys %PossibleLinkList ) {
 
         # extract objects
-        my $Object1 = $PossibleLinkList{$PossibleLink}{Object1};
-        my $Object2 = $PossibleLinkList{$PossibleLink}{Object2};
+        my $Object1 = $PossibleLinkList{$PossibleLink}->{Object1};
+        my $Object2 = $PossibleLinkList{$PossibleLink}->{Object2};
 
         next POSSIBLELINK if $Param{Object} ne $Object1 && $Param{Object} ne $Object2;
 
@@ -286,15 +292,15 @@ sub PossibleLinkList {
         for my $Argument (qw(Object1 Object2 Type)) {
 
             # set empty string as default value
-            $PossibleLinkList{$PossibleLink}{$Argument} ||= '';
+            $PossibleLinkList{$PossibleLink}->{$Argument} ||= '';
 
             # trim the argument
             $Self->{CheckItemObject}->StringClean(
-                StringRef => \$PossibleLinkList{$PossibleLink}{$Argument},
+                StringRef => \$PossibleLinkList{$PossibleLink}->{$Argument},
             );
 
             # extract value
-            my $Value = $PossibleLinkList{$PossibleLink}{$Argument} || '';
+            my $Value = $PossibleLinkList{$PossibleLink}->{$Argument} || '';
 
             next ARGUMENT if $Value && $Value !~ m{ :: }xms && $Value !~ m{ \s }xms;
 
@@ -319,12 +325,12 @@ sub PossibleLinkList {
     POSSIBLELINK:
     for my $PossibleLink ( keys %PossibleLinkList ) {
 
-        # check if object backends exists
+        # check if object backends exist
         ARGUMENT:
         for my $Argument (qw(Object1 Object2)) {
 
             # extract object
-            my $Object = $PossibleLinkList{$PossibleLink}{$Argument};
+            my $Object = $PossibleLinkList{$PossibleLink}->{$Argument};
 
             next ARGUMENT if -e $BackendLocation . $Object . '.pm';
 
@@ -345,7 +351,7 @@ sub PossibleLinkList {
     for my $PossibleLink ( keys %PossibleLinkList ) {
 
         # extract type
-        my $Type = $PossibleLinkList{$PossibleLink}{Type};
+        my $Type = $PossibleLinkList{$PossibleLink}->{Type};
 
         next POSSIBLELINK if $TypeList{$Type};
 
@@ -355,7 +361,7 @@ sub PossibleLinkList {
             Message  => "The LinkType '$Type' is invalid in SysConfig (LinkObject::PossibleLink)!",
         );
 
-        # remove entry from list if type doesn't exists
+        # remove entry from list if type doesn't exist
         delete $PossibleLinkList{$PossibleLink};
     }
 
@@ -450,7 +456,7 @@ sub LinkAdd {
     );
 
     # check if link already exists in database
-    $Self->{DBObject}->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT source_object_id, source_key, state_id '
             . 'FROM link_relation '
             . 'WHERE ( ( source_object_id = ? AND source_key = ? '
@@ -1041,7 +1047,7 @@ sub LinkList {
     }
 
     # get links where the given object is the source
-    $Self->{DBObject}->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT target_object_id, target_key, type_id '
             . 'FROM link_relation '
             . 'WHERE source_object_id = ? '
@@ -1085,7 +1091,7 @@ sub LinkList {
     }
 
     # get links where the given object is the target
-    $Self->{DBObject}->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL =>
             'SELECT source_object_id, source_key, type_id '
             . 'FROM link_relation '
@@ -1493,11 +1499,12 @@ sub ObjectLookup {
     if ( $Param{ObjectID} ) {
 
         # check cache
-        return $Self->{Cache}->{ObjectLookup}->{ObjectID}->{ $Param{ObjectID} }
-            if $Self->{Cache}->{ObjectLookup}->{ObjectID}->{ $Param{ObjectID} };
+        my $CacheKey = 'ObjectLookup::ObjectID::' . $Param{ObjectID};
+        my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+        return $Cache if $Cache;
 
         # ask the database
-        $Self->{DBObject}->Prepare(
+        return if !$Self->{DBObject}->Prepare(
             SQL   => 'SELECT name FROM link_object WHERE id = ?',
             Bind  => [ \$Param{ObjectID} ],
             Limit => 1,
@@ -1518,17 +1525,20 @@ sub ObjectLookup {
             return;
         }
 
-        # cache result
-        $Self->{Cache}->{ObjectLookup}->{ObjectID}->{ $Param{ObjectID} } = $Name;
-        $Self->{Cache}->{ObjectLookup}->{Name}->{$Name} = $Param{ObjectID};
+        # set cache
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => $Name,
+        );
 
         return $Name;
     }
     else {
 
         # check cache
-        return $Self->{Cache}->{ObjectLookup}->{Name}->{ $Param{Name} }
-            if $Self->{Cache}->{ObjectLookup}->{Name}->{ $Param{Name} };
+        my $CacheKey = 'ObjectLookup::Name::' . $Param{Name};
+        my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+        return $Cache if $Cache;
 
         # investigate the object id
         my $ObjectID;
@@ -1536,7 +1546,7 @@ sub ObjectLookup {
         for my $Try ( 1 .. 3 ) {
 
             # ask the database
-            $Self->{DBObject}->Prepare(
+            return if !$Self->{DBObject}->Prepare(
                 SQL   => 'SELECT id FROM link_object WHERE name = ?',
                 Bind  => [ \$Param{Name} ],
                 Limit => 1,
@@ -1572,9 +1582,11 @@ sub ObjectLookup {
             );
         }
 
-        # cache result
-        $Self->{Cache}->{ObjectLookup}->{Name}->{ $Param{Name} } = $ObjectID;
-        $Self->{Cache}->{ObjectLookup}->{ObjectID}->{$ObjectID} = $Param{Name};
+        # set cache
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => $ObjectID,
+        );
 
         return $ObjectID;
     }
@@ -1619,11 +1631,12 @@ sub TypeLookup {
     if ( $Param{TypeID} ) {
 
         # check cache
-        return $Self->{Cache}->{TypeLookup}->{TypeID}->{ $Param{TypeID} }
-            if $Self->{Cache}->{TypeLookup}->{TypeID}->{ $Param{TypeID} };
+        my $CacheKey = 'TypeLookup::TypeID::' . $Param{TypeID};
+        my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+        return $Cache if $Cache;
 
         # ask the database
-        $Self->{DBObject}->Prepare(
+        return if !$Self->{DBObject}->Prepare(
             SQL   => 'SELECT name FROM link_type WHERE id = ?',
             Bind  => [ \$Param{TypeID} ],
             Limit => 1,
@@ -1644,9 +1657,11 @@ sub TypeLookup {
             return;
         }
 
-        # cache result
-        $Self->{Cache}->{TypeLookup}->{TypeID}->{ $Param{TypeID} } = $Name;
-        $Self->{Cache}->{TypeLookup}->{Name}->{$Name} = $Param{TypeID};
+        # set cache
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => $Name,
+        );
 
         return $Name;
     }
@@ -1658,8 +1673,9 @@ sub TypeLookup {
         );
 
         # check cache
-        return $Self->{Cache}->{TypeLookup}->{Name}->{ $Param{Name} }
-            if $Self->{Cache}->{TypeLookup}->{Name}->{ $Param{Name} };
+        my $CacheKey = 'TypeLookup::Name::' . $Param{Name};
+        my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+        return $Cache if $Cache;
 
         # investigate the type id
         my $TypeID;
@@ -1667,7 +1683,7 @@ sub TypeLookup {
         for my $Try ( 1 .. 2 ) {
 
             # ask the database
-            $Self->{DBObject}->Prepare(
+            return if !$Self->{DBObject}->Prepare(
                 SQL   => 'SELECT id FROM link_type WHERE name = ?',
                 Bind  => [ \$Param{Name} ],
                 Limit => 1,
@@ -1707,9 +1723,11 @@ sub TypeLookup {
             return;
         }
 
-        # cache result
-        $Self->{Cache}->{TypeLookup}->{Name}->{ $Param{Name} } = $TypeID;
-        $Self->{Cache}->{TypeLookup}->{TypeID}->{$TypeID} = $Param{Name};
+        # set cache
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => $TypeID,
+        );
 
         return $TypeID;
     }
@@ -1756,7 +1774,7 @@ sub TypeGet {
         if $Self->{Cache}->{TypeGet}->{TypeID}->{ $Param{TypeID} };
 
     # ask the database
-    $Self->{DBObject}->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT id, name, create_time, create_by, change_time, change_by '
             . 'FROM link_type WHERE id = ?',
         Bind  => [ \$Param{TypeID} ],
@@ -1979,7 +1997,7 @@ sub TypeGroupList {
                     "The LinkType '$Type' is invalid in SysConfig (LinkObject::TypeGroup)!",
             );
 
-            # remove entry from list if type doesn't exists
+            # remove entry from list if type doesn't exist
             delete $TypeGroupList{$TypeGroup};
 
             next TYPEGROUP;
@@ -2072,11 +2090,12 @@ sub StateLookup {
     if ( $Param{StateID} ) {
 
         # check cache
-        return $Self->{Cache}->{StateLookup}->{StateID}->{ $Param{StateID} }
-            if $Self->{Cache}->{StateLookup}->{StateID}->{ $Param{StateID} };
+        my $CacheKey = 'StateLookup::StateID::' . $Param{StateID};
+        my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+        return $Cache if $Cache;
 
         # ask the database
-        $Self->{DBObject}->Prepare(
+        return if !$Self->{DBObject}->Prepare(
             SQL   => 'SELECT name FROM link_state WHERE id = ?',
             Bind  => [ \$Param{StateID} ],
             Limit => 1,
@@ -2097,20 +2116,23 @@ sub StateLookup {
             return;
         }
 
-        # cache result
-        $Self->{Cache}->{StateLookup}->{StateID}->{ $Param{StateID} } = $Name;
-        $Self->{Cache}->{StateLookup}->{Name}->{$Name} = $Param{StateID};
+        # set cache
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => $Name,
+        );
 
         return $Name;
     }
     else {
 
         # check cache
-        return $Self->{Cache}->{StateLookup}->{Name}->{ $Param{Name} }
-            if $Self->{Cache}->{StateLookup}->{Name}->{ $Param{Name} };
+        my $CacheKey = 'StateLookup::Name::' . $Param{Name};
+        my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+        return $Cache if $Cache;
 
         # ask the database
-        $Self->{DBObject}->Prepare(
+        return if !$Self->{DBObject}->Prepare(
             SQL   => 'SELECT id FROM link_state WHERE name = ?',
             Bind  => [ \$Param{Name} ],
             Limit => 1,
@@ -2131,9 +2153,11 @@ sub StateLookup {
             return;
         }
 
-        # cache result
-        $Self->{Cache}->{StateLookup}->{Name}->{ $Param{Name} } = $StateID;
-        $Self->{Cache}->{StateLookup}->{StateID}->{$StateID} = $Param{Name};
+        # set cache
+        $Self->{CacheInternalObject}->Set(
+            Key   => $CacheKey,
+            Value => $StateID,
+        );
 
         return $StateID;
     }
@@ -2181,7 +2205,7 @@ sub StateList {
     }
 
     # ask database
-    $Self->{DBObject}->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL => "SELECT id, name FROM link_state $SQLWhere",
     );
 
@@ -2301,6 +2325,8 @@ sub ObjectSearch {
     return \%ObjectList;
 }
 
+=begin Internal:
+
 =item _LoadBackend()
 
 to load a link object backend module
@@ -2345,9 +2371,6 @@ sub _LoadBackend {
     my $BackendObject = $BackendModule->new(
         %{$Self},
         %Param,
-
-        # REMOVE ME in OTRS 2.5 and higher: not longer needed
-        LinkObject => 'not_used',
     );
 
     if ( !$BackendObject ) {
@@ -2366,20 +2389,22 @@ sub _LoadBackend {
 
 1;
 
+=end Internal:
+
 =back
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.52.2.1 $ $Date: 2009/10/01 18:05:44 $
+$Revision: 1.58 $ $Date: 2010/08/27 19:07:11 $
 
 =cut
