@@ -1,12 +1,12 @@
 # --
 # Kernel/System/LinkObject/Ticket.pm - to link ticket objects
-# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Ticket.pm,v 1.31 2008/08/02 13:53:05 martin Exp $
+# $Id: Ticket.pm,v 1.38 2012/01/10 14:44:27 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::LinkObject::Ticket;
@@ -16,8 +16,71 @@ use warnings;
 
 use Kernel::System::Ticket;
 
+=head1 NAME
+
+Kernel::System::LinkObject::Ticket
+
+=head1 SYNOPSIS
+
+Ticket backend for the ticket link object.
+
+=head1 PUBLIC INTERFACE
+
+=over 4
+
+=cut
+
+=item new()
+
+create an object
+
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Time;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::LinkObject::Ticket;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $TimeObject = Kernel::System::Time->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        MainObject   => $MainObject,
+    );
+    my $TicketObject = Kernel::System::LinkObject::Ticket->new(
+        ConfigObject       => $ConfigObject,
+        LogObject          => $LogObject,
+        DBObject           => $DBObject,
+        MainObject         => $MainObject,
+        TimeObject         => $TimeObject,
+        EncodeObject       => $EncodeObject,
+        GroupObject        => $GroupObject,        # if given
+        CustomerUserObject => $CustomerUserObject, # if given
+        QueueObject        => $QueueObject,        # if given
+    );
+
+=cut
+
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.31 $) [1];
+$VERSION = qw($Revision: 1.38 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -27,7 +90,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(DBObject ConfigObject LogObject MainObject TimeObject LinkObject)) {
+    for (qw(DBObject ConfigObject LogObject MainObject EncodeObject TimeObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
     $Self->{TicketObject} = Kernel::System::Ticket->new( %{$Self} );
@@ -78,8 +141,9 @@ sub LinkListWithData {
 
                 # get ticket data
                 my %TicketData = $Self->{TicketObject}->TicketGet(
-                    TicketID => $TicketID,
-                    UserID   => $Param{UserID},
+                    TicketID      => $TicketID,
+                    UserID        => $Param{UserID},
+                    DynamicFields => 0,
                 );
 
                 # remove id from hash if ticket can not get
@@ -139,8 +203,9 @@ sub ObjectDescriptionGet {
 
     # get ticket
     my %Ticket = $Self->{TicketObject}->TicketGet(
-        TicketID => $Param{Key},
-        UserID   => 1,
+        TicketID      => $Param{Key},
+        UserID        => 1,
+        DynamicFields => 0,
     );
 
     return if !%Ticket;
@@ -212,13 +277,15 @@ sub ObjectSearch {
     my @TicketIDs = $Self->{TicketObject}->TicketSearch(
         %{ $Param{SearchParams} },
         %Search,
-        Limit           => 50,
-        Result          => 'ARRAY',
-        ConditionInline => 1,
-        FullTextIndex   => 1,
-        OrderBy         => 'Down',
-        SortBy          => 'Age',
-        UserID          => $Param{UserID},
+        Limit               => 50,
+        Result              => 'ARRAY',
+        ConditionInline     => 1,
+        ContentSearchPrefix => '*',
+        ContentSearchSuffix => '*',
+        FullTextIndex       => 1,
+        OrderBy             => 'Down',
+        SortBy              => 'Age',
+        UserID              => $Param{UserID},
     );
 
     my %SearchList;
@@ -227,8 +294,9 @@ sub ObjectSearch {
 
         # get ticket data
         my %TicketData = $Self->{TicketObject}->TicketGet(
-            TicketID => $TicketID,
-            UserID   => $Param{UserID},
+            TicketID      => $TicketID,
+            UserID        => $Param{UserID},
+            DynamicFields => 0,
         );
 
         next TICKETID if !%TicketData;
@@ -344,10 +412,12 @@ sub LinkAddPost {
         );
 
         # ticket event
-        $Self->{TicketObject}->TicketEventHandlerPost(
-            Event    => 'TicketSlaveLinkAdd' . $Param{Type},
-            UserID   => $Param{UserID},
-            TicketID => $Param{Key},
+        $Self->{TicketObject}->EventHandler(
+            Event => 'TicketSlaveLinkAdd' . $Param{Type},
+            Data  => {
+                TicketID => $Param{Key},
+            },
+            UserID => $Param{UserID},
         );
 
         return 1;
@@ -370,10 +440,12 @@ sub LinkAddPost {
         );
 
         # ticket event
-        $Self->{TicketObject}->TicketEventHandlerPost(
-            Event    => 'TicketMasterLinkAdd' . $Param{Type},
-            UserID   => $Param{UserID},
-            TicketID => $Param{Key},
+        $Self->{TicketObject}->EventHandler(
+            Event  => 'TicketMasterLinkAdd' . $Param{Type},
+            UserID => $Param{UserID},
+            Data   => {
+                TicketID => $Param{Key},
+            },
         );
 
         return 1;
@@ -486,10 +558,12 @@ sub LinkDeletePost {
         );
 
         # ticket event
-        $Self->{TicketObject}->TicketEventHandlerPost(
-            Event    => 'TicketSlaveLinkDelete' . $Param{Type},
-            UserID   => $Param{UserID},
-            TicketID => $Param{Key},
+        $Self->{TicketObject}->EventHandler(
+            Event => 'TicketSlaveLinkDelete' . $Param{Type},
+            Data  => {
+                TicketID => $Param{Key},
+            },
+            UserID => $Param{UserID},
         );
 
         return 1;
@@ -512,10 +586,12 @@ sub LinkDeletePost {
         );
 
         # ticket event
-        $Self->{TicketObject}->TicketEventHandlerPost(
-            Event    => 'TicketMasterLinkDelete' . $Param{Type},
-            UserID   => $Param{UserID},
-            TicketID => $Param{Key},
+        $Self->{TicketObject}->EventHandler(
+            Event => 'TicketMasterLinkDelete' . $Param{Type},
+            Data  => {
+                TicketID => $Param{Key},
+            },
+            UserID => $Param{UserID},
         );
 
         return 1;
@@ -525,3 +601,19 @@ sub LinkDeletePost {
 }
 
 1;
+
+=back
+
+=head1 TERMS AND CONDITIONS
+
+This software is part of the OTRS project (L<http://otrs.org/>).
+
+This software comes with ABSOLUTELY NO WARRANTY. For details, see
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=head1 VERSION
+
+$Revision: 1.38 $ $Date: 2012/01/10 14:44:27 $
+
+=cut
