@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Lock.pm - All Groups related function should be here eventually
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: Lock.pm,v 1.29 2009/04/17 08:36:44 tr Exp $
+# $Id: Lock.pm,v 1.35 2012/03/19 01:10:11 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,10 +14,11 @@ package Kernel::System::Lock;
 use strict;
 use warnings;
 
+use Kernel::System::CacheInternal;
 use Kernel::System::Valid;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.29 $) [1];
+$VERSION = qw($Revision: 1.35 $) [1];
 
 =head1 NAME
 
@@ -27,6 +28,9 @@ Kernel::System::Lock - lock lib
 
 All lock functions.
 
+The whole lock API is just for "reading" lock states. Per default you have "unlock", "lock" and "lock-tmp".
+Usually you will not modify those lock states, because there is not usecase for this.
+
 =head1 PUBLIC INTERFACE
 
 =over 4
@@ -40,7 +44,6 @@ create an object
     use Kernel::Config;
     use Kernel::System::Encode;
     use Kernel::System::Log;
-    use Kernel::System::Time;
     use Kernel::System::Main;
     use Kernel::System::DB;
     use Kernel::System::Lock;
@@ -53,10 +56,6 @@ create an object
         ConfigObject => $ConfigObject,
         EncodeObject => $EncodeObject,
     );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
     my $MainObject = Kernel::System::Main->new(
         ConfigObject => $ConfigObject,
         EncodeObject => $EncodeObject,
@@ -72,7 +71,8 @@ create an object
         ConfigObject => $ConfigObject,
         LogObject    => $LogObject,
         DBObject     => $DBObject,
-        TimeObject   => $TimeObject,
+        MainObject   => $MainObject,
+        EncodeObject => $EncodeObject,
     );
 
 =cut
@@ -85,10 +85,15 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(DBObject ConfigObject LogObject)) {
+    for (qw(DBObject ConfigObject LogObject MainObject EncodeObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
-    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
+    $Self->{ValidObject}         = Kernel::System::Valid->new(%Param);
+    $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
+        %Param,
+        Type => 'Lock',
+        TTL  => 60 * 60 * 3,
+    );
 
     # get ViewableLocks
     $Self->{ViewableLocks} = $Self->{ConfigObject}->Get('Ticket::ViewableLocks')
@@ -99,16 +104,24 @@ sub new {
 
 =item LockViewableLock()
 
-get list of lock types
+get list of viewable lock types (used to show available tickets)
 
     my @List = $LockObject->LockViewableLock(
         Type => 'Name', # ID|Name
     );
 
-    my @List = $LockObject->LockViewableLock(
+Returns:
+
+    @List = ( 'unlock', 'lock', 'lock-tmp' );
+
+    my @ListID = $LockObject->LockViewableLock(
         Type => 'ID', # ID|Name
     );
 
+Returns:
+
+    @List = ( 1, 2, 3 );
+
 =cut
 
 sub LockViewableLock {
@@ -124,9 +137,8 @@ sub LockViewableLock {
 
     # check cache
     my $CacheKey = 'LockViewableLock::' . $Param{Type};
-    if ( $Self->{$CacheKey} ) {
-        return @{ $Self->{$CacheKey} };
-    }
+    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    return @{$Cache} if $Cache;
 
     # sql
     return if !$Self->{DBObject}->Prepare(
@@ -135,28 +147,30 @@ sub LockViewableLock {
             . " valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )",
     );
 
-    my @Name = ();
-    my @ID   = ();
+    my @Name;
+    my @ID;
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
         push @Name, $Data[1];
         push @ID,   $Data[0];
     }
 
-    # cache result
-    $Self->{'LockViewableLock::Name'} = \@Name;
-    $Self->{'LockViewableLock::ID'}   = \@ID;
+    # set cache
+    $Self->{CacheInternalObject}->Set(
+        Key   => 'LockViewableLock::Name',
+        Value => \@Name,
+    );
+    $Self->{CacheInternalObject}->Set(
+        Key   => 'LockViewableLock::ID',
+        Value => \@ID,
+    );
 
-    if ( $Param{Type} eq 'Name' ) {
-        return @Name;
-    }
-    else {
-        return @ID;
-    }
+    return @Name if $Param{Type} eq 'Name';
+    return @ID;
 }
 
 =item LockLookup()
 
-lock lookup
+lock state lookup by ID or Name
 
     my $LockID = $LockObject->LockLookup( Lock => 'lock' );
 
@@ -167,60 +181,54 @@ lock lookup
 sub LockLookup {
     my ( $Self, %Param ) = @_;
 
-    # check needed stuff
-    my $Key = '';
-    if ( !$Param{Lock} && $Param{LockID} ) {
-        $Key = 'LockID';
-    }
-    if ( $Param{Lock} && !$Param{LockID} ) {
-        $Key = 'Lock';
-    }
-    if ( !$Param{Lock} && !$Param{LockID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Lock or LockID!' );
-        return;
-    }
+    # get (already cached) lock list
+    my %LockList = $Self->LockList(
+        UserID => 1,
+    );
 
-    # check if we ask the same request?
-    my $CacheKey = 'Lock::Lookup::' . $Param{$Key};
-    if ( $Self->{$CacheKey} ) {
-        return $Self->{$CacheKey};
-    }
-
-    # db query
-    my $SQL;
-    my @Bind;
-    if ( $Param{Lock} ) {
-        $SQL = 'SELECT id FROM ticket_lock_type WHERE name = ?';
-        push @Bind, \$Param{Lock};
+    my $Key;
+    my $Value;
+    my $ReturnData;
+    if ( $Param{LockID} ) {
+        $Key        = 'LockID';
+        $Value      = $Param{LockID};
+        $ReturnData = $LockList{ $Param{LockID} };
     }
     else {
-        $SQL = 'SELECT name FROM ticket_lock_type WHERE id = ?';
-        push @Bind, \$Param{LockID};
-    }
-    $Self->{DBObject}->Prepare( SQL => $SQL, Bind => \@Bind );
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
-        $Self->{$CacheKey} = $Row[0];
+        $Key   = 'Lock';
+        $Value = $Param{Lock};
+        my %LockListReverse = reverse %LockList;
+        $ReturnData = $LockListReverse{ $Param{Lock} };
     }
 
     # check if data exists
-    if ( !$Self->{$CacheKey} ) {
+    if ( !defined $ReturnData ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "No Lock/LockID for $Param{$Key} found!",
+            Message  => "No $Key for $Value found!",
         );
         return;
     }
-    return $Self->{$CacheKey};
+
+    return $ReturnData;
 }
 
 =item LockList()
 
-get lock list
+get lock state list
 
     my %List = $LockObject->LockList(
         UserID => 123,
     );
 
+Returns:
+
+    %List = (
+        1 => 'unlock',
+        2 => 'lock',
+        3 => 'lock-tmp',
+    );
+
 =cut
 
 sub LockList {
@@ -233,21 +241,27 @@ sub LockList {
     }
 
     # check cache
-    if ( $Self->{LockList} ) {
-        return %{ $Self->{LockList} };
-    }
+    my $CacheKey = 'LockList';
+    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    return %{$Cache} if $Cache;
 
     # sql
     return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT id, name FROM ticket_lock_type',
     );
-    my %Data = ();
+
+    # fetch the result
+    my %Data;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
 
-    # cache result
-    $Self->{LockList} = \%Data;
+    # set cache
+    $Self->{CacheInternalObject}->Set(
+        Key   => $CacheKey,
+        Value => \%Data,
+    );
+
     return %Data;
 }
 
@@ -257,16 +271,16 @@ sub LockList {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.29 $ $Date: 2009/04/17 08:36:44 $
+$Revision: 1.35 $ $Date: 2012/03/19 01:10:11 $
 
 =cut
