@@ -1,8 +1,8 @@
 # --
 # Kernel/System/MailAccount/POP3S.pm - lib for pop3 accounts
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: POP3S.pm,v 1.10.2.1 2010/01/13 16:56:02 martin Exp $
+# $Id: POP3S.pm,v 1.13 2011/03/09 13:41:55 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -23,7 +23,7 @@ use IO::Socket::SSL;
 use Kernel::System::PostMaster;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.10.2.1 $) [1];
+$VERSION = qw($Revision: 1.13 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -43,6 +43,61 @@ sub new {
     return $Self;
 }
 
+sub Connect {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    for (qw(Login Password Host Timeout Debug)) {
+        if ( !defined $Param{$_} ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            return;
+        }
+    }
+
+    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
+    #    my $PopObject
+    #        = Net::POP3->new( $Param{Host}, Port => 995, Timeout => $Timeout, Debug => $Debug );
+
+    # connect to host
+    my $PopObject = Mail::POP3Client->new(
+        USER     => $Param{Login},
+        PASSWORD => $Param{Password},
+        HOST     => $Param{Host},
+        USESSL   => 'true',
+    );
+
+    if ( !$PopObject ) {
+        return ( Successful => 0, Message => "POP3S: Can't connect to $Param{Host}" );
+    }
+
+    # authentcation
+    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
+    #    my $NOM = $PopObject->login( $Param{Login}, $Param{Password} );
+    #    if ( !defined $NOM ) {
+    #        $PopObject->quit();
+    #        $Self->{LogObject}->Log(
+    #            Priority => 'error',
+    #            Message  => "$AuthType: Auth for user $Param{Login}/$Param{Host} failed!",
+    #        );
+    #        return;
+    #    }
+    my $NOM = $PopObject->Count();
+
+    # if there is no connection, Mail::POP3Client will return a -1 (see bug 3790)
+    if ( $NOM == -1 ) {
+        return (
+            Successful => 0,
+            Message    => "POP3S: Auth for user $Param{Login}/$Param{Host} failed!"
+        );
+    }
+
+    return (
+        Successful => 1,
+        PopObject  => $PopObject,
+        NOM        => $NOM
+    );
+}
+
 sub Fetch {
     my ( $Self, %Param ) = @_;
 
@@ -87,53 +142,34 @@ sub _Fetch {
 
     $Self->{Reconnect} = 0;
 
-    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
-    #    my $PopObject
-    #        = Net::POP3->new( $Param{Host}, Port => 995, Timeout => $Timeout, Debug => $Debug );
-
-    # connect to host
-    my $PopObject = Mail::POP3Client->new(
-        USER     => $Param{Login},
-        PASSWORD => $Param{Password},
-        HOST     => $Param{Host},
-        USESSL   => 'true',
+    my %Connect = $Self->Connect(
+        Host     => $Param{Host},
+        Login    => $Param{Login},
+        Password => $Param{Password},
+        Timeout  => $Timeout,
+        Debug    => $Debug
     );
 
-    if ( !$PopObject ) {
+    if ( !$Connect{Successful} ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "$AuthType: Can't connect to $Param{Host}",
-        );
-        return;
-    }
-
-    # authentcation
-    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
-    #    my $NOM = $PopObject->login( $Param{Login}, $Param{Password} );
-    #    if ( !defined $NOM ) {
-    #        $PopObject->quit();
-    #        $Self->{LogObject}->Log(
-    #            Priority => 'error',
-    #            Message  => "$AuthType: Auth for user $Param{Login}/$Param{Host} failed!",
-    #        );
-    #        return;
-    #    }
-    my $NOM = $PopObject->Count();
-
-    # if there is no connection, Mail::POP3Client will return a -1 (see bug 3790)
-    if ( $NOM == -1 ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => "$AuthType: Can't connect to $Param{Host}",
+            Message  => $Connect{Message},
         );
         return;
     }
+    my $PopObject = $Connect{PopObject};
+    my $NOM       = $Connect{NOM};
 
     # fetch messages
-    if ( $NOM > 0 ) {
+    if ( !$NOM ) {
+        if ($CMD) {
+            print "$AuthType: No messages ($Param{Login}/$Param{Host})\n";
+        }
+    }
+    else {
 
-    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
-    #        for my $Messageno ( sort { $a <=> $b } keys %{ $PopObject->list() } ) {
+        # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client
+        # temporally for my $Messageno ( sort { $a <=> $b } keys %{ $PopObject->list() } ) {
         for my $MessagenoString ( $PopObject->List() ) {
             my ( $Messageno, $MessageSize ) = split( '\s+', $MessagenoString );
 
@@ -149,16 +185,16 @@ sub _Fetch {
                 print "$AuthType: Message $Messageno/$NOM ($Param{Login}/$Param{Host})\n";
             }
 
-    # check message size
-    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
-    #            my $MessageSize = int( $PopObject->list($Messageno) / 1024 );
+            # check message size
+            # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client
+            # temporally
+            # my $MessageSize = int( $PopObject->list($Messageno) / 1024 );
             $MessageSize = int( $MessageSize / 1024 );
             if ( $MessageSize > $MaxEmailSize ) {
                 $Self->{LogObject}->Log(
                     Priority => 'error',
-                    Message =>
-                        "$AuthType: Can't fetch email $NOM from $Param{Login}/$Param{Host}. Email to "
-                        . "big ($MessageSize KB - max $MaxEmailSize KB)!",
+                    Message => "$AuthType: Can't fetch email $NOM from $Param{Login}/$Param{Host}. "
+                        . "Email too big ($MessageSize KB - max $MaxEmailSize KB)!",
                 );
             }
             else {
@@ -180,9 +216,10 @@ sub _Fetch {
                     sleep 3;
                 }
 
-    # get message (header and body)
-    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
-    #                my $Lines            = $PopObject->get($Messageno);
+                # get message (header and body)
+                # Net::POP3::SSLWrapper is not working with gmail, so we switched to
+                # Mail::POP3Client temporally
+                # my $Lines = $PopObject->get($Messageno);
                 my $Line = $PopObject->HeadAndBody($Messageno);
                 if ( !$Line ) {
                     $Self->{LogObject}->Log(
@@ -204,8 +241,9 @@ sub _Fetch {
                     my @Return = $PostMasterObject->Run( QueueID => $Param{QueueID} || 0 );
                     if ( !$Return[0] ) {
 
-    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
-    #                    my $Lines = $PopObject->get($Messageno);
+                        # Net::POP3::SSLWrapper is not working with gmail, so we switched to
+                        # Mail::POP3Client temporally
+                        # my $Lines = $PopObject->get($Messageno);
                         my $Line = $PopObject->HeadAndBody($Messageno);
                         my @Lines = split( /\n/, $Line );
                         for my $LineItem (@Lines) {
@@ -221,9 +259,10 @@ sub _Fetch {
                     undef $PostMasterObject;
                 }
 
-    # mark email to delete if it got processed
-    # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
-    #                $PopObject->delete($Messageno);
+                # mark email to delete if it got processed
+                # Net::POP3::SSLWrapper is not working with gmail, so we switched to
+                # Mail::POP3Client temporally
+                # $PopObject->delete($Messageno);
                 $PopObject->Delete($Messageno);
 
                 # check limit
@@ -239,11 +278,6 @@ sub _Fetch {
             }
         }
     }
-    else {
-        if ($CMD) {
-            print "$AuthType: No messages ($Param{Login}/$Param{Host})\n";
-        }
-    }
 
     # log status
     if ( $Debug > 0 || $FetchCounter ) {
@@ -254,7 +288,7 @@ sub _Fetch {
     }
 
     # Net::POP3::SSLWrapper is not working with gmail, so we switched to Mail::POP3Client temporally
-    #    $PopObject->quit();
+    # $PopObject->quit();
     $PopObject->Close();
     if ($CMD) {
         print "$AuthType: Connection to $Param{Host} closed.\n\n";
