@@ -1,8 +1,8 @@
 # --
 # Kernel/System/PostMaster/NewTicket.pm - sub part of PostMaster.pm
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: NewTicket.pm,v 1.75 2009/03/24 12:14:34 martin Exp $
+# $Id: NewTicket.pm,v 1.86 2012/04/19 21:12:39 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::AutoResponse;
 use Kernel::System::CustomerUser;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.75 $) [1];
+$VERSION = qw($Revision: 1.86 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -30,7 +30,10 @@ sub new {
     $Self->{Debug} = $Param{Debug} || 0;
 
     # get all objects
-    for (qw(DBObject ConfigObject TicketObject LogObject ParserObject TimeObject QueueObject)) {
+    for (
+        qw(DBObject ConfigObject TicketObject LogObject ParserObject TimeObject QueueObject StateObject PriorityObject)
+        )
+    {
         $Self->{$_} = $Param{$_} || die 'Got no $_';
     }
 
@@ -60,13 +63,33 @@ sub Run {
     # get state
     my $State = $Self->{ConfigObject}->Get('PostmasterDefaultState') || 'new';
     if ( $GetParam{'X-OTRS-State'} ) {
-        $State = $GetParam{'X-OTRS-State'};
+        my $StateID = $Self->{StateObject}->StateLookup( State => $GetParam{'X-OTRS-State'} );
+        if ($StateID) {
+            $State = $GetParam{'X-OTRS-State'};
+        }
+        else {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message => "State $GetParam{'X-OTRS-State'} does not exist, falling back to $State!"
+            );
+        }
     }
 
     # get priority
     my $Priority = $Self->{ConfigObject}->Get('PostmasterDefaultPriority') || '3 normal';
     if ( $GetParam{'X-OTRS-Priority'} ) {
-        $Priority = $GetParam{'X-OTRS-Priority'};
+        my $PriorityID
+            = $Self->{PriorityObject}->PriorityLookup( Priority => $GetParam{'X-OTRS-Priority'} );
+        if ($PriorityID) {
+            $Priority = $GetParam{'X-OTRS-Priority'};
+        }
+        else {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message =>
+                    "Priority $GetParam{'X-OTRS-Priority'} does not exist, falling back to $Priority!"
+            );
+        }
     }
 
     # get sender email
@@ -89,7 +112,7 @@ sub Run {
 
     # get customer user data form From: (sender address)
     if ( !$GetParam{'X-OTRS-CustomerUser'} ) {
-        my %CustomerData = ();
+        my %CustomerData;
         if ( $GetParam{From} ) {
             my @EmailAddresses = $Self->{ParserObject}->SplitAddressLine(
                 Line => $GetParam{From},
@@ -113,7 +136,7 @@ sub Run {
         if ( $CustomerData{UserLogin} && !$GetParam{'X-OTRS-CustomerUser'} ) {
             $GetParam{'X-OTRS-CustomerUser'} = $CustomerData{UserLogin};
 
-            # notice that UserLogin is form customer source backend
+            # notice that UserLogin is from customer source backend
             $Self->{LogObject}->Log(
                 Priority => 'notice',
                 Message  => "Take UserLogin ($CustomerData{UserLogin}) from "
@@ -123,7 +146,7 @@ sub Run {
         if ( $CustomerData{UserCustomerID} && !$GetParam{'X-OTRS-CustomerNo'} ) {
             $GetParam{'X-OTRS-CustomerNo'} = $CustomerData{UserCustomerID};
 
-            # notice that UserCustomerID is form customer source backend
+            # notice that UserCustomerID is from customer source backend
             $Self->{LogObject}->Log(
                 Priority => 'notice',
                 Message  => "Take UserCustomerID ($CustomerData{UserCustomerID})"
@@ -159,6 +182,7 @@ sub Run {
         OwnerID      => $Param{InmailUserID},
         UserID       => $Param{InmailUserID},
     );
+
     if ( !$TicketID ) {
         return;
     }
@@ -194,20 +218,72 @@ sub Run {
         }
     }
 
-    # set ticket free text
-    my @Values = ( 'X-OTRS-TicketKey', 'X-OTRS-TicketValue' );
-    for my $Count ( 1 .. 16 ) {
-        if ( $GetParam{ $Values[0] . $Count } ) {
-            $Self->{TicketObject}->TicketFreeTextSet(
-                TicketID => $TicketID,
-                Key      => $GetParam{ $Values[0] . $Count },
-                Value    => $GetParam{ $Values[1] . $Count },
-                Counter  => $Count,
-                UserID   => $Param{InmailUserID},
+    # dynamic fields
+    my $DynamicFieldList =
+        $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldList(
+        Valid      => 1,
+        ResultType => 'HASH',
+        ObjectType => 'Ticket'
+        );
+
+    # set dynamic fields for Ticket object type
+    DYNAMICFIELDID:
+    for my $DynamicFieldID ( sort keys %{$DynamicFieldList} ) {
+        next DYNAMICFIELDID if !$DynamicFieldID;
+        next DYNAMICFIELDID if !$DynamicFieldList->{$DynamicFieldID};
+        my $Key = 'X-OTRS-DynamicField-' . $DynamicFieldList->{$DynamicFieldID};
+
+        if ( $GetParam{$Key} ) {
+
+            # get dynamic field config
+            my $DynamicFieldGet
+                = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+                ID => $DynamicFieldID,
+                );
+
+            $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
+                DynamicFieldConfig => $DynamicFieldGet,
+                ObjectID           => $TicketID,
+                Value              => $GetParam{$Key},
+                UserID             => $Param{InmailUserID},
             );
+
             if ( $Self->{Debug} > 0 ) {
-                print "TicketKey$Count: " . $GetParam{ $Values[0] . $Count } . "\n";
-                print "TicketValue$Count: " . $GetParam{ $Values[1] . $Count } . "\n";
+                print "$Key: " . $GetParam{$Key} . "\n";
+            }
+        }
+    }
+
+    # reverse dynamic field list
+    my %DynamicFieldListReversed = reverse %{$DynamicFieldList};
+
+    # set ticket free text
+    my %Values =
+        (
+        'X-OTRS-TicketKey'   => 'TicketFreeKey',
+        'X-OTRS-TicketValue' => 'TicketFreeText',
+        );
+    for my $Item ( sort keys %Values ) {
+        for my $Count ( 1 .. 16 ) {
+            my $Key = $Item . $Count;
+            if ( $GetParam{$Key} && $DynamicFieldListReversed{ $Values{$Item} . $Count } ) {
+
+                # get dynamic field config
+                my $DynamicFieldGet = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+                    ID => $DynamicFieldListReversed{ $Values{$Item} . $Count },
+                );
+                if ($DynamicFieldGet) {
+                    my $Success = $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
+                        DynamicFieldConfig => $DynamicFieldGet,
+                        ObjectID           => $TicketID,
+                        Value              => $GetParam{$Key},
+                        UserID             => $Param{InmailUserID},
+                    );
+                }
+
+                if ( $Self->{Debug} > 0 ) {
+                    print "TicketKey$Count: " . $GetParam{$Key} . "\n";
+                }
             }
         }
     }
@@ -219,21 +295,21 @@ sub Run {
             my $SystemTime = $Self->{TimeObject}->TimeStamp2SystemTime(
                 String => $GetParam{$Key},
             );
-            my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $Self->{TimeObject}->SystemTime2Date(
-                SystemTime => $SystemTime,
-            );
-            if ( $Year && $Month && $Day && $Hour && $Min ) {
-                $Self->{TicketObject}->TicketFreeTimeSet(
-                    'TicketFreeTime' . $Count . 'Year'   => $Year,
-                    'TicketFreeTime' . $Count . 'Month'  => $Month,
-                    'TicketFreeTime' . $Count . 'Day'    => $Day,
-                    'TicketFreeTime' . $Count . 'Hour'   => $Hour,
-                    'TicketFreeTime' . $Count . 'Minute' => $Min,
-                    Prefix                               => 'TicketFreeTime',
-                    TicketID                             => $TicketID,
-                    Counter                              => $Count,
-                    UserID                               => $Param{InmailUserID},
+            if ( $SystemTime && $DynamicFieldListReversed{ 'TicketFreeTime' . $Count } ) {
+
+                # get dynamic field config
+                my $DynamicFieldGet = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+                    ID => $DynamicFieldListReversed{ 'TicketFreeTime' . $Count },
                 );
+                if ($DynamicFieldGet) {
+                    my $Success = $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
+                        DynamicFieldConfig => $DynamicFieldGet,
+                        ObjectID           => $TicketID,
+                        Value              => $GetParam{$Key},
+                        UserID             => $Param{InmailUserID},
+                    );
+                }
+
                 if ( $Self->{Debug} > 0 ) {
                     print "TicketTime$Count: " . $GetParam{$Key} . "\n";
                 }
@@ -292,21 +368,71 @@ sub Run {
         print "ArticleType: $GetParam{'X-OTRS-ArticleType'}\n";
     }
 
-    # set free article text
-    @Values = ( 'X-OTRS-ArticleKey', 'X-OTRS-ArticleValue' );
-    for my $Count ( 1 .. 3 ) {
-        if ( $GetParam{ $Values[0] . $Count } ) {
-            $Self->{TicketObject}->ArticleFreeTextSet(
-                TicketID  => $TicketID,
-                ArticleID => $ArticleID,
-                Key       => $GetParam{ $Values[0] . $Count },
-                Value     => $GetParam{ $Values[1] . $Count },
-                Counter   => $Count,
-                UserID    => $Param{InmailUserID},
+    # dynamic fields
+    $DynamicFieldList =
+        $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldList(
+        Valid      => 1,
+        ResultType => 'HASH',
+        ObjectType => 'Article'
+        );
+
+    # set dynamic fields for Article object type
+    DYNAMICFIELDID:
+    for my $DynamicFieldID ( sort keys %{$DynamicFieldList} ) {
+        next DYNAMICFIELDID if !$DynamicFieldID;
+        next DYNAMICFIELDID if !$DynamicFieldList->{$DynamicFieldID};
+        my $Key = 'X-OTRS-DynamicField-' . $DynamicFieldList->{$DynamicFieldID};
+        if ( $GetParam{$Key} ) {
+
+            # get dynamic field config
+            my $DynamicFieldGet
+                = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+                ID => $DynamicFieldID,
+                );
+
+            $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
+                DynamicFieldConfig => $DynamicFieldGet,
+                ObjectID           => $ArticleID,
+                Value              => $GetParam{$Key},
+                UserID             => $Param{InmailUserID},
             );
+
             if ( $Self->{Debug} > 0 ) {
-                print "ArticleKey$Count: " . $GetParam{ $Values[0] . $Count } . "\n";
-                print "ArticleValue$Count: " . $GetParam{ $Values[1] . $Count } . "\n";
+                print "$Key: " . $GetParam{$Key} . "\n";
+            }
+        }
+    }
+
+    # reverse dynamic field list
+    %DynamicFieldListReversed = reverse %{$DynamicFieldList};
+
+    # set free article text
+    %Values =
+        (
+        'X-OTRS-ArticleKey'   => 'ArticleFreeKey',
+        'X-OTRS-ArticleValue' => 'ArticleFreeText',
+        );
+    for my $Item ( sort keys %Values ) {
+        for my $Count ( 1 .. 16 ) {
+            my $Key = $Item . $Count;
+            if ( $GetParam{$Key} && $DynamicFieldListReversed{ $Values{$Item} . $Count } ) {
+
+                # get dynamic field config
+                my $DynamicFieldGet = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+                    ID => $DynamicFieldListReversed{ $Values{$Item} . $Count },
+                );
+                if ($DynamicFieldGet) {
+                    my $Success = $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
+                        DynamicFieldConfig => $DynamicFieldGet,
+                        ObjectID           => $ArticleID,
+                        Value              => $GetParam{$Key},
+                        UserID             => $Param{InmailUserID},
+                    );
+                }
+
+                if ( $Self->{Debug} > 0 ) {
+                    print "TicketKey$Count: " . $GetParam{$Key} . "\n";
+                }
             }
         }
     }
