@@ -1,8 +1,8 @@
 # --
 # Kernel/System/PostMaster/Reject.pm - the sub part of PostMaster.pm
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: Reject.pm,v 1.15 2009/03/24 12:14:35 martin Exp $
+# $Id: Reject.pm,v 1.23 2011/11/25 10:23:24 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.15 $) [1];
+$VERSION = qw($Revision: 1.23 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -47,7 +47,10 @@ sub Run {
     my %GetParam = %{ $Param{GetParam} };
 
     # get ticket data
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     my $Comment          = $Param{Comment}          || '';
     my $Lock             = $Param{Lock}             || '';
@@ -112,25 +115,72 @@ sub Run {
         );
     }
 
-    # set free article text
-    my @Values = ( 'X-OTRS-FollowUp-ArticleKey', 'X-OTRS-FollowUp-ArticleValue' );
-    my $CounterTmp = 0;
-    while ( $CounterTmp <= 3 ) {
-        $CounterTmp++;
-        if ( $GetParam{"$Values[0]$CounterTmp"} ) {
-            $Self->{TicketObject}->ArticleFreeTextSet(
-                TicketID  => $Param{TicketID},
-                ArticleID => $ArticleID,
-                Key       => $GetParam{"$Values[0]$CounterTmp"},
-                Value     => $GetParam{"$Values[1]$CounterTmp"},
-                Counter   => $CounterTmp,
-                UserID    => $Param{InmailUserID},
-            );
-            if ( $Self->{Debug} > 0 ) {
-                print "ArticleKey$CounterTmp: " . $GetParam{"$Values[0]$CounterTmp"} . "\n";
-                print "ArticleValue$CounterTmp: " . $GetParam{"$Values[1]$CounterTmp"} . "\n";
-            }
+    # dynamic fields
+    my $DynamicFieldList =
+        $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldList(
+        Valid      => 0,
+        ResultType => 'HASH',
+        ObjectType => 'Article'
+        );
 
+    # set dynamic fields for Article object type
+    DYNAMICFIELDID:
+    for my $DynamicFieldID ( sort keys %{$DynamicFieldList} ) {
+        next DYNAMICFIELDID if !$DynamicFieldID;
+        next DYNAMICFIELDID if !$DynamicFieldList->{$DynamicFieldID};
+        my $Key = 'X-OTRS-FollowUp-DynamicField-' . $DynamicFieldList->{$DynamicFieldID};
+        if ( $GetParam{$Key} ) {
+
+            # get dynamic field config
+            my $DynamicFieldGet
+                = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+                ID => $DynamicFieldID,
+                );
+
+            $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
+                DynamicFieldConfig => $DynamicFieldGet,
+                ObjectID           => $ArticleID,
+                Value              => $GetParam{$Key},
+                UserID             => $Param{InmailUserID},
+            );
+
+            if ( $Self->{Debug} > 0 ) {
+                print "$Key: " . $GetParam{$Key} . "\n";
+            }
+        }
+    }
+
+    # reverse dynamic field list
+    my %DynamicFieldListReversed = reverse %{$DynamicFieldList};
+
+    # set free article text
+    my %Values =
+        (
+        'X-OTRS-FollowUp-ArticleKey'   => 'ArticleFreeKey',
+        'X-OTRS-FollowUp-ArticleValue' => 'ArticleFreeText',
+        );
+    for my $Item ( sort keys %Values ) {
+        for my $Count ( 1 .. 16 ) {
+            my $Key = $Item . $Count;
+            if ( $GetParam{$Key} && $DynamicFieldListReversed{ $Values{$Item} . $Count } ) {
+
+                # get dynamic field config
+                my $DynamicFieldGet = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+                    ID => $DynamicFieldListReversed{ $Values{$Item} . $Count },
+                );
+                if ($DynamicFieldGet) {
+                    my $Success = $Self->{TicketObject}->{DynamicFieldBackendObject}->ValueSet(
+                        DynamicFieldConfig => $DynamicFieldGet,
+                        ObjectID           => $ArticleID,
+                        Value              => $GetParam{$Key},
+                        UserID             => $Param{InmailUserID},
+                    );
+                }
+
+                if ( $Self->{Debug} > 0 ) {
+                    print "TicketKey$Count: " . $GetParam{$Key} . "\n";
+                }
+            }
         }
     }
 
