@@ -1,12 +1,12 @@
 # --
 # Kernel/System/Signature.pm - All signature related function should be here eventually
-# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: Signature.pm,v 1.6 2008/05/08 09:36:19 mh Exp $
+# $Id: Signature.pm,v 1.17 2010/06/17 21:39:40 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Signature;
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::Valid;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.6 $) [1];
+$VERSION = qw($Revision: 1.17 $) [1];
 
 =head1 NAME
 
@@ -38,29 +38,37 @@ All signature functions.
 create an object
 
     use Kernel::Config;
-    use Kernel::System::Time;
+    use Kernel::System::Encode;
     use Kernel::System::Log;
+    use Kernel::System::Main;
     use Kernel::System::DB;
     use Kernel::System::Signature;
 
     my $ConfigObject = Kernel::Config->new();
-    my $TimeObject   = Kernel::System::Time->new(
+    my $EncodeObject = Kernel::System::Encode->new(
         ConfigObject => $ConfigObject,
     );
     my $LogObject = Kernel::System::Log->new(
         ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
     );
     my $DBObject = Kernel::System::DB->new(
         ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
         LogObject    => $LogObject,
         MainObject   => $MainObject,
     );
-
     my $SignatureObject = Kernel::System::Signature->new(
         ConfigObject => $ConfigObject,
         LogObject    => $LogObject,
         DBObject     => $DBObject,
-        TimeObject   => $TimeObject,
+        MainObject   => $MainObject,
+        EncodeObject => $EncodeObject,
     );
 
 =cut
@@ -73,7 +81,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(DBObject ConfigObject LogObject)) {
+    for (qw(DBObject ConfigObject LogObject MainObject EncodeObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
     $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
@@ -86,11 +94,12 @@ sub new {
 add new signatures
 
     my $ID = $SignatureObject->SignatureAdd(
-        Name    => 'New Signature',
-        Text    => "--\nSome Signature Infos",
-        Comment => 'some comment',
-        ValidID => 1,
-        UserID  => 123,
+        Name        => 'New Signature',
+        Text        => "--\nSome Signature Infos",
+        ContentType => 'text/plain; charset=utf-8',
+        Comment     => 'some comment',
+        ValidID     => 1,
+        UserID      => 123,
     );
 
 =cut
@@ -99,7 +108,7 @@ sub SignatureAdd {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
-    for (qw(Name Text ValidID UserID)) {
+    for (qw(Name Text ContentType ValidID UserID)) {
         if ( !$Param{$_} ) {
             $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
@@ -107,12 +116,12 @@ sub SignatureAdd {
     }
 
     return if !$Self->{DBObject}->Do(
-        SQL => 'INSERT INTO signature (name, text, comments, valid_id, '
+        SQL => 'INSERT INTO signature (name, text, content_type, comments, valid_id, '
             . ' create_time, create_by, change_time, change_by)'
-            . ' VALUES (?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
+            . ' VALUES (?, ?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
         Bind => [
-            \$Param{Name}, \$Param{Text}, \$Param{Comment}, \$Param{ValidID},
-            \$Param{UserID}, \$Param{UserID},
+            \$Param{Name}, \$Param{Text}, \$Param{ContentType}, \$Param{Comment},
+            \$Param{ValidID}, \$Param{UserID}, \$Param{UserID},
         ],
     );
 
@@ -147,27 +156,23 @@ sub SignatureGet {
         return;
     }
 
-    # quote params
-    for (qw(ID)) {
-        $Param{$_} = $Self->{DBObject}->Quote( $Param{$_}, 'Integer' );
-    }
-
     # sql
     return if !$Self->{DBObject}->Prepare(
-        SQL => 'SELECT id, name, text, comments, valid_id, change_time, create_time '
+        SQL => 'SELECT id, name, text, content_type, comments, valid_id, change_time, create_time '
             . ' FROM signature WHERE id = ?',
         Bind => [ \$Param{ID} ],
     );
-    my %Data = ();
+    my %Data;
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
         %Data = (
-            ID         => $Data[0],
-            Name       => $Data[1],
-            Text       => $Data[2],
-            Comment    => $Data[3],
-            ValidID    => $Data[4],
-            ChangeTime => $Data[5],
-            CreateTime => $Data[6],
+            ID          => $Data[0],
+            Name        => $Data[1],
+            Text        => $Data[2],
+            ContentType => $Data[3] || 'text/plain',
+            Comment     => $Data[4],
+            ValidID     => $Data[5],
+            ChangeTime  => $Data[6],
+            CreateTime  => $Data[7],
         );
     }
 
@@ -189,12 +194,13 @@ sub SignatureGet {
 update signature attributes
 
     $SignatureObject->SignatureUpdate(
-        ID      => 123,
-        Name    => 'New Signature',
-        Text    => "--\nSome Signature Infos",
-        Comment => 'some comment',
-        ValidID => 1,
-        UserID  => 123,
+        ID          => 123,
+        Name        => 'New Signature',
+        Text        => "--\nSome Signature Infos",
+        ContentType => 'text/plain; charset=utf-8',
+        Comment     => 'some comment',
+        ValidID     => 1,
+        UserID      => 123,
     );
 
 =cut
@@ -203,7 +209,7 @@ sub SignatureUpdate {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
-    for (qw(ID Name Text ValidID UserID)) {
+    for (qw(ID Name Text ContentType ValidID UserID)) {
         if ( !$Param{$_} ) {
             $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
@@ -211,14 +217,15 @@ sub SignatureUpdate {
     }
 
     # sql
-    return $Self->{DBObject}->Do(
-        SQL => 'UPDATE signature SET name = ?, text = ?, comments = ?, valid_id = ?, '
-            . ' change_time = current_timestamp, change_by = ? WHERE id = ?',
+    return if !$Self->{DBObject}->Do(
+        SQL => 'UPDATE signature SET name = ?, text = ?, content_type = ?, comments = ?, '
+            . ' valid_id = ?, change_time = current_timestamp, change_by = ? WHERE id = ?',
         Bind => [
-            \$Param{Name}, \$Param{Text}, \$Param{Comment}, \$Param{ValidID},
-            \$Param{UserID}, \$Param{ID},
-            ]
+            \$Param{Name}, \$Param{Text}, \$Param{ContentType}, \$Param{Comment},
+            \$Param{ValidID}, \$Param{UserID}, \$Param{ID},
+        ],
     );
+    return 1;
 }
 
 =item SignatureList()
@@ -239,7 +246,7 @@ sub SignatureList {
     my $Valid = 1;
 
     # check needed stuff
-    if ( !$Param{Valid} && defined( $Param{Valid} ) ) {
+    if ( !$Param{Valid} && defined $Param{Valid} ) {
         $Valid = 0;
     }
 
@@ -258,16 +265,16 @@ sub SignatureList {
 
 =head1 TERMS AND CONDITIONS
 
-This Software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.6 $ $Date: 2008/05/08 09:36:19 $
+$Revision: 1.17 $ $Date: 2010/06/17 21:39:40 $
 
 =cut
