@@ -1,8 +1,8 @@
 # --
-# Kernel/System/State.pm - All state related function should be here eventually
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Kernel/System/State.pm - All ticket state related functions
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: State.pm,v 1.48.2.1 2011/06/17 10:10:08 mb Exp $
+# $Id: State.pm,v 1.56 2012/03/18 22:06:23 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,13 +14,13 @@ package Kernel::System::State;
 use strict;
 use warnings;
 
-use Kernel::System::Valid;
-use Kernel::System::Time;
-use Kernel::System::SysConfig;
 use Kernel::System::CacheInternal;
+use Kernel::System::SysConfig;
+use Kernel::System::Time;
+use Kernel::System::Valid;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.48.2.1 $) [1];
+$VERSION = qw($Revision: 1.56 $) [1];
 
 =head1 NAME
 
@@ -28,7 +28,7 @@ Kernel::System::State - state lib
 
 =head1 SYNOPSIS
 
-All state functions.
+All ticket state functions.
 
 =head1 PUBLIC INTERFACE
 
@@ -92,11 +92,13 @@ sub new {
     for (qw(DBObject ConfigObject LogObject MainObject EncodeObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
+
+    # create addititional objects
     $Self->{ValidObject}         = Kernel::System::Valid->new(%Param);
     $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
         %Param,
         Type => 'State',
-        TTL  => 60 * 60 * 3,
+        TTL  => 60 * 60 * 24 * 20,
     );
 
     # check needed config options
@@ -134,7 +136,7 @@ sub StateAdd {
 
     # store data
     return if !$Self->{DBObject}->Do(
-        SQL => 'INSERT INTO ticket_state (name, valid_id, type_id, comments, '
+        SQL => 'INSERT INTO ticket_state (name, valid_id, type_id, comments,'
             . ' create_time, create_by, change_time, change_by)'
             . ' VALUES (?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
         Bind => [
@@ -145,13 +147,17 @@ sub StateAdd {
 
     # get new state id
     return if !$Self->{DBObject}->Prepare(
-        SQL  => 'SELECT id FROM ticket_state WHERE name = ?',
-        Bind => [ \$Param{Name} ],
+        SQL   => 'SELECT id FROM ticket_state WHERE name = ?',
+        Bind  => [ \$Param{Name} ],
+        Limit => 1,
     );
+
+    # fetch the result
     my $ID;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $ID = $Row[0];
     }
+
     return if !$ID;
 
     # delete cache
@@ -209,8 +215,8 @@ sub StateGet {
 
     # sql
     my @Bind;
-    my $SQL = 'SELECT ts.id, ts.name, ts.valid_id, ts.comments, ts.type_id, tst.name, '
-        . ' ts.change_time, ts.create_time '
+    my $SQL = 'SELECT ts.id, ts.name, ts.valid_id, ts.comments, ts.type_id, tst.name,'
+        . ' ts.change_time, ts.create_time'
         . ' FROM ticket_state ts, ticket_state_type tst WHERE ts.type_id = tst.id AND ';
     if ( $Param{Name} ) {
         $SQL .= ' ts.name = ?';
@@ -220,7 +226,14 @@ sub StateGet {
         $SQL .= ' ts.id = ?';
         push @Bind, \$Param{ID};
     }
-    return if !$Self->{DBObject}->Prepare( SQL => $SQL, Bind => \@Bind );
+
+    return if !$Self->{DBObject}->Prepare(
+        SQL   => $SQL,
+        Bind  => \@Bind,
+        Limit => 1,
+    );
+
+    # fetch the result
     my %Data;
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
         %Data = (
@@ -245,12 +258,11 @@ sub StateGet {
     if ( !%Data ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "State '$Param{Name}' not found!"
+            Message  => "State '$Param{Name}' not found!",
         );
         return;
     }
 
-    # return data
     return %Data;
 }
 
@@ -300,41 +312,38 @@ sub StateUpdate {
     # delete cache
     $Self->{CacheInternalObject}->CleanUp();
 
+    # check all sysconfig options
+    return 1 if !$Param{CheckSysConfig};
+
     # create a time object locally, needed for the local SysConfigObject
     my $TimeObject = Kernel::System::Time->new( %{$Self} );
 
-    # check all sysconfig options
-    if ( $Param{CheckSysConfig} ) {
+    # create a sysconfig object locally for performance reasons
+    my $SysConfigObject = Kernel::System::SysConfig->new(
+        %{$Self},
+        TimeObject => $TimeObject,
+    );
 
-        # create a sysconfig object locally for performance reasons
-        my $SysConfigObject = Kernel::System::SysConfig->new(
-            %{$Self},
-            TimeObject => $TimeObject,
-        );
-
-        # check all sysconfig options and correct them automatically if neccessary
-        $SysConfigObject->ConfigItemCheckAll();
-    }
+    # check all sysconfig options and correct them automatically if neccessary
+    $SysConfigObject->ConfigItemCheckAll();
 
     return 1;
 }
 
 =item StateGetStatesByType()
 
-get list of state types
+get list of states for a type or a list of state types.
 
-    get all states with state type open and new
-    (available: new, open, closed, pending reminder, pending auto,
-    removed, merged)
+Get all states with state type open and new:
+(available: new, open, closed, pending reminder, pending auto, removed, merged)
 
     my @List = $StateObject->StateGetStatesByType(
         StateType => ['open', 'new'],
         Result    => 'ID', # HASH|ID|Name
     );
 
-    get all state types used by config option named like
-
-    Ticket::ViewableStateType for "Viewable" state types
+Get all state types used by config option named like
+Ticket::ViewableStateType for "Viewable" state types.
 
     my %List = $StateObject->StateGetStatesByType(
         Type   => 'Viewable',
@@ -411,13 +420,17 @@ sub StateGetStatesByType {
             push @StateType, $Param{StateType};
         }
     }
-    my $SQL = "SELECT ts.id, ts.name, tst.name  "
-        . " FROM ticket_state ts, ticket_state_type tst WHERE "
-        . " tst.id = ts.type_id AND "
-        . " tst.name IN ('${\(join '\', \'', sort @StateType)}' ) AND "
-        . " ts.valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
+
+    my $SQL = ''
+        . 'SELECT ts.id, ts.name, tst.name'
+        . ' FROM ticket_state ts, ticket_state_type tst'
+        . ' WHERE tst.id = ts.type_id'
+        . " AND tst.name IN ('${\(join '\', \'', sort @StateType)}' )"
+        . " AND ts.valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
+
     return if !$Self->{DBObject}->Prepare( SQL => $SQL );
 
+    # fetch the result
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
         push @Name, $Data[1];
         push @ID,   $Data[0];
@@ -443,6 +456,7 @@ sub StateGetStatesByType {
     elsif ( $Param{Result} eq 'HASH' ) {
         return %Data;
     }
+
     return @ID;
 }
 
@@ -483,27 +497,42 @@ returns
 sub StateList {
     my ( $Self, %Param ) = @_;
 
-    my $Valid = 1;
-
     # check needed stuff
     if ( !$Param{UserID} ) {
         $Self->{LogObject}->Log( Priority => 'error', Message => 'UserID!' );
         return;
     }
+
+    my $Valid = 1;
     if ( !$Param{Valid} && defined( $Param{Valid} ) ) {
         $Valid = 0;
     }
 
+    # check cache
+    my $CacheKey = 'StateList::' . $Valid;
+    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    return %{$Cache} if $Cache;
+
     # sql
     my $SQL = 'SELECT id, name FROM ticket_state';
     if ($Valid) {
         $SQL .= " WHERE valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
     }
+
     return if !$Self->{DBObject}->Prepare( SQL => $SQL );
+
+    # fetch the result
     my %Data;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
+
+    # set cache
+    $Self->{CacheInternalObject}->Set(
+        Key   => $CacheKey,
+        Value => \%Data,
+    );
+
     return %Data;
 }
 
@@ -512,11 +541,11 @@ sub StateList {
 returns the id or the name of a state
 
     my $StateID = $StateObject->StateLookup(
-        State => '3 normal',
+        State => 'closed successful',
     );
 
     my $State = $StateObject->StateLookup(
-        StateID => 1,
+        StateID => 2,
     );
 
 =cut
@@ -530,54 +559,37 @@ sub StateLookup {
         return;
     }
 
-    # check cache
-    my $CacheKey;
+    # get (already cached) state list
+    my %StateList = $Self->StateList(
+        Valid  => 0,
+        UserID => 1,
+    );
+
     my $Key;
     my $Value;
-    if ( $Param{State} ) {
-        $Key      = 'State';
-        $Value    = $Param{State};
-        $CacheKey = 'StateLookup::Name::' . $Param{State};
+    my $ReturnData;
+    if ( $Param{StateID} ) {
+        $Key        = 'StateID';
+        $Value      = $Param{StateID};
+        $ReturnData = $StateList{ $Param{StateID} };
     }
     else {
-        $Key      = 'StateID';
-        $Value    = $Param{StateID};
-        $CacheKey = 'StateLookup::ID::' . $Param{StateID};
+        $Key   = 'State';
+        $Value = $Param{State};
+        my %StateListReverse = reverse %StateList;
+        $ReturnData = $StateListReverse{ $Param{State} };
     }
 
-    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
-    return $Cache if $Cache;
-
-    # db query
-    my $SQL;
-    my @Bind;
-    if ( $Param{State} ) {
-        $SQL = 'SELECT id FROM ticket_state WHERE name = ?';
-        push @Bind, \$Param{State};
-    }
-    else {
-        $SQL = 'SELECT name FROM ticket_state WHERE id = ?';
-        push @Bind, \$Param{StateID};
-    }
-    return if !$Self->{DBObject}->Prepare( SQL => $SQL, Bind => \@Bind );
-    my $Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
-        $Data = $Row[0];
-    }
-
-    # set cache
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => $Data );
-
     # check if data exists
-    if ( !defined $Data ) {
+    if ( !defined $ReturnData ) {
         $Self->{LogObject}->Log(
-            State   => 'error',
-            Message => "No $Key for $Value found!",
+            Priority => 'error',
+            Message  => "No $Key for $Value found!",
         );
         return;
     }
 
-    return $Data;
+    return $ReturnData;
 }
 
 =item StateTypeList()
@@ -611,14 +623,25 @@ sub StateTypeList {
         return;
     }
 
+    # check cache
+    my $CacheKey = 'StateTypeList';
+    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    return %{$Cache} if $Cache;
+
     # sql
     return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT id, name FROM ticket_state_type',
     );
+
+    # fetch the result
     my %Data;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
+
+    # set cache
+    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%Data );
+
     return %Data;
 }
 
@@ -630,6 +653,8 @@ returns the id or the name of a state type
         StateType => 'pending auto',
     );
 
+or
+
     my $StateType = $StateTypeObject->StateTypeLookup(
         StateTypeID => 1,
     );
@@ -641,59 +666,43 @@ sub StateTypeLookup {
 
     # check needed stuff
     if ( !$Param{StateType} && !$Param{StateTypeID} ) {
-        $Self->{LogObject}
-            ->Log( StateType => 'error', Message => 'Need StateType or StateTypeID!' );
-        return;
-    }
-
-    # check cache
-    my $CacheKey;
-    my $Key;
-    my $Value;
-    if ( $Param{StateType} ) {
-        $Key      = 'StateType';
-        $Value    = $Param{StateType};
-        $CacheKey = 'StateTypeLookup::Name::' . $Param{StateType};
-    }
-    else {
-        $Key      = 'StateTypeID';
-        $Value    = $Param{StateTypeID};
-        $CacheKey = 'StateTypeLookup::ID::' . $Param{StateTypeID};
-    }
-
-    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
-    return $Cache if $Cache;
-
-    # db query
-    my $SQL;
-    my @Bind;
-    if ( $Param{StateType} ) {
-        $SQL = 'SELECT id FROM ticket_state_type WHERE name = ?';
-        push @Bind, \$Param{StateType};
-    }
-    else {
-        $SQL = 'SELECT name FROM ticket_state_type WHERE id = ?';
-        push @Bind, \$Param{StateTypeID};
-    }
-    return if !$Self->{DBObject}->Prepare( SQL => $SQL, Bind => \@Bind );
-    my $Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
-        $Data = $Row[0];
-    }
-
-    # set cache
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => $Data );
-
-    # check if data exists
-    if ( !defined $Data ) {
         $Self->{LogObject}->Log(
             StateType => 'error',
-            Message   => "No $Key for $Value found!",
+            Message   => 'Need StateType or StateTypeID!',
         );
         return;
     }
 
-    return $Data;
+    # get (already cached) state type list
+    my %StateTypeList = $Self->StateTypeList(
+        UserID => 1,
+    );
+
+    my $Key;
+    my $Value;
+    my $ReturnData;
+    if ( $Param{StateTypeID} ) {
+        $Key        = 'StateTypeID';
+        $Value      = $Param{StateTypeID};
+        $ReturnData = $StateTypeList{ $Param{StateTypeID} };
+    }
+    else {
+        $Key   = 'StateType';
+        $Value = $Param{StateType};
+        my %StateTypeListReverse = reverse %StateTypeList;
+        $ReturnData = $StateTypeListReverse{ $Param{StateType} };
+    }
+
+    # check if data exists
+    if ( !defined $ReturnData ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "No $Key for $Value found!",
+        );
+        return;
+    }
+
+    return $ReturnData;
 }
 
 1;
@@ -712,6 +721,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.48.2.1 $ $Date: 2011/06/17 10:10:08 $
+$Revision: 1.56 $ $Date: 2012/03/18 22:06:23 $
 
 =cut
