@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Stats/Dynamic/TicketSolutionResponseTime.pm - stats about ticket solution and response time
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: TicketSolutionResponseTime.pm,v 1.3 2009/04/23 13:47:08 mh Exp $
+# $Id: TicketSolutionResponseTime.pm,v 1.13 2012/02/28 10:38:01 jp Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,9 +19,12 @@ use Kernel::System::Service;
 use Kernel::System::SLA;
 use Kernel::System::Ticket;
 use Kernel::System::Type;
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.3 $) [1];
+$VERSION = qw($Revision: 1.13 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -37,15 +40,23 @@ sub new {
     {
         $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
     }
-    $Self->{QueueObject}    = Kernel::System::Queue->new( %{$Self} );
-    $Self->{TicketObject}   = Kernel::System::Ticket->new( %{$Self} );
-    $Self->{StateObject}    = Kernel::System::State->new( %{$Self} );
-    $Self->{PriorityObject} = Kernel::System::Priority->new( %{$Self} );
-    $Self->{LockObject}     = Kernel::System::Lock->new( %{$Self} );
-    $Self->{CustomerUser}   = Kernel::System::CustomerUser->new( %{$Self} );
-    $Self->{ServiceObject}  = Kernel::System::Service->new( %{$Self} );
-    $Self->{SLAObject}      = Kernel::System::SLA->new( %{$Self} );
-    $Self->{TypeObject}     = Kernel::System::Type->new( %{$Self} );
+    $Self->{QueueObject}        = Kernel::System::Queue->new( %{$Self} );
+    $Self->{TicketObject}       = Kernel::System::Ticket->new( %{$Self} );
+    $Self->{StateObject}        = Kernel::System::State->new( %{$Self} );
+    $Self->{PriorityObject}     = Kernel::System::Priority->new( %{$Self} );
+    $Self->{LockObject}         = Kernel::System::Lock->new( %{$Self} );
+    $Self->{CustomerUser}       = Kernel::System::CustomerUser->new( %{$Self} );
+    $Self->{ServiceObject}      = Kernel::System::Service->new( %{$Self} );
+    $Self->{SLAObject}          = Kernel::System::SLA->new( %{$Self} );
+    $Self->{TypeObject}         = Kernel::System::Type->new( %{$Self} );
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
+
+    # get the dynamic fields for ticket object
+    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid      => 1,
+        ObjectType => ['Ticket'],
+    );
 
     return $Self;
 }
@@ -450,72 +461,59 @@ sub GetObjectAttributes {
         push @ObjectAttributes, \%ObjectAttribute;
     }
 
-    FREEKEY:
-    for my $FreeKey ( 1 .. 16 ) {
+    # cycle trough the activated Dynamic Fields for this screen
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
 
-        # get ticket free key config
-        my $TicketFreeKey = $Self->{ConfigObject}->Get( 'TicketFreeKey' . $FreeKey );
+        my $PossibleValuesFilter;
 
-        next FREEKEY if ref $TicketFreeKey ne 'HASH';
-
-        my @FreeKey = keys %{$TicketFreeKey};
-        my $Name    = '';
-
-        if ( scalar @FreeKey == 1 ) {
-            $Name = $TicketFreeKey->{ $FreeKey[0] };
-        }
-        else {
-            $Name = 'TicketFreeText' . $FreeKey;
-
-            my %ObjectAttribute = (
-                Name             => 'TicketFreeKey' . $FreeKey,
-                UseAsXvalue      => 1,
-                UseAsValueSeries => 1,
-                UseAsRestriction => 1,
-                Element          => 'TicketFreeKey' . $FreeKey,
-                Block            => 'MultiSelectField',
-                Values           => $TicketFreeKey,
-                Translation      => 0,
-            );
-
-            push @ObjectAttributes, \%ObjectAttribute;
+        # set possible values filter from ACLs
+        my $ACL = $Self->{TicketObject}->TicketAcl(
+            Action        => 'AgentStats',
+            Type          => 'DynamicField_' . $DynamicFieldConfig->{Name},
+            ReturnType    => 'Ticket',
+            ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
+            Data          => $DynamicFieldConfig->{Config}->{PossibleValues} || {},
+            UserID        => 1,
+        );
+        if ($ACL) {
+            my %Filter = $Self->{TicketObject}->TicketAclData();
+            $PossibleValuesFilter = \%Filter;
         }
 
-        # get ticket free text
-        my $TicketFreeText = $Self->{TicketObject}->TicketFreeTextGet(
-            Type   => 'TicketFreeText' . $FreeKey,
-            Action => 'AgentStats',
-            FillUp => 1,
-            UserID => 1,
+        # get field html
+        my $DynamicFieldStatsParameter = $Self->{BackendObject}->StatsFieldParameterBuild(
+            DynamicFieldConfig   => $DynamicFieldConfig,
+            PossibleValuesFilter => $PossibleValuesFilter,
         );
 
-        if ($TicketFreeText) {
+        if ( IsHashRefWithData($DynamicFieldStatsParameter) ) {
+            if ( IsHashRefWithData( $DynamicFieldStatsParameter->{Values} ) ) {
 
-            my %ObjectAttribute = (
-                Name             => $Name,
-                UseAsXvalue      => 1,
-                UseAsValueSeries => 1,
-                UseAsRestriction => 1,
-                Element          => 'TicketFreeText' . $FreeKey,
-                Block            => 'MultiSelectField',
-                Values           => $TicketFreeText,
-                Translation      => 0,
-            );
-
-            push @ObjectAttributes, \%ObjectAttribute;
-        }
-        else {
-
-            my %ObjectAttribute = (
-                Name             => $Name,
-                UseAsXvalue      => 0,
-                UseAsValueSeries => 0,
-                UseAsRestriction => 1,
-                Element          => 'TicketFreeText' . $FreeKey,,
-                Block            => 'InputField',
-            );
-
-            push @ObjectAttributes, \%ObjectAttribute;
+                my %ObjectAttribute = (
+                    Name             => $DynamicFieldStatsParameter->{Name},
+                    UseAsXvalue      => 1,
+                    UseAsValueSeries => 1,
+                    UseAsRestriction => 1,
+                    Element          => $DynamicFieldStatsParameter->{Element},
+                    Block            => 'MultiSelectField',
+                    Values           => $DynamicFieldStatsParameter->{Values},
+                    Translation      => 0,
+                );
+                push @ObjectAttributes, \%ObjectAttribute;
+            }
+            else {
+                my %ObjectAttribute = (
+                    Name             => $DynamicFieldStatsParameter->{Name},
+                    UseAsXvalue      => 0,
+                    UseAsValueSeries => 0,
+                    UseAsRestriction => 1,
+                    Element          => $DynamicFieldStatsParameter->{Element},
+                    Block            => 'InputField',
+                );
+                push @ObjectAttributes, \%ObjectAttribute;
+            }
         }
     }
 
@@ -526,7 +524,7 @@ sub GetObjectAttributes {
 
 sub GetStatTable {
     my ( $Self, %Param ) = @_;
-    my @StatArray = ();
+    my @StatArray;
     if ( $Param{XValue}{Element} && $Param{XValue}{Element} eq 'KindsOfReporting' ) {
 
         for my $Row ( sort keys %{ $Param{TableStructure} } ) {
@@ -586,21 +584,250 @@ sub GetStatTable {
     return @StatArray;
 }
 
+sub GetHeaderLine {
+
+    my ( $Self, %Param ) = @_;
+
+    if ( $Param{XValue}{Element} eq 'KindsOfReporting' ) {
+
+        my %Selected = map { $_ => 1 } @{ $Param{XValue}{SelectedValues} };
+
+        my $Attributes = $Self->_KindsOfReporting();
+        my @HeaderLine = ('Evaluation by');
+        my $SortedRef  = $Self->_SortedKindsOfReporting();
+
+        ATTRIBUTE:
+        for my $Attribute ( @{$SortedRef} ) {
+            next ATTRIBUTE if !$Selected{$Attribute};
+            push @HeaderLine, $Attributes->{$Attribute};
+        }
+        return \@HeaderLine;
+
+    }
+    return;
+}
+
+sub ExportWrapper {
+    my ( $Self, %Param ) = @_;
+
+    # wrap ids to used spelling
+    for my $Use (qw(UseAsValueSeries UseAsRestriction UseAsXvalue)) {
+        ELEMENT:
+        for my $Element ( @{ $Param{$Use} } ) {
+            next ELEMENT if !$Element || !$Element->{SelectedValues};
+            my $ElementName = $Element->{Element};
+            my $Values      = $Element->{SelectedValues};
+
+            if ( $ElementName eq 'QueueIDs' || $ElementName eq 'CreatedQueueIDs' ) {
+                ID:
+                for my $ID ( @{$Values} ) {
+                    next ID if !$ID;
+                    $ID->{Content} = $Self->{QueueObject}->QueueLookup( QueueID => $ID->{Content} );
+                }
+            }
+            elsif ( $ElementName eq 'StateIDs' || $ElementName eq 'CreatedStateIDs' ) {
+                my %StateList = $Self->{StateObject}->StateList( UserID => 1 );
+                ID:
+                for my $ID ( @{$Values} ) {
+                    next ID if !$ID;
+                    $ID->{Content} = $StateList{ $ID->{Content} };
+                }
+            }
+            elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
+                my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
+                ID:
+                for my $ID ( @{$Values} ) {
+                    next ID if !$ID;
+                    $ID->{Content} = $PriorityList{ $ID->{Content} };
+                }
+            }
+            elsif (
+                $ElementName    eq 'OwnerIDs'
+                || $ElementName eq 'CreatedUserIDs'
+                || $ElementName eq 'ResponsibleIDs'
+                )
+            {
+                ID:
+                for my $ID ( @{$Values} ) {
+                    next ID if !$ID;
+                    $ID->{Content} = $Self->{UserObject}->UserLookup( UserID => $ID->{Content} );
+                }
+            }
+
+            # Locks and statustype don't have to wrap because they are never different
+        }
+    }
+    return \%Param;
+}
+
+sub ImportWrapper {
+    my ( $Self, %Param ) = @_;
+
+    # wrap used spelling to ids
+    for my $Use (qw(UseAsValueSeries UseAsRestriction UseAsXvalue)) {
+        ELEMENT:
+        for my $Element ( @{ $Param{$Use} } ) {
+            next ELEMENT if !$Element || !$Element->{SelectedValues};
+            my $ElementName = $Element->{Element};
+            my $Values      = $Element->{SelectedValues};
+
+            if ( $ElementName eq 'QueueIDs' || $ElementName eq 'CreatedQueueIDs' ) {
+                ID:
+                for my $ID ( @{$Values} ) {
+                    next ID if !$ID;
+                    if ( $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} ) ) {
+                        $ID->{Content}
+                            = $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} );
+                    }
+                    else {
+                        $Self->{LogObject}->Log(
+                            Priority => 'error',
+                            Message  => "Import: Can' find the queue $ID->{Content}!"
+                        );
+                        $ID = undef;
+                    }
+                }
+            }
+            elsif ( $ElementName eq 'StateIDs' || $ElementName eq 'CreatedStateIDs' ) {
+                ID:
+                for my $ID ( @{$Values} ) {
+                    next ID if !$ID;
+
+                    my %State = $Self->{StateObject}->StateGet(
+                        Name  => $ID->{Content},
+                        Cache => 1,
+                    );
+                    if ( $State{ID} ) {
+                        $ID->{Content} = $State{ID};
+                    }
+                    else {
+                        $Self->{LogObject}->Log(
+                            Priority => 'error',
+                            Message  => "Import: Can' find state $ID->{Content}!"
+                        );
+                        $ID = undef;
+                    }
+                }
+            }
+            elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
+                my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
+                my %PriorityIDs;
+                for my $Key ( keys %PriorityList ) {
+                    $PriorityIDs{ $PriorityList{$Key} } = $Key;
+                }
+                ID:
+                for my $ID ( @{$Values} ) {
+                    next ID if !$ID;
+
+                    if ( $PriorityIDs{ $ID->{Content} } ) {
+                        $ID->{Content} = $PriorityIDs{ $ID->{Content} };
+                    }
+                    else {
+                        $Self->{LogObject}->Log(
+                            Priority => 'error',
+                            Message  => "Import: Can' find priority $ID->{Content}!"
+                        );
+                        $ID = undef;
+                    }
+                }
+            }
+            elsif (
+                $ElementName    eq 'OwnerIDs'
+                || $ElementName eq 'CreatedUserIDs'
+                || $ElementName eq 'ResponsibleIDs'
+                )
+            {
+                ID:
+                for my $ID ( @{$Values} ) {
+                    next ID if !$ID;
+
+                    if ( $Self->{UserObject}->UserLookup( UserLogin => $ID->{Content} ) ) {
+                        $ID->{Content} = $Self->{UserObject}->UserLookup(
+                            UserLogin => $ID->{Content}
+                        );
+                    }
+                    else {
+                        $Self->{LogObject}->Log(
+                            Priority => 'error',
+                            Message  => "Import: Can' find user $ID->{Content}!"
+                        );
+                        $ID = undef;
+                    }
+                }
+            }
+
+            # Locks and statustype don't have to wrap because they are never different
+        }
+    }
+    return \%Param;
+}
+
 sub _ReportingValues {
     my ( $Self, %Param ) = @_;
     my $SearchAttributes = $Param{SearchAttributes};
 
+    #
+    # escape search attributes for ticket search
+    #
+    my %AttributesToEscape = (
+        'CustomerID' => 1,
+        'Title'      => 1,
+    );
+
     # get ticket search relevant attributes
-    my %TicketSearch = ();
+    my %TicketSearch;
     ATTRIBUTE:
     for my $Attribute ( @{ $Self->_AllowedTicketSearchAttributes() } ) {
         next ATTRIBUTE if !$SearchAttributes->{$Attribute};
         $TicketSearch{$Attribute} = $SearchAttributes->{$Attribute};
+
+        next ATTRIBUTE if !$AttributesToEscape{$Attribute};
+
+        # escape search parameters for ticket search
+        if ( ref $TicketSearch{$Attribute} ) {
+            if ( ref $TicketSearch{$Attribute} eq 'ARRAY' ) {
+                $TicketSearch{$Attribute} = [
+                    map { $Self->{DBObject}->QueryStringEscape( QueryString => $_ ) }
+                        @{ $TicketSearch{$Attribute} }
+                ];
+            }
+        }
+        else {
+            $TicketSearch{$Attribute} = $Self->{DBObject}->QueryStringEscape(
+                QueryString => $TicketSearch{$Attribute}
+            );
+        }
     }
 
     # do nothing, if there are no search attributes
     return map { $_ => 0 } @{ $Param{SelectedKindsOfReporting} } if !%TicketSearch;
 
+    for my $ParameterName ( keys %TicketSearch ) {
+        if ( $ParameterName =~ m{\A DynamicField_ ( [a-zA-Z\d]+ ) \z}xms ) {
+
+            # loop over the dynamic fields configured
+            DYNAMICFIELD:
+            for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+                next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+                next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+
+                # skip all fields that does not match with current field name ($1)
+                # without the 'DynamicField_' prefix
+                next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $1;
+
+                # get new search parameter
+                my $DynamicFieldStatsSearchParameter
+                    = $Self->{BackendObject}->CommonSearchFieldParameterBuild(
+                    DynamicFieldConfig => $DynamicFieldConfig,
+                    Value              => $TicketSearch{$ParameterName},
+                    );
+
+                # add new search parameter
+                $TicketSearch{$ParameterName} = $DynamicFieldStatsSearchParameter;
+            }
+        }
+    }
+
     # get the involved tickets
     my @TicketIDs = $Self->{TicketObject}->TicketSearch(
         UserID     => 1,
@@ -617,18 +844,19 @@ sub _ReportingValues {
     my $Counter        = 0;
     my $CounterAllOver = 0;
 
-    my %SolutionAllOver     = ();
-    my %Solution            = ();
-    my %SolutionWorkingTime = ();
-    my %Response            = ();
-    my %ResponseWorkingTime = ();
+    my %SolutionAllOver;
+    my %Solution;
+    my %SolutionWorkingTime;
+    my %Response;
+    my %ResponseWorkingTime;
 
     for my $TicketID (@TicketIDs) {
         $CounterAllOver++;
         my %Ticket = $Self->{TicketObject}->TicketGet(
-            TicketID => $TicketID,
-            UserID   => 1,
-            Extended => 1,
+            TicketID      => $TicketID,
+            UserID        => 1,
+            Extended      => 1,
+            DynamicFields => 0,
         );
 
         my $SolutionTime = $Self->{TimeObject}->TimeStamp2SystemTime(
@@ -659,7 +887,7 @@ sub _ReportingValues {
         }
     }
 
-    my %Reporting = ();
+    my %Reporting;
     my %SelectedKindsOfReporting = map { $_ => 1 } @{ $Param{SelectedKindsOfReporting} };
 
     # different solution averages
@@ -807,7 +1035,9 @@ sub _ReportingValues {
         )
         )
     {
-        $Reporting{$Key} = int( $Reporting{$Key} / 60 + 0.5 );
+        if ( defined $Reporting{$Key} ) {
+            $Reporting{$Key} = int( $Reporting{$Key} / 60 + 0.5 );
+        }
     }
 
     # convert min in hh:mm
@@ -945,204 +1175,19 @@ sub _AllowedTicketSearchAttributes {
         TicketEscalationResponseTimeOlderDate
         TicketEscalationSolutionTimeNewerDate
         TicketEscalationSolutionTimeOlderDate
-        TicketFreeTime1NewerDate
-        TicketFreeTime1OlderDate
-        TicketFreeTime2NewerDate
-        TicketFreeTime2OlderDate
-        TicketFreeTime3NewerDate
-        TicketFreeTime3OlderDate
-        TicketFreeTime4NewerDate
-        TicketFreeTime4OlderDate
-        TicketFreeTime5NewerDate
-        TicketFreeTime5OlderDate
-        TicketFreeTime6NewerDate
-        TicketFreeTime6OlderDate
     );
 
-    FREEKEY:
-    for my $FreeKey ( 1 .. 16 ) {
-        push @Attributes, 'TicketFreeKey' . $FreeKey, 'TicketFreeText' . $FreeKey;
+    # loop over the dynamic fields configured
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+        next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+
+        # add dynamic field to Attribute list
+        push @Attributes, 'DynamicField_' . $DynamicFieldConfig->{Name};
     }
 
     return \@Attributes;
 }
 
-sub GetHeaderLine {
-
-    my ( $Self, %Param ) = @_;
-
-    if ( $Param{XValue}{Element} eq 'KindsOfReporting' ) {
-
-        my %Selected = map { $_ => 1 } @{ $Param{XValue}{SelectedValues} };
-
-        my $Attributes = $Self->_KindsOfReporting();
-        my @HeaderLine = ('Evaluation by');
-        my $SortedRef  = $Self->_SortedKindsOfReporting();
-
-        ATTRIBUTE:
-        for my $Attribute ( @{$SortedRef} ) {
-            next ATTRIBUTE if !$Selected{$Attribute};
-            push @HeaderLine, $Attributes->{$Attribute};
-        }
-        return \@HeaderLine;
-
-    }
-    return;
-}
-
-sub ExportWrapper {
-    my ( $Self, %Param ) = @_;
-
-    # wrap ids to used spelling
-    for my $Use (qw(UseAsValueSeries UseAsRestriction UseAsXvalue)) {
-        ELEMENT:
-        for my $Element ( @{ $Param{$Use} } ) {
-            next ELEMENT if !$Element || !$Element->{SelectedValues};
-            my $ElementName = $Element->{Element};
-            my $Values      = $Element->{SelectedValues};
-
-            if ( $ElementName eq 'QueueIDs' || $ElementName eq 'CreatedQueueIDs' ) {
-                ID:
-                for my $ID ( @{$Values} ) {
-                    next ID if !$ID;
-                    $ID->{Content} = $Self->{QueueObject}->QueueLookup( QueueID => $ID->{Content} );
-                }
-            }
-            elsif ( $ElementName eq 'StateIDs' || $ElementName eq 'CreatedStateIDs' ) {
-                my %StateList = $Self->{StateObject}->StateList( UserID => 1 );
-                ID:
-                for my $ID ( @{$Values} ) {
-                    next ID if !$ID;
-                    $ID->{Content} = $StateList{ $ID->{Content} };
-                }
-            }
-            elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
-                my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
-                ID:
-                for my $ID ( @{$Values} ) {
-                    next ID if !$ID;
-                    $ID->{Content} = $PriorityList{ $ID->{Content} };
-                }
-            }
-            elsif (
-                $ElementName    eq 'OwnerIDs'
-                || $ElementName eq 'CreatedUserIDs'
-                || $ElementName eq 'ResponsibleIDs'
-                )
-            {
-                ID:
-                for my $ID ( @{$Values} ) {
-                    next ID if !$ID;
-                    $ID->{Content} = $Self->{UserObject}->UserLookup( UserID => $ID->{Content} );
-                }
-            }
-
-            # Locks and statustype don't have to wrap because they are never different
-        }
-    }
-    return \%Param;
-}
-
-sub ImportWrapper {
-    my ( $Self, %Param ) = @_;
-
-    # wrap used spelling to ids
-    for my $Use (qw(UseAsValueSeries UseAsRestriction UseAsXvalue)) {
-        ELEMENT:
-        for my $Element ( @{ $Param{$Use} } ) {
-            next ELEMENT if !$Element || !$Element->{SelectedValues};
-            my $ElementName = $Element->{Element};
-            my $Values      = $Element->{SelectedValues};
-
-            if ( $ElementName eq 'QueueIDs' || $ElementName eq 'CreatedQueueIDs' ) {
-                ID:
-                for my $ID ( @{$Values} ) {
-                    next ID if !$ID;
-                    if ( $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} ) ) {
-                        $ID->{Content}
-                            = $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} );
-                    }
-                    else {
-                        $Self->{LogObject}->Log(
-                            Priority => 'error',
-                            Message  => "Import: Can' find the queue $ID->{Content}!"
-                        );
-                        $ID = undef;
-                    }
-                }
-            }
-            elsif ( $ElementName eq 'StateIDs' || $ElementName eq 'CreatedStateIDs' ) {
-                ID:
-                for my $ID ( @{$Values} ) {
-                    next ID if !$ID;
-
-                    my %State = $Self->{StateObject}->StateGet(
-                        Name  => $ID->{Content},
-                        Cache => 1,
-                    );
-                    if ( $State{ID} ) {
-                        $ID->{Content} = $State{ID};
-                    }
-                    else {
-                        $Self->{LogObject}->Log(
-                            Priority => 'error',
-                            Message  => "Import: Can' find state $ID->{Content}!"
-                        );
-                        $ID = undef;
-                    }
-                }
-            }
-            elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
-                my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
-                my %PriorityIDs = ();
-                for my $Key ( keys %PriorityList ) {
-                    $PriorityIDs{ $PriorityList{$Key} } = $Key;
-                }
-                ID:
-                for my $ID ( @{$Values} ) {
-                    next ID if !$ID;
-
-                    if ( $PriorityIDs{ $ID->{Content} } ) {
-                        $ID->{Content} = $PriorityIDs{ $ID->{Content} };
-                    }
-                    else {
-                        $Self->{LogObject}->Log(
-                            Priority => 'error',
-                            Message  => "Import: Can' find priority $ID->{Content}!"
-                        );
-                        $ID = undef;
-                    }
-                }
-            }
-            elsif (
-                $ElementName    eq 'OwnerIDs'
-                || $ElementName eq 'CreatedUserIDs'
-                || $ElementName eq 'ResponsibleIDs'
-                )
-            {
-                ID:
-                for my $ID ( @{$Values} ) {
-                    next ID if !$ID;
-
-                    if ( $Self->{UserObject}->UserLookup( UserLogin => $ID->{Content} ) ) {
-                        $ID->{Content} = $Self->{UserObject}->UserLookup(
-                            UserLogin => $ID->{Content}
-                        );
-                    }
-                    else {
-                        $Self->{LogObject}->Log(
-                            Priority => 'error',
-                            Message  => "Import: Can' find user $ID->{Content}!"
-                        );
-                        $ID = undef;
-                    }
-                }
-            }
-
-            # Locks and statustype don't have to wrap because they are never different
-        }
-    }
-    return \%Param;
-}
-
 1;
