@@ -1,8 +1,8 @@
 # --
 # Kernel/System/SystemAddress.pm - lib for system addresses
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: SystemAddress.pm,v 1.25 2009/04/17 08:36:44 tr Exp $
+# $Id: SystemAddress.pm,v 1.35 2012/03/26 21:47:00 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.25 $) [1];
+$VERSION = qw($Revision: 1.35 $) [1];
 
 =head1 NAME
 
@@ -67,6 +67,7 @@ create an object
         ConfigObject => $ConfigObject,
         LogObject    => $LogObject,
         DBObject     => $DBObject,
+        EncodeObject => $EncodeObject,
     );
 
 =cut
@@ -79,7 +80,7 @@ sub new {
     bless( $Self, $Type );
 
     # get needed objects
-    for (qw(ConfigObject LogObject DBObject)) {
+    for (qw(ConfigObject LogObject DBObject MainObject EncodeObject)) {
         if ( $Param{$_} ) {
             $Self->{$_} = $Param{$_};
         }
@@ -88,7 +89,7 @@ sub new {
         }
     }
 
-    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
+    $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
 
     return $Self;
 }
@@ -119,7 +120,7 @@ sub SystemAddressAdd {
         }
     }
 
-    # sql
+    # insert new system address
     return if !$Self->{DBObject}->Do(
         SQL => 'INSERT INTO system_address (value0, value1, valid_id, comments, queue_id, '
             . ' create_time, create_by, change_time, change_by)'
@@ -129,14 +130,20 @@ sub SystemAddressAdd {
             \$Param{QueueID}, \$Param{UserID}, \$Param{UserID},
         ],
     );
+
+    # get system address id
     $Self->{DBObject}->Prepare(
-        SQL => 'SELECT id FROM system_address WHERE value0 = ? AND value1 = ?',
-        Bind => [ \$Param{Name}, \$Param{Realname}, ],
+        SQL   => 'SELECT id FROM system_address WHERE value0 = ? AND value1 = ?',
+        Bind  => [ \$Param{Name}, \$Param{Realname}, ],
+        Limit => 1,
     );
+
+    # fetch the result
     my $ID;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $ID = $Row[0];
     }
+
     return $ID;
 }
 
@@ -148,6 +155,19 @@ get system address with attributes
         ID => 1,
     );
 
+returns:
+
+    %SystemAddress = (
+        'ID'         => 1,
+        'Name'       => 'info@example.com'
+        'Realname'   => 'Hotline',
+        'QueueID'    => 123,
+        'Comment'    => 'some comment',
+        'ValidID'    => 1,
+        'CreateTime' => '2010-11-29 11:04:04',
+        'ChangeTime' => '2010-12-07 12:33:56',
+    )
+
 =cut
 
 sub SystemAddressGet {
@@ -159,13 +179,16 @@ sub SystemAddressGet {
         return;
     }
 
-    # sql
+    # get system address
     return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT value0, value1, comments, valid_id, queue_id, change_time, create_time '
             . ' FROM system_address WHERE id = ?',
-        Bind => [ \$Param{ID} ],
+        Bind  => [ \$Param{ID} ],
+        Limit => 1,
     );
-    my %Data = ();
+
+    # fetch the result
+    my %Data;
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
         %Data = (
             ID         => $Param{ID},
@@ -178,6 +201,7 @@ sub SystemAddressGet {
             CreateTime => $Data[6],
         );
     }
+
     return %Data;
 }
 
@@ -208,8 +232,8 @@ sub SystemAddressUpdate {
         }
     }
 
-    # sql
-    return $Self->{DBObject}->Do(
+    # update system address
+    return if !$Self->{DBObject}->Do(
         SQL => 'UPDATE system_address SET value0 = ?, value1 = ?, comments = ?, valid_id = ?, '
             . ' change_time = current_timestamp, change_by = ?, queue_id = ? WHERE id = ?',
         Bind => [
@@ -217,15 +241,25 @@ sub SystemAddressUpdate {
             \$Param{UserID}, \$Param{QueueID}, \$Param{ID},
         ],
     );
+
+    return 1;
 }
 
 =item SystemAddressList()
 
-get a system address list
+get a list of system addresses
 
-    my %List = $SystemAddessObject->SystemAddressList();
+    my %List = $SystemAddressObject->SystemAddressList();
 
-    my %List = $SystemAddessObject->SystemAddressList( Valid => 1 );
+    my %List = $SystemAddressObject->SystemAddressList( Valid => 1 );
+
+returns:
+
+    %List = (
+        '1' => 'Acme Sales ( sales@example.com )',
+        '2' => 'Acme Purchasing ( purchasing@example.com )',
+        '3' => 'Acme Support ( support@example.com )',
+    )
 
 =cut
 
@@ -233,9 +267,10 @@ sub SystemAddressList {
     my ( $Self, %Param ) = @_;
 
     my $Valid = 1;
-    if ( !$Param{Valid} && defined( $Param{Valid} ) ) {
+    if ( !$Param{Valid} && defined $Param{Valid} ) {
         $Valid = 0;
     }
+
     return $Self->{DBObject}->GetTableData(
         What  => 'id, value1, value0',
         Valid => $Valid,
@@ -246,9 +281,10 @@ sub SystemAddressList {
 
 =item SystemAddressIsLocalAddress()
 
-check if used system address is a local address
+Checks if the given address is a local (system) address. Returns true
+for local addresses.
 
-    if ($SystemAddressObject->SystemAddressIsLocalAddress(Address => 'info@example.com')) {
+    if ( $SystemAddressObject->SystemAddressIsLocalAddress( Address => 'info@example.com' ) ) {
         # is local
     }
     else {
@@ -267,19 +303,52 @@ sub SystemAddressIsLocalAddress {
             return;
         }
     }
-    my $SQL = "SELECT value0, value1, comments, valid_id, queue_id "
-        . " FROM system_address WHERE "
-        . " valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
 
-    return if !$Self->{DBObject}->Prepare( SQL => $SQL );
-    my $Hit = 0;
-    $Param{Address} =~ s/ //g;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
-        if ( $Row[0] =~ /^\Q$Param{Address}\E$/i ) {
-            $Hit = 1;
+    return $Self->SystemAddressQueueID(%Param);
+}
+
+=item SystemAddressQueueID()
+
+find dispatching queue id of email address
+
+    my $QueueID = $SystemAddressObject->SystemAddressQueueID( Address => 'info@example.com' );
+
+=cut
+
+sub SystemAddressQueueID {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    for (qw(Address)) {
+        if ( !$Param{$_} ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            return;
         }
     }
-    return $Hit;
+
+    # remove spaces
+    $Param{Address} =~ s/\s+//g;
+
+    my $Lower = '';
+    if ( !$Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+        $Lower = 'LOWER';
+    }
+
+    return if !$Self->{DBObject}->Prepare(
+        SQL => "SELECT queue_id FROM system_address WHERE "
+            . "valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} ) "
+            . "AND $Lower(value0) = $Lower(?)",
+        Bind  => [ \$Param{Address} ],
+        Limit => 1,
+    );
+
+    # fetch the result
+    my $QueueID;
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        $QueueID = $Row[0];
+    }
+
+    return $QueueID;
 }
 
 1;
@@ -288,16 +357,16 @@ sub SystemAddressIsLocalAddress {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.25 $ $Date: 2009/04/17 08:36:44 $
+$Revision: 1.35 $ $Date: 2012/03/26 21:47:00 $
 
 =cut
