@@ -1,8 +1,8 @@
 # --
 # Kernel/System/TemplateGenerator.pm - generate salutations, signatures and responses
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: TemplateGenerator.pm,v 1.34.2.1 2009/12/09 14:20:23 martin Exp $
+# $Id: TemplateGenerator.pm,v 1.60.2.1 2012/06/04 10:21:06 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,13 +17,17 @@ use warnings;
 use Kernel::System::HTMLUtils;
 use Kernel::System::Salutation;
 use Kernel::System::Signature;
-use Kernel::System::StdResponse;
 use Kernel::System::SystemAddress;
+use Kernel::System::StandardResponse;
 use Kernel::System::Notification;
 use Kernel::System::AutoResponse;
+use Kernel::Language;
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.34.2.1 $) [1];
+$VERSION = qw($Revision: 1.60.2.1 $) [1];
 
 =head1 NAME
 
@@ -122,6 +126,7 @@ create an object
         CustomerUserObject => $CustomerUserObject,
         QueueObject        => $QueueObject,
         TicketObject       => $TicketObject,
+        MainObject         => $MainObject,
     );
 
 =cut
@@ -135,7 +140,7 @@ sub new {
 
     # check needed objects
     for (
-        qw(DBObject ConfigObject LogObject TicketObject CustomerUserObject QueueObject UserObject EncodeObject)
+        qw(DBObject ConfigObject LogObject TicketObject CustomerUserObject QueueObject UserObject MainObject EncodeObject)
         )
     {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
@@ -143,13 +148,24 @@ sub new {
 
     $Self->{RichText} = $Self->{ConfigObject}->Get('Frontend::RichText');
 
-    $Self->{HTMLUtilsObject}     = Kernel::System::HTMLUtils->new(%Param);
-    $Self->{SalutationObject}    = Kernel::System::Salutation->new(%Param);
-    $Self->{SignatureObject}     = Kernel::System::Signature->new(%Param);
-    $Self->{StdResponseObject}   = Kernel::System::StdResponse->new(%Param);
-    $Self->{SystemAddressObject} = Kernel::System::SystemAddress->new(%Param);
-    $Self->{NotificationObject}  = Kernel::System::Notification->new(%Param);
-    $Self->{AutoResponseObject}  = Kernel::System::AutoResponse->new(%Param);
+    $Self->{HTMLUtilsObject}        = Kernel::System::HTMLUtils->new(%Param);
+    $Self->{SalutationObject}       = Kernel::System::Salutation->new(%Param);
+    $Self->{SignatureObject}        = Kernel::System::Signature->new(%Param);
+    $Self->{SystemAddressObject}    = Kernel::System::SystemAddress->new(%Param);
+    $Self->{StandardResponseObject} = Kernel::System::StandardResponse->new(%Param);
+    $Self->{NotificationObject}     = Kernel::System::Notification->new(%Param);
+    $Self->{AutoResponseObject}     = Kernel::System::AutoResponse->new(%Param);
+    $Self->{DynamicFieldObject}     = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}          = Kernel::System::DynamicField::Backend->new(
+        TimeObject => $Self->{TicketObject}->{TimeObject},
+        %Param
+    );
+
+    # get the dynamic fields for ticket object
+    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid      => 1,
+        ObjectType => ['Ticket'],
+    );
 
     return $Self;
 }
@@ -181,7 +197,10 @@ sub Salutation {
     }
 
     # get  queue
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # get salutation
     my %Queue = $Self->{QueueObject}->QueueGet(
@@ -261,28 +280,30 @@ sub Signature {
 
     # need ticket id or queue id
     if ( !$Param{TicketID} && !$Param{QueueID} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => "Need TicketID or QueueID!" );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need TicketID or QueueID!' );
         return;
     }
 
+    # get salutation ticket based
     my %Queue;
     if ( $Param{TicketID} ) {
-
-        # get  queue
-        my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
-
-        # get salutation
+        my %Ticket = $Self->{TicketObject}->TicketGet(
+            TicketID      => $Param{TicketID},
+            DynamicFields => 0,
+        );
         %Queue = $Self->{QueueObject}->QueueGet(
             ID => $Ticket{QueueID},
         );
     }
-    else {
 
-        # get salutation
+    # get salutation queue based
+    else {
         %Queue = $Self->{QueueObject}->QueueGet(
             ID => $Param{QueueID},
         );
     }
+
+    # get signature
     my %Signature = $Self->{SignatureObject}->SignatureGet(
         ID => $Queue{SignatureID},
     );
@@ -309,6 +330,7 @@ sub Signature {
         Text     => $Signature{Text},
         TicketID => $Param{TicketID} || '',
         Data     => $Param{Data},
+        QueueID  => $Param{QueueID},
         UserID   => $Param{UserID},
     );
 
@@ -322,6 +344,82 @@ sub Signature {
     return $SignatureText;
 }
 
+=item Sender()
+
+generate sender address (FROM string) for emails
+
+my $Sender = $TemplateGeneratorObject->Sender(
+        QueueID    => 123,
+        UserID     => 123,
+    );
+
+returns:
+
+    "John Doe at Super Support <support@example.com>"
+
+=cut
+
+sub Sender {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    for (qw( UserID QueueID)) {
+        if ( !$Param{$_} ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            return;
+        }
+    }
+
+    # get sender attributes
+    my %Address = $Self->{QueueObject}->GetSystemAddress( QueueID => $Param{QueueID} );
+
+    # check config for agent real name
+    my $UseAgentRealName = $Self->{ConfigObject}->Get('Ticket::DefineEmailFrom');
+    if ( $UseAgentRealName && $UseAgentRealName =~ /^(AgentName|AgentNameSystemAddressName)$/ ) {
+
+        # get data from current agent
+        my %UserData = $Self->{UserObject}->GetUserData(
+            UserID        => $Param{UserID},
+            NoOutOfOffice => 1,
+        );
+
+        # set real name with user name
+        if ( $UseAgentRealName eq 'AgentName' ) {
+
+            # check for user data
+            if ( $UserData{UserLastname} && $UserData{UserFirstname} ) {
+
+                # rewrite RealName
+                $Address{RealName} = "$UserData{UserFirstname} $UserData{UserLastname}";
+            }
+        }
+
+        # set real name with user name
+        if ( $UseAgentRealName eq 'AgentNameSystemAddressName' ) {
+
+            # check for user data
+            if ( $UserData{UserLastname} && $UserData{UserFirstname} ) {
+
+                # rewrite RealName
+                my $Separator = ' ' . $Self->{ConfigObject}->Get('Ticket::DefineEmailFromSeparator')
+                    || '';
+                $Address{RealName} = $UserData{UserFirstname} . ' ' . $UserData{UserLastname}
+                    . $Separator . ' ' . $Address{RealName};
+            }
+        }
+
+    }
+
+    # prepare realname quote
+    if ( $Address{RealName} =~ /(,|@|\(|\)|:)/ && $Address{RealName} !~ /^("|')/ ) {
+        $Address{RealName} =~ s/"/\"/g;
+        $Address{RealName} = '"' . $Address{RealName} . '"';
+    }
+    my $Sender = "$Address{RealName} <$Address{Email}>";
+
+    return $Sender;
+}
+
 =item Response()
 
 generate response
@@ -334,7 +432,7 @@ generate response
     );
 
 returns
-    StdResponse
+    StandardResponse
     Salutation
     Signature
 
@@ -352,13 +450,16 @@ sub Response {
     }
 
     # get  queue
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # get salutation
     my %Queue = $Self->{QueueObject}->QueueGet(
         ID => $Ticket{QueueID},
     );
-    my %Response = $Self->{StdResponseObject}->StdResponseGet(
+    my %Response = $Self->{StandardResponseObject}->StandardResponseGet(
         ID => $Param{ResponseID},
     );
 
@@ -392,9 +493,10 @@ sub Response {
     my $Signature = $Self->Signature(%Param);
 
     return (
-        StdResponse => $ResponseText,
-        Salutation  => $Salutation,
-        Signature   => $Signature,
+        StandardResponse => $ResponseText,
+        StdResponse      => $ResponseText,
+        Salutation       => $Salutation,
+        Signature        => $Signature,
     );
 }
 
@@ -407,10 +509,11 @@ generate attributes
         ArticleID  => 123,
         ResponseID => 123
         UserID     => 123,
+        Action     => 'Forward', # Possible values are Reply and Forward, Reply is default.
     );
 
 returns
-    StdResponse
+    StandardResponse
     Salutation
     Signature
 
@@ -427,27 +530,24 @@ sub Attributes {
         }
     }
 
-    # get  queue
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    # get queue
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # prepare subject ...
     $Param{Data}->{Subject} = $Self->{TicketObject}->TicketSubjectBuild(
         TicketNumber => $Ticket{TicketNumber},
-        Subject => $Param{Data}->{Subject} || '',
+        Subject      => $Param{Data}->{Subject} || '',
+        Action       => $Param{Action} || '',
     );
 
-    # get sender attributes
-    my %Address = $Self->{QueueObject}->GetSystemAddress( QueueID => $Ticket{QueueID} );
-
-    # prepare realname quote
-    if ( $Address{RealName} =~ /(,|@|\(|\)|:)/ && $Address{RealName} !~ /^("|')/ ) {
-        $Address{RealName} =~ s/"/\"/g;
-        $Address{RealName} = '"' . $Address{RealName} . '"';
-    }
-    $Param{Data}->{SenderAddress}  = $Address{Email};
-    $Param{Data}->{SenderRealname} = $Address{RealName};
-    $Param{Data}->{From}           = "$Address{RealName} <$Address{Email}>";
-
+    # get sender address
+    $Param{Data}->{From} = $Self->Sender(
+        QueueID => $Ticket{QueueID},
+        UserID  => $Param{UserID},
+    );
     return %{ $Param{Data} };
 }
 
@@ -493,7 +593,10 @@ sub AutoResponse {
     }
 
     # get ticket
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     # get auto default responses
     my %AutoResponse = $Self->{AutoResponseObject}->AutoResponseGetByTypeQueueID(
@@ -503,9 +606,10 @@ sub AutoResponse {
 
     return if !%AutoResponse;
 
-    # get old article for quoteing
+    # get old article for quoting
     my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
-        TicketID => $Param{TicketID},
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
     );
 
     for (qw(From To Cc Subject Body)) {
@@ -518,7 +622,11 @@ sub AutoResponse {
     # format body (only if longer the 86 chars)
     if ( $Param{OrigHeader}->{Body} ) {
         if ( length $Param{OrigHeader}->{Body} > 86 ) {
-            $Param{OrigHeader}->{Body} =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
+            my @lines = split /\n/, $Param{OrigHeader}->{Body};
+            for my $line (@lines) {
+                $line =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
+            }
+            $Param{OrigHeader}->{Body} = join '', @lines;
         }
     }
 
@@ -614,7 +722,7 @@ sub AutoResponse {
 
 generate response
 
-NotifcationAgent
+NotificationAgent
     TicketID
         Owner
         Responsible
@@ -654,10 +762,16 @@ sub NotificationAgent {
     }
 
     # get ticket
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
-    # get old article for quoteing
-    my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle( TicketID => $Param{TicketID} );
+    # get old article for quoting
+    my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
     for (qw(From To Cc Subject Body)) {
         if ( !$Param{CustomerMessageParams}->{$_} ) {
@@ -669,7 +783,11 @@ sub NotificationAgent {
     # format body (only if longer the 86 chars)
     if ( $Param{CustomerMessageParams}->{Body} ) {
         if ( length $Param{CustomerMessageParams}->{Body} > 86 ) {
-            $Param{CustomerMessageParams}->{Body} =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
+            my @lines = split /\n/, $Param{CustomerMessageParams}->{Body};
+            for my $line (@lines) {
+                $line =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
+            }
+            $Param{CustomerMessageParams}->{Body} = join '', @lines;
         }
     }
 
@@ -683,7 +801,6 @@ sub NotificationAgent {
     # get recipient
     my %User = $Self->{UserObject}->GetUserData(
         UserID => $Param{RecipientID},
-        Cached => 1,
         Valid  => 1,
     );
 
@@ -726,6 +843,7 @@ sub NotificationAgent {
         Data        => $Param{CustomerMessageParams},
         TicketID    => $Param{TicketID},
         UserID      => $Param{UserID},
+        Language    => $Language,
     );
     $Notification{Subject} = $Self->_Replace(
         RichText    => 0,
@@ -734,6 +852,7 @@ sub NotificationAgent {
         Data        => $Param{CustomerMessageParams},
         TicketID    => $Param{TicketID},
         UserID      => $Param{UserID},
+        Language    => $Language,
     );
 
     # prepare subject (insert old subject)
@@ -774,7 +893,7 @@ sub NotificationAgent {
 
 generate response
 
-NotifcationCustomer
+NotificationCustomer
     TicketID
         Owner
         Responsible
@@ -814,9 +933,17 @@ sub NotificationCustomer {
         }
     }
 
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
+    );
 
-    my %User = ();
+    my %Queue;
+    if ( $Param{QueueID} ) {
+        %Queue = $Self->{QueueObject}->QueueGet( ID => $Param{QueueID} );
+    }
+
+    my %User;
 
     # get user language
     my $Language = $User{UserLanguage} || $Self->{ConfigObject}->Get('DefaultLanguage') || 'en';
@@ -842,6 +969,7 @@ sub NotificationCustomer {
             Text     => $Notification{$_},
             TicketID => $Param{TicketID},
             UserID   => $Param{UserID},
+            Language => $Language,
         );
     }
 
@@ -853,6 +981,10 @@ sub NotificationCustomer {
     return %Notification;
 }
 
+=begin Internal:
+
+=cut
+
 sub _Replace {
     my ( $Self, %Param ) = @_;
 
@@ -874,7 +1006,29 @@ sub _Replace {
 
     my %Ticket;
     if ( $Param{TicketID} ) {
-        %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
+        %Ticket = $Self->{TicketObject}->TicketGet(
+            TicketID      => $Param{TicketID},
+            DynamicFields => 1,
+        );
+    }
+
+    # translate ticket values if needed
+    if ( $Param{Language} ) {
+        my $LanguageObject = Kernel::Language->new(
+            MainObject   => $Self->{MainObject},
+            ConfigObject => $Self->{ConfigObject},
+            EncodeObject => $Self->{EncodeObject},
+            LogObject    => $Self->{LogObject},
+            UserLanguage => $Param{Language},
+        );
+        for my $Field (qw(Type State StateType Lock Priority)) {
+            $Ticket{$Field} = $LanguageObject->Get( $Ticket{$Field} );
+        }
+    }
+
+    my %Queue;
+    if ( $Param{QueueID} ) {
+        %Queue = $Self->{QueueObject}->QueueGet( ID => $Param{QueueID} );
     }
 
     # replace config options
@@ -888,11 +1042,11 @@ sub _Replace {
     $Tag = $Start . 'OTRS_';
     if ( $Param{RecipientID} ) {
         my %Recipient = $Self->{UserObject}->GetUserData(
-            UserID => $Param{RecipientID},
-            Cached => 1,
+            UserID        => $Param{RecipientID},
+            NoOutOfOffice => 1,
         );
 
-        # html quoteing of content
+        # html quoting of content
         if ( $Param{RichText} ) {
             for ( keys %Recipient ) {
                 next if !$Recipient{$_};
@@ -913,10 +1067,11 @@ sub _Replace {
     $Tag = $Start . 'OTRS_OWNER_';
     if ( $Ticket{OwnerID} ) {
         my %Owner = $Self->{UserObject}->GetUserData(
-            UserID => $Ticket{OwnerID},
+            UserID        => $Ticket{OwnerID},
+            NoOutOfOffice => 1,
         );
 
-        # html quoteing of content
+        # html quoting of content
         if ( $Param{RichText} ) {
             for ( keys %Owner ) {
                 next if !$Owner{$_};
@@ -940,10 +1095,11 @@ sub _Replace {
     $Tag = $Start . 'OTRS_RESPONSIBLE_';
     if ( $Ticket{ResponsibleID} ) {
         my %Responsible = $Self->{UserObject}->GetUserData(
-            UserID => $Ticket{ResponsibleID},
+            UserID        => $Ticket{ResponsibleID},
+            NoOutOfOffice => 1,
         );
 
-        # html quoteing of content
+        # html quoting of content
         if ( $Param{RichText} ) {
             for ( keys %Responsible ) {
                 next if !$Responsible{$_};
@@ -964,10 +1120,13 @@ sub _Replace {
     $Param{Text} =~ s/$Tag.+?$End/-/gi;
 
     $Tag = $Start . 'OTRS_Agent_';
-    my $Tag2 = $Start . 'OTRS_CURRENT_';
-    my %CurrentUser = $Self->{UserObject}->GetUserData( UserID => $Param{UserID} );
+    my $Tag2        = $Start . 'OTRS_CURRENT_';
+    my %CurrentUser = $Self->{UserObject}->GetUserData(
+        UserID        => $Param{UserID},
+        NoOutOfOffice => 1,
+    );
 
-    # html quoteing of content
+    # html quoting of content
     if ( $Param{RichText} ) {
         for ( keys %CurrentUser ) {
             next if !$CurrentUser{$_};
@@ -995,7 +1154,7 @@ sub _Replace {
     # ticket data
     $Tag = $Start . 'OTRS_TICKET_';
 
-    # html quoteing of content
+    # html quoting of content
     if ( $Param{RichText} ) {
         for ( keys %Ticket ) {
             next if !$Ticket{$_};
@@ -1005,6 +1164,23 @@ sub _Replace {
         }
     }
 
+    # cycle trough the activated Dynamic Fields for this screen
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+        # get the readable value for each dynamic field
+        my $ValueStrg = $Self->{BackendObject}->ReadableValueRender(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Value              => $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
+        );
+
+        # replace ticket content with the value from ReadableValueRender (if any)
+        if ( IsHashRefWithData($ValueStrg) ) {
+            $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = $ValueStrg->{Value};
+        }
+    }
+
     # replace it
     for ( keys %Ticket ) {
         next if !defined $Ticket{$_};
@@ -1014,7 +1190,12 @@ sub _Replace {
     # COMPAT
     $Param{Text} =~ s/$Start OTRS_TICKET_ID $End/$Ticket{TicketID}/gixms;
     $Param{Text} =~ s/$Start OTRS_TICKET_NUMBER $End/$Ticket{TicketNumber}/gixms;
-    $Param{Text} =~ s/$Start OTRS_QUEUE $End/$Ticket{Queue}/gixms;
+    if ( $Param{TicketID} ) {
+        $Param{Text} =~ s/$Start OTRS_QUEUE $End/$Ticket{Queue}/gixms;
+    }
+    if ( $Param{QueueID} ) {
+        $Param{Text} =~ s/$Start OTRS_TICKET_QUEUE $End/$Queue{Name}/gixms;
+    }
 
     # cleanup
     $Param{Text} =~ s/$Tag.+?$End/-/gi;
@@ -1022,7 +1203,7 @@ sub _Replace {
     # get customer params and replace it with <OTRS_CUSTOMER_...
     my %Data = %{ $Param{Data} };
 
-    # html quoteing of content
+    # html quoting of content
     if ( $Param{RichText} ) {
         for ( keys %Data ) {
             next if !$Data{$_};
@@ -1076,10 +1257,10 @@ sub _Replace {
                 }
                 chomp $NewOldBody;
 
-                # html quoteing of content
+                # html quoting of content
                 if ( $Param{RichText} && $NewOldBody ) {
 
-                    # remove tailing new lines
+                    # remove trailing new lines
                     for ( 1 .. 10 ) {
                         $NewOldBody =~ s/(<br\/>)\s{0,20}$//gs;
                     }
@@ -1126,10 +1307,10 @@ sub _Replace {
             }
             chomp $NewOldBody;
 
-            # html quoteing of content
+            # html quoting of content
             if ( $Param{RichText} && $NewOldBody ) {
 
-                # remove tailing new lines
+                # remove trailing new lines
                 for ( 1 .. 10 ) {
                     $NewOldBody =~ s/(<br\/>)\s{0,20}$//gs;
                 }
@@ -1186,7 +1367,7 @@ sub _Replace {
             # remove email addresses
             $From =~ s/&lt;.*&gt;|<.*>|\(.*\)|\"|&quot;|;|,//g;
 
-            # remove leading/tailing spaces
+            # remove leading/trailing spaces
             $From =~ s/^\s+//g;
             $From =~ s/\s+$//g;
         }
@@ -1203,7 +1384,7 @@ sub _Replace {
             User => $Ticket{CustomerUserID},
         );
 
-        # html quoteing of content
+        # html quoting of content
         if ( $Param{RichText} ) {
             for ( keys %CustomerUser ) {
                 next if !$CustomerUser{$_};
@@ -1230,20 +1411,22 @@ sub _Replace {
 
 1;
 
+=end Internal:
+
 =back
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (http://otrs.org/).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.34.2.1 $ $Date: 2009/12/09 14:20:23 $
+$Revision: 1.60.2.1 $ $Date: 2012/06/04 10:21:06 $
 
 =cut
