@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Ticket/ArticleSearchIndex/RuntimeDB.pm - article search index backend runtime
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: RuntimeDB.pm,v 1.7.2.3 2009/10/12 18:24:34 mb Exp $
+# $Id: RuntimeDB.pm,v 1.14 2011/09/02 15:09:49 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.7.2.3 $) [1];
+$VERSION = qw($Revision: 1.14 $) [1];
 
 sub ArticleIndexBuild {
     my ( $Self, %Param ) = @_;
@@ -71,8 +71,6 @@ sub _ArticleIndexQuerySQL {
     }
 
     # use also article table if required
-    my $SQL    = '';
-    my $SQLExt = '';
     for (
         qw(
         From To Cc Subject Body
@@ -83,13 +81,11 @@ sub _ArticleIndexQuerySQL {
     {
 
         if ( $Param{Data}->{$_} ) {
-            $SQL    = ', article art ';
-            $SQLExt = ' AND st.id = art.ticket_id';
-            last;
+            return ' INNER JOIN article art ON st.id = art.ticket_id ';
         }
     }
 
-    return $SQL, $SQLExt;
+    return '';
 }
 
 sub _ArticleIndexQuerySQLExt {
@@ -113,61 +109,61 @@ sub _ArticleIndexQuerySQLExt {
     my $SQLExt      = '';
     my $FullTextSQL = '';
     for my $Key ( keys %FieldSQLMapFullText ) {
-        if ( $Param{Data}->{$Key} ) {
-            $Param{Data}->{$Key} =~ s/\*/%/gi;
+        next if !$Param{Data}->{$Key};
 
-            # check search attribute, we do not need to search for *
-            next if $Param{Data}->{$Key} =~ /^\%{1,3}$/;
+        # replace * by % for SQL like
+        $Param{Data}->{$Key} =~ s/\*/%/gi;
 
-            if ($FullTextSQL) {
-                $FullTextSQL .= ' ' . $Param{Data}->{ContentSearch} . ' ';
+        # check search attribute, we do not need to search for *
+        next if $Param{Data}->{$Key} =~ /^\%{1,3}$/;
+
+        if ($FullTextSQL) {
+            $FullTextSQL .= ' ' . $Param{Data}->{ContentSearch} . ' ';
+        }
+
+        # check if search condition extension is used
+        if ( $Param{Data}->{ConditionInline} ) {
+            $FullTextSQL .= $Self->{DBObject}->QueryCondition(
+                Key          => $FieldSQLMapFullText{$Key},
+                Value        => $Param{Data}->{$Key},
+                SearchPrefix => $Param{Data}->{ContentSearchPrefix},
+                SearchSuffix => $Param{Data}->{ContentSearchSuffix},
+                Extended     => 1,
+            );
+        }
+        else {
+
+            my $Field = $FieldSQLMapFullText{$Key};
+            my $Value = $Param{Data}->{$Key};
+
+            if ( $Param{Data}->{ContentSearchPrefix} ) {
+                $Value = $Param{Data}->{ContentSearchPrefix} . $Value;
+            }
+            if ( $Param{Data}->{ContentSearchSuffix} ) {
+                $Value .= $Param{Data}->{ContentSearchSuffix};
             }
 
-            # check if search condition extention is used
-            if (
-                $Param{Data}->{ConditionInline}
-                && $Param{Data}->{$Key} =~ /(&&|\|\||\!|\+|AND|OR)/
-                )
-            {
-                my %Search;
-                if ( $Param{Data}->{FullTextIndex} ) {
-                    %Search = (
-                        SearchPrefix => '*',
-                        SearchSuffix => '*',
-                    );
-                }
-                $FullTextSQL .= $Self->{DBObject}->QueryCondition(
-                    Key   => $FieldSQLMapFullText{$Key},
-                    Value => $Param{Data}->{$Key},
-                    %Search,
-                );
+            # replace %% by % for SQL
+            $Param{Data}->{$Key} =~ s/%%/%/gi;
+
+            # db quote
+            $Value = $Self->{DBObject}->Quote( $Value, 'Like' );
+
+            # check if database supports LIKE in large text types (in this case for body)
+            if ( $Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+                $FullTextSQL .= " $Field LIKE '$Value'";
+            }
+            elsif ( $Self->{DBObject}->GetDatabaseFunction('LcaseLikeInLargeText') ) {
+                $FullTextSQL .= " LCASE($Field) LIKE LCASE('$Value')";
             }
             else {
-
-                # check if database supports LIKE in large text types (in this case for body)
-                if ( $Self->{DBObject}->GetDatabaseFunction('NoLowerInLargeText') ) {
-                    $FullTextSQL .= " $FieldSQLMapFullText{$Key} LIKE '"
-                        . $Self->{DBObject}->Quote( $Param{Data}->{$Key}, 'Like' ) . "'";
-                }
-                elsif ( $Self->{DBObject}->GetDatabaseFunction('LcaseLikeInLargeText') ) {
-                    $FullTextSQL .= " LCASE($FieldSQLMapFullText{$Key}) LIKE LCASE('"
-                        . $Self->{DBObject}->Quote( $Param{Data}->{$Key}, 'Like' ) . "')";
-                }
-                elsif ( $Self->{DBObject}->GetDatabaseFunction('Type') eq 'ingres' ) {
-                    $FullTextSQL .= " LOWER(VARCHAR($FieldSQLMapFullText{$Key})) LIKE LOWER('"
-                        . $Self->{DBObject}->Quote( $Param{Data}->{$Key}, 'Like' ) . "')";
-                }
-                else {
-                    $FullTextSQL .= " LOWER($FieldSQLMapFullText{$Key}) LIKE LOWER('"
-                        . $Self->{DBObject}->Quote( $Param{Data}->{$Key}, 'Like' ) . "')";
-                }
+                $FullTextSQL .= " LOWER($Field) LIKE LOWER('$Value')";
             }
         }
     }
     if ($FullTextSQL) {
         $SQLExt = ' AND (' . $FullTextSQL . ')';
     }
-
     return $SQLExt;
 }
 
