@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Ticket/ArticleSearchIndex/StaticDB.pm - article search index backend static
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: StaticDB.pm,v 1.10.2.4 2009/10/23 14:15:15 martin Exp $
+# $Id: StaticDB.pm,v 1.21 2011/12/08 14:06:42 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.10.2.4 $) [1];
+$VERSION = qw($Revision: 1.21 $) [1];
 
 sub ArticleIndexBuild {
     my ( $Self, %Param ) = @_;
@@ -29,8 +29,9 @@ sub ArticleIndexBuild {
     }
 
     my %Article = $Self->ArticleGet(
-        ArticleID => $Param{ArticleID},
-        UserID    => $Param{UserID},
+        ArticleID     => $Param{ArticleID},
+        UserID        => $Param{UserID},
+        DynamicFields => 0,
     );
 
     for my $Key (qw(From To Cc Subject)) {
@@ -127,8 +128,6 @@ sub _ArticleIndexQuerySQL {
     }
 
     # use also article table if required
-    my $SQL    = '';
-    my $SQLExt = '';
     for (
         qw(
         From To Cc Subject Body
@@ -138,13 +137,11 @@ sub _ArticleIndexQuerySQL {
         )
     {
         if ( $Param{Data}->{$_} ) {
-            $SQL    = ', article_search art ';
-            $SQLExt = ' AND st.id = art.ticket_id';
-            last;
+            return ' INNER JOIN article_search art ON st.id = art.ticket_id ';
         }
     }
 
-    return $SQL, $SQLExt;
+    return '';
 }
 
 sub _ArticleIndexQuerySQLExt {
@@ -168,50 +165,51 @@ sub _ArticleIndexQuerySQLExt {
     my $SQLExt      = '';
     my $FullTextSQL = '';
     for my $Key ( keys %FieldSQLMapFullText ) {
-        if ( $Param{Data}->{$Key} ) {
-            $Param{Data}->{$Key} =~ s/\*/%/gi;
+        next if !$Param{Data}->{$Key};
 
-            # check search attribute, we do not need to search for *
-            next if $Param{Data}->{$Key} =~ /^\%{1,3}$/;
+        # replace * by % for SQL like
+        $Param{Data}->{$Key} =~ s/\*/%/gi;
 
-            if ($FullTextSQL) {
-                $FullTextSQL .= ' ' . $Param{Data}->{ContentSearch} . ' ';
+        # check search attribute, we do not need to search for *
+        next if $Param{Data}->{$Key} =~ /^\%{1,3}$/;
+
+        if ($FullTextSQL) {
+            $FullTextSQL .= ' ' . $Param{Data}->{ContentSearch} . ' ';
+        }
+
+        # check if search condition extension is used
+        if ( $Param{Data}->{ConditionInline} ) {
+            $FullTextSQL .= $Self->{DBObject}->QueryCondition(
+                Key          => $FieldSQLMapFullText{$Key},
+                Value        => $Param{Data}->{$Key},
+                SearchPrefix => $Param{Data}->{ContentSearchPrefix},
+                SearchSuffix => $Param{Data}->{ContentSearchSuffix},
+                Extended     => 1,
+            );
+        }
+        else {
+
+            my $Field = $FieldSQLMapFullText{$Key};
+            my $Value = $Param{Data}->{$Key};
+
+            if ( $Param{Data}->{ContentSearchPrefix} ) {
+                $Value = $Param{Data}->{ContentSearchPrefix} . $Value;
+            }
+            if ( $Param{Data}->{ContentSearchSuffix} ) {
+                $Value .= $Param{Data}->{ContentSearchSuffix};
             }
 
-            # check if search condition extention is used
-            if (
-                $Param{Data}->{ConditionInline}
-                && $Param{Data}->{$Key} =~ /(&&|\|\||\!|\+|AND|OR)/
-                )
-            {
-                my %Search;
-                if ( $Param{Data}->{FullTextIndex} ) {
-                    %Search = (
-                        SearchPrefix => '*',
-                        SearchSuffix => '*',
-                    );
-                }
-                $FullTextSQL .= $Self->{DBObject}->QueryCondition(
-                    Key   => $FieldSQLMapFullText{$Key},
-                    Value => $Param{Data}->{$Key},
-                    %Search,
-                );
+            # replace %% by % for SQL
+            $Param{Data}->{$Key} =~ s/%%/%/gi;
+
+            # db quote
+            $Value = lc $Self->{DBObject}->Quote( $Value, 'Like' );
+
+            if ( $Self->{DBObject}->GetDatabaseFunction('LcaseLikeInLargeText') ) {
+                $FullTextSQL .= " LCASE($Field) LIKE LCASE('$Value')";
             }
             else {
-
-                # check if database supports LIKE in large text types (in this case for body)
-                if ( $Self->{DBObject}->GetDatabaseFunction('NoLowerInLargeText') ) {
-                    $FullTextSQL .= " $FieldSQLMapFullText{$Key} LIKE '"
-                        . $Self->{DBObject}->Quote( $Param{Data}->{$Key}, 'Like' ) . "'";
-                }
-                elsif ( $Self->{DBObject}->GetDatabaseFunction('LcaseLikeInLargeText') ) {
-                    $FullTextSQL .= " LCASE($FieldSQLMapFullText{$Key}) LIKE LCASE('"
-                        . $Self->{DBObject}->Quote( $Param{Data}->{$Key}, 'Like' ) . "')";
-                }
-                else {
-                    $FullTextSQL .= " LOWER($FieldSQLMapFullText{$Key}) LIKE LOWER('"
-                        . $Self->{DBObject}->Quote( $Param{Data}->{$Key}, 'Like' ) . "')";
-                }
+                $FullTextSQL .= " $Field LIKE '$Value'";
             }
         }
     }
@@ -309,7 +307,7 @@ sub _ArticleIndexStringToWord {
     my $LengthMin = $Param{WordLengthMin} || $Config->{WordLengthMin} || 3;
     my $LengthMax = $Param{WordLengthMax} || $Config->{WordLengthMax} || 30;
     my @ListOfWords = split /\s+/, ${ $Param{String} };
-    my @ListOfWordsNew = ();
+    my @ListOfWordsNew;
     for my $Word (@ListOfWords) {
 
         # remove some not needed chars
@@ -325,7 +323,7 @@ sub _ArticleIndexStringToWord {
             next;
         }
 
-        # do not index words/strings longer the x chars
+        # do not index words/strings longer then x chars
         if ( $Length > $LengthMax ) {
             next;
         }
