@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Ticket/ArticleStorageDB.pm - article storage module for OTRS kernel
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: ArticleStorageDB.pm,v 1.78.2.1 2011/04/08 16:54:59 en Exp $
+# $Id: ArticleStorageDB.pm,v 1.80 2012/03/20 20:43:59 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,8 +17,10 @@ use warnings;
 use MIME::Base64;
 use MIME::Words qw(:all);
 
+use Kernel::System::VariableCheck qw(:all);
+
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.78.2.1 $) [1];
+$VERSION = qw($Revision: 1.80 $) [1];
 
 sub ArticleStorageInit {
     my ( $Self, %Param ) = @_;
@@ -47,6 +49,27 @@ sub ArticleDelete {
         }
     }
 
+    my $DynamicFieldListArticle = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        ObjectType => 'Article',
+        Valid      => 0,
+    );
+
+    # delete dynamicfield values for this article
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{$DynamicFieldListArticle} ) {
+
+        next DYNAMICFIELD if !$DynamicFieldConfig;
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+        next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+        next DYNAMICFIELD if !IsHashRefWithData( $DynamicFieldConfig->{Config} );
+
+        $Self->{DynamicFieldBackendObject}->ValueDelete(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            ObjectID           => $Param{ArticleID},
+            UserID             => $Param{UserID},
+        );
+    }
+
     # delete index
     $Self->ArticleIndexDelete(
         ArticleID => $Param{ArticleID},
@@ -77,6 +100,12 @@ sub ArticleDelete {
         Bind => [ \$Param{ArticleID} ],
     );
 
+    # delete article history entries
+    return if !$Self->{DBObject}->Do(
+        SQL  => 'DELETE FROM ticket_history WHERE article_id = ?',
+        Bind => [ \$Param{ArticleID} ],
+    );
+
     # delete storage directory
     $Self->_ArticleDeleteDirectory(
         ArticleID => $Param{ArticleID},
@@ -144,8 +173,7 @@ sub ArticleDeleteAttachment {
         Bind => [ \$Param{ArticleID} ],
     );
 
-    # return if only delete in my backend...
-    # it is for moving attachments form one backend to the other one
+    # return of only delete in my backend
     return 1 if $Param{OnlyMyBackend};
 
     # delete from fs
