@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Ticket/ArticleStorageFS.pm - article storage module for OTRS kernel
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: ArticleStorageFS.pm,v 1.63 2009/08/13 07:56:40 martin Exp $
+# $Id: ArticleStorageFS.pm,v 1.79 2012/03/20 20:43:59 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,15 +13,18 @@ package Kernel::System::Ticket::ArticleStorageFS;
 
 use strict;
 use warnings;
+
 use File::Path;
 use File::Basename;
 use MIME::Base64;
 
+use Kernel::System::VariableCheck qw(:all);
+
 # to get it writable for the otrs group (just in case)
 umask 002;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.63 $) [1];
+$VERSION = qw($Revision: 1.79 $) [1];
 
 sub ArticleStorageInit {
     my ( $Self, %Param ) = @_;
@@ -39,14 +42,12 @@ sub ArticleStorageInit {
     # check fs write permissions!
     my $Path = "$Self->{ArticleDataDir}/$Self->{ArticleContentPath}/check_permissions.$$";
     if ( -d $Path ) {
-        File::Path::rmtree( [$Path] ) || die "Can't remove $Path: $!\n";
+        File::Path::rmtree( [$Path] );
     }
     if ( mkdir( "$Self->{ArticleDataDir}/check_permissions_$$", 022 ) ) {
-        if ( !rmdir("$Self->{ArticleDataDir}/check_permissions_$$") ) {
-            die "Can't remove $Self->{ArticleDataDir}/check_permissions_$$: $!\n";
-        }
+        rmdir("$Self->{ArticleDataDir}/check_permissions_$$");
         if ( File::Path::mkpath( [$Path], 0, 0775 ) ) {
-            File::Path::rmtree( [$Path] ) || die "Can't remove $Path: $!\n";
+            File::Path::rmtree( [$Path] );
         }
     }
     else {
@@ -54,10 +55,10 @@ sub ArticleStorageInit {
         $Self->{LogObject}->Log(
             Priority => 'notice',
             Message  => "Can't create $Self->{ArticleDataDir}/check_permissions_$$: $Error, "
-                . "Try: \$OTRS_HOME/bin/SetPermissions.pl !",
+                . "Try: \$OTRS_HOME/bin/otrs.SetPermissions.pl !",
         );
         die "Error: Can't create $Self->{ArticleDataDir}/check_permissions_$$: $Error \n\n "
-            . "Try: \$OTRS_HOME/bin/SetPermissions.pl !!!\n";
+            . "Try: \$OTRS_HOME/bin/otrs.SetPermissions.pl !!!\n";
     }
     return 1;
 }
@@ -73,6 +74,27 @@ sub ArticleDelete {
         }
     }
 
+    my $DynamicFieldListArticle = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        ObjectType => 'Article',
+        Valid      => 0,
+    );
+
+    # delete dynamicfield values for this article
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{$DynamicFieldListArticle} ) {
+
+        next DYNAMICFIELD if !$DynamicFieldConfig;
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+        next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+        next DYNAMICFIELD if !IsHashRefWithData( $DynamicFieldConfig->{Config} );
+
+        $Self->{DynamicFieldBackendObject}->ValueDelete(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            ObjectID           => $Param{ArticleID},
+            UserID             => $Param{UserID},
+        );
+    }
+
     # delete index
     $Self->ArticleIndexDelete(
         ArticleID => $Param{ArticleID},
@@ -103,6 +125,12 @@ sub ArticleDelete {
         Bind => [ \$Param{ArticleID} ],
     );
 
+    # delete article history entries
+    return if !$Self->{DBObject}->Do(
+        SQL  => 'DELETE FROM ticket_history WHERE article_id = ?',
+        Bind => [ \$Param{ArticleID} ],
+    );
+
     # delete storage directory
     $Self->_ArticleDeleteDirectory(
         ArticleID => $Param{ArticleID},
@@ -118,32 +146,6 @@ sub ArticleDelete {
     return 1;
 }
 
-sub _ArticleDeleteDirectory {
-    my ( $Self, %Param ) = @_;
-
-    # check needed stuff
-    for (qw(ArticleID UserID)) {
-        if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
-            return;
-        }
-    }
-
-    # delete directory from fs
-    my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
-    my $Path = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}";
-    if ( -d $Path ) {
-        if ( !rmdir($Path) ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Can't remove: $Path: $!!",
-            );
-            return;
-        }
-    }
-    return 1;
-}
-
 sub ArticleDeletePlain {
     my ( $Self, %Param ) = @_;
 
@@ -159,7 +161,7 @@ sub ArticleDeletePlain {
     my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
     my $File = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/plain.txt";
     if ( -f $File ) {
-        if ( !unlink($File) ) {
+        if ( !unlink $File ) {
             $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "Can't remove: $File: $!!",
@@ -168,7 +170,7 @@ sub ArticleDeletePlain {
         }
     }
 
-    # return of only delete in my backend
+    # return if only delete in my backend
     return 1 if $Param{OnlyMyBackend};
 
     # delete plain from db
@@ -195,7 +197,11 @@ sub ArticleDeleteAttachment {
     my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
     my $Path = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}";
     if ( -e $Path ) {
-        my @List = glob( $Path . "/*" );
+        my @List = $Self->{MainObject}->DirectoryRead(
+            Directory => $Path,
+            Filter    => "*",
+        );
+
         for my $File (@List) {
             if ( $File !~ /(\/|\\)plain.txt$/ ) {
                 if ( !unlink "$File" ) {
@@ -208,7 +214,7 @@ sub ArticleDeleteAttachment {
         }
     }
 
-    # return of only delete in my backend
+    # return if only delete in my backend
     return 1 if $Param{OnlyMyBackend};
 
     # delete attachments from db
@@ -285,21 +291,27 @@ sub ArticleWriteAttachment {
     # strip dots from filenames
     $Param{Filename} =~ s/^\.//g;
     my $NewFileName = $Param{Filename};
-    my %UsedFile    = ();
-    my %Index       = $Self->ArticleAttachmentIndex( ArticleID => $Param{ArticleID}, );
-    for ( keys %Index ) {
-        $UsedFile{ $Index{$_}->{Filename} } = 1;
-    }
-    for ( my $i = 1; $i <= 50; $i++ ) {
-        if ( exists $UsedFile{$NewFileName} ) {
-            if ( $Param{Filename} =~ /^(.*)\.(.+?)$/ ) {
-                $NewFileName = "$1-$i.$2";
-            }
-            else {
-                $NewFileName = "$Param{Filename}-$i";
+    my %UsedFile;
+    my %Index = $Self->ArticleAttachmentIndex(
+        ArticleID => $Param{ArticleID},
+        UserID    => $Param{UserID},
+    );
+    if ( !$Param{Force} ) {
+        for ( keys %Index ) {
+            $UsedFile{ $Index{$_}->{Filename} } = 1;
+        }
+        for ( my $i = 1; $i <= 50; $i++ ) {
+            if ( exists $UsedFile{$NewFileName} ) {
+                if ( $Param{Filename} =~ /^(.*)\.(.+?)$/ ) {
+                    $NewFileName = "$1-$i.$2";
+                }
+                else {
+                    $NewFileName = "$Param{Filename}-$i";
+                }
             }
         }
     }
+
     $Param{Filename} = $NewFileName;
 
     # write attachment to backend
@@ -392,7 +404,7 @@ sub ArticlePlain {
         return ${$Data};
     }
 
-    # return of only delete in my backend
+    # return if only delete in my backend
     return if $Param{OnlyMyBackend};
 
     # can't open article, try database
@@ -415,7 +427,7 @@ sub ArticlePlain {
     return $Data;
 }
 
-sub ArticleAttachmentIndex {
+sub ArticleAttachmentIndexRaw {
     my ( $Self, %Param ) = @_;
 
     # check ArticleContentPath
@@ -430,12 +442,17 @@ sub ArticleAttachmentIndex {
         return;
     }
     my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
-    my %Index       = ();
-    my $Counter     = 0;
+    my %Index;
+    my $Counter = 0;
 
     # try fs
-    my @List = glob("$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/*");
-    for my $Filename (@List) {
+    my @List = $Self->{MainObject}->DirectoryRead(
+        Directory => "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}",
+        Filter    => "*",
+        Silent    => 1,
+    );
+
+    for my $Filename ( sort @List ) {
         my $FileSize    = -s $Filename;
         my $FileSizeRaw = $FileSize;
 
@@ -445,17 +462,8 @@ sub ArticleAttachmentIndex {
         next if $Filename =~ /\.content_type$/;
         next if $Filename =~ /\/plain.txt$/;
 
-        # convert the file name in utf-8 if utf-8 is used
-        $Filename = $Self->{EncodeObject}->Decode(
-            Text => $Filename,
-            From => 'utf-8',
-        );
-
         # human readable file size
         if ($FileSize) {
-
-            # remove meta data in files
-            $FileSize = $FileSize - 30 if ( $FileSize > 30 );
             if ( $FileSize > ( 1024 * 1024 ) ) {
                 $FileSize = sprintf "%.1f MBytes", ( $FileSize / ( 1024 * 1024 ) );
             }
@@ -529,13 +537,13 @@ sub ArticleAttachmentIndex {
     # return if index exists
     return %Index if %Index;
 
-    # return of only delete in my backend
+    # return if only delete in my backend
     return %Index if $Param{OnlyMyBackend};
 
     # try database (if there is no index in fs)
     return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT filename, content_type, content_size, content_id, content_alternative'
-            . ' FROM article_attachment WHERE article_id = ? ORDER BY id',
+            . ' FROM article_attachment WHERE article_id = ? ORDER BY filename, id',
         Bind => [ \$Param{ArticleID} ],
     );
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
@@ -572,7 +580,7 @@ sub ArticleAttachment {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
-    for (qw(ArticleID FileID)) {
+    for (qw(ArticleID FileID UserID)) {
         if ( !$Param{$_} ) {
             $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
@@ -584,13 +592,22 @@ sub ArticleAttachment {
     $Param{ArticleID} =~ s/\0//g;
 
     # get attachment index
-    my %Index = $Self->ArticleAttachmentIndex( ArticleID => $Param{ArticleID} );
+    my %Index = $Self->ArticleAttachmentIndex(
+        ArticleID => $Param{ArticleID},
+        UserID    => $Param{UserID},
+    );
 
     # get content path
     my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
     my %Data        = %{ $Index{ $Param{FileID} } };
     my $Counter     = 0;
-    my @List        = glob("$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/*");
+
+    my @List = $Self->{MainObject}->DirectoryRead(
+        Directory => "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}",
+        Filter    => "*",
+        Silent    => 1,
+    );
+
     if (@List) {
         for my $Filename (@List) {
             next if $Filename =~ /\.content_alternative$/;
@@ -602,11 +619,6 @@ sub ArticleAttachment {
             $Counter++;
             if ( $Counter == $Param{FileID} ) {
 
-                # convert the file name in utf-8 if utf-8 is used
-                $Filename = $Self->{EncodeObject}->Decode(
-                    Text => $Filename,
-                    From => 'utf-8',
-                );
                 if ( -e "$Filename.content_type" ) {
 
                     # read content type
@@ -667,7 +679,7 @@ sub ArticleAttachment {
                     && $Data{ContentType} =~ /(utf\-8|utf8)/i
                     )
                 {
-                    $Self->{EncodeObject}->Encode( \$Data{Content} );
+                    $Self->{EncodeObject}->EncodeInput( \$Data{Content} );
                 }
                 chomp $Data{ContentType};
                 return %Data;
@@ -675,13 +687,13 @@ sub ArticleAttachment {
         }
     }
 
-    # return of only delete in my backend
+    # return if only delete in my backend
     return if $Param{OnlyMyBackend};
 
     # try database, if no content is found
     return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT content_type, content, content_id, content_alternative'
-            . ' FROM article_attachment WHERE article_id = ? ORDER BY id',
+            . ' FROM article_attachment WHERE article_id = ? ORDER BY filename, id',
         Bind   => [ \$Param{ArticleID} ],
         Limit  => $Param{FileID},
         Encode => [ 1, 0, 0, 0 ],
@@ -710,4 +722,30 @@ sub ArticleAttachment {
     return %Data;
 }
 
+sub _ArticleDeleteDirectory {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    for (qw(ArticleID UserID)) {
+        if ( !$Param{$_} ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            return;
+        }
+    }
+
+    # delete directory from fs
+    my $ContentPath = $Self->ArticleGetContentPath( ArticleID => $Param{ArticleID} );
+    my $Path = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}";
+    if ( -d $Path ) {
+        if ( !rmdir($Path) ) {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Can't remove: $Path: $!!",
+            );
+            return;
+        }
+    }
+    return 1;
+}
+
 1;
