@@ -2,7 +2,7 @@
 # Kernel/System/UnitTest.pm - the global test wrapper
 # Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: UnitTest.pm,v 1.45.2.7 2011/03/09 17:01:33 mh Exp $
+# $Id: UnitTest.pm,v 1.60 2011/10/10 14:06:19 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.45.2.7 $) [1];
+$VERSION = qw($Revision: 1.60 $) [1];
 
 =head1 NAME
 
@@ -200,10 +200,12 @@ sub Run {
     $ResultSummary{OS}      = $^O;
 
     if ( -e '/etc/SuSE-release' ) {
+
         my $ConfigFile = $Self->{MainObject}->FileRead(
             Location => '/etc/SuSE-release',
             Result   => 'ARRAY',
         );
+
         if ( $ConfigFile && $ConfigFile->[0] ) {
             $ResultSummary{Vendor} = $ConfigFile->[0];
         }
@@ -212,10 +214,12 @@ sub Run {
         }
     }
     elsif ( -e '/etc/fedora-release' ) {
+
         my $ConfigFile = $Self->{MainObject}->FileRead(
             Location => '/etc/fedora-release',
             Result   => 'ARRAY',
         );
+
         if ( $ConfigFile && $ConfigFile->[0] ) {
             $ResultSummary{Vendor} = $ConfigFile->[0];
         }
@@ -224,10 +228,12 @@ sub Run {
         }
     }
     elsif ( -e '/etc/redhat-release' ) {
+
         my $ConfigFile = $Self->{MainObject}->FileRead(
             Location => '/etc/redhat-release',
             Result   => 'ARRAY',
         );
+
         if ( $ConfigFile && $ConfigFile->[0] ) {
             $ResultSummary{Vendor} = $ConfigFile->[0];
         }
@@ -236,26 +242,35 @@ sub Run {
         }
     }
     elsif ( -e '/etc/lsb-release' ) {
+
         my $ConfigFile = $Self->{MainObject}->FileRead(
             Location => '/etc/lsb-release',
             Result   => 'ARRAY',
         );
+
         if ( $ConfigFile && $ConfigFile->[0] ) {
             $ConfigFile->[0] =~ s/DISTRIB_ID=//;
             $ResultSummary{Vendor} = $ConfigFile->[0];
-            $ConfigFile->[1] =~ s/DISTRIB_RELEASE=//;
-            chomp( $ResultSummary{Vendor} );
-            $ResultSummary{Vendor} .= ' ' . $ConfigFile->[1];
+            if ( $ConfigFile->[1] ) {
+                $ConfigFile->[1] =~ s/DISTRIB_RELEASE=//;
+                chomp $ResultSummary{Vendor};
+                $ResultSummary{Vendor} .= ' ' . $ConfigFile->[1];
+            }
+            else {
+                $ResultSummary{Vendor} .= ' (unknown release)';
+            }
         }
         else {
             $ResultSummary{Vendor} = 'Ubuntu unknown';
         }
     }
     elsif ( -e '/etc/debian_version' ) {
+
         my $ConfigFile = $Self->{MainObject}->FileRead(
             Location => '/etc/debian_version',
             Result   => 'ARRAY',
         );
+
         if ( $ConfigFile && $ConfigFile->[0] ) {
             $ResultSummary{Vendor} = 'Debian ' . $ConfigFile->[0];
         }
@@ -264,10 +279,12 @@ sub Run {
         }
     }
     elsif ( -e '/etc/gentoo-release' ) {
+
         my $ConfigFile = $Self->{MainObject}->FileRead(
             Location => '/etc/gentoo-release',
             Result   => 'ARRAY',
         );
+
         if ( $ConfigFile && $ConfigFile->[0] ) {
             $ResultSummary{Vendor} = $ConfigFile->[0];
         }
@@ -276,14 +293,37 @@ sub Run {
         }
     }
     elsif ( $^O eq 'freebsd' ) {
+
         my $Release = `uname -r`;
         $ResultSummary{Vendor} = 'FreeBSD ' . $Release;
     }
+    elsif ( $^O eq 'MSWin32' ) {
+
+        $ResultSummary{Vendor} = 'MS Windows unknown';
+
+        my @Release = `systeminfo`;
+
+        for my $Row (@Release) {
+
+            my ($Name) = $Row =~ m{ \A OS \s Name: \s+ (.+?) \s* \z }xms;
+
+            if ($Name) {
+                $Name =~ s{Microsoft}{MS}xmsg;
+                $ResultSummary{Vendor} = $Name;
+            }
+
+            my ($Version) = $Row =~ m{ \A OS \s Version: \s+ (.+?) \s* \z }xms;
+
+            if ($Version) {
+                $ResultSummary{Vendor} .= ' ' . $Version;
+            }
+        }
+    }
     else {
         $ResultSummary{Vendor} = 'unknown';
     }
 
-    chomp( $ResultSummary{Vendor} );
+    chomp $ResultSummary{Vendor};
     $ResultSummary{Database}  = $Self->{DBObject}->{'DB::Type'};
     $ResultSummary{TestOk}    = $Self->{TestCountOk};
     $ResultSummary{TestNotOk} = $Self->{TestCountNotOk};
@@ -509,9 +549,9 @@ Where $ParamA and $ParamB must be references to a structure (scalar, list or has
 Returns 1 if the data structures are the same, or undef otherwise.
 
     my $IsDeeplyResult = $UnitTestObject->IsDeeply(
-     \%ResultHash,           # test data
-     \%ExpectedHash,         # expected value
-     'Dummy Test Name',
+        \%ResultHash,           # test data
+        \%ExpectedHash,         # expected value
+        'Dummy Test Name',
     );
 
 =cut
@@ -708,8 +748,12 @@ sub _DataDiff {
         # compare %A with %B and remove it if checked
         for my $Key ( keys %A ) {
 
-            # do nothing, it's ok
-            next if !defined $A{$Key} && !defined $B{$Key};
+            # Check if both are undefined
+            if ( !defined $A{$Key} && !defined $B{$Key} ) {
+                delete $A{$Key};
+                delete $B{$Key};
+                next;
+            }
 
             # return diff, because its different
             return 1 if !defined $A{$Key} || !defined $B{$Key};
@@ -880,6 +924,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.45.2.7 $ $Date: 2011/03/09 17:01:33 $
+$Revision: 1.60 $ $Date: 2011/10/10 14:06:19 $
 
 =cut
