@@ -1,8 +1,8 @@
 # --
 # Kernel/System/User.pm - some user functions
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: User.pm,v 1.116 2011/07/01 07:31:04 mg Exp $
+# $Id: User.pm,v 1.121 2012/03/26 21:59:24 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,14 +15,13 @@ use strict;
 use warnings;
 
 use Crypt::PasswdMD5 qw(unix_md5_crypt);
-use Digest::SHA::PurePerl qw(sha1_hex sha256_hex);
 
+use Kernel::System::CacheInternal;
 use Kernel::System::CheckItem;
 use Kernel::System::Valid;
-use Kernel::System::CacheInternal;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.116 $) [1];
+$VERSION = qw($Revision: 1.121 $) [1];
 
 =head1 NAME
 
@@ -112,6 +111,12 @@ sub new {
         TTL  => 60 * 60 * 3,
     );
 
+    # set lower if database is case sensitive
+    $Self->{Lower} = '';
+    if ( !$Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+        $Self->{Lower} = 'LOWER';
+    }
+
     # load generator preferences module
     my $GeneratorModule = $Self->{ConfigObject}->Get('User::PreferencesModule')
         || 'Kernel::System::User::Preferences::DB';
@@ -190,16 +195,23 @@ sub GetUserData {
     my $SQL = "SELECT $Self->{UserTableUserID}, $Self->{UserTableUser}, "
         . " title, first_name, last_name, $Self->{UserTableUserPW}, valid_id, "
         . " create_time, change_time FROM $Self->{UserTable} WHERE ";
+
     if ( $Param{User} ) {
         my $User = lc $Param{User};
-        $SQL .= " LOWER($Self->{UserTableUser}) = ?";
+        $SQL .= " $Self->{Lower}($Self->{UserTableUser}) = ?";
         push @Bind, \$User;
     }
     else {
         $SQL .= " $Self->{UserTableUserID} = ?";
         push @Bind, \$Param{UserID};
     }
-    return if !$Self->{DBObject}->Prepare( SQL => $SQL, Bind => \@Bind );
+
+    return if !$Self->{DBObject}->Prepare(
+        SQL   => $SQL,
+        Bind  => \@Bind,
+        Limit => 1,
+    );
+
     my %Data;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{UserID}        = $Row[0];
@@ -233,12 +245,15 @@ sub GetUserData {
 
     # check valid, return if there is locked for valid users
     if ( $Param{Valid} ) {
+
         my $Hit = 0;
+
         for ( $Self->{ValidObject}->ValidIDsGet() ) {
             if ( $_ eq $Data{ValidID} ) {
                 $Hit = 1;
             }
         }
+
         if ( !$Hit ) {
 
             # set cache
@@ -284,7 +299,8 @@ sub GetUserData {
 
     # add preferences defaults
     my $Config = $Self->{ConfigObject}->Get('PreferencesGroups');
-    if ($Config) {
+    if ( $Config && ref $Config eq 'HASH' ) {
+
         for my $Key ( keys %{$Config} ) {
 
             # next if no default data exists
@@ -301,7 +317,6 @@ sub GetUserData {
     # set cache
     $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%Data );
 
-    # return data
     return %Data;
 }
 
@@ -370,9 +385,12 @@ sub UserAdd {
     my $UserLogin = lc $Param{UserLogin};
     return if !$Self->{DBObject}->Prepare(
         SQL => "SELECT $Self->{UserTableUserID} FROM $Self->{UserTable} "
-            . " WHERE LOWER($Self->{UserTableUser}) = ?",
-        Bind => [ \$UserLogin ],
+            . " WHERE $Self->{Lower}($Self->{UserTableUser}) = ?",
+        Bind  => [ \$UserLogin ],
+        Limit => 1,
     );
+
+    # fetch the result
     my $UserID;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $UserID = $Row[0];
@@ -561,10 +579,12 @@ sub UserSearch {
         ) . ' ';
     }
     elsif ( $Param{PostMasterSearch} ) {
+
         my %UserID = $Self->SearchPreferences(
             Key   => 'UserEmail',
             Value => $Param{PostMasterSearch},
         );
+
         for ( sort keys %UserID ) {
             my %User = $Self->GetUserData(
                 UserID => $_,
@@ -574,11 +594,12 @@ sub UserSearch {
                 return %UserID;
             }
         }
+
         return;
     }
     elsif ( $Param{UserLogin} ) {
         $Param{UserLogin} =~ s/\*/%/g;
-        $SQL .= " LOWER($Self->{UserTableUser}) LIKE LOWER('"
+        $SQL .= " $Self->{Lower}($Self->{UserTableUser}) LIKE $Self->{Lower}('"
             . $Self->{DBObject}->Quote( $Param{UserLogin}, 'Like' ) . "') $LikeEscapeString";
     }
 
@@ -592,6 +613,8 @@ sub UserSearch {
         SQL => $SQL,
         Limit => $Self->{UserSearchListLimit} || $Param{Limit},
     );
+
+    # fetch the result
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         for ( 1 .. 8 ) {
             if ( $Row[$_] ) {
@@ -600,6 +623,7 @@ sub UserSearch {
         }
         $Users{ $Row[0] } =~ s/^(.*)\s(.+?\@.+?\..+?)(\s|)$/"$1" <$2>/;
     }
+
     return %Users;
 }
 
@@ -616,7 +640,6 @@ to set users passwords
 
 sub SetPassword {
     my ( $Self, %Param ) = @_;
-    my $Pw = $Param{PW} || '';
 
     # check needed stuff
     if ( !$Param{UserLogin} ) {
@@ -630,10 +653,12 @@ sub SetPassword {
         $Self->{LogObject}->Log( Priority => 'error', Message => 'No such User!' );
         return;
     }
+
+    my $Pw = $Param{PW} || '';
     my $CryptedPw = '';
 
     # get crypt type
-    my $CryptType = $Self->{ConfigObject}->Get('AuthModule::DB::CryptType') || '';
+    my $CryptType = $Self->{ConfigObject}->Get('AuthModule::DB::CryptType') || 'sha256';
 
     # crypt plain (no crypt at all)
     if ( $CryptType eq 'plain' ) {
@@ -663,21 +688,40 @@ sub SetPassword {
     # crypt with sha1
     elsif ( $CryptType eq 'sha1' ) {
 
+        my $SHAObject;
+        if ( $Self->{MainObject}->Require('Digest::SHA') ) {
+            $SHAObject = Digest::SHA->new('sha1');
+        }
+        else {
+            $Self->{MainObject}->Require('Digest::SHA::PurePerl');
+            $SHAObject = Digest::SHA::PurePerl->new('sha1');
+        }
+
         # encode output, needed by sha1_hex() only non utf8 signs
         $Self->{EncodeObject}->EncodeOutput( \$Pw );
 
-        $CryptedPw = sha1_hex($Pw);
+        $SHAObject->add($Pw);
+        $CryptedPw = $SHAObject->hexdigest();
     }
 
-    # crypt with sha2
-    # if $CryptType is set to anything else icluding sha2
+    # crypt with sha256
+    # if $CryptType is set to anything else including sha2
     else {
 
+        my $SHAObject;
+        if ( $Self->{MainObject}->Require('Digest::SHA') ) {
+            $SHAObject = Digest::SHA->new('sha256');
+        }
+        else {
+            $Self->{MainObject}->Require('Digest::SHA::PurePerl');
+            $SHAObject = Digest::SHA::PurePerl->new('sha256');
+        }
+
         # encode output, needed by sha256_hex() only non utf8 signs
         $Self->{EncodeObject}->EncodeOutput( \$Pw );
 
-        $CryptedPw = sha256_hex($Pw);
-
+        $SHAObject->add($Pw);
+        $CryptedPw = $SHAObject->hexdigest();
     }
 
     # md5 sum of pw, needed for password history
@@ -690,7 +734,7 @@ sub SetPassword {
     my $UserLogin = lc $Param{UserLogin};
     return if !$Self->{DBObject}->Do(
         SQL => "UPDATE $Self->{UserTable} SET $Self->{UserTableUserPW} = ? "
-            . " WHERE LOWER($Self->{UserTableUser}) = ?",
+            . " WHERE $Self->{Lower}($Self->{UserTableUser}) = ?",
         Bind => [ \$CryptedPw, \$UserLogin ],
     );
 
@@ -699,6 +743,7 @@ sub SetPassword {
         Priority => 'notice',
         Message  => "User: '$Param{UserLogin}' changed password successfully!",
     );
+
     return 1;
 }
 
@@ -724,6 +769,7 @@ sub UserLookup {
         $Self->{LogObject}->Log( Priority => 'error', Message => 'Need UserLogin or UserID!' );
         return;
     }
+
     if ( $Param{UserLogin} ) {
 
         # check cache
@@ -733,15 +779,20 @@ sub UserLookup {
 
         # build sql query
         my $UserLogin = lc $Param{UserLogin};
+
         return if !$Self->{DBObject}->Prepare(
             SQL => "SELECT $Self->{UserTableUserID} FROM $Self->{UserTable} "
-                . " WHERE LOWER($Self->{UserTableUser}) = ?",
-            Bind => [ \$UserLogin ],
+                . " WHERE $Self->{Lower}($Self->{UserTableUser}) = ?",
+            Bind  => [ \$UserLogin ],
+            Limit => 1,
         );
+
+        # fetch the result
         my $ID;
         while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
             $ID = $Row[0];
         }
+
         if ( !$ID ) {
             $Self->{LogObject}->Log(
                 Priority => 'error',
@@ -755,6 +806,7 @@ sub UserLookup {
 
         return $ID;
     }
+
     else {
 
         # check cache
@@ -766,12 +818,16 @@ sub UserLookup {
         return if !$Self->{DBObject}->Prepare(
             SQL => "SELECT $Self->{UserTableUser} FROM $Self->{UserTable} "
                 . " WHERE $Self->{UserTableUserID} = ?",
-            Bind => [ \$Param{UserID} ],
+            Bind  => [ \$Param{UserID} ],
+            Limit => 1,
         );
+
+        # fetch the result
         my $Login;
         while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
             $Login = $Row[0];
         }
+
         if ( !$Login ) {
             $Self->{LogObject}->Log(
                 Priority => 'error',
@@ -807,6 +863,7 @@ sub UserName {
     my ( $Self, %Param ) = @_;
 
     my %User = $Self->GetUserData(%Param);
+
     return if !%User;
     return "$User{UserFirstname} $User{UserLastname}";
 }
@@ -847,6 +904,7 @@ sub UserList {
             . " last_name, first_name, "
             . " $Self->{ConfigObject}->{DatabaseUserTableUser}";
     }
+
     my %Users = $Self->{DBObject}->GetTableData(
         What  => $Param{What},
         Table => $Self->{ConfigObject}->{DatabaseUserTable},
@@ -1037,7 +1095,6 @@ sub TokenGenerate {
         UserID => $Param{UserID},
     );
 
-    # Return the Token.
     return $Token;
 }
 
@@ -1100,6 +1157,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.116 $ $Date: 2011/07/01 07:31:04 $
+$Revision: 1.121 $ $Date: 2012/03/26 21:59:24 $
 
 =cut
