@@ -1,8 +1,8 @@
 # --
 # Kernel/System/User/Preferences/DB.pm - some user functions
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.18 2009/02/16 11:45:13 tr Exp $
+# $Id: DB.pm,v 1.23 2012/03/26 21:47:00 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.18 $) [1];
+$VERSION = qw($Revision: 1.23 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -25,7 +25,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(DBObject ConfigObject LogObject)) {
+    for (qw(DBObject ConfigObject LogObject EncodeObject MainObject CacheInternalObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
 
@@ -39,6 +39,13 @@ sub new {
     $Self->{PreferencesTableUserID} = $Self->{ConfigObject}->Get('PreferencesTableUserID')
         || 'user_id';
 
+    # create cache prefix
+    $Self->{CachePrefix} = 'UserPreferencesDB'
+        . $Self->{PreferencesTable}
+        . $Self->{PreferencesTableKey}
+        . $Self->{PreferencesTableValue}
+        . $Self->{PreferencesTableUserID};
+
     return $Self;
 }
 
@@ -53,6 +60,8 @@ sub SetPreferences {
         }
     }
 
+    my $Value = defined $Param{Value} ? $Param{Value} : '';
+
     # delete old data
     return if !$Self->{DBObject}->Do(
         SQL => "DELETE FROM $Self->{PreferencesTable} WHERE "
@@ -61,12 +70,19 @@ sub SetPreferences {
     );
 
     # insert new data
-    return $Self->{DBObject}->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => "INSERT INTO $Self->{PreferencesTable} ($Self->{PreferencesTableUserID}, "
             . " $Self->{PreferencesTableKey}, $Self->{PreferencesTableValue}) "
             . " VALUES (?, ?, ?)",
-        Bind => [ \$Param{UserID}, \$Param{Key}, \$Param{Value} ],
+        Bind => [ \$Param{UserID}, \$Param{Key}, \$Value ],
     );
+
+    # delete cache
+    $Self->{CacheInternalObject}->Delete(
+        Key => $Self->{CachePrefix} . $Param{UserID},
+    );
+
+    return 1;
 }
 
 sub GetPreferences {
@@ -80,44 +96,62 @@ sub GetPreferences {
         }
     }
 
+    # read cache
+    my $Cache = $Self->{CacheInternalObject}->Get(
+        Key => $Self->{CachePrefix} . $Param{UserID},
+    );
+    return %{$Cache} if $Cache;
+
     # get preferences
     return if !$Self->{DBObject}->Prepare(
         SQL => "SELECT $Self->{PreferencesTableKey}, $Self->{PreferencesTableValue} "
             . " FROM $Self->{PreferencesTable} WHERE $Self->{PreferencesTableUserID} = ?",
         Bind => [ \$Param{UserID} ],
     );
+
+    # fetch the result
     my %Data;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
 
-    # return data
+    # set cache
+    $Self->{CacheInternalObject}->Set(
+        Key   => $Self->{CachePrefix} . $Param{UserID},
+        Value => \%Data,
+    );
+
     return %Data;
 }
 
 sub SearchPreferences {
     my ( $Self, %Param ) = @_;
 
-    my %UserID = ();
-    my $Key    = $Param{Key} || '';
-    my $Value  = $Param{Value} || '';
+    my $Key   = $Param{Key}   || '';
+    my $Value = $Param{Value} || '';
+
+    my $Lower = '';
+    if ( !$Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+        $Lower = 'LOWER';
+    }
 
     # get preferences
-    my $SQL = "SELECT $Self->{PreferencesTableUserID}, $Self->{PreferencesTableValue} "
-        . " FROM "
-        . " $Self->{PreferencesTable} "
-        . " WHERE "
-        . " $Self->{PreferencesTableKey} = '"
-        . $Self->{DBObject}->Quote($Key) . "'" . " AND "
-        . " LOWER($Self->{PreferencesTableValue}) LIKE LOWER('"
-        . $Self->{DBObject}->Quote( $Value, 'Like' ) . "')";
+    return if !$Self->{DBObject}->Prepare(
+        SQL => "SELECT $Self->{PreferencesTableUserID}, $Self->{PreferencesTableValue} "
+            . " FROM "
+            . " $Self->{PreferencesTable} "
+            . " WHERE "
+            . " $Self->{PreferencesTableKey} = ? AND "
+            . " $Lower($Self->{PreferencesTableValue}) LIKE $Lower(?)",
+        Bind => [ \$Key, \$Value ],
+    );
 
-    $Self->{DBObject}->Prepare( SQL => $SQL );
+    # fetch the result
+    my %UserID;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $UserID{ $Row[0] } = $Row[1];
     }
 
-    # return data
     return %UserID;
 }
 
