@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Web/InterfacePublic.pm - the public interface file
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: InterfacePublic.pm,v 1.32 2010/12/03 15:24:56 ub Exp $
+# $Id: InterfacePublic.pm,v 1.33 2011/02/08 15:57:38 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @INC);
-$VERSION = qw($Revision: 1.32 $) [1];
+$VERSION = qw($Revision: 1.33 $) [1];
 
 # all framework needed  modules
 use Kernel::Config;
@@ -49,7 +49,10 @@ create public web interface object
     use Kernel::System::Web::InterfacePublic;
 
     my $Debug = 0;
-    my $Interface = Kernel::System::Web::InterfacePublic->new(Debug => $Debug);
+    my $Interface = Kernel::System::Web::InterfacePublic->new(
+        Debug      => $Debug,
+        WebRequest => CGI::Fast->new(), # optional, e. g. if fast cgi is used, the CGI object is already provided
+    );
 
 =cut
 
@@ -290,6 +293,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.32 $ $Date: 2010/12/03 15:24:56 $
+$Revision: 1.33 $ $Date: 2011/02/08 15:57:38 $
 
 =cut
