@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Web/UploadCache.pm - a fs upload cache
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: UploadCache.pm,v 1.23 2011/02/14 10:29:59 martin Exp $
+# $Id: UploadCache.pm,v 1.24 2012/03/27 18:34:39 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.23 $) [1];
+$VERSION = qw($Revision: 1.24 $) [1];
 
 =head1 NAME
 
@@ -140,7 +140,7 @@ ContentID is optional (automatically generated if not given on disposition = inl
         FormID      => 12345,
         Filename    => 'somefile.html',
         Content     => $FileInString,
-        CententID   => 'some_id@example.com',
+        ContentID   => 'some_id@example.com',
         ContentType => 'text/html',
         Disposition => 'inline', # optional
     );
@@ -240,6 +240,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.23 $ $Date: 2011/02/14 10:29:59 $
+$Revision: 1.24 $ $Date: 2012/03/27 18:34:39 $
 
 =cut
