@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # bin/cgi-bin/index.pl - the global CGI handle file (incl. auth) for OTRS
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: index.pl,v 1.88 2009/02/16 12:26:57 tr Exp $
+# $Id: index.pl,v 1.90 2011/03/08 14:11:25 mb Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -28,12 +28,10 @@ use warnings;
 use FindBin qw($Bin);
 use lib "$Bin/../..";
 use lib "$Bin/../../Kernel/cpan-lib";
+use lib "$Bin/../../Custom";
 
-use vars qw($VERSION @INC);
-$VERSION = qw($Revision: 1.88 $) [1];
-
-# check @INC for mod_perl (add lib path for "require module"!)
-push( @INC, "$Bin/../..", "$Bin/../../Kernel/cpan-lib" );
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.90 $) [1];
 
 # 0=off;1=on;
 my $Debug = 0;
