@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # bin/otrs.GenerateStats.pl - send stats output via email
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: otrs.GenerateStats.pl,v 1.3 2010/08/06 17:49:20 cr Exp $
+# $Id: otrs.GenerateStats.pl,v 1.8 2011/08/12 09:06:15 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -30,9 +30,9 @@ use FindBin qw($RealBin);
 use lib dirname($RealBin);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.3 $) [1];
+$VERSION = qw($Revision: 1.8 $) [1];
 
-use Getopt::Std;
+use Getopt::Long;
 use Kernel::Config;
 use Kernel::System::Encode;
 use Kernel::System::Time;
@@ -69,13 +69,28 @@ $CommonObject{EmailObject}     = Kernel::System::Email->new(%CommonObject);
 $CommonObject{PDFObject}       = Kernel::System::PDF->new(%CommonObject);
 
 # get options
+Getopt::Long::Configure('no_ignore_case');
 my %Opts = ();
-getopt( 'nrsmoplfS', \%Opts );
-if ( $Opts{h} ) {
+GetOptions(
+    'number|n=n'     => \$Opts{n},
+    'param|p=s'      => \$Opts{p},
+    'outputdir|o=s'  => \$Opts{o},
+    'recipient|r=s@' => \$Opts{r},
+    'sender|s=s'     => \$Opts{s},
+    'message|m=s'    => \$Opts{m},
+    'language|l=s'   => \$Opts{l},
+    'format|f=s'     => \$Opts{f},
+    'separator|S=s'  => \$Opts{S},
+    'reportname|R'   => \$Opts{R},
+    'filename|F=s'   => \$Opts{F},
+    'help|h'         => \$Opts{h},
+);
+
+if ( $Opts{h} || !$Opts{n} ) {
     print "otrs.GenerateStats.pl <Revision $VERSION> - OTRS cmd stats\n";
-    print "Copyright (C) 2001-2010 OTRS AG, http://otrs.org/\n";
+    print "Copyright (C) 2001-2011 OTRS AG, http://otrs.org/\n";
     print
-        "usage: otrs.GenerateStats.pl -n <StatNumber> [-p <PARAM_STRING>] [-o <DIRECTORY>] [-r <RECIPIENT> -s <SENDER>] [-m <MESSAGE>] [-l <LANGUAGE>] [-f CSV|Print] [-S <SEPARATOR>]\n";
+        "usage: otrs.GenerateStats.pl -n <StatNumber> [-p <PARAM_STRING>] [-o <DIRECTORY>] [-r <RECIPIENT> -r ... -s <SENDER>] [-m <MESSAGE>] [-l <LANGUAGE>] [-f CSV|Print] [-S <SEPARATOR>] [-F <FILENAME> [-R]\n";
     print
         "       <PARAM_STRING> e. g. 'Year=1977&Month=10' (only for static files)\n";
     print "       <DIRECTORY> /output/dir/\n";
@@ -139,15 +154,6 @@ if ( $Opts{c} ) {
     $Separator = $Opts{S};
 }
 
-# recipient check
-if ( $Opts{r} ) {
-    if ( !$CommonObject{CheckItemObject}->CheckEmail( Address => $Opts{r} ) ) {
-        print STDERR "ERROR: "
-            . $CommonObject{CheckItemObject}->CheckError() . "\n";
-        exit 1;
-    }
-}
-
 # sender, if given
 if ( !$Opts{s} ) {
     $Opts{s} = '';
@@ -321,7 +327,7 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
     while ($Loop) {
 
         # if first page
-        if ( $Counter eq 1 ) {
+        if ( $Counter == 1 ) {
             $CommonObject{PDFObject}->PageNew(
                 %PageParam, FooterRight => $Page . ' ' . $Counter,
             );
@@ -351,11 +357,16 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
     # return the document
     my $PDFString = $CommonObject{PDFObject}->DocumentOutput();
 
-    # save the pdf with the title and timestamp as filename
-    my $Filename =
-        $CommonObject{StatsObject}->StringAndTimestamp2Filename(
-        String => $Stat->{Title} . " Created",
+    # save the csv with the title and timestamp as filename, or read it from param
+    my $Filename;
+    if ( $Opts{F} ) {
+        $Filename = $Opts{F};
+    }
+    else {
+        $Filename = $CommonObject{StatsObject}->StringAndTimestamp2Filename(
+            String => $Stat->{Title} . " Created",
         );
+    }
     %Attachment = (
         Filename    => $Filename . ".pdf",
         ContentType => "application/pdf",
@@ -366,19 +377,30 @@ if ( $Format eq 'Print' && $CommonObject{PDFObject} ) {
 }
 else {
 
-    # Create the CVS data
-    my $Output = "Name: $Title; Created: $Time\n";
+    # Create the CSV data
+    my $Output;
+    warn "creating data";
+
+    # Only add the name if parameter is set
+    if ( $Opts{R} ) {
+        $Output .= "Name: $Title; Created: $Time\n";
+    }
     $Output .= $CommonObject{CSVObject}->Array2CSV(
         Head      => $HeadArrayRef,
         Data      => \@StatArray,
         Separator => $Separator,
     );
 
-    # save the csv with the title and timestamp as filename
-    my $Filename =
-        $CommonObject{StatsObject}->StringAndTimestamp2Filename(
-        String => $Stat->{Title} . " Created",
+    # save the csv with the title and timestamp as filename, or read it from param
+    my $Filename;
+    if ( $Opts{F} ) {
+        $Filename = $Opts{F};
+    }
+    else {
+        $Filename = $CommonObject{StatsObject}->StringAndTimestamp2Filename(
+            String => $Stat->{Title} . " Created",
         );
+    }
 
     %Attachment = (
         Filename    => $Filename . ".csv",
@@ -404,18 +426,26 @@ if ( $Opts{o} ) {
 }
 
 # send email
-elsif (
+
+RECIPIENT:
+for my $Recipient ( @{ $Opts{r} } ) {
+
+    # recipient check
+    if ( !$CommonObject{CheckItemObject}->CheckEmail( Address => $Recipient ) ) {
+        print STDERR "Warning: email address $Recipient invalid, skipping address."
+            . $CommonObject{CheckItemObject}->CheckError() . "\n";
+        next RECIPIENT;
+    }
     $CommonObject{EmailObject}->Send(
         From       => $Opts{s},
-        To         => $Opts{r},
+        To         => $Recipient,
         Subject    => "[Stats - $CountStatArray Records] $Title; Created: $Time",
         Body       => $CommonObject{LanguageObject}->Get( $Opts{m} ),
-        Charset    => $CommonObject{ConfigObject}->{DefaultCharset},
+        Charset    => 'utf-8',
         Attachment => [ {%Attachment}, ],
-    )
-    )
-{
-    print "NOTICE: Email sent to '$Opts{r}'.\n";
+    );
+    print "NOTICE: Email sent to '$Recipient'.\n";
+
 }
 exit(0);
 
