@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # scripts/apache-perl-startup.pl - to load the modules if mod_perl is used
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: apache2-perl-startup.pl,v 1.47 2010/09/03 07:10:35 martin Exp $
+# $Id: apache2-perl-startup.pl,v 1.53 2011/12/12 17:12:23 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -32,6 +32,7 @@ $ENV{MOD_PERL} =~ /mod_perl/ or die "MOD_PERL not used!";
 BEGIN {
     $ModPerl::Util::DEFAULT_UNLOAD_METHOD = 'unload_package_xs';
 }
+
 use ModPerl::Util;
 
 # set otrs lib path!
@@ -47,9 +48,7 @@ use CGI ();
 CGI->compile(':cgi');
 use CGI::Carp ();
 
-#use Apache::DBI ();
-#Apache::DBI->connect_on_init('DBI:mysql:otrs', 'otrs', 'some-pass');
-use DBI ();
+use Apache::DBI;
 
 # enable this if you use mysql
 #use DBD::mysql ();
@@ -188,9 +187,8 @@ use Kernel::Modules::AdminRoleGroup;
 use Kernel::Modules::CustomerPreferences;
 use Kernel::Modules::CustomerTicketAttachment;
 use Kernel::Modules::CustomerTicketMessage;
-use Kernel::Modules::CustomerTicketOverView;
+use Kernel::Modules::CustomerTicketOverview;
 use Kernel::Modules::CustomerTicketZoom;
-use Kernel::Modules::CustomerZoom;
 
 # frontend modules
 use Kernel::Output::HTML::Layout;
@@ -201,7 +199,6 @@ use Kernel::Output::HTML::PreferencesPassword;
 use Kernel::Output::HTML::PreferencesTheme;
 use Kernel::Output::HTML::NavBarModuleAdmin;
 use Kernel::Output::HTML::NotificationUIDCheck;
-use Kernel::Output::HTML::NotificationCharsetCheck;
 use Kernel::Output::HTML::NotificationAgentOnline;
 use Kernel::Output::HTML::NotificationCustomerOnline;
 use Kernel::Output::HTML::TicketMenuGeneric;
