@@ -1,9 +1,9 @@
 #!/bin/sh
 # --
 # auto_build.sh - build automatically OTRS tar, rpm and src-rpm
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: auto_build.sh,v 1.87.2.3 2011/07/01 05:21:46 martin Exp $
+# $Id: auto_build.sh,v 1.108 2012/02/09 12:33:29 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -21,35 +21,35 @@
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
-echo "auto_build.sh - build automatically OTRS tar, rpm and src-rpm <\$Revision: 1.87.2.3 $>"
-echo "Copyright (C) 2001-2011 OTRS AG, http://otrs.org/\n";
+echo "auto_build.sh - build automatically OTRS tar, rpm and src-rpm <\$Revision: 1.108 $>"
+echo "Copyright (C) 2001-2012 OTRS AG, http://otrs.org/\n";
 
 PATH_TO_CVS_SRC=$1
 PRODUCT=OTRS
 VERSION=$2
 RELEASE=$3
-#RELEASE=01
-#ARCHIVE_DIR="otrs-$VERSION-$RELEASE"
 ARCHIVE_DIR="otrs-$VERSION"
-#ARCHIVE_DIR="otrs"
 PACKAGE=otrs
 PACKAGE_BUILD_DIR="/tmp/$PACKAGE-build"
 PACKAGE_DEST_DIR="/tmp/$PACKAGE-packages"
 PACKAGE_TMP_SPEC="/tmp/$PACKAGE.spec"
-#RPM_BUILD="rpmbuild"
-RPM_BUILD="rpm"
-SUPPORT_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/Support-1.2.6.opm"
-#IPHONE_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/iPhoneHandle-1.0.2.opm"
-IPHONE_PACKAGE="http://users.otrs.com/~me/iPhoneHandle-1.0.3.opm"
+RPM_BUILD="rpmbuild"
+#RPM_BUILD="rpm"
+
+SUPPORT_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/Support-1.3.3.opm"
+#IPHONE_PACKAGE="http://ftp.otrs.org/pub/otrs/packages/iPhoneHandle-1.0.3.opm"
+MANUAL_EN="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.1/en/pdf/otrs_admin_book.pdf"
+MANUAL_DE="http://ftp.otrs.org/pub/otrs/doc/doc-admin/3.1/de/pdf/otrs_admin_book.pdf"
+
 
 if ! test $PATH_TO_CVS_SRC || ! test $VERSION || ! test $RELEASE; then
     # --
     # build src needed
     # --
     echo ""
-    echo "Usage: auto_build.sh <PATH_TO_CVS_SRC> <VERSION>"
+    echo "Usage: auto_build.sh <PATH_TO_CVS_SRC> <VERSION> <BUILD>"
     echo ""
-    echo "  Try: auto_build.sh /home/ernie/src/otrs 1.0.2"
+    echo "  Try: auto_build.sh /home/ernie/src/otrs 3.1.0.beta1 01"
     echo ""
     exit 1;
 else
@@ -96,16 +96,12 @@ rm -rf $PACKAGE_DEST_DIR
 mkdir $PACKAGE_DEST_DIR
 mkdir $PACKAGE_DEST_DIR/RPMS
 mkdir $PACKAGE_DEST_DIR/RPMS/suse
-mkdir $PACKAGE_DEST_DIR/RPMS/suse/9.0
-mkdir $PACKAGE_DEST_DIR/RPMS/suse/9.1
 mkdir $PACKAGE_DEST_DIR/RPMS/suse/10.0
 mkdir $PACKAGE_DEST_DIR/RPMS/suse/11.0
 mkdir $PACKAGE_DEST_DIR/RPMS/fedora
 mkdir $PACKAGE_DEST_DIR/RPMS/fedora/4
 mkdir $PACKAGE_DEST_DIR/SRPMS
 mkdir $PACKAGE_DEST_DIR/SRPMS/suse
-mkdir $PACKAGE_DEST_DIR/SRPMS/suse/9.0
-mkdir $PACKAGE_DEST_DIR/SRPMS/suse/9.1
 mkdir $PACKAGE_DEST_DIR/SRPMS/suse/10.0
 mkdir $PACKAGE_DEST_DIR/SRPMS/suse/11.0
 mkdir $PACKAGE_DEST_DIR/SRPMS/fedora
@@ -127,7 +123,6 @@ cp -a $PATH_TO_CVS_SRC/* $PACKAGE_BUILD_DIR/$ARCHIVE_DIR/ || exit 1;
 RELEASEFILE=$PACKAGE_BUILD_DIR/$ARCHIVE_DIR/RELEASE
 echo "PRODUCT = $PRODUCT" > $RELEASEFILE
 echo "VERSION = $VERSION" >> $RELEASEFILE
-#echo "VERSION = $VERSION $RELEASE" >> $RELEASEFILE
 echo "BUILDDATE = `date`" >> $RELEASEFILE
 echo "BUILDHOST = `hostname -f`" >> $RELEASEFILE
 
@@ -148,31 +143,46 @@ find -name ".cvsignore" | xargs rm -rf
 rm -f var/sessions/*
 rm -rf var/article/*
 rm -rf var/spool/*
-# remove swap stuff
-find -name ".#*" | xargs rm -rf
 rm -rf Kernel/Config.pm
 
-# build html docu
-#$PATH_TO_CVS_SRC/scripts/auto_docbuild.sh $PATH_TO_CVS_SRC/../doc/ > /dev/null
-mkdir doc/manual
-cp -R /tmp/OTRSDOC-package/* doc/manual/
+# remove development content
+rm -rf development
+
+# remove swap stuff
+find -name ".#*" | xargs rm -rf
+
+# include pdf docs
+mkdir -p doc/manual/en
+wget "$MANUAL_EN" || exit 1;
+mv otrs_admin_book.pdf doc/manual/en
+
+mkdir -p doc/manual/de
+wget "$MANUAL_DE" || exit 1;
+mv otrs_admin_book.pdf doc/manual/de
 
 # mk ARCHIVE
 bin/otrs.CheckSum.pl -a create
 
 # add pre installed packages
 mkdir var/packages/
-wget "$SUPPORT_PACKAGE"
-mv Support*.opm var/packages/
 
-wget "$IPHONE_PACKAGE"
-mv iPhoneHandle*.opm var/packages/
+if test $SUPPORT_PACKAGE; then
+    wget "$SUPPORT_PACKAGE" || exit 1;
+    mv Support*.opm var/packages/
+fi
+
+if test $IPHONE_PACKAGE; then
+    wget "$IPHONE_PACKAGE" || exit 1;
+    mv iPhoneHandle*.opm var/packages/
+fi
 
 # --
 # create tar
 # --
 cd $PACKAGE_BUILD_DIR/ || exit 1;
 SOURCE_LOCATION=$SYSTEM_SOURCE_DIR/$PACKAGE-$VERSION.tar.gz
+rm $SOURCE_LOCATION
+echo "Building tar.gz..."
 tar -czf $SOURCE_LOCATION $ARCHIVE_DIR/ || exit 1;
 cp $SOURCE_LOCATION $PACKAGE_DEST_DIR/
 
@@ -181,6 +191,8 @@ cp $SOURCE_LOCATION $PACKAGE_DEST_DIR/
 # --
 cd $PACKAGE_BUILD_DIR/ || exit 1;
 SOURCE_LOCATION=$SYSTEM_SOURCE_DIR/$PACKAGE-$VERSION.tar.bz2
+rm $SOURCE_LOCATION
+echo "Building tar.bz2..."
 tar -cjf $SOURCE_LOCATION $ARCHIVE_DIR/ || exit 1;
 cp $SOURCE_LOCATION $PACKAGE_DEST_DIR/
 
@@ -189,8 +201,11 @@ cp $SOURCE_LOCATION $PACKAGE_DEST_DIR/
 # --
 cd $PACKAGE_BUILD_DIR/ || exit 1;
 SOURCE_LOCATION=$SYSTEM_SOURCE_DIR/$PACKAGE-$VERSION.zip
-#zip -r $SOURCE_LOCATION $ARCHIVE_DIR/ || exit 1;
-#cp $SOURCE_LOCATION $PACKAGE_DEST_DIR/
+rm $SOURCE_LOCATION
+echo "Building zip..."
+zip -r $SOURCE_LOCATION $ARCHIVE_DIR/ || exit 1;
+cp $SOURCE_LOCATION $PACKAGE_DEST_DIR/
+
 
 # --
 # create rpm spec files
@@ -201,6 +216,7 @@ FILES=$PATH_TO_CVS_SRC/scripts/auto_build/files.txt
 # --
 # build SuSE 11.0 rpm
 # --
+echo "Building SuSE 11.0 rpm..."
 specfile=$PACKAGE_TMP_SPEC
 # replace version and release
 cat $ARCHIVE_DIR/scripts/suse-otrs-11.0.spec | sed "s/^Version:.*/Version:      $VERSION/" | sed "s/^Release:.*/Release:      $RELEASE/" > $specfile.tmp
@@ -217,6 +233,7 @@ mv $SYSTEM_SRPM_DIR/$PACKAGE*$VERSION*$RELEASE*.src.rpm $PACKAGE_DEST_DIR/SRPMS/
 # --
 # build SuSE 10.0 rpm
 # --
+echo "Building SuSE 10.0 rpm..."
 specfile=$PACKAGE_TMP_SPEC
 # replace version and release
 cat $ARCHIVE_DIR/scripts/suse-otrs-10.0.spec | sed "s/^Version:.*/Version:      $VERSION/" | sed "s/^Release:.*/Release:      $RELEASE/" > $specfile.tmp
@@ -229,40 +246,11 @@ rm $specfile || exit 1;
 
 mv $SYSTEM_RPM_DIR/*/$PACKAGE*$VERSION*$RELEASE*.rpm $PACKAGE_DEST_DIR/RPMS/suse/10.0/
 mv $SYSTEM_SRPM_DIR/$PACKAGE*$VERSION*$RELEASE*.src.rpm $PACKAGE_DEST_DIR/SRPMS/suse/10.0/
-# --
-# build SuSE 9.1 rpm
-# --
-specfile=$PACKAGE_TMP_SPEC
-# replace version and release
-cat $ARCHIVE_DIR/scripts/suse-otrs-9.1.spec | sed "s/^Version:.*/Version:      $VERSION/" | sed "s/^Release:.*/Release:      $RELEASE/" > $specfile.tmp
-# replace sourced files
-perl -e "open(SPEC, '< $specfile.tmp');while(<SPEC>){\$spec.=\$_;};open(IN, '< $FILES');while(<IN>){\$i.=\$_;}\$spec=~s/<FILES>/\$i/g;print \$spec;" > $specfile.tmp1
-# replace package description
-perl -e "open(SPEC, '< $specfile.tmp1');while(<SPEC>){\$spec.=\$_;};open(IN, '< $DESCRIPTION');while(<IN>){\$i.=\$_;}\$spec=~s/<DESCRIPTION>/\$i/g;print \$spec;" > $specfile
-$RPM_BUILD -ba --clean $specfile || exit 1;
-rm $specfile || exit 1;
-
-mv $SYSTEM_RPM_DIR/*/$PACKAGE*$VERSION*$RELEASE*.rpm $PACKAGE_DEST_DIR/RPMS/suse/9.1/
-mv $SYSTEM_SRPM_DIR/$PACKAGE*$VERSION*$RELEASE*.src.rpm $PACKAGE_DEST_DIR/SRPMS/suse/9.1/
-# --
-# build SuSE 9.0 rpm
-# --
-specfile=$PACKAGE_TMP_SPEC
-# replace version and release
-cat $ARCHIVE_DIR/scripts/suse-otrs-9.0.spec | sed "s/^Version:.*/Version:      $VERSION/" | sed "s/^Release:.*/Release:      $RELEASE/" > $specfile.tmp
-# replace sourced files
-perl -e "open(SPEC, '< $specfile.tmp');while(<SPEC>){\$spec.=\$_;};open(IN, '< $FILES');while(<IN>){\$i.=\$_;}\$spec=~s/<FILES>/\$i/g;print \$spec;" > $specfile.tmp1
-# replace package description
-perl -e "open(SPEC, '< $specfile.tmp1');while(<SPEC>){\$spec.=\$_;};open(IN, '< $DESCRIPTION');while(<IN>){\$i.=\$_;}\$spec=~s/<DESCRIPTION>/\$i/g;print \$spec;" > $specfile
-$RPM_BUILD -ba --clean $specfile || exit 1;
-rm $specfile || exit 1;
-
-mv $SYSTEM_RPM_DIR/*/$PACKAGE*$VERSION*$RELEASE*.rpm $PACKAGE_DEST_DIR/RPMS/suse/9.0/
-mv $SYSTEM_SRPM_DIR/$PACKAGE*$VERSION*$RELEASE*.src.rpm $PACKAGE_DEST_DIR/SRPMS/suse/9.0/
 
 # --
 # build Fedora rpm
 # --
+echo "Building Fedora rpm..."
 cp $ARCHIVE_DIR/scripts/redhat-rpmmacros ~/.rpmmacros || exit 1
 specfile=$PACKAGE_TMP_SPEC
 cat $ARCHIVE_DIR/scripts/fedora-otrs-4.spec | sed "s/^Version:.*/Version:      $VERSION/" | sed "s/^Release:.*/Release:      $RELEASE/" > $specfile.tmp
@@ -310,9 +298,9 @@ else
 fi
 echo "-----------------------------------------------------------------";
 echo "Note: You may have to tag your cvs tree:     cvs tag rel-2_x_x";
-echo "Note: You may have to braunch your cvs tree: cvs tag -b rel-2_x";
+echo "Note: You may have to branch your cvs tree:  cvs tag -b rel-2_x";
 echo "Note: To delete a tag:                       cvs tag -d rel-2_x_x";
-echo "Note: To check out by an timestamp:          cvs co -r rel-2_x -D \"2008-10-02 17:00\" otrs";
+echo "Note: To check out by timestamp:             cvs co -r rel-2_x -D \"2008-10-02 17:00\" otrs";
 echo "-----------------------------------------------------------------";
 
 # --
