@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # scripts/backup.pl - the backup script
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: backup.pl,v 1.17 2009/04/16 11:20:40 tr Exp $
+# $Id: backup.pl,v 1.25 2011/01/10 15:06:19 martin Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -31,7 +31,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.17 $) [1];
+$VERSION = qw($Revision: 1.25 $) [1];
 
 use Getopt::Std;
 use Kernel::Config;
@@ -43,16 +43,16 @@ use Kernel::System::DB;
 use Date::Pcalc qw(Today Today_and_Now Add_Delta_Days);
 
 # get options
-my %Opts        = ();
+my %Opts;
 my $Compress    = '';
 my $CompressCMD = '';
 my $FullBackup  = 0;
 my $DB          = '';
 my $DBDump      = '';
 getopt( 'hcrtd', \%Opts );
-if ( $Opts{'h'} ) {
+if ( exists $Opts{h} ) {
     print "backup.pl <Revision $VERSION> - backup script\n";
-    print "Copyright (C) 2001-2009 OTRS AG, http://otrs.org/\n";
+    print "Copyright (C) 2001-2011 OTRS AG, http://otrs.org/\n";
     print
         "usage: backup.pl -d /data_backup_dir/ [-c gzip|bzip2] [-r 30] [-t fullbackup|nofullbackup]\n";
     exit 1;
@@ -69,7 +69,7 @@ elsif ( !-d $Opts{d} ) {
 }
 
 # check compress mode
-if ( $Opts{c} && $Opts{c} =~ /bzip2/i ) {
+if ( $Opts{c} && $Opts{c} =~ m/bzip2/i ) {
     $Compress    = 'j';
     $CompressCMD = 'bzip2';
 }
@@ -79,7 +79,7 @@ else {
 }
 
 # check backup type
-if ( $Opts{t} && $Opts{t} =~ /no/i ) {
+if ( $Opts{t} && $Opts{t} =~ m/no/i ) {
     $FullBackup = 0;
 }
 else {
@@ -87,7 +87,7 @@ else {
 }
 
 # create common objects
-my %CommonObject = ();
+my %CommonObject;
 $CommonObject{ConfigObject} = Kernel::Config->new();
 $CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
 $CommonObject{LogObject}    = Kernel::System::Log->new(
@@ -96,6 +96,7 @@ $CommonObject{LogObject}    = Kernel::System::Log->new(
 );
 $CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
 $CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
+$CommonObject{DBObject}   = Kernel::System::DB->new( %CommonObject, AutoConnectNo => 1 );
 my $DatabaseHost = $CommonObject{ConfigObject}->Get('DatabaseHost');
 my $Database     = $CommonObject{ConfigObject}->Get('Database');
 my $DatabaseUser = $CommonObject{ConfigObject}->Get('DatabaseUser');
@@ -104,22 +105,16 @@ my $DatabaseDSN  = $CommonObject{ConfigObject}->Get('DatabaseDSN');
 my $ArticleDir   = $CommonObject{ConfigObject}->Get('ArticleDir');
 
 # decrypt pw (if needed)
-if ( $DatabasePw =~ /^\{(.*)\}$/ ) {
-    my $Length = length($1) * 4;
-    $DatabasePw = pack( "h$Length", $1 );
-    $DatabasePw = unpack( "B$Length", $DatabasePw );
-    $DatabasePw =~ s/1/A/g;
-    $DatabasePw =~ s/0/1/g;
-    $DatabasePw =~ s/A/0/g;
-    $DatabasePw = pack( "B$Length", $DatabasePw );
+if ( $DatabasePw =~ m/^\{(.*)\}$/ ) {
+    $DatabasePw = $CommonObject{DBObject}->_Decrypt($1);
 }
 
 # check db backup support
-if ( $DatabaseDSN =~ /:mysql/i ) {
+if ( $DatabaseDSN =~ m/:mysql/i ) {
     $DB     = 'MySQL';
     $DBDump = 'mysqldump';
 }
-elsif ( $DatabaseDSN =~ /:pg/i ) {
+elsif ( $DatabaseDSN =~ m/:pg/i ) {
     $DB     = 'PostgreSQL';
     $DBDump = 'pg_dump';
 }
@@ -144,7 +139,7 @@ for my $CMD ( 'cp', 'tar', $DBDump, $CompressCMD ) {
 
 # remove old backups
 if ( $Opts{r} ) {
-    my %LeaveBackups = ();
+    my %LeaveBackups;
     my ( $Year, $Month, $Day ) = Today_and_Now();
     for ( 0 .. $Opts{r} ) {
         my ( $DYear, $DMonth, $DDay ) = Add_Delta_Days( $Year, $Month, $Day, -$_ );
@@ -153,11 +148,14 @@ if ( $Opts{r} ) {
         $LeaveBackups{ sprintf( "%04d-%01d-%02d", $DYear, $DMonth, $DDay ) } = 1;
         $LeaveBackups{ sprintf( "%04d-%02d-%02d", $DYear, $DMonth, $DDay ) } = 1;
     }
-    my @Direcroties = glob( $Opts{d} . "/*" );
-    for my $Directory (@Direcroties) {
+    my @Directories = $CommonObject{MainObject}->DirectoryRead(
+        Directory => $Opts{d},
+        Filter    => '*',
+    );
+    for my $Directory (@Directories) {
         my $Leave = 0;
         for my $Data ( keys %LeaveBackups ) {
-            if ( $Directory =~ /$Data/ ) {
+            if ( $Directory =~ m/$Data/ ) {
                 $Leave = 1;
             }
         }
@@ -165,7 +163,10 @@ if ( $Opts{r} ) {
 
             # remove files and directory
             print "deleting old backup in $Directory ... ";
-            my @Files = glob( $Directory . '/*' );
+            my @Files = $CommonObject{MainObject}->DirectoryRead(
+                Directory => $Directory,
+                Filter    => '*',
+            );
             for my $File (@Files) {
                 if ( -e $File ) {
 
@@ -189,7 +190,7 @@ chdir($Home);
 my ( $s, $m, $h, $D, $M, $Y ) = $CommonObject{TimeObject}->SystemTime2Date(
     SystemTime => $CommonObject{TimeObject}->SystemTime(),
 );
-my $Directory = "$Opts{'d'}/$Y-$M-$D" . "_" . "$h-$m";
+my $Directory = "$Opts{d}/$Y-$M-$D" . "_" . "$h-$m";
 if ( !mkdir($Directory) ) {
     print STDERR "ERROR: Can't create directory: $Directory: $!\n";
     exit 1;
@@ -232,9 +233,9 @@ else {
 }
 
 # backup datadir
-if ( $ArticleDir !~ /\Q$Home\E/ ) {
+if ( $ArticleDir !~ m/\Q$Home\E/ ) {
     print "Backup $Directory/DataDir.tar.gz ... ";
-    if ( !system("tar -czf $Directory/DataDir.tar.gz .") ) {
+    if ( !system("tar -czf $Directory/DataDir.tar.gz $ArticleDir") ) {
         print "done\n";
     }
     else {
@@ -243,10 +244,10 @@ if ( $ArticleDir !~ /\Q$Home\E/ ) {
 }
 
 # backup database
-if ( $DB =~ /mysql/i ) {
+if ( $DB =~ m/mysql/i ) {
     print "Dump $DB rdbms ... ";
     if ($DatabasePw) {
-        $DatabasePw = "-p$DatabasePw";
+        $DatabasePw = "-p'$DatabasePw'";
     }
     if (
         !system(
