@@ -1,5 +1,5 @@
 -- ----------------------------------------------------------
---  driver: ingres, generated: 2010-12-21 12:13:37
+--  driver: ingres, generated: 2012-01-26 13:53:53
 -- ----------------------------------------------------------
 -- ----------------------------------------------------------
 --  insert into table valid
@@ -607,7 +607,7 @@ INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, cha
 -- ----------------------------------------------------------
 INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
     VALUES
-    (28, 'TicketFreeTextUpdate', 1, 1, current_timestamp, 1, current_timestamp);\g
+    (28, 'TicketDynamicFieldUpdate', 1, 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table ticket_history_type
 -- ----------------------------------------------------------
@@ -681,6 +681,60 @@ INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, cha
     VALUES
     (40, 'ArchiveFlagUpdate', 1, 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (41, 'EscalationSolutionTimeStop', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (42, 'EscalationResponseTimeStart', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (43, 'EscalationUpdateTimeStart', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (44, 'EscalationSolutionTimeStart', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (45, 'EscalationResponseTimeNotifyBefore', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (46, 'EscalationUpdateTimeNotifyBefore', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (47, 'EscalationSolutionTimeNotifyBefore', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (48, 'EscalationResponseTimeStop', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
+--  insert into table ticket_history_type
+-- ----------------------------------------------------------
+INSERT INTO ticket_history_type (id, name, valid_id, create_by, create_time, change_by, change_time)
+    VALUES
+    (49, 'EscalationUpdateTimeStop', 1, 1, current_timestamp, 1, current_timestamp);\g
+-- ----------------------------------------------------------
 --  insert into table article_type
 -- ----------------------------------------------------------
 INSERT INTO article_type (id, name, valid_id, create_by, create_time, change_by, change_time)
@@ -779,14 +833,14 @@ INSERT INTO article (id, ticket_id, article_type_id, article_sender_type_id, a_f
 
 Thank you for installing OTRS.
 
-You will find updates and patches at http://otrs.org/. Online
-documentation is available at http://doc.otrs.org/. You can also
-use our mailing lists http://lists.otrs.org/ or our forums at
-http://forums.otrs.org/
+You will find updates and patches at http://www.otrs.com/open-source/.
+Online documentation is available at http://doc.otrs.org/.
+You can also use our mailing lists http://lists.otrs.org/
+or our forums at http://forums.otrs.org/
 
 Regards,
 
-The OTRS.org Project
+The OTRS Project
 ', '<007@localhost>', 1280750400, '2010/08/02', 1, 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table article_plain
@@ -801,14 +855,14 @@ Welcome!
 
 Thank you for installing OTRS.
 
-You will find updates and patches at http://otrs.org/. Online
-documentation is available at http://doc.otrs.org/. You can also
-use our mailing lists http://lists.otrs.org/ or our forums at
-http://forums.otrs.org/
+You will find updates and patches at http://www.otrs.com/open-source/.
+Online documentation is available at http://doc.otrs.org/.
+You can also use our mailing lists http://lists.otrs.org/
+or our forums at http://forums.otrs.org/
 
 Regards,
 
-The OTRS.org Project
+The OTRS Project
 ', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table ticket_history
@@ -831,7 +885,7 @@ There is a new ticket in <OTRS_TICKET_Queue>!
 <OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -849,7 +903,7 @@ You''ve got a follow up!
 <OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -867,7 +921,7 @@ The lock timeout period on [<OTRS_TICKET_TicketNumber>] has been reached, it is
 <OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -883,7 +937,7 @@ Comment:
 
 <OTRS_COMMENT>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -899,7 +953,7 @@ Comment:
 
 <OTRS_COMMENT>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -914,7 +968,7 @@ INSERT INTO notifications (notification_type, notification_charset, notification
 Note:
 <OTRS_CUSTOMER_BODY>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -930,7 +984,7 @@ INSERT INTO notifications (notification_type, notification_charset, notification
 <OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -951,7 +1005,7 @@ wrote:
 
 Please have a look at:
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -975,7 +1029,7 @@ wrote:
 
 Please have a look at:
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -999,7 +1053,7 @@ wrote:
 
 Please have a look at:
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Your OTRS Notification Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1017,7 +1071,7 @@ es ist ein neues Ticket in <OTRS_TICKET_Queue>!
 <OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1035,7 +1089,7 @@ Sie haben eine Nachfrage bekommen!
 <OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1053,7 +1107,7 @@ Aufhebung der Sperre auf Dein gesperrtes Ticket [<OTRS_TICKET_TicketNumber>].
 <OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1069,7 +1123,7 @@ Kommentar:
 
 <OTRS_COMMENT>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1085,7 +1139,7 @@ Kommentar:
 
 <OTRS_COMMENT>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1100,7 +1154,7 @@ INSERT INTO notifications (notification_type, notification_charset, notification
 Notiz:
 <OTRS_CUSTOMER_BODY>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1116,7 +1170,7 @@ INSERT INTO notifications (notification_type, notification_charset, notification
 <OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1137,7 +1191,7 @@ schrieb:
 
 Bitte um weitere Bearbeitung:
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1161,7 +1215,7 @@ schrieb:
 
 Bitte um Bearbeitung:
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1185,7 +1239,7 @@ schrieb:
 
 Bitte um Bearbeitung:
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 
 Ihr OTRS Benachrichtigungs-Master', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
@@ -1202,7 +1256,7 @@ Er is een nieuw ticket aangemaakt in <OTRS_TICKET_Queue>!
 <OTRS_CUSTOMER_EMAIL[30]>
 (eerste 30 regels zijn weergegeven)
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
 -- ----------------------------------------------------------
@@ -1217,7 +1271,7 @@ Er is een reactie ontvangen op onderstaand ticket.
 <OTRS_CUSTOMER_EMAIL[30]>
 (eerste 30 regels zijn weergegeven)
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
@@ -1233,7 +1287,7 @@ De bewerkingstijd van ticket [<OTRS_TICKET_TicketNumber>] is overschreden, het t
 <OTRS_CUSTOMER_EMAIL[30]>
 (eerste 30 regels zijn weergegeven)
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
@@ -1248,7 +1302,7 @@ Opmerking:
 
 <OTRS_COMMENT>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
@@ -1263,7 +1317,7 @@ Opmerking:
 
 <OTRS_COMMENT>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
@@ -1277,7 +1331,7 @@ INSERT INTO notifications (notification_type, notification_charset, notification
 Notitie:
 <OTRS_CUSTOMER_BODY>
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
@@ -1291,7 +1345,7 @@ INSERT INTO notifications (notification_type, notification_charset, notification
 <OTRS_CUSTOMER_EMAIL[30]>
 (eerste 30 regels zijn weergegeven)
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
@@ -1307,7 +1361,7 @@ Het herinnermoment voor ticket [<OTRS_TICKET_TicketNumber>] is bereikt.
 <OTRS_CUSTOMER_EMAIL[30]>
 (eerste 30 regels zijn weergegeven)
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
@@ -1316,17 +1370,17 @@ INSERT INTO notifications (notification_type, notification_charset, notification
     VALUES
     ('Agent::Escalation', 'utf-8', 'nl', 'Escalatie (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Beste <OTRS_UserFirstname>,
 
-Het ticket [<OTRS_TICKET_TicketNumber>] is gescaleerd!
+Het ticket [<OTRS_TICKET_TicketNumber>] is geëscaleerd!
 
-Gescaleerd op:    <OTRS_TICKET_EscalationDestinationDate>
-Gescaleerd sinds: <OTRS_TICKET_EscalationDestinationIn>
+Geëscaleerd op:    <OTRS_TICKET_EscalationDestinationDate>
+Geëscaleerd sinds: <OTRS_TICKET_EscalationDestinationIn>
 
 <OTRS_CUSTOMER_FROM> schreef:
 
 <OTRS_CUSTOMER_EMAIL[30]>
 (eerste 30 regels zijn weergegeven)
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
 -- ----------------------------------------------------------
 --  insert into table notifications
@@ -1345,5 +1399,5 @@ Escalatie over: <OTRS_TICKET_EscalationDestinationIn>
 <OTRS_CUSTOMER_EMAIL[30]>
 (eerste 30 regels zijn weergegeven)
 
-<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom;TicketID=<OTRS_TICKET_TicketID>
+<OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentTicketZoom;TicketID=<OTRS_TICKET_TicketID>
 ', 'text/plain', 1, current_timestamp, 1, current_timestamp);\g
