@@ -1,5 +1,5 @@
 -- ----------------------------------------------------------
---  driver: oracle, generated: 2010-08-03 10:09:04
+--  driver: oracle, generated: 2011-12-08 11:40:33
 -- ----------------------------------------------------------
 SET DEFINE OFF;
 -- ----------------------------------------------------------
@@ -596,44 +596,6 @@ CREATE TABLE ticket (
     escalation_update_time NUMBER (12, 0) NOT NULL,
     escalation_response_time NUMBER (12, 0) NOT NULL,
     escalation_solution_time NUMBER (12, 0) NOT NULL,
-    freekey1 VARCHAR2 (80) NULL,
-    freetext1 VARCHAR2 (150) NULL,
-    freekey2 VARCHAR2 (80) NULL,
-    freetext2 VARCHAR2 (150) NULL,
-    freekey3 VARCHAR2 (80) NULL,
-    freetext3 VARCHAR2 (150) NULL,
-    freekey4 VARCHAR2 (80) NULL,
-    freetext4 VARCHAR2 (150) NULL,
-    freekey5 VARCHAR2 (80) NULL,
-    freetext5 VARCHAR2 (150) NULL,
-    freekey6 VARCHAR2 (80) NULL,
-    freetext6 VARCHAR2 (150) NULL,
-    freekey7 VARCHAR2 (80) NULL,
-    freetext7 VARCHAR2 (150) NULL,
-    freekey8 VARCHAR2 (80) NULL,
-    freetext8 VARCHAR2 (150) NULL,
-    freekey9 VARCHAR2 (80) NULL,
-    freetext9 VARCHAR2 (150) NULL,
-    freekey10 VARCHAR2 (80) NULL,
-    freetext10 VARCHAR2 (150) NULL,
-    freekey11 VARCHAR2 (80) NULL,
-    freetext11 VARCHAR2 (150) NULL,
-    freekey12 VARCHAR2 (80) NULL,
-    freetext12 VARCHAR2 (150) NULL,
-    freekey13 VARCHAR2 (80) NULL,
-    freetext13 VARCHAR2 (150) NULL,
-    freekey14 VARCHAR2 (80) NULL,
-    freetext14 VARCHAR2 (150) NULL,
-    freekey15 VARCHAR2 (80) NULL,
-    freetext15 VARCHAR2 (150) NULL,
-    freekey16 VARCHAR2 (80) NULL,
-    freetext16 VARCHAR2 (150) NULL,
-    freetime1 DATE NULL,
-    freetime2 DATE NULL,
-    freetime3 DATE NULL,
-    freetime4 DATE NULL,
-    freetime5 DATE NULL,
-    freetime6 DATE NULL,
     valid_id NUMBER (5, 0) NOT NULL,
     archive_flag NUMBER (5, 0) DEFAULT 0 NOT NULL,
     create_time_unix NUMBER (20, 0) NOT NULL,
@@ -692,7 +654,8 @@ CREATE TABLE ticket_flag (
     ticket_key VARCHAR2 (50) NOT NULL,
     ticket_value VARCHAR2 (50) NULL,
     create_time DATE NOT NULL,
-    create_by NUMBER (12, 0) NOT NULL
+    create_by NUMBER (12, 0) NOT NULL,
+    CONSTRAINT ticket_flag_per_user UNIQUE (ticket_id, ticket_key, create_by)
 );
 CREATE INDEX FK_ticket_flag_create_by ON ticket_flag (create_by);
 CREATE INDEX ticket_flag_ticket_id ON ticket_flag (ticket_id);
@@ -798,10 +761,10 @@ CREATE INDEX ticket_watcher_user_id ON ticket_watcher (user_id);
 CREATE TABLE ticket_index (
     ticket_id NUMBER (20, 0) NOT NULL,
     queue_id NUMBER (12, 0) NOT NULL,
-    queue VARCHAR2 (70) NOT NULL,
+    queue VARCHAR2 (200) NOT NULL,
     group_id NUMBER (12, 0) NOT NULL,
-    s_lock VARCHAR2 (70) NOT NULL,
-    s_state VARCHAR2 (70) NOT NULL,
+    s_lock VARCHAR2 (200) NOT NULL,
+    s_state VARCHAR2 (200) NOT NULL,
     create_time_unix NUMBER (20, 0) NOT NULL
 );
 CREATE INDEX ticket_index_group_id ON ticket_index (group_id);
@@ -921,12 +884,6 @@ CREATE TABLE article (
     a_body CLOB NOT NULL,
     incoming_time NUMBER (12, 0) NOT NULL,
     content_path VARCHAR2 (250) NULL,
-    a_freekey1 VARCHAR2 (250) NULL,
-    a_freetext1 VARCHAR2 (250) NULL,
-    a_freekey2 VARCHAR2 (250) NULL,
-    a_freetext2 VARCHAR2 (250) NULL,
-    a_freekey3 VARCHAR2 (250) NULL,
-    a_freetext3 VARCHAR2 (250) NULL,
     valid_id NUMBER (5, 0) NOT NULL,
     create_time DATE NOT NULL,
     create_by NUMBER (12, 0) NOT NULL,
@@ -969,13 +926,7 @@ CREATE TABLE article_search (
     a_subject VARCHAR2 (3800) NULL,
     a_message_id VARCHAR2 (3800) NULL,
     a_body CLOB NOT NULL,
-    incoming_time NUMBER (12, 0) NOT NULL,
-    a_freekey1 VARCHAR2 (250) NULL,
-    a_freetext1 VARCHAR2 (250) NULL,
-    a_freekey2 VARCHAR2 (250) NULL,
-    a_freetext2 VARCHAR2 (250) NULL,
-    a_freekey3 VARCHAR2 (250) NULL,
-    a_freetext3 VARCHAR2 (250) NULL
+    incoming_time NUMBER (12, 0) NOT NULL
 );
 ALTER TABLE article_search ADD CONSTRAINT PK_article_search PRIMARY KEY (id);
 CREATE INDEX article_search_article_sendec7 ON article_search (article_sender_type_id);
@@ -1500,6 +1451,7 @@ CREATE TABLE mail_account (
     account_type VARCHAR2 (20) NOT NULL,
     queue_id NUMBER (12, 0) NOT NULL,
     trusted NUMBER (5, 0) NOT NULL,
+    imap_folder VARCHAR2 (250) NULL,
     comments VARCHAR2 (250) NULL,
     valid_id NUMBER (5, 0) NOT NULL,
     create_time DATE NOT NULL,
@@ -1564,7 +1516,8 @@ CREATE TABLE process_id (
     process_name VARCHAR2 (200) NOT NULL,
     process_id VARCHAR2 (200) NOT NULL,
     process_host VARCHAR2 (200) NOT NULL,
-    process_create NUMBER (12, 0) NOT NULL
+    process_create NUMBER (12, 0) NOT NULL,
+    process_change NUMBER (12, 0) NOT NULL
 );
 -- ----------------------------------------------------------
 --  create table web_upload_cache
@@ -1870,3 +1823,266 @@ end;
 --;
 CREATE INDEX FK_package_repository_changed7 ON package_repository (change_by);
 CREATE INDEX FK_package_repository_create99 ON package_repository (create_by);
+-- ----------------------------------------------------------
+--  create table gi_webservice_config
+-- ----------------------------------------------------------
+CREATE TABLE gi_webservice_config (
+    id NUMBER (12, 0) NOT NULL,
+    name VARCHAR2 (200) NOT NULL,
+    config CLOB NOT NULL,
+    config_md5 VARCHAR2 (32) NOT NULL,
+    valid_id NUMBER (5, 0) NOT NULL,
+    create_time DATE NOT NULL,
+    create_by NUMBER (12, 0) NOT NULL,
+    change_time DATE NOT NULL,
+    change_by NUMBER (12, 0) NOT NULL,
+    CONSTRAINT gi_webservice_config_config_89 UNIQUE (config_md5),
+    CONSTRAINT gi_webservice_config_name UNIQUE (name)
+);
+ALTER TABLE gi_webservice_config ADD CONSTRAINT PK_gi_webservice_config PRIMARY KEY (id);
+DROP SEQUENCE SE_gi_webservice_config;
+CREATE SEQUENCE SE_gi_webservice_config;
+CREATE OR REPLACE TRIGGER SE_gi_webservice_config_t
+before insert on gi_webservice_config
+for each row
+begin
+  if :new.id IS NULL then
+    select SE_gi_webservice_config.nextval
+    into :new.id
+    from dual;
+  end if;
+end;
+/
+--;
+CREATE INDEX FK_gi_webservice_config_chan16 ON gi_webservice_config (change_by);
+CREATE INDEX FK_gi_webservice_config_crea62 ON gi_webservice_config (create_by);
+CREATE INDEX FK_gi_webservice_config_vali90 ON gi_webservice_config (valid_id);
+-- ----------------------------------------------------------
+--  create table gi_webservice_config_history
+-- ----------------------------------------------------------
+CREATE TABLE gi_webservice_config_history (
+    id NUMBER (20, 0) NOT NULL,
+    config_id NUMBER (12, 0) NOT NULL,
+    config CLOB NOT NULL,
+    config_md5 VARCHAR2 (32) NOT NULL,
+    create_time DATE NOT NULL,
+    create_by NUMBER (12, 0) NOT NULL,
+    change_time DATE NOT NULL,
+    change_by NUMBER (12, 0) NOT NULL,
+    CONSTRAINT gi_webservice_config_history8b UNIQUE (config_md5)
+);
+ALTER TABLE gi_webservice_config_history ADD CONSTRAINT PK_gi_webservice_config_hist06 PRIMARY KEY (id);
+DROP SEQUENCE SE_gi_webservice_config_hi2f;
+CREATE SEQUENCE SE_gi_webservice_config_hi2f;
+CREATE OR REPLACE TRIGGER SE_gi_webservice_config_hi2f_t
+before insert on gi_webservice_config_history
+for each row
+begin
+  if :new.id IS NULL then
+    select SE_gi_webservice_config_hi2f.nextval
+    into :new.id
+    from dual;
+  end if;
+end;
+/
+--;
+CREATE INDEX FK_gi_webservice_config_histe6 ON gi_webservice_config_history (change_by);
+CREATE INDEX FK_gi_webservice_config_histeb ON gi_webservice_config_history (config_id);
+CREATE INDEX FK_gi_webservice_config_hist3d ON gi_webservice_config_history (create_by);
+-- ----------------------------------------------------------
+--  create table scheduler_task_list
+-- ----------------------------------------------------------
+CREATE TABLE scheduler_task_list (
+    id NUMBER (20, 0) NOT NULL,
+    task_data CLOB NOT NULL,
+    task_data_md5 VARCHAR2 (32) NOT NULL,
+    task_type VARCHAR2 (200) NOT NULL,
+    due_time DATE NOT NULL,
+    create_time DATE NOT NULL,
+    CONSTRAINT scheduler_task_list_task_dat81 UNIQUE (task_data_md5)
+);
+ALTER TABLE scheduler_task_list ADD CONSTRAINT PK_scheduler_task_list PRIMARY KEY (id);
+DROP SEQUENCE SE_scheduler_task_list;
+CREATE SEQUENCE SE_scheduler_task_list;
+CREATE OR REPLACE TRIGGER SE_scheduler_task_list_t
+before insert on scheduler_task_list
+for each row
+begin
+  if :new.id IS NULL then
+    select SE_scheduler_task_list.nextval
+    into :new.id
+    from dual;
+  end if;
+end;
+/
+--;
+-- ----------------------------------------------------------
+--  create table gi_debugger_entry
+-- ----------------------------------------------------------
+CREATE TABLE gi_debugger_entry (
+    id NUMBER (20, 0) NOT NULL,
+    communication_id VARCHAR2 (32) NOT NULL,
+    communication_type VARCHAR2 (50) NOT NULL,
+    remote_ip VARCHAR2 (50) NULL,
+    webservice_id NUMBER (12, 0) NOT NULL,
+    create_time DATE NOT NULL,
+    CONSTRAINT gi_debugger_entry_communicat94 UNIQUE (communication_id)
+);
+ALTER TABLE gi_debugger_entry ADD CONSTRAINT PK_gi_debugger_entry PRIMARY KEY (id);
+DROP SEQUENCE SE_gi_debugger_entry;
+CREATE SEQUENCE SE_gi_debugger_entry;
+CREATE OR REPLACE TRIGGER SE_gi_debugger_entry_t
+before insert on gi_debugger_entry
+for each row
+begin
+  if :new.id IS NULL then
+    select SE_gi_debugger_entry.nextval
+    into :new.id
+    from dual;
+  end if;
+end;
+/
+--;
+CREATE INDEX FK_gi_debugger_entry_webserv43 ON gi_debugger_entry (webservice_id);
+CREATE INDEX gi_debugger_entry_create_time ON gi_debugger_entry (create_time);
+-- ----------------------------------------------------------
+--  create table gi_debugger_entry_content
+-- ----------------------------------------------------------
+CREATE TABLE gi_debugger_entry_content (
+    id NUMBER (20, 0) NOT NULL,
+    gi_debugger_entry_id NUMBER (20, 0) NOT NULL,
+    debug_level VARCHAR2 (50) NOT NULL,
+    subject VARCHAR2 (255) NOT NULL,
+    content CLOB NULL,
+    create_time DATE NOT NULL
+);
+ALTER TABLE gi_debugger_entry_content ADD CONSTRAINT PK_gi_debugger_entry_content PRIMARY KEY (id);
+DROP SEQUENCE SE_gi_debugger_entry_content;
+CREATE SEQUENCE SE_gi_debugger_entry_content;
+CREATE OR REPLACE TRIGGER SE_gi_debugger_entry_content_t
+before insert on gi_debugger_entry_content
+for each row
+begin
+  if :new.id IS NULL then
+    select SE_gi_debugger_entry_content.nextval
+    into :new.id
+    from dual;
+  end if;
+end;
+/
+--;
+CREATE INDEX FK_gi_debugger_entry_contentc3 ON gi_debugger_entry_content (gi_debugger_entry_id);
+CREATE INDEX gi_debugger_entry_content_cr4e ON gi_debugger_entry_content (create_time);
+CREATE INDEX gi_debugger_entry_content_dea1 ON gi_debugger_entry_content (debug_level);
+-- ----------------------------------------------------------
+--  create table gi_object_lock_state
+-- ----------------------------------------------------------
+CREATE TABLE gi_object_lock_state (
+    webservice_id NUMBER (12, 0) NOT NULL,
+    object_type VARCHAR2 (30) NOT NULL,
+    object_id NUMBER (20, 0) NOT NULL,
+    lock_state VARCHAR2 (30) NOT NULL,
+    lock_state_counter NUMBER (12, 0) NOT NULL,
+    create_time DATE NOT NULL,
+    change_time DATE NOT NULL,
+    CONSTRAINT gi_object_lock_state_U_638 UNIQUE (webservice_id, object_type, object_id)
+);
+CREATE INDEX FK_gi_object_lock_state_webs55 ON gi_object_lock_state (webservice_id);
+CREATE INDEX object_lock_state_list_state ON gi_object_lock_state (webservice_id, object_type, object_id, lock_state);
+-- ----------------------------------------------------------
+--  create table smime_signer_cert_relations
+-- ----------------------------------------------------------
+CREATE TABLE smime_signer_cert_relations (
+    id NUMBER (12, 0) NOT NULL,
+    cert_hash VARCHAR2 (8) NOT NULL,
+    cert_fingerprint VARCHAR2 (59) NOT NULL,
+    ca_hash VARCHAR2 (8) NOT NULL,
+    ca_fingerprint VARCHAR2 (59) NOT NULL,
+    create_time DATE NOT NULL,
+    create_by NUMBER (12, 0) NOT NULL,
+    change_time DATE NOT NULL,
+    change_by NUMBER (12, 0) NOT NULL
+);
+ALTER TABLE smime_signer_cert_relations ADD CONSTRAINT PK_smime_signer_cert_relations PRIMARY KEY (id);
+DROP SEQUENCE SE_smime_signer_cert_relatef;
+CREATE SEQUENCE SE_smime_signer_cert_relatef;
+CREATE OR REPLACE TRIGGER SE_smime_signer_cert_relatef_t
+before insert on smime_signer_cert_relations
+for each row
+begin
+  if :new.id IS NULL then
+    select SE_smime_signer_cert_relatef.nextval
+    into :new.id
+    from dual;
+  end if;
+end;
+/
+--;
+CREATE INDEX FK_smime_signer_cert_relatiob7 ON smime_signer_cert_relations (change_by);
+CREATE INDEX FK_smime_signer_cert_relatiobb ON smime_signer_cert_relations (create_by);
+-- ----------------------------------------------------------
+--  create table dynamic_field_value
+-- ----------------------------------------------------------
+CREATE TABLE dynamic_field_value (
+    id NUMBER (12, 0) NOT NULL,
+    field_id NUMBER (12, 0) NOT NULL,
+    object_id NUMBER (20, 0) NOT NULL,
+    value_text VARCHAR2 (3800) NULL,
+    value_date DATE NULL,
+    value_int NUMBER (20, 0) NULL
+);
+ALTER TABLE dynamic_field_value ADD CONSTRAINT PK_dynamic_field_value PRIMARY KEY (id);
+DROP SEQUENCE SE_dynamic_field_value;
+CREATE SEQUENCE SE_dynamic_field_value;
+CREATE OR REPLACE TRIGGER SE_dynamic_field_value_t
+before insert on dynamic_field_value
+for each row
+begin
+  if :new.id IS NULL then
+    select SE_dynamic_field_value.nextval
+    into :new.id
+    from dual;
+  end if;
+end;
+/
+--;
+CREATE INDEX FK_dynamic_field_value_field90 ON dynamic_field_value (field_id);
+CREATE INDEX index_field_values ON dynamic_field_value (field_id, object_id);
+CREATE INDEX index_search_date ON dynamic_field_value (field_id, value_date);
+CREATE INDEX index_search_int ON dynamic_field_value (field_id, value_int);
+-- ----------------------------------------------------------
+--  create table dynamic_field
+-- ----------------------------------------------------------
+CREATE TABLE dynamic_field (
+    id NUMBER (12, 0) NOT NULL,
+    name VARCHAR2 (200) NOT NULL,
+    label VARCHAR2 (200) NOT NULL,
+    field_order NUMBER (12, 0) NOT NULL,
+    field_type VARCHAR2 (200) NOT NULL,
+    object_type VARCHAR2 (200) NOT NULL,
+    config CLOB NULL,
+    valid_id NUMBER (5, 0) NOT NULL,
+    create_time DATE NOT NULL,
+    create_by NUMBER (12, 0) NOT NULL,
+    change_time DATE NOT NULL,
+    change_by NUMBER (12, 0) NOT NULL,
+    CONSTRAINT dynamic_field_U_603 UNIQUE (name)
+);
+ALTER TABLE dynamic_field ADD CONSTRAINT PK_dynamic_field PRIMARY KEY (id);
+DROP SEQUENCE SE_dynamic_field;
+CREATE SEQUENCE SE_dynamic_field;
+CREATE OR REPLACE TRIGGER SE_dynamic_field_t
+before insert on dynamic_field
+for each row
+begin
+  if :new.id IS NULL then
+    select SE_dynamic_field.nextval
+    into :new.id
+    from dual;
+  end if;
+end;
+/
+--;
+CREATE INDEX FK_dynamic_field_change_by ON dynamic_field (change_by);
+CREATE INDEX FK_dynamic_field_create_by ON dynamic_field (create_by);
+CREATE INDEX FK_dynamic_field_valid_id ON dynamic_field (valid_id);
