@@ -1,6 +1,7 @@
 -- ----------------------------------------------------------
---  driver: postgresql, generated: 2010-08-03 10:09:05
+--  driver: postgresql, generated: 2011-12-08 11:40:34
 -- ----------------------------------------------------------
+SET standard_conforming_strings TO ON;
 -- ----------------------------------------------------------
 --  create table valid
 -- ----------------------------------------------------------
@@ -347,44 +348,6 @@ CREATE TABLE ticket (
     escalation_update_time INTEGER NOT NULL,
     escalation_response_time INTEGER NOT NULL,
     escalation_solution_time INTEGER NOT NULL,
-    freekey1 VARCHAR (80) NULL,
-    freetext1 VARCHAR (150) NULL,
-    freekey2 VARCHAR (80) NULL,
-    freetext2 VARCHAR (150) NULL,
-    freekey3 VARCHAR (80) NULL,
-    freetext3 VARCHAR (150) NULL,
-    freekey4 VARCHAR (80) NULL,
-    freetext4 VARCHAR (150) NULL,
-    freekey5 VARCHAR (80) NULL,
-    freetext5 VARCHAR (150) NULL,
-    freekey6 VARCHAR (80) NULL,
-    freetext6 VARCHAR (150) NULL,
-    freekey7 VARCHAR (80) NULL,
-    freetext7 VARCHAR (150) NULL,
-    freekey8 VARCHAR (80) NULL,
-    freetext8 VARCHAR (150) NULL,
-    freekey9 VARCHAR (80) NULL,
-    freetext9 VARCHAR (150) NULL,
-    freekey10 VARCHAR (80) NULL,
-    freetext10 VARCHAR (150) NULL,
-    freekey11 VARCHAR (80) NULL,
-    freetext11 VARCHAR (150) NULL,
-    freekey12 VARCHAR (80) NULL,
-    freetext12 VARCHAR (150) NULL,
-    freekey13 VARCHAR (80) NULL,
-    freetext13 VARCHAR (150) NULL,
-    freekey14 VARCHAR (80) NULL,
-    freetext14 VARCHAR (150) NULL,
-    freekey15 VARCHAR (80) NULL,
-    freetext15 VARCHAR (150) NULL,
-    freekey16 VARCHAR (80) NULL,
-    freetext16 VARCHAR (150) NULL,
-    freetime1 timestamp(0) NULL,
-    freetime2 timestamp(0) NULL,
-    freetime3 timestamp(0) NULL,
-    freetime4 timestamp(0) NULL,
-    freetime5 timestamp(0) NULL,
-    freetime6 timestamp(0) NULL,
     valid_id INTEGER NOT NULL,
     archive_flag INTEGER DEFAULT 0 NOT NULL,
     create_time_unix INTEGER NOT NULL,
@@ -424,7 +387,8 @@ CREATE TABLE ticket_flag (
     ticket_key VARCHAR (50) NOT NULL,
     ticket_value VARCHAR (50) NULL,
     create_time timestamp(0) NOT NULL,
-    create_by INTEGER NOT NULL
+    create_by INTEGER NOT NULL,
+    CONSTRAINT ticket_flag_per_user UNIQUE (ticket_id, ticket_key, create_by)
 );
 CREATE INDEX ticket_flag_ticket_id ON ticket_flag (ticket_id);
 CREATE INDEX ticket_flag_ticket_id_create_by ON ticket_flag (ticket_id, create_by);
@@ -492,10 +456,10 @@ CREATE INDEX ticket_watcher_user_id ON ticket_watcher (user_id);
 CREATE TABLE ticket_index (
     ticket_id INTEGER NOT NULL,
     queue_id INTEGER NOT NULL,
-    queue VARCHAR (70) NOT NULL,
+    queue VARCHAR (200) NOT NULL,
     group_id INTEGER NOT NULL,
-    s_lock VARCHAR (70) NOT NULL,
-    s_state VARCHAR (70) NOT NULL,
+    s_lock VARCHAR (200) NOT NULL,
+    s_state VARCHAR (200) NOT NULL,
     create_time_unix INTEGER NOT NULL
 );
 CREATE INDEX ticket_index_group_id ON ticket_index (group_id);
@@ -581,12 +545,6 @@ CREATE TABLE article (
     a_body VARCHAR NOT NULL,
     incoming_time INTEGER NOT NULL,
     content_path VARCHAR (250) NULL,
-    a_freekey1 VARCHAR (250) NULL,
-    a_freetext1 VARCHAR (250) NULL,
-    a_freekey2 VARCHAR (250) NULL,
-    a_freetext2 VARCHAR (250) NULL,
-    a_freekey3 VARCHAR (250) NULL,
-    a_freetext3 VARCHAR (250) NULL,
     valid_id INTEGER NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by INTEGER NOT NULL,
@@ -613,12 +571,6 @@ CREATE TABLE article_search (
     a_message_id VARCHAR (3800) NULL,
     a_body VARCHAR NOT NULL,
     incoming_time INTEGER NOT NULL,
-    a_freekey1 VARCHAR (250) NULL,
-    a_freetext1 VARCHAR (250) NULL,
-    a_freekey2 VARCHAR (250) NULL,
-    a_freetext2 VARCHAR (250) NULL,
-    a_freekey3 VARCHAR (250) NULL,
-    a_freetext3 VARCHAR (250) NULL,
     PRIMARY KEY(id)
 );
 CREATE INDEX article_search_article_sender_type_id ON article_search (article_sender_type_id);
@@ -932,6 +884,7 @@ CREATE TABLE mail_account (
     account_type VARCHAR (20) NOT NULL,
     queue_id INTEGER NOT NULL,
     trusted INTEGER NOT NULL,
+    imap_folder VARCHAR (250) NULL,
     comments VARCHAR (250) NULL,
     valid_id INTEGER NOT NULL,
     create_time timestamp(0) NOT NULL,
@@ -979,7 +932,8 @@ CREATE TABLE process_id (
     process_name VARCHAR (200) NOT NULL,
     process_id VARCHAR (200) NOT NULL,
     process_host VARCHAR (200) NOT NULL,
-    process_create INTEGER NOT NULL
+    process_create INTEGER NOT NULL,
+    process_change INTEGER NOT NULL
 );
 -- ----------------------------------------------------------
 --  create table web_upload_cache
@@ -1155,3 +1109,139 @@ CREATE TABLE package_repository (
     change_by INTEGER NOT NULL,
     PRIMARY KEY(id)
 );
+-- ----------------------------------------------------------
+--  create table gi_webservice_config
+-- ----------------------------------------------------------
+CREATE TABLE gi_webservice_config (
+    id serial NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    config TEXT NOT NULL,
+    config_md5 VARCHAR (32) NOT NULL,
+    valid_id INTEGER NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    CONSTRAINT gi_webservice_config_config_md5 UNIQUE (config_md5),
+    CONSTRAINT gi_webservice_config_name UNIQUE (name)
+);
+-- ----------------------------------------------------------
+--  create table gi_webservice_config_history
+-- ----------------------------------------------------------
+CREATE TABLE gi_webservice_config_history (
+    id serial NOT NULL,
+    config_id INTEGER NOT NULL,
+    config TEXT NOT NULL,
+    config_md5 VARCHAR (32) NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    CONSTRAINT gi_webservice_config_history_config_md5 UNIQUE (config_md5)
+);
+-- ----------------------------------------------------------
+--  create table scheduler_task_list
+-- ----------------------------------------------------------
+CREATE TABLE scheduler_task_list (
+    id serial NOT NULL,
+    task_data VARCHAR (8000) NOT NULL,
+    task_data_md5 VARCHAR (32) NOT NULL,
+    task_type VARCHAR (200) NOT NULL,
+    due_time timestamp(0) NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    PRIMARY KEY(id),
+    CONSTRAINT scheduler_task_list_task_data_md5 UNIQUE (task_data_md5)
+);
+-- ----------------------------------------------------------
+--  create table gi_debugger_entry
+-- ----------------------------------------------------------
+CREATE TABLE gi_debugger_entry (
+    id serial NOT NULL,
+    communication_id VARCHAR (32) NOT NULL,
+    communication_type VARCHAR (50) NOT NULL,
+    remote_ip VARCHAR (50) NULL,
+    webservice_id INTEGER NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    PRIMARY KEY(id),
+    CONSTRAINT gi_debugger_entry_communication_id UNIQUE (communication_id)
+);
+CREATE INDEX gi_debugger_entry_create_time ON gi_debugger_entry (create_time);
+-- ----------------------------------------------------------
+--  create table gi_debugger_entry_content
+-- ----------------------------------------------------------
+CREATE TABLE gi_debugger_entry_content (
+    id serial NOT NULL,
+    gi_debugger_entry_id INTEGER NOT NULL,
+    debug_level VARCHAR (50) NOT NULL,
+    subject VARCHAR (255) NOT NULL,
+    content TEXT NULL,
+    create_time timestamp(0) NOT NULL,
+    PRIMARY KEY(id)
+);
+CREATE INDEX gi_debugger_entry_content_create_time ON gi_debugger_entry_content (create_time);
+CREATE INDEX gi_debugger_entry_content_debug_level ON gi_debugger_entry_content (debug_level);
+-- ----------------------------------------------------------
+--  create table gi_object_lock_state
+-- ----------------------------------------------------------
+CREATE TABLE gi_object_lock_state (
+    webservice_id INTEGER NOT NULL,
+    object_type VARCHAR (30) NOT NULL,
+    object_id INTEGER NOT NULL,
+    lock_state VARCHAR (30) NOT NULL,
+    lock_state_counter INTEGER NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    CONSTRAINT gi_object_lock_state_U_474 UNIQUE (webservice_id, object_type, object_id)
+);
+CREATE INDEX object_lock_state_list_state ON gi_object_lock_state (webservice_id, object_type, object_id, lock_state);
+-- ----------------------------------------------------------
+--  create table smime_signer_cert_relations
+-- ----------------------------------------------------------
+CREATE TABLE smime_signer_cert_relations (
+    id serial NOT NULL,
+    cert_hash VARCHAR (8) NOT NULL,
+    cert_fingerprint VARCHAR (59) NOT NULL,
+    ca_hash VARCHAR (8) NOT NULL,
+    ca_fingerprint VARCHAR (59) NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id)
+);
+-- ----------------------------------------------------------
+--  create table dynamic_field_value
+-- ----------------------------------------------------------
+CREATE TABLE dynamic_field_value (
+    id serial NOT NULL,
+    field_id INTEGER NOT NULL,
+    object_id INTEGER NOT NULL,
+    value_text VARCHAR (3800) NULL,
+    value_date timestamp(0) NULL,
+    value_int INTEGER NULL,
+    PRIMARY KEY(id)
+);
+CREATE INDEX index_field_values ON dynamic_field_value (field_id, object_id);
+CREATE INDEX index_search_date ON dynamic_field_value (field_id, value_date);
+CREATE INDEX index_search_int ON dynamic_field_value (field_id, value_int);
+-- ----------------------------------------------------------
+--  create table dynamic_field
+-- ----------------------------------------------------------
+CREATE TABLE dynamic_field (
+    id serial NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    label VARCHAR (200) NOT NULL,
+    field_order INTEGER NOT NULL,
+    field_type VARCHAR (200) NOT NULL,
+    object_type VARCHAR (200) NOT NULL,
+    config TEXT NULL,
+    valid_id INTEGER NOT NULL,
+    create_time timestamp(0) NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp(0) NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    CONSTRAINT dynamic_field_U_499 UNIQUE (name)
+);
