@@ -1,23 +1,24 @@
 #!/usr/bin/perl -w
 # --
 # xml2html.pl - a "_simple_" xml2html viewer
-# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
 # --
-# $Id: xml2html.pl,v 1.14 2008/06/09 14:52:11 tr Exp $
+# $Id: xml2html.pl,v 1.18 2009/04/23 13:47:27 mh Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU AFFERO General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 # use ../../ as lib location
@@ -29,6 +30,7 @@ use strict;
 use warnings;
 
 use Kernel::Config;
+use Kernel::System::Encode;
 use Kernel::System::Log;
 use Kernel::System::Main;
 use Kernel::System::Time;
@@ -36,21 +38,30 @@ use Kernel::System::DB;
 use Kernel::System::XML;
 
 my $ConfigObject = Kernel::Config->new();
-my $LogObject    = Kernel::System::Log->new( ConfigObject => $ConfigObject, );
-my $MainObject   = Kernel::System::Main->new(
+my $EncodeObject = Kernel::System::Encode->new(
+    ConfigObject => $ConfigObject,
+);
+my $LogObject = Kernel::System::Log->new(
+    ConfigObject => $ConfigObject,
+    EncodeObject => $EncodeObject,
+);
+my $MainObject = Kernel::System::Main->new(
     ConfigObject => $ConfigObject,
     LogObject    => $LogObject,
+    EncodeObject => $EncodeObject,
 );
 my $DBObject = Kernel::System::DB->new(
     MainObject   => $MainObject,
     ConfigObject => $ConfigObject,
     LogObject    => $LogObject,
+    EncodeObject => $EncodeObject,
 );
 my $XMLObject = Kernel::System::XML->new(
     MainObject   => $MainObject,
     ConfigObject => $ConfigObject,
     LogObject    => $LogObject,
     DBObject     => $DBObject,
+    EncodeObject => $EncodeObject,
 );
 
 my $Title       = 'xml2html: ';
@@ -116,7 +127,7 @@ for my $Tag (@XMLARRAY) {
 }
 
 sub Content {
-    my ($C) = @_;
+    my $C = shift;
 
     return "<span style=\"font-size:10pt;font-family:monospace,fixed;margin:"
         . ( ( $Layer * 20 ) + 5 )
