@@ -1,8 +1,8 @@
 // --
 // Core.Agent.TicketZoom.js - provides the special module functions for TicketZoom
-// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
-// $Id: Core.Agent.TicketZoom.js,v 1.34.2.1 2011/03/18 06:35:04 mp Exp $
+// $Id: Core.Agent.TicketZoom.js,v 1.37.2.1 2012/04/26 12:23:08 mn Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -24,6 +24,32 @@ Core.Agent.TicketZoom = (function (TargetNS) {
     var CheckURLHashTimeout,
         InitialArticleID;
 
+    /**
+     * @function
+     * @param {String} TicketID of ticket which get's shown
+     * @return nothing
+     *      Mark all articles as seen in frontend and backend.
+     *      Article Filters will not be considered
+     */
+    TargetNS.MarkTicketAsSeen = function (TicketID) {
+        TargetNS.TicketMarkAsSeenTimeout = window.setTimeout(function () {
+            // Mark old row as readed
+            $('#FixedTable .ArticleID').closest('tr').removeClass('UnreadArticles').find('span.UnreadArticles').remove();
+
+            // Mark article as seen in backend
+            var Data = {
+                Action: 'AgentTicketZoom',
+                Subaction: 'TicketMarkAsSeen',
+                TicketID: TicketID
+            };
+            Core.AJAX.FunctionCall(
+                Core.Config.Get('CGIHandle'),
+                Data,
+                function () {}
+            );
+        }, 3000);
+    };
+
     /**
      * @function
      * @param {String} TicketID of ticket which get's shown
@@ -185,12 +211,18 @@ Core.Agent.TicketZoom = (function (TargetNS) {
     TargetNS.Init = function (Options) {
         var $THead = $('#FixedTable thead'),
             $TBody = $('#FixedTable tbody'),
-            ZoomExpand = !$('div.ArticleView a.OneArticle').hasClass('Active'),
+            ZoomExpand = false,
             URLHash,
             $ArticleElement,
             ResizeTimeoutScroller,
             ResizeTimeoutWindow;
 
+        // Check, if ZoomExpand is active or not
+        // Only active on tickets with less than 400 articles (see bug#8424)
+        if ($('div.ArticleView a.OneArticle').length) {
+            ZoomExpand = !$('div.ArticleView a.OneArticle').hasClass('Active');
+        }
+
         Core.UI.Resizable.Init($('#ArticleTableBody'), Options.ArticleTableHeight, function (Event, UI, Height, Width) {
             // remember new height for next reload
             window.clearTimeout(ResizeTimeoutScroller);
@@ -295,7 +327,7 @@ Core.Agent.TicketZoom = (function (TargetNS) {
         });
 
         // Scroll to active article
-        if (!ZoomExpand) {
+        if ( !ZoomExpand && $('#FixedTable tbody tr.Active').length ) {
             $('div.Scroller').get(0).scrollTop = parseInt($('#FixedTable tbody tr.Active').offset().top, 10) - 30;
         }
     };
