@@ -1,8 +1,8 @@
 // --
 // Core.Form.Validate.js - provides functions for validating form inputs
-// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
-// $Id: Core.Form.Validate.js,v 1.32.2.1 2011/03/18 06:35:04 mp Exp $
+// $Id: Core.Form.Validate.js,v 1.34.2.5 2012/05/30 15:25:14 mn Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -74,9 +74,15 @@ Core.Form.Validate = (function (TargetNS) {
             ErrorType = 'Error';
         }
 
+        // Check if the element has already an error class
+        // (that means, this function call is an additional call)
+        if ($Element.hasClass(Options.ErrorClass)) {
+            return;
+        }
+
         // Add error class to field and its label
         $Element.addClass(Options.ErrorClass);
-        $(Element.form).find("label[for=" + Element.id + "]").addClass(Options.ErrorLabelClass);
+        $(Element.form).find("label[for=" + Core.App.EscapeSelector(Element.id) + "]").addClass(Options.ErrorLabelClass);
 
         // mark field as invalid for screenreader users
         $Element.attr('aria-invalid', true);
@@ -107,6 +113,13 @@ Core.Form.Validate = (function (TargetNS) {
 
         // speak the error message for screen reader users
         Core.UI.Accessibility.AudibleAlert(InputErrorMessageText);
+
+        // if the element, which has an validation error, is a richtext element, than manually trigger the focus event
+        if (Core.UI.RichTextEditor.IsEnabled($Element)) {
+            window.setTimeout(function () {
+                $Element.focus();
+            }, 0);
+        }
     }
 
     /**
@@ -142,7 +155,7 @@ Core.Form.Validate = (function (TargetNS) {
         if (RemoveError) {
             // remove error classes from element and its label
             $Element.removeClass(Options.ErrorClass).removeClass(Options.ServerErrorClass);
-            $(Element.form).find("label[for=" + Element.id + "]").removeClass(Options.ErrorLabelClass);
+            $(Element.form).find("label[for=" + Core.App.EscapeSelector(Element.id) + "]").removeClass(Options.ErrorLabelClass);
 
             // mark field as valid for screenreader users
             $Element.attr('aria-invalid', false);
@@ -233,6 +246,17 @@ Core.Form.Validate = (function (TargetNS) {
     // If email address should be validated, this function is overwritten in Init method
     $.validator.addMethod("Validate_Email", ValidatorMethodRequired, "");
 
+    // Use the maxlength attribute to have a dynamic validation
+    // Textarea fields will need JS code to set the maxlength attribute since is not supported by
+    // XHTML
+    $.validator.addMethod("Validate_MaxLength",function (Value, Element) {
+
+        // JS takes new lines '\n\r' in textarea elements as 1 character '\n' for length
+        // calculation purposes therefore is needed to re-add the '\r' to get the correct length
+        // for validation and match to perl and database criteria
+        return ( Value.replace(/\n\r?/g, "\n\r").length <= $(Element).attr('maxlength') );
+    }, "");
+
     $.validator.addMethod("Validate_DateYear", function (Value, Element) {
         return (parseInt(Value, 10) > 999 && parseInt(Value, 10) < 10000);
     }, "");
@@ -340,6 +364,10 @@ Core.Form.Validate = (function (TargetNS) {
         Validate_Email: true
     });
 
+    $.validator.addClassRules("Validate_MaxLength", {
+        Validate_MaxLength: true
+    });
+
     // Backwards compatibility: these methods are deprecated, do not use them!
     // They will be removed in OTRS 3.1.
     $.validator.addClassRules("Validate_RequiredDropdown", {
