@@ -1,8 +1,8 @@
 // --
 // Core.UI.Dialog.js - Dialogs
-// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 // --
-// $Id: Core.UI.Dialog.js,v 1.31.2.1 2011/03/18 06:35:04 mp Exp $
+// $Id: Core.UI.Dialog.js,v 1.35 2012/02/14 14:24:46 ep Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -25,7 +25,7 @@ Core.UI.Dialog = (function (TargetNS) {
     /*
      * check dependencies first
      */
-    if (!Core.Debug.CheckDependency('Core.UI.Dialog', '$([]).draggable', 'jQuery UI dialog')) {
+    if (!Core.Debug.CheckDependency('Core.UI.Dialog', '$([]).draggable', 'jQuery UI draggable')) {
         return;
     }
     if (!Core.Debug.CheckDependency('Core.UI.Dialog', 'Core.Config', 'Core.Config')) {
@@ -137,10 +137,10 @@ Core.UI.Dialog = (function (TargetNS) {
      *               Headline: string (default: undefined) Defines a special headline within the dialog window
      *               Text: string (default: undefined) The text which is outputtet in the dialog window
      *               HTML: string (default: undefined) Used for content dialog windows. Contains a complete HTML snippet or an jQuery object with containing HTML
-     *               PositionTop: value (default: undefined) Defines the top position of the dilaog window
-     *               PositionBottom: value (default: undefined) Defines the bottom position of the dilaog window
-     *               PositionLeft: value|Center (default: undefined) Defines the left position of the dilaog window. Center centers the window
-     *               PositionRight: value (default: undefined) Defines the right position of the dilaog window
+     *               PositionTop: value (default: undefined) Defines the top position of the dialog window
+     *               PositionBottom: value (default: undefined) Defines the bottom position of the dialog window
+     *               PositionLeft: value|Center (default: undefined) Defines the left position of the dialog window. Center centers the window
+     *               PositionRight: value (default: undefined) Defines the right position of the dialog window
      *               CloseOnClickOutside true|false (default: false) If true, clicking outside the dialog closes the dialog
      *               CloseOnEscape true|false (default: false) If true, pressing escape key closes the dialog
      *               NotDraggableIE7: true|false (default: false) If true, the dialog is not draggable in IE7 (due to performance reasons)
@@ -159,6 +159,12 @@ Core.UI.Dialog = (function (TargetNS) {
         // this invokes the callback and the closing of the dialog
         function HandleClosingAction() {
             var $CloseButton = $('.Dialog:visible button.Close');
+
+            // Hide any possibly existing tooltips.
+            if (Core.Form && Core.Form.ErrorTooltips) {
+                Core.Form.ErrorTooltips.HideTooltip();
+            }
+
             if ($CloseButton.length) {
                 $CloseButton.trigger('click');
             }
@@ -374,7 +380,14 @@ Core.UI.Dialog = (function (TargetNS) {
         if (!(Params.NotDraggableIE7 && $.browser.msie && parseInt($.browser.version, 10) === 7)) {
             $Dialog.draggable({
                 containment: 'body',
-                handle: '.Header'
+                handle: '.Header',
+                start: function(Event, UI) {
+                    // Hide any possibly existing tooltips as they will not be moved
+                    //  with this dialog.
+                    if (Core.Form && Core.Form.ErrorTooltips) {
+                        Core.Form.ErrorTooltips.HideTooltip();
+                    }
+                }
             });
         }
 
