@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -124,7 +124,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @extends CKEDITOR.ui.dialog.uiElement
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>label</strong> (Required) The label string.</li>
@@ -158,10 +158,10 @@ CKEDITOR.plugins.add( 'dialogui' );
 						html.push( '<label class="cke_dialog_ui_labeled_label' + requiredClass + '" ',
 								' id="'+  _.labelId + '"',
 								' for="' + _.inputId + '"',
-								' style="' + elementDefinition.labelStyle + '">',
+								( elementDefinition.labelStyle ? ' style="' + elementDefinition.labelStyle + '"' : '' ) +'>',
 								elementDefinition.label,
 								'</label>',
-								'<div class="cke_dialog_ui_labeled_content" role="presentation">',
+								'<div class="cke_dialog_ui_labeled_content"' + ( elementDefinition.controlStyle ? ' style="' + elementDefinition.controlStyle + '"' : '' ) + ' role="presentation">',
 								contentHtml.call( this, dialog, elementDefinition ),
 								'</div>' );
 					else
@@ -177,13 +177,13 @@ CKEDITOR.plugins.add( 'dialogui' );
 									html : '<label class="cke_dialog_ui_labeled_label' + requiredClass + '"' +
 										' id="' + _.labelId + '"' +
 										' for="' + _.inputId + '"' +
-										' style="' + elementDefinition.labelStyle + '">' +
+										( elementDefinition.labelStyle ? ' style="' + elementDefinition.labelStyle + '"' : '' ) +'>' +
 										   CKEDITOR.tools.htmlEncode( elementDefinition.label ) +
 										'</span>'
 								},
 								{
 									type : 'html',
-									html : '<span class="cke_dialog_ui_labeled_content">' +
+									html : '<span class="cke_dialog_ui_labeled_content"' + ( elementDefinition.controlStyle ? ' style="' + elementDefinition.controlStyle + '"' : '' ) + '>' +
 										contentHtml.call( this, dialog, elementDefinition ) +
 										'</span>'
 								}
@@ -204,7 +204,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @extends CKEDITOR.ui.dialog.labeledElement
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>default</strong> (Optional) The default value.</li>
@@ -224,7 +224,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 
 				initPrivateObject.call( this, elementDefinition );
 				var domId = this._.inputId = CKEDITOR.tools.getNextId() + '_textInput',
-					attributes = { 'class' : 'cke_dialog_ui_input_' + elementDefinition.type, id : domId, type : 'text' },
+					attributes = { 'class' : 'cke_dialog_ui_input_' + elementDefinition.type, id : domId, type : elementDefinition.type },
 					i;
 
 				// Set the validator, if any.
@@ -237,8 +237,8 @@ CKEDITOR.plugins.add( 'dialogui' );
 				if ( elementDefinition.size )
 					attributes.size = elementDefinition.size;
 
-				if ( elementDefinition.controlStyle )
-					attributes.style = elementDefinition.controlStyle;
+				if ( elementDefinition.inputStyle )
+					attributes.style = elementDefinition.inputStyle;
 
 				// If user presses Enter in a text box, it implies clicking OK for the dialog.
 				var me = this, keyPressedOnMe = false;
@@ -293,7 +293,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @example
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>rows</strong> (Optional) The number of rows displayed.
@@ -323,6 +323,10 @@ CKEDITOR.plugins.add( 'dialogui' );
 				attributes.rows = elementDefinition.rows || 5;
 				attributes.cols = elementDefinition.cols || 20;
 
+				if ( typeof elementDefinition.inputStyle != 'undefined' )
+					attributes.style = elementDefinition.inputStyle;
+
+
 				/** @ignore */
 				var innerHTML = function()
 				{
@@ -344,7 +348,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @example
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>checked</strong> (Optional) Whether the checkbox is checked
@@ -380,11 +384,11 @@ CKEDITOR.plugins.add( 'dialogui' );
 					if ( elementDefinition[ 'default' ] )
 						attributes.checked = 'checked';
 
-					if ( typeof myDefinition.controlStyle != 'undefined' )
-						myDefinition.style = myDefinition.controlStyle;
+					if ( typeof myDefinition.inputStyle != 'undefined' )
+						myDefinition.style = myDefinition.inputStyle;
 
 					_.checkbox = new CKEDITOR.ui.dialog.uiElement( dialog, myDefinition, html, 'input', null, attributes );
-					html.push( ' <label id="', labelId, '" for="', attributes.id, '">',
+					html.push( ' <label id="', labelId, '" for="', attributes.id, '"' + ( elementDefinition.labelStyle ? ' style="' + elementDefinition.labelStyle + '"' : '' ) + '>',
 							CKEDITOR.tools.htmlEncode( elementDefinition.label ),
 							'</label>' );
 					return html.join( '' );
@@ -400,7 +404,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @extends CKEDITOR.ui.dialog.labeledElement
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>default</strong> (Required) The default value.</li>
@@ -462,8 +466,8 @@ CKEDITOR.plugins.add( 'dialogui' );
 						cleanInnerDefinition( inputDefinition );
 						cleanInnerDefinition( labelDefinition );
 
-						if ( typeof inputDefinition.controlStyle != 'undefined' )
-							inputDefinition.style = inputDefinition.controlStyle;
+						if ( typeof inputDefinition.inputStyle != 'undefined' )
+							inputDefinition.style = inputDefinition.inputStyle;
 
 						children.push( new CKEDITOR.ui.dialog.uiElement( dialog, inputDefinition, inputHtml, 'input', null, inputAttributes ) );
 						inputHtml.push( ' ' );
@@ -471,7 +475,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 							   item[0] );
 						inputHtmlList.push( inputHtml.join( '' ) );
 					}
-					new CKEDITOR.ui.dialog.hbox( dialog, [], inputHtmlList, html );
+					new CKEDITOR.ui.dialog.hbox( dialog, children, inputHtmlList, html );
 					return html.join( '' );
 				};
 
@@ -486,7 +490,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @extends CKEDITOR.ui.dialog.uiElement
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>label</strong> (Required) The button label.</li>
@@ -569,7 +573,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @constructor
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>default</strong> (Required) The default value.</li>
@@ -618,12 +622,12 @@ CKEDITOR.plugins.add( 'dialogui' );
 					for ( var i = 0, item ; i < elementDefinition.items.length && ( item = elementDefinition.items[i] ) ; i++ )
 					{
 						innerHTML.push( '<option value="',
-							CKEDITOR.tools.htmlEncode( item[1] !== undefined ? item[1] : item[0] ), '" /> ',
+							CKEDITOR.tools.htmlEncode( item[1] !== undefined ? item[1] : item[0] ).replace( /"/g, '&quot;' ), '" /> ',
 							CKEDITOR.tools.htmlEncode( item[0] ) );
 					}
 
-					if ( typeof myDefinition.controlStyle != 'undefined' )
-						myDefinition.style = myDefinition.controlStyle;
+					if ( typeof myDefinition.inputStyle != 'undefined' )
+						myDefinition.style = myDefinition.inputStyle;
 
 					_.select = new CKEDITOR.ui.dialog.uiElement( dialog, myDefinition, html, 'select', null, attributes, innerHTML.join( '' ) );
 					return html.join( '' );
@@ -639,7 +643,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @constructor
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>validate</strong> (Optional) The validation function.</li>
@@ -712,7 +716,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * @constructor
 			 * @param {CKEDITOR.dialog} dialog
 			 * Parent dialog object.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>for</strong> (Required) The file input's page and element Id
@@ -765,7 +769,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 				 * @extends CKEDITOR.ui.dialog.uiElement
 				 * @name CKEDITOR.ui.dialog.html
 				 * @param {CKEDITOR.dialog} dialog Parent dialog object.
-				 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition Element definition.
+				 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition Element definition.
 				 * Accepted fields:
 				 * <ul>
 				 * 	<li><strong>html</strong> (Required) HTML code of this element.</li>
@@ -837,7 +841,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 			 * objects in childObjList.
 			 * @param {Array} htmlList
 			 * Array of HTML code that this element will output to.
-			 * @param {CKEDITOR.dialog.uiElementDefinition} elementDefinition
+			 * @param {CKEDITOR.dialog.definition.uiElement} elementDefinition
 			 * The element definition. Accepted fields:
 			 * <ul>
 			 * 	<li><strong>label</strong> (Optional) The legend of the this fieldset.</li>
@@ -851,7 +855,9 @@ CKEDITOR.plugins.add( 'dialogui' );
 				var innerHTML = function()
 				{
 					var html = [];
-					legendLabel && html.push( '<legend>' + legendLabel + '</legend>' );
+					legendLabel && html.push( '<legend' +
+						( elementDefinition.labelStyle ? ' style="' + elementDefinition.labelStyle + '"' : '' ) +
+						'>' + legendLabel + '</legend>' );
 					for ( var i = 0; i < childHtmlList.length; i++ )
 						html.push( childHtmlList[ i ] );
 					return html.join( '' );
@@ -965,7 +971,13 @@ CKEDITOR.plugins.add( 'dialogui' );
 						/** @ignore */
 						onClick : function( dialog, func )
 						{
-							this.on( 'click', func );
+							this.on( 'click', function()
+								{
+									// Some browsers (Chrome, IE8, IE7 compat mode) don't move
+									// focus to clicked button. Force this.
+									this.getElement().focus();
+									func.apply( this, arguments );
+								});
 						}
 					}, true ),
 
@@ -1466,7 +1478,7 @@ CKEDITOR.plugins.add( 'dialogui' );
 
 				getValue : function()
 				{
-					return this.getInputElement().$.value;
+					return this.getInputElement().$.value || '';
 				},
 
 				/***
@@ -1527,3 +1539,17 @@ CKEDITOR.plugins.add( 'dialogui' );
 	CKEDITOR.dialog.addUIElement( 'html', commonBuilder );
 	CKEDITOR.dialog.addUIElement( 'fieldset', containerBuilder );
 })();
+
+/**
+ * Fired when the value of the uiElement is changed
+ * @name CKEDITOR.ui.dialog.uiElement#change
+ * @event
+ */
+
+/**
+ * Fired when the inner frame created by the element is ready.
+ * Each time the button is used or the dialog is loaded a new
+ * form might be created.
+ * @name CKEDITOR.ui.dialog.fileButton#formLoaded
+ * @event
+ */
